function accumulate, array, j, norm=norm, zero=zero
;
; Accumulate 1D array: result(n) = sum(0...n)array
; Accumulate 2D array: j=1: along 1. axis
;                           result(n,*) = sum(0...n)array(i,*)
; Accumulate 2D array: j=2: along 2. axis
;                           result(*,n) = sum(0...n)array(*,i)
;
; Keywords: norm:   normalize result
;                   in the 2D case normalization will be row by row (j=1)
;                                           or column by column (j=2)
;           zero:   add an element = 0 in beginning
;
sz = size(array)
if sz(0) eq 0 then return, array ; Scalar, no action
if sz(0) gt 2 then begin
   print,'ACCUMULATE error, too high dimensionality'
   return, array ; No action
endif
q = array
if sz(0) eq 1 then begin ; 1D array
   for i = 1, n_elements(array)-1 do q(i) = q(i-1) + array(i)
   if keyword_set(norm) then q = q / max(q)
   if keyword_set(zero) then q = [0,q]
endif
if sz(0) eq 2 then begin ; 2D array
   if j lt 1 or j gt 2 then begin
      print,'ACCUMULATE error, 2D case, bad 2. parameter'
      return, total(array)
   endif
   if j eq 1 then begin ; accumulate along 1. axis
      for i = 1, sz(1)-1 do q(i,*) = q(i-1,*) + array(i,*)
      if keyword_set(norm) then $
         for i = 0, sz(2)-1 do q(*,i) = q(*,i)/max(q(*,i))
      if keyword_set(zero) then begin
         qq = fltarr(sz(1)+1,sz(2))
         qq(1:*,*) = q
         q = qq
      endif
   endif else begin     ; accumulate along 2. axis
      for i = 1, sz(2)-1 do q(*,i) = q(*,i-1) + array(*,i)
      if keyword_set(norm) then $
         for i = 0, sz(1)-1 do q(i,*) = q(i,*)/max(q(i,*))
      if keyword_set(zero) then begin
         qq = fltarr(sz(1),sz(2)+1)
         qq(*,1:*) = q
         q = qq
      endif
   endelse
endif
return, q
end
