pro add_catalog_src_positions, catdol, outfile=outfile
;
;  Add catalog positions to a FITS catalog where the source
;  coordinates (RA and DEC) are in columns RA_OBJ and DEC_OBJ
;
;    2005-10-05/NJW
;    2006-09-20/NJW updated to produce a special FITS file with
;                   the RA_CAT and DEC_CAT columns since
;                   wrnewfitscol does not handle variable length
;                   columns
;
if n_params() lt 1 then begin
   print,'Syntax: add_catalog_src_positions, catdol[,outfile=]'
   return
endif

rdfitscol, catdol, ra_obj, 'ra_obj',/sil,nrows=nrows
rdfitscol, catdol, dec_obj, 'dec_obj',/sil

ra_cat = fltarr(nrows)
dec_cat = fltarr(nrows)
name_cat = strarr(nrows) ; only used if 'outfile' is defined

for i = 0L, nrows-1 do begin
   res = nearest_source(ra_obj(i),dec_obj(i),0.08,clog='/r6/jemx/catalogs/gnrl_refr_cat_latest.fits+1')
   name_cat(i) = res(0)
   ra_cat(i) = float(res(1))
   dec_cat(i) = float(res(2))
endfor

if keyword_set(outfile) then begin
   wrmfitscols, outfile, 'NAME', name_cat, 'RA_CAT', ra_cat, 'DEC_CAT', dec_cat
endif else begin
   wrnewfitscol, catdol, 'RA_CAT', ra_cat, 'DEC_CAT', dec_cat
endelse

end
