pro add_col_swid_ijd, fitsdol
;
;   Add two columns to FITS table with TSTART and TSTOP in IJD
;   when a SWID column exists
;
;   2005-08-02/NJW
;   2006-12-13/NJW Updated to get timetable from /r6/jemx/integral_history
;
if n_params() lt 1 then begin
   print,'Syntax: add_col_swid_ijd, fitsdol'
   return
endif


rdfitscol,fitsdol,swid,'SWID',nrows=nrows

tbegin = dblarr(nrows)
tend = dblarr(nrows)
n_err = 0

doltimetable_prev = 'xx'
for i = 0, nrows-1 do begin
   revol = strmid( swid(i), 0, 4 )
   doltimetable = '/r6/jemx/integral_history/swid_timetable_'+revol+'.fits+1'
   if doltimetable_prev ne doltimetable then begin
      rdfitscol, doltimetable, swidt, 'SWID'
      rdfitscol, doltimetable, tstart, 'TSTART', /sil
      rdfitscol, doltimetable, tstop, 'TSTOP', /sil
      doltimetable_prev = doltimetable
   endif
   
   w = where( swid(i) eq swidt, nw)
   if nw ne 1 then begin
      n_err = n_err + 1
      print,'Error at input SWID: ',swid(i)
      if nw lt 1 then begin
         print,'      not found in timetable: ', timetable
      endif else begin
         print,'      has multiple entries in: ', timetable
      endelse
      if n_err gt 20 then begin
         print,'Terminating because there are more than 20 errors!'
         return
      endif
      continue
   endif
   tbegin(i) = tstart(w(0))
   tend(i) = tstop(w(0))
endfor

wrnewfitscol, fitsdol,'TSTART',tbegin,'TSTOP',tend

end
