function add_images, dol1, dol2, dol3, dol4, dol5, dol6, dol7,$
                     save=save,append=append
;
;  Function to add up to 7 FITS images together
;           or all the files found using wild cards in dol1
;               (assumes all have same extension number)
;           or, if dol1 is an array of strings, add these dols
;           or, if the first character in dol1 is '@' then the remainder
;               is interpreted as a filename
;
;   2004-10-01/NJW updated from rather old version

if keyword_set(save) then lsave = 1 else lsave = 0
nim = n_params()
if nim lt 1 then begin
   print,'Syntax: add_images, dol1[, dol2, ...][,save=][,/append]'
   print,'   Accepts up to 7 dol''s'
   return,-1
endif

sz = size(dol1)

; in the case that 'dol1' is a string array

if sz(0) eq 1 then begin
   list = dol1
   num = sz(1)
endif else begin
   get_exten_no, dol1, filename, extno
   ; dol1 is a string, check for '@' character
   if strmid(filename,0,1) eq '@' then begin
      filename = strmid(filename,1,999)
      list = read_slist(filename,count=num)
   endif else list = file_search(filename,/test_reg,count=num)
end
print,'ADD_IMAGES found ', num,' files : ', list
print
print,'in the first argument'
case num of
   0 : begin
         print,'ADD_IMAGES: file not found'
         return,-1
       end
   1 : begin  ; no wild cards in first filename

; ---  Case where the arguments are the images to be added

         if nim lt 2 then begin
            print,'ADD_IMAGES must be called with at least 2 FITS files to be added'
            retall
         endif
         if nim gt 7 then begin
            print,'ADD_IMAGES does not accept more than 7 FITS files to be added'
            retall
         endif
         get_exten_no, dol1, file1, ext1
         im1 = readfits(file1,ext=ext1,hdr)
         fxaddpar,hdr,'COMMENT','add '+dol1
         im1 = im1 * 1.0
         print,'Starting with '+dol1

         get_exten_no, dol2, file2, ext2
         im2 = readfits(file2, ext=ext2)
         im1 = im1 + im2
         fxaddpar,hdr,'COMMENT','add '+dol2
         print,'adding '+dol2
         if nim gt 2 then begin
            get_exten_no, dol3, file3, ext3
            im2 = readfits(file3,ext=ext3)
            im1 = im1 + im2
            fxaddpar,hdr,'COMMENT','add '+dol3
            print,'adding '+dol3
         endif
         if nim gt 3 then begin
            get_exten_no, dol4, file4, ext4
            im2 = readfits(file4,ext=ext4)
            im1 = im1 + im2
            fxaddpar,hdr,'COMMENT','add '+dol4
            print,'adding '+dol4
         endif
         if nim gt 4 then begin
            get_exten_no, dol5, file5, ext5
            im2 = readfits(file5,ext=ext5)
            im1 = im1 + im2
            fxaddpar,hdr,'COMMENT','add '+dol5
            print,'adding '+dol5
         endif
         if nim gt 5 then begin
            get_exten_no, dol6, file6, ext6
            im2 = readfits(file6,ext=ext6)
            im1 = im1 + im2
            fxaddpar,hdr,'COMMENT','add '+dol6
            print,'adding '+dol6
         endif
         if nim gt 6 then begin
            get_exten_no, dol7, file7, ext7
            im2 = readfits(file7,ext=ext7)
            im1 = im1 + im2
            fxaddpar,hdr,'COMMENT','add '+dol7
            print,'adding '+dol7
         endif
      end
   else : begin

; --- Case of list of dol's from first name

            get_exten_no, list(0), filename, extno
            im1 = readfits(filename, hdr, ext=extno)
            fxaddpar, hdr,'COMMENT','add '+list(0)
            im1 = im1 * 1.0
            print,'Starting with '+list(0)
            for i = 1, num-1 do begin
               get_exten_no, list(i), filename, extno
               im2 = readfits(filename,ext=extno)
               im1 = im1 + im2
               fxaddpar, hdr,'COMMENT','add '+list(i)
               print,'adding  '+list(i)
            endfor
         end
   endcase

if lsave then begin
   if not keyword_set(append) then fits_make_prim,save else begin
      if not file_test(save,/reg) then fits_make_prim,save
   endelse
   writefits,save,im1,hdr,/append
   print,'Result saved in '+save
endif

return, im1

end
