pro add_iros_sx_source_cat, cat_file
;
;   2005-07-29/NJW
;
;   Read catalog produced by mk_jiir_fits_source_cat.pro and
;   estimate the flux as 'sx' (in erg/cm2/s) in the first two
;   energy intervals, 2-10 keV, and 5-15 keV
;
if n_params() lt 1 then begin
   print,'Syntax: add_iros_sx_source_cat, cat_file_name'
   print,'    where cat_file_name is a catalog generated by ''mk_jiir_fits_source_cat'''
   return
endif

rdfitscol,cat_file+'+1',swid,'SWID',nrows=nrows,/sil
rdfitscol,cat_file+'+1',ra_obj,'RA_OBJ',/sil
rdfitscol,cat_file+'+1',dec_obj,'DEC_OBJ',/sil
rdfitscol,cat_file+'+1',jemx_num,'JEMX_NUM',/sil
rdfitscol,cat_file+'+1',ebin_num,'EBIN_NUM',/sil
rdfitscol,cat_file+'+1',e_min,'E_MIN',/sil
rdfitscol,cat_file+'+1',e_max,'E_MAX',/sil
rdfitscol,cat_file+'+1',flux,'FLUX',/sil
rdfitscol,cat_file+'+1',flux_err,'FLUX_ERR',/sil

sx1 = fltarr(nrows)
sx2 = fltarr(nrows)
sx2_10kev = fltarr(nrows)
sx5_15kev = fltarr(nrows)
sx1_err = fltarr(nrows)
sx2_err = fltarr(nrows)
sx2_10kev_err = fltarr(nrows)
sx5_15kev_err = fltarr(nrows)

for i = 0, nrows-1 do begin
   revol = fix(strmid(swid(i),0,4))
   emin_in = e_min(0:1,i)
   emax_in = e_max(0:1,i)
   cflux = flux(0:1,i)
   if( min(cflux) gt 1.e-4 ) then begin
      relative_err = sqrt(total((flux_err(0:1,i)/flux(0:1,i))^2))
   endif else relative_err = 0.99
   sxs = calc_iros_sx( jemx_num(i), revol, cflux, emin_in, emax_in, chatter=0 )
   sx1(i) = sxs(1)
   sx1_err(i) = sxs(1) * relative_err
   sx2(i) = sxs(2)
   sx2_err(i) = sxs(2) * relative_err
   sx2_10kev(i)     = sxs(3)
   sx2_10kev_err(i) = sxs(3) * relative_err
   sx5_15kev(i)     = sxs(4)
   sx5_15kev_err(i) = sxs(4) * relative_err
endfor

wrnewfitscol,cat_file+'+1','SX1',sx1,'SX1_ERR',sx1_err
wrnewfitscol,cat_file+'+1','SX2',sx2,'SX2_ERR',sx2_err
wrnewfitscol,cat_file+'+1','SX2_10KEV',sx2_10kev,'SX2_10KEV_ERR',sx2_10kev_err
wrnewfitscol,cat_file+'+1','SX5_15KEV',sx5_15kev,'SX5_15KEV_ERR',sx5_15kev_err

end
