function add_peak_1d, x, y, xl, sigma, ampl, rel=rel
;
;   Add a Gaussian peak to a 1D array
;
;   2004-09-16/NJW
;   2005-12-08/NJW updated to include keyword 'rel' to add with
;                  relative amplitude
;
if n_params() lt 4 then begin
   print,'Syntax: res = add_peak_1d( x, y, xl, sigma, ampl[, /rel])'
   print,'   Keyword ''rel'' implies that ''ampl'' is defined'
   print,'          relative to ''y'' around ''xl'''
   print,'   Returns the input array with peak added'
   return,-1
endif

if keyword_set(rel) then begin
   return, y * (1 + ampl*exp(-0.5*(((x-xl)/sigma)^2)))
endif else begin
   return, y + ampl*exp(-0.5*(((x-xl)/sigma)^2))
endelse

end
