pro add_pointing_source_cat, catdol, gal=gal
;
;  Add pointing directions to a FITS catalog where a SWID
;  column is present
;
;    2005-10-27/NJW
;
if n_params() lt 1 then begin
   print,'Syntax: add_pointing_source_cat, catdol[, /gal]'
   print,'    Keyword /gal will create two extra columns with'
   print,'    galactic latitude (GALLAT) and longitude (GALLON)'
   return
endif

rdfitscol, catdol, swid, 'SWID',/sil,nrows=nrows

ra_scx = fltarr(nrows)
dec_scx = fltarr(nrows)
roll = fltarr(nrows)

for i = 0L, nrows-1 do begin

   strrevol = strmid( swid(i), 0, 4)
   pointing_file = '/r6/jemx/pointings/pointings_'+strrevol+'p.dat'
   rscolm,pointing_file,pswid, 1,/str,/sil
   rscolm,pointing_file,pra_scx, 2,/sil
   rscolm,pointing_file,pdec_scx, 3,/sil
   rscolm,pointing_file,pposangle, 4,/sil

   w = where( pswid eq swid(i), nw )
   if nw eq 0 then begin
      print,'Error - gave up on '+swid(i)
   endif else begin
      ra_scx(i) = pra_scx(w(0))
      dec_scx(i) = pdec_scx(w(0))
      roll(i) = pposangle(w(0))
   endelse

endfor

wrnewfitscol, catdol, 'RA_SCX', ra_scx, 'DEC_SCX', dec_scx
wrnewfitscol, catdol, 'ROLL', roll

if keyword_set(gal) then begin
   print,'Adding the columns with galactic coordinates'
   euler, ra_scx, dec_scx, lii_scx, bii_scx, 1 ; '1' implies RadecJ2000 -> galactic
   wrnewfitscol, catdol, 'GALLAT', float(bii_scx), 'GALLON', float(lii_scx)
endif

end
