pro add_regions, region_file, text=text, offset=offset, diameter=diameter, charsize=charsize
;
;  Add regions to plot by 'plofitsky'
;
;  2004-05-26/NJW
;
if n_params() lt 1 then begin
   print,'Syntax: add_regions, region_file[,/text][,offset=][,diameter=] $'
   print,'               [,charsize=]'
   return
endif

common pfs_image_info, imheader

if not keyword_set(diameter) then diameter = 2
if not keyword_set(offset) then offset = [0.01,0.01]
if not keyword_set(charsize) then charsize = 1.

radec = grab_coords_reg(region_file,text=names,n_t=ntext)
sz = size(radec)
n_radec = n_elements(radec)/3

if n_radec eq 0 and ntext eq 0 then begin
   print,'No regions found, exit'
   return
endif

naxis1 = fxpar(imheader,'NAXIS1')
naxis2 = fxpar(imheader,'NAXIS2')

; Calculate image size to select only interesting regions 

cd1_1 = fxpar(imheader,'CD1_1')
cd1_2 = fxpar(imheader,'CD1_2')
cd2_1 = fxpar(imheader,'CD2_1')
cd2_2 = fxpar(imheader,'CD2_2')
cdelt = sqrt(cd1_1^2 + cd1_2^2)
im_radius = naxis1 * cdelt * 1.414 / 2.
print,'Image radius: ',im_radius,' deg'

crval1 = fxpar(imheader,'CRVAL1')
crval2 = fxpar(imheader,'CRVAL2')

r = arcdist(crval1,crval2,radec(0,*),radec(1,*))
w = where( r lt im_radius, n_radec)
print,n_radec,' regions are possible'


def_sym,'c'
for i = 0, n_radec-1 do begin

   skypos_fits, imheader, pix1, pix2, radec(0,w(i)), $
	   radec(1,w(i)), /hdr, dir='pix',/sil
   x = (pix1-0)/naxis1
   y = (pix2-0)/naxis2
   if x gt 0.0 and x lt 1.0 and y gt 0.0 and y lt 1.0 then $
      oplot,[x],[y],ps=8,symsize=diameter, col=255

endfor

if keyword_set(text) and ntext gt 0 then begin

   r = arcdist(crval1,crval2,names.ra,names.dec)
   w = where( r lt im_radius, ntext)
   print,ntext,' texts are possible'

   for i = 0, ntext-1 do begin
      skypos_fits, imheader, pix1, pix2, names(w(i)).ra, $
	      names(w(i)).dec, /hdr, dir='pix',/sil
      x = (pix1-0)/naxis1
      y = (pix2-0)/naxis2
      if x gt 0.0 and x lt 1.0 and y gt 0.0 and y lt 1.0 then begin
         align = 0.
	 if x gt 0.7 then align = 1.
         xyouts,x+offset(0)-2.*offset(1)*align,y+offset(1), $
	     names(w(i)).name,charsize=charsize,col=255,align=align
      endif
   endfor
endif
end
