pro add_spec_flux_source_cat, cat_file, code, specdir=specdir
;
;   2005-05-25/NJW
;
;   Read catalog produced by mk_jiir_fits_source_cat.pro and
;   extract the flux of each source from the corresponding
;   spectral file
;
if n_params() lt 2 then begin
   print,'Syntax: add_spec_flux_source_cat, cat_file, code[,specdir=]'
   print,'    where cat_file is a catalog generated by ''mk_jiir_fits_source_cat'''
   print,'    and code is a string such as ''_b2'''
   print,'    If directory for the spectral files is not ''/nfs/lin6/users/njw/analysis/srcl_res'''
   print,'    then it must be defined by keyword ''specdir''.'
   return
endif

rdfitscol,cat_file+'+1',swid,'SWID',nrows=nrows,/sil
rdfitscol,cat_file+'+1',ra_obj,'RA_OBJ',/sil
rdfitscol,cat_file+'+1',dec_obj,'DEC_OBJ',/sil
rdfitscol,cat_file+'+1',jemx_num,'JEMX_NUM',/sil
rdfitscol,cat_file+'+1',ebin_num,'EBIN_NUM',/sil
rdfitscol,cat_file+'+1',e_min,'E_MIN',/sil
rdfitscol,cat_file+'+1',e_max,'E_MAX',/sil

spec_flux = fltarr(16,nrows)
spec_flux_err = fltarr(16,nrows)

if not keyword_set(specdir) then $
   specdir = '/nfs/lin6/users/njw/analysis/srcl_res'

for i = 0, nrows-1 do begin
   specfile = specdir+'/jmx' $
        +stri(jemx_num(i))+'_srcl_spe'+code+'_'+swid(i)+'.fits'
   if file_test(specfile,/reg) then print,'Found '+specfile
   ; Locate the source
   rdfitscol,specfile+'+1',spec_ra_obj,'RA_OBJ',/sil
   rdfitscol,specfile+'+1',spec_dec_obj,'DEC_OBJ',/sil
   rdfitscol,specfile+'+1',spec_rate,'RATE',/sil
   rdfitscol,specfile+'+1',spec_stat_err,'STAT_ERR',/sil
   sz = size(spec_rate)
   print,'size spec_rate: ', sz
   print,'total spec_rate: ', total(spec_rate)
   print,'total spec_stat_err: ', total(spec_stat_err)
   if sz(0) eq 1 then begin
      spec_rate = reform(spec_rate,256,1)
      spec_stat_err = reform(spec_stat_err,256,1)
   endif

   r = arcdist(ra_obj(i),dec_obj(i),spec_ra_obj,spec_dec_obj)
   s = min(r,jmin)
   print,'jmin s = ', jmin, s
   ; Get the PI value limits
   for ie = 0, ebin_num(i)-1 do begin
      spawn,'kev2pi -dn '+stri(e_min(ie,i))+' '+stri(e_max(ie,i)),result
      pi_low = fix(result(0))
      pi_high = fix(result(1))
      print,'PI limits: ', pi_low, pi_high
      spec_flux(ie,i) = total(spec_rate(pi_low:pi_high,jmin))
      spec_flux_err(ie,i) = sqrt(total(spec_stat_err(pi_low:pi_high,jmin)^2))
      print,' ie i spec_flux_err: ', ie, i, spec_flux_err(ie,i)
   endfor
endfor

wrnewfitscol,cat_file+'+1','SPEC_FLUX',spec_flux,'SPEC_FLUX_ERR',spec_flux_err

end
