;
;  Add or update the XSPEC spectral description
;  to a DSRI X-ray catalogue (e.g. DSRI_CAT.fits)
;
;   NJW/2002-01-07
;
spawn,'back testsky.fits'

; Check whether the SPECMOD and SPECPAR columns exist

rdfitscol,'testsky.fits+1',spectrcode,'SPECTRCODE',hdr=hdr,/sil
rdfitscol,'testsky.fits+1',intenscode,'INTENSCODE',/sil
rdfitscol,'testsky.fits+1',intens,'INTENS',/sil
rdfitscol,'testsky.fits+1',nh,'NH',/sil
rdfitscol,'testsky.fits+1',param1,'PARAM1',/sil

cols = strtrim(fxpar(hdr,'TTYPE*'),2)
colspecmod = where( cols eq 'SPECMOD', n_mod)
colspecpar = where( cols eq 'SPECPAR', n_par)

if n_mod eq 0 and n_par eq 0 then exist = 0
if n_mod gt 0 and n_par gt 0 then exist = 1
if (n_mod gt 0 and n_par eq 0) or (n_mod eq 0 and n_par gt 0) then begin
   print,'problem with missing column'
   stop
endif


part1 = 'phabs[1]('
part2_pl = 'powerlaw[2])'
part2_tb = 'bremss[2])'
e = xloggen(300,2.,10.)


nrows = n_elements(nh)
specpar = fltarr(nrows,32)
specmod = strarr(nrows)

for i = 0, nrows-1 do begin
   case spectrcode(i) of
     'PL ' : begin
      if intenscode(i) eq 'SX ' then begin
         flux = e^(-param1(i)) * absorp(nh(i),e)
         sx = sflux(2.,10., e, flux)
         ak = intens(i) / sx
      endif else begin
         ak = intens(i)
      endelse
      specpar(i,0) = nh(i) / 1.e22
      specpar(i,1) = param1(i)
      specpar(i,2) = ak
      specmod(i) = strpaddtolen(part1+part2_pl,128)
         end
     'TB ' : begin
      if intenscode(i) eq 'SX ' then begin
         flux = (exp(-e/param1(i))/e) * absorp(nh(i),e)
         sx = sflux(2.,10., e, flux)
         ak = intens(i) / sx
      endif else begin
         ak = intens(i)
      endelse
      specpar(i,0) = nh(i) / 1.e22
      specpar(i,1) = param1(i)
      specpar(i,2) = ak
      specmod(i) = strpaddtolen(part1+part2_tb,128)
         end
      default : begin
          print,'Illegal spectral code'
          return
                end
   endcase
endfor
 
if exist then begin ; rewrite the columns
   fxbopen,unit,'testsky.fits',1,access='RW'
   for row = 1, nrows do begin
      fxbwrite,unit,specmod(row-1),colspecmod(0)+1,row
      fxbwrite,unit,reform(specpar(row-1,*),32),colspecpar(0)+1,row
   endfor
   fxbfinish,unit
endif else begin
   wrnewfitscol,'testsky.fits+1','SPECMOD',specmod
   wrnewfitscol,'testsky.fits+1','SPECPAR',specpar
endelse

end

