pro adds,sn=sn,rd=rd,dd=dd,cd=cd,ic=ic,sc=sc,in=in,p1=p1,p2=p2,rf=rf,cl=cl,cg=cg,ib=ib
;
;  Add a source to 'DSRI_CAT.fits' catalogue
;  (Previously add_src_dsri_cat)
;
;  NJW/010124
;
;  Define structure to hold all source information
;
;  A copy of the catalog information is kept (updated) in the
;  common area: cat_com. All changes to the catalog are entered
;  both in the common variables: cat and num_entries_cat, and in the
;  disk version of the catalog (DSRI_CAT.fits)
;
;  Keywords:   sn     sourcename
;              rd     RA (decimal degrees)
;              dd     DEC (decimal degrees)
;              cd     Column density (NH) [/cm2]
;              ic     intensity_code (SX or AK)
;              sc     spectral_code (PL, TB, or DF)
;              in     intensity if SX: in erg/cm2/s; if AK norm.
;              p1     spectral parameter 1
;              p2     spectral parameter 2
;              rf     reference number
;              cl     catalog name for origin of source information
;              cg     source category
;              ib     (boolean) in xbase book?

; Use standard common format to hold the catalogue

common cat_com, cat, num_entries_cat, dol_of_cat

chat = 10

source = {   sourcename:'', ra:0.0, dec:0.0, nh:0.0, intenscode:'', $
             spectrcode:'', intens:0.0, param1:0.0, param2:0.0, serial:0L, $
             refernce:0, catalog:'', category:'', inbook:0}


print
print,'******     adds VERSION 2.0    *******'
print

dol_dsri_cat = '/r6/jemx/catalogs/DSRI_CAT_002.fits[1]'
dol_dsri_cat_flux = '/home/njw/jsim/Catalogs/DSRI_CAT_FLUX.fits[1]'
dol_dsri_cat_ref = '/home/njw/jsim/Catalogs/DSRI_CAT_REF.fits[1]'
dol_dsri_cat_iden = '/home/njw/jsim/Catalogs/DSRI_CAT_IDEN.fits[1]'

print,'  Updating ', dol_dsri_cat
print

parfile = 'add_src_dsri_cat.par'
if not file_test(parfile,/reg) then begin
   openw,lun,parfile,/get_lun
   printf,lun,'// sourcename = default'
   printf,lun,'// ra = 0.0'
   printf,lun,'// dec = 0.0'
   printf,lun,'// nh = 3.e21'
   printf,lun,'// intenscode = SX'
   printf,lun,'// spectrcode = PL'
   printf,lun,'// intens = 1.1111e-9'
   printf,lun,'// param1 = 0.7'
   printf,lun,'// param2 = 0.0'
   printf,lun,'// refernce = 0'
   printf,lun,'// catalog = 0'
   printf,lun,'// category = ?'
   printf,lun,'// inbook = 0'
   free_lun,lun
   print,'Parameter file : ', parfile,' has been created'
endif

if keyword_setx(sn) then print,'Def. sourcename: ', sn
if keyword_setx(rd) then print,'Def. ra        : ', rd
if keyword_setx(dd) then print,'Def. dec       : ', dd
if keyword_setx(cd) then print,'Def. col. dens.: ', cd
if keyword_setx(ic) then print,'Def. intenscode: ', ic
if keyword_setx(sc) then print,'Def. spectrcode: ', sc
if keyword_setx(in) then print,'Def. intensity : ', in
if keyword_setx(p1) then print,'Def. param1    : ', p1
if keyword_setx(p2) then print,'Def. param2    : ', p2
if keyword_setx(rf) then print,'Def. refernce  : ', rf
if keyword_setx(cl) then print,'Def. catalog   : ', cl
if keyword_setx(cg) then print,'Def. category  : ', cg
if keyword_setx(ib) then print,'Def. in book   : ', ib

answer = ''
read,'Input new source ? ... ', answer
if answer eq 'y' then begin

   ; Read the contents of 'DSRI_CAT.fits'
   
   force_reading = 0
   sz = size( cat )
   if sz(0)+sz(1) eq 0 then begin
      force_reading = 1
   endif else begin
      if dol_of_cat ne dol_dsri_cat then force_reading = 1
   endelse

   if force_reading then begin

      dol_of_cat = dol_dsri_cat
      errmsg = ''
      print,'Reading '+dol_dsri_cat+' ...'
      rdfitscol,dol_dsri_cat,sourcename,'SOURCENAME',err=errmsg,/sil
      rdfitscol,dol_dsri_cat,ra,'RA',err=errmsg,/sil
      rdfitscol,dol_dsri_cat,dec,'DEC',err=errmsg,/sil
      rdfitscol,dol_dsri_cat,nh,'NH',err=errmsg,/sil
      rdfitscol,dol_dsri_cat,intenscode,'INTENSCODE',err=errmsg,/sil
      rdfitscol,dol_dsri_cat,spectrcode,'SPECTRCODE',err=errmsg,/sil
      rdfitscol,dol_dsri_cat,intens,'INTENS',err=errmsg,/sil
      rdfitscol,dol_dsri_cat,param1,'PARAM1',err=errmsg,/sil
      rdfitscol,dol_dsri_cat,param2,'PARAM2',err=errmsg,/sil
      rdfitscol,dol_dsri_cat,serial,'SERIAL',err=errmsg,/sil
      rdfitscol,dol_dsri_cat,refernce,'REFERNCE',err=errmsg,/sil
      rdfitscol,dol_dsri_cat,catalog,'CATALOG',err=errmsg,/sil
      rdfitscol,dol_dsri_cat,category,'CATEGORY',err=errmsg,/sil
      rdfitscol,dol_dsri_cat,inbook,'INBOOK',err=errmsg,/sil
   
      if errmsg ne '' then begin
         print,errmsg
         return
      endif
   
      num_entries_cat = n_elements(ra)
      if chat gt 2 then print,'##0## num_entries_cat = ', num_entries_cat

      cat = replicate(source, num_entries_cat)

      for i = 0, num_entries_cat-1 do begin
         cat(i).sourcename = sourcename(i)
         cat(i).ra = ra(i)
         cat(i).dec = dec(i)
         cat(i).nh = nh(i)
         cat(i).intenscode = intenscode(i)
         cat(i).spectrcode = spectrcode(i)
         cat(i).intens = intens(i)
         cat(i).param1 = param1(i)
         cat(i).param2 = param2(i)
         cat(i).serial = serial(i)
         cat(i).refernce = refernce(i)
         cat(i).catalog = catalog(i)
         cat(i).category = category(i)
         cat(i).inbook = inbook(i)
      endfor

   endif else begin
      if chat gt 2 then print,'##1## copy ra, dec, serial'
      ra = cat.ra
      dec = cat.dec
      serial = cat.serial
   endelse

   serial_max = max(serial)
   if chat gt 2 then print,'##2## serial_max = ', serial_max
   
   ; Get data for the new source
   
   source_new = source

   source_new.sourcename = get_ppar_s(parfile,'sourcename',kw=sn)
   source_new.ra         = get_ppar_ra(parfile,'ra',kw=rd)
   source_new.dec        = get_ppar_dec(parfile,'dec',kw=dd)
   source_new.nh         = get_ppar_e(parfile,'nh',kw=cd)
   source_new.intenscode = get_ppar_s(parfile,'intenscode',kw=ic)
   source_new.spectrcode = get_ppar_s(parfile,'spectrcode',kw=sc)
   source_new.intens     = get_ppar_e(parfile,'intens',kw=in)
   source_new.param1     = get_ppar_e(parfile,'param1',kw=p1)
   source_new.param2     = get_ppar_e(parfile,'param2',kw=p2)
   ;** source_new.serial = get_ppar_e(parfile,'serial',kw=se)
   source_new.refernce   = get_ppar_i(parfile,'refernce', kw=rf)
   source_new.catalog    = get_ppar_s(parfile,'catalog',kw=cl)
   source_new.category   = get_ppar_s(parfile,'category',kw=cg)
   source_new.inbook     = get_ppar_i(parfile,'inbook', kw=ib)
   
   ;  See if the source already exists in the catalog (by distance)

   dist = arcdist( source_new.ra, source_new.dec, ra, dec, /deg )

   selection = where( dist lt 0.2, n_selection )

   print
   if n_selection gt 0 then begin

      if n_selection gt 1 then begin
         print,'There are ', n_selection,' sources close to the new one'
      endif else begin
         print,'There is a single source close to the new one'
      endelse

      for i = 0, n_selection-1 do begin
         j = selection(i)
         flash_src, cat(j), i, dist=dist(j)*60.
      endfor

   endif else begin
      print,'There are NO sources close to the new one'
   endelse
   print

   proceed = 0
   print
   answer = ''
   print,'Do you want to ...'
   print,'         add source to catalog ?  Enter ''a'''
   print,'         replace other source ? Enter serial#'
   print,'         update identifiers ?     Enter ''i''
   print,'         quit ?                   Enter ''q'''
   read,'                                     Option ... ', answer

   if answer eq 'q' then return

   if answer eq 'i' then begin

      serial_new = 0L
      read,'Enter source serial number : ... ', serial_new
      serial_new = long( serial_new )

      goto, update_identifiers

   endif

   if answer eq 'a' then begin

      ;  Going to add to 'DSRI_CAT.fits'
   
      ; Add another row to the 'DSRI_CAT.fits'
   
      spawn,'/home/njw/jsim/add_rows/add_rows "'+dol_dsri_cat+'" 1'
   
      serial_new = serial_max + 1
      rownum = num_entries_cat + 1
      num_entries_cat = num_entries_cat + 1
      source_new.serial = serial_new

      ; did not work: cat = [ cat, source_new ]

      catx = replicate(source,num_entries_cat)
      for i = 0, num_entries_cat-2 do begin
         catx(i).sourcename = cat(i).sourcename
         catx(i).ra = cat(i).ra
         catx(i).dec = cat(i).dec
         catx(i).nh = cat(i).nh
         catx(i).intenscode = cat(i).intenscode
         catx(i).spectrcode = cat(i).spectrcode
         catx(i).intens = cat(i).intens
         catx(i).param1 = cat(i).param1
         catx(i).param2 = cat(i).param2
         catx(i).serial = cat(i).serial
         catx(i).refernce = cat(i).refernce
         catx(i).catalog = cat(i).catalog
         catx(i).category = cat(i).category
         catx(i).inbook = cat(i).inbook
      endfor
      i = num_entries_cat - 1
      catx(i).sourcename = source_new.sourcename
      catx(i).ra = source_new.ra
      catx(i).dec = source_new.dec
      catx(i).nh = source_new.nh
      catx(i).intenscode = source_new.intenscode
      catx(i).spectrcode = source_new.spectrcode
      catx(i).intens = source_new.intens
      catx(i).param1 = source_new.param1
      catx(i).param2 = source_new.param2
      catx(i).serial = source_new.serial
      catx(i).refernce = source_new.refernce
      catx(i).catalog = source_new.catalog
      catx(i).category = source_new.category
      catx(i).inbook = source_new.inbook

      cat = catx
   
   endif else begin

      ;  Replace old source with the new source

      serial_new = long(answer)
      source_new.serial = serial_new

      ; find the row number

      sel = where( serial eq serial_new, n_sel)

      if n_sel eq 0 then begin
         print,'No such serial# could be found'
         return
      endif

      ; substitute old with new
      if chat gt 2 then print,'##3## substitute index #', sel(0)
      if chat gt 2 then print,'##4## old serial  #', cat(sel(0)).serial
      if chat gt 2 then print,'##5## substitute serial #', serial_new
      cat(sel(0)).sourcename = source_new.sourcename
      cat(sel(0)).ra = source_new.ra
      cat(sel(0)).dec = source_new.dec
      cat(sel(0)).nh = source_new.nh
      cat(sel(0)).intenscode = source_new.intenscode
      cat(sel(0)).spectrcode = source_new.spectrcode
      cat(sel(0)).intens = source_new.intens
      cat(sel(0)).param1 = source_new.param1
      cat(sel(0)).param2 = source_new.param2
      cat(sel(0)).serial = source_new.serial
      cat(sel(0)).refernce = source_new.refernce
      cat(sel(0)).catalog = source_new.catalog
      cat(sel(0)).category = source_new.category
      cat(sel(0)).inbook = source_new.inbook

      rownum = sel(0) + 1 ; row number in catalog FITS dol

   endelse

   print,'This source gets the serial number: ', serial_new
   
   get_exten_no, dol_dsri_cat, filename, extno
   fxbopen,unit,filename,extno,hdr,access='RW'
   if chat gt 2 then print,'##6## going to update row# ', rownum
   errmsg = ''
   colnum = fxbcolnum( unit, 'SOURCENAME', err=errmsg)
   if errmsg ne '' then print,'##7## errmsg: ', errmsg
   fxbwrite, unit, source_new.sourcename, colnum, rownum, err=errmsg
   if errmsg ne '' then print,'##8## errmsg: ', errmsg
   colnum = fxbcolnum( unit, 'RA', err=errmsg)
   fxbwrite, unit, source_new.ra, colnum, rownum, err=errmsg
   colnum = fxbcolnum( unit, 'DEC', err=errmsg)
   fxbwrite, unit, source_new.dec, colnum, rownum, err=errmsg
   colnum = fxbcolnum( unit, 'NH', err=errmsg)
   fxbwrite, unit, source_new.nh, colnum, rownum, err=errmsg
   colnum = fxbcolnum( unit, 'INTENSCODE', err=errmsg)
   fxbwrite, unit, source_new.intenscode, colnum, rownum, err=errmsg
   colnum = fxbcolnum( unit, 'SPECTRCODE', err=errmsg)
   fxbwrite, unit, source_new.spectrcode, colnum, rownum, err=errmsg
   colnum = fxbcolnum( unit, 'INTENS', err=errmsg)
   fxbwrite, unit, source_new.intens, colnum, rownum, err=errmsg
   colnum = fxbcolnum( unit, 'PARAM1', err=errmsg)
   fxbwrite, unit, source_new.param1, colnum, rownum, err=errmsg
   colnum = fxbcolnum( unit, 'PARAM2', err=errmsg)
   fxbwrite, unit, source_new.param2, colnum, rownum, err=errmsg
   colnum = fxbcolnum( unit, 'SERIAL', err=errmsg)
   fxbwrite, unit, source_new.serial, colnum, rownum, err=errmsg
   colnum = fxbcolnum( unit, 'REFERNCE', err=errmsg)
   fxbwrite, unit, fix(source_new.refernce), colnum, rownum, err=errmsg
   colnum = fxbcolnum( unit, 'CATALOG', err=errmsg)
   fxbwrite, unit, source_new.catalog, colnum, rownum, err=errmsg
   colnum = fxbcolnum( unit, 'CATEGORY', err=errmsg)
   fxbwrite, unit, source_new.category, colnum, rownum, err=errmsg
   colnum = fxbcolnum( unit, 'INBOOK', err=errmsg)
   fxbwrite, unit, fix(source_new.inbook), colnum, rownum, err=errmsg
   
   fxbfinish, unit, err=errmsg
   
   if errmsg ne '' then begin
      print,'##9## errmsg: ', errmsg
   endif else begin
      print,'Terminated updating ',dol_dsri_cat,' OK'
   endelse

   serial_new = source_new.serial

endif else begin; Terminate 'if you want to add a new source'

   serial_new = 0L
   read,'Enter source serial number : ... ', serial_new
   serial_new = long(serial_new)

endelse

; Section for flux measurements for this source

answer = ''
read,' Do you want to update the flux measurements ? ... ', answer

if answer eq 'y' then begin

   get_exten_no, dol_dsri_cat_flux, filename, extno
   fxbopen,unit,filename,extno,hdr
   fxbclose,unit
   num_entries_flux = fxpar(hdr,'NAXIS2')
   errmsg = ''
   new_flux = 1

   while new_flux do begin

      mission_new = get_pars('add_src_dsri_cat_flux.dat','mission')
      instrument_new = get_pars('add_src_dsri_cat_flux.dat','instrument')
      date_new = get_pars('add_src_dsri_cat_flux.dat','date')
      mjd_new = get_par('add_src_dsri_cat_flux.dat','mjd')
      duration_new = float(get_par('add_src_dsri_cat_flux.dat','duration'))
      emin_new = float(get_par('add_src_dsri_cat_flux.dat','emin'))
      emax_new = float(get_par('add_src_dsri_cat_flux.dat','emax'))
      value_new = float(get_par('add_src_dsri_cat_flux.dat','value'))
      unit_new = get_pars('add_src_dsri_cat_flux.dat','unit')
      refernce_new = get_par('add_src_dsri_cat_flux.dat','refernce',/int)
      print,'size of refernce_new: ', size(refernce_new)
      valstd_new = float(get_par('add_src_dsri_cat_flux.dat','valstd'))
      notes_new = get_pars('add_src_dsri_cat_flux.dat','notes')

      spawn,'/home/njw/jsim/add_rows/add_rows "'+dol_dsri_cat_flux+'" 1'

      fxbopen,unit,filename,extno,hdr,access='RW'
      colnum = fxbcolnum( unit, 'SERIAL', err=errmsg)
      if errmsg ne '' then print,'##10## errmsg: ', errmsg
      fxbwrite, unit, serial_new, colnum, num_entries_flux+1, err=errmsg
      if errmsg ne '' then print,'##11## errmsg: ', errmsg
      colnum = fxbcolnum( unit, 'MISSION', err=errmsg)
      fxbwrite, unit, mission_new, colnum, num_entries_flux+1, err=errmsg
      colnum = fxbcolnum( unit, 'INSTRUMENT', err=errmsg)
      fxbwrite, unit, instrument_new, colnum, num_entries_flux+1, err=errmsg
      colnum = fxbcolnum( unit, 'DATE', err=errmsg)
      fxbwrite, unit, date_new, colnum, num_entries_flux+1, err=errmsg
      colnum = fxbcolnum( unit, 'MJD', err=errmsg)
      fxbwrite, unit, mjd_new, colnum, num_entries_flux+1, err=errmsg
      colnum = fxbcolnum( unit, 'DURATION', err=errmsg)
      fxbwrite, unit, duration_new, colnum, num_entries_flux+1, err=errmsg
      colnum = fxbcolnum( unit, 'EMIN', err=errmsg)
      fxbwrite, unit, emin_new, colnum, num_entries_flux+1, err=errmsg
      colnum = fxbcolnum( unit, 'EMAX', err=errmsg)
      fxbwrite, unit, emax_new, colnum, num_entries_flux+1, err=errmsg
      colnum = fxbcolnum( unit, 'VALUE', err=errmsg)
      fxbwrite, unit, value_new, colnum, num_entries_flux+1, err=errmsg
      colnum = fxbcolnum( unit, 'UNIT', err=errmsg)
      fxbwrite, unit, unit_new, colnum, num_entries_flux+1, err=errmsg
      colnum = fxbcolnum( unit, 'REFERNCE', err=errmsg)
      fxbwrite, unit, refernce_new, colnum, num_entries_flux+1, err=errmsg
      colnum = fxbcolnum( unit, 'VALSTD', err=errmsg)
      fxbwrite, unit, valstd_new, colnum, num_entries_flux+1, err=errmsg
      colnum = fxbcolnum( unit, 'NOTES', err=errmsg)
      fxbwrite, unit, notes_new, colnum, num_entries_flux+1, err=errmsg

      fxbfinish, unit, err=errmsg


      answer = ''
      read,' Another flux measurement ? ... ', answer
      if answer ne 'y' then new_flux = 0

      num_entries_flux = num_entries_flux + 1

   endwhile

endif  ;   Terminate 'if you want to add flux measurements'


update_identifiers:

; Section for identifiers for this source

answer = ''
read,' Do you want to update the identifiers for source#' $
     +strtrim(serial_new,2)+' ? ... ', answer

if answer eq 'y' then begin

   if not file_test('add_src_dsri_cat_iden.dat',/reg) then begin
      spawn,'cp /home/njw/jsim/Catalogs/add_src_dsri_cat_iden.dat .'
   endif
   get_exten_no, dol_dsri_cat_iden, filename, extno
   fxbopen,unit,filename,extno,hdr
   fxbclose,unit
   num_entries_iden = fxpar(hdr,'NAXIS2')
   print, num_entries_iden,' rows in identifier table'
   errmsg = ''
   new_iden = 1

   while new_iden do begin

      identifier_new = get_pars('add_src_dsri_cat_iden.dat','identifier')

      spawn,'/home/njw/jsim/add_rows/add_rows "'+dol_dsri_cat_iden+'" 1'

      fxbopen,unit,filename,extno,hdr,access='RW'
      colnum = fxbcolnum( unit, 'SERIAL', err=errmsg)
      if errmsg ne '' then print,'##12## errmsg: ', errmsg
      fxbwrite, unit, serial_new, colnum, num_entries_iden+1, err=errmsg
      if errmsg ne '' then print,'##13## errmsg: ', errmsg
      colnum = fxbcolnum( unit, 'IDENTIFIER', err=errmsg)
      fxbwrite, unit, identifier_new, colnum, num_entries_iden+1, err=errmsg

      fxbfinish, unit, err=errmsg


      answer = ''
      read,' Another identifier ? ... ', answer
      if answer ne 'y' then new_iden = 0

      num_entries_iden = num_entries_iden + 1

   endwhile

endif  ;   Terminate 'if you want to add identifier'

end
