pro amoeba_x, p, y
;
; This fitting procedure has been adapted for X-ray model
; fitting. The only change, though, is the name of the function
; which now is fchi2 (originally funk)
;
sp = size(p)
if( sp(0) ne 2 ) then begin
   print,' p array does not have 2 dimensions'
   return
endif
if( sp(1) ne 1+sp(2) ) then begin
   print,' p array dimensions do not match internally'
   return
endif
if( sp(1) ne n_elements(y) ) then begin
   print,' p array dimensions do not match the y dimension'
   return
endif
;
ndim = sp(2)
alpha = 1.0
beta = 0.5
gamma = 2.0
itmax = 40
it = 0
ftol = 1.e-4
; p = fltarr(ndim+1,ndim)
; y = fltarr(ndim+1)
pr = fltarr(ndim)
prr = fltarr(ndim)
pbar = fltarr(ndim)

while( 1 gt 0) do begin

; Get highest, next highest and lowest point
   ymax = max(y,ihi)
   ymin = min(y,ilo)
   y(ilo) = ymin - 1.
   y(ihi) = ymin - 1.
   ynhi = max(y,inhi)
   y(ihi) = ymax
   y(ilo) = ymin
   print,ihi,inhi,ilo
   print,ymax,ynhi,ymin,' = least chi2'
   print,' at : ',p(ilo,*)

; Test for satisfactory approximation
   denom = abs(ymax) + abs(ymin)
   if( denom lt ftol ) then begin
      return
   endif else begin
      rtol = 2.*abs(ymax-ymin) / denom
      if( rtol lt ftol ) then return
   endelse

; Test for number of iterations
   if( it eq itmax ) then begin
      print, itmax,' max no. of iterations - stop'
      return
   endif
   it = it + 1

   pbar(*) = 0.
   for i = 0, ndim do begin
      if( i ne ihi ) then pbar(*) = pbar(*) + p(i,*)
   endfor
   pbar = pbar / ndim
   pr = (1.+alpha)*pbar - alpha*p(ihi,*)
   ypr = fchi2(pr)   ; evaluate the function at the reflected point
   case 1 of
      (ypr le ymin) : begin
         prr = gamma*pr + (1. - gamma)*pbar
         yprr = fchi2(prr)
         if( yprr lt ymin ) then begin
            p(ihi,*) = prr
            y(ihi) = yprr
         endif else begin  ; extra long step failed - use first step
            p(ihi,*) = pr
            y(ihi) = ypr
         endelse
      end
      (ypr ge ynhi) : begin
         if( ypr lt ymax ) then begin
            p(ihi,*) = pr
            y(ihi) = ypr
         endif
         prr = beta*pr + (1. - beta)*pbar
         yprr = fchi2(prr)
         if( yprr lt y(ihi) ) then begin
            p(ihi,*) = prr
            y(ihi) = yprr
         endif else begin
            for i = 0, ndim do begin
               if( i ne ilo ) then begin
                  pr = 0.5*(p(i,*) + p(ilo,*))
                  p(i,*) = pr
                  y(i) = fchi2(pr)
               endif
            endfor
         endelse
      end
      else : begin
         p(ihi,*) = pr
         y(ihi) = ypr
      end
   endcase
endwhile
end
