function arcdist, ra1, dc1, ra2, dc2, deg=deg, rad=rad

; Return distance along great circle from one point to another
; Unit must be supplied if not degrees (default)

if n_params() lt 4 then begin
   print,'Syntax: res = arcdist(ra1,dc1,ra2,dc2,/deg XOR /rad)'
   return,-1.
endif

iu = 0
if keyword_set(deg) then iu = iu + 1
if keyword_set(rad) then iu = iu + 2
if iu eq 3 then begin
   print,'ARCDIST: only one unit can be defined /deg xor /rad'
   return,0.
endif
if iu lt 2 then iu = 1 ; choose degrees as default

; Avoid singularity when coordinates are very close to
; being identical
factor = 1.d0
if iu eq 1 then factor = !pi/double(180)
r1 = ra1 * factor
d1 = dc1 * factor
r2 = ra2 * factor
d2 = dc2 * factor
arg = (sin(d1)*sin(d2) + cos(d1)*cos(d2)*cos(r2-r1)) < 1.d0
return,acos(arg)/factor
end
