pro arf2phaii, specresp, outarfname, spename=spename
;
;  Write an ARF table to a standard PHAII file
;
;    2005-11-16/NJW, first version cloned from 'spec2phaii'
;

nparams = n_params()
if nparams lt 2 then begin
   print
   print,'Syntax: arf2phaii, specresp, outarfname[,spename=]'
   print,'    Keyword: spename , if given this spectral file'
   print,'         will be updated in the ANCRFILE column'
   print
   return
endif

if n_elements(specresp) ne 500 then begin
   print,'The number of elements of ''specresp'' must be 500'
   return
endif

; Prepare the output file jmxi_nnnn_arf.fits
; in the current directory


spawn,'cp /home/njw/jemx/spectra/jmx1_coll_arf.fits '+outarfname

;  Update file with the ARF

print,'New ARF file: '+outarfname
fxbopen, unit, outarfname, 1, access='RW'
fxbwrite, unit, reform(specresp,500,1), fxbcolnum(unit,'SPECRESP'), 1
fxbfinish, unit

;  Update the checksum

spawn,'fchecksum '+outarfname+' update=yes'

if keyword_set(spename) then begin
   if not file_test(spename,/reg) then begin
      print,'File '+spename+' does not exist - skip updating'
      return
   endif
   hdr = headfits(spename,ext=1)
   nrows = fxpar(hdr,'NAXIS2')
   if nrows gt 1 then begin
      print,'Warning: There are '+stri(nrows)+' rows in the spectral file but only'
      print,'         the first row will be updated for ANCRFILE'
   endif
   fxbopen, unit, spename, 1, access='RW'
   fxbwrite, unit, outarfname+'{1}', fxbcolnum(unit,'ANCRFILE'), 1
   fxbfinish, unit
   print,'Updating of '+spename+' has been done'
endif

end
