function arffit_photspec, p, pl=pl
;
;  Function that returns the photon spectrum for a
;  given set of spectral parameters
;  in array 'p':  (norm, param1, nh/1.e22)
;
;   NJW/2002-06-28
;   2004-02-09/NJW updated with newer Crab data from Rev 102
;
if n_params() lt 1 then begin
   print,'Syntax: flux = arffit_photspec(p)'
   return, -1.
endif
if( n_elements(p) ne 3 ) then begin
   print,'arffit_photspec must be called with 3 element array'
   return, -1.
endif

;   Define the common areas

common instrument, e_min, e_max, matrix, arf
common observation, rate, stat_err, countspec, number
common model, elo, ehi, eline, spectrcode
common results, const, param1, nh, chi2red, sx


const = p(0)
param1 = p(1)
nh = p(2) * 1.e22

;   Generate the input spectrum


case spectrcode of
     'PL' : begin
             flux = p(0) * eline^(-param1) * absorp(nh, eline)
            end
     'TB' : begin
             flux = p(0) * (exp(-eline/param1) / eline) * absorp(nh, eline)
            end
     'DF' : begin
             dum = min(abs(eline-param1),index)
             flux = fltarr(n_elements(eline))
             flux(index) = p(0) * absorp(nh, param1)
            end
     default : begin
               print,'No such spectral model allowed: ', spectrcode
               return, -1.
               end
endcase


return, flux

end
