function best_skypos, ra, dec, weight
;
;  Returns average sky position array: [ra,dec]
;  when arrays of RA and Dec are given in degrees
;
;  The third argument is a weight array
;  If not given then same weight is applied to
;  all positions
;
;   2003-10-27/NJW
;
np = n_params()
if np lt 2 then begin
   print,'syntax: pos = best_skypos(ra, dec[, weight])
   return,-1
endif
nval = n_elements(ra)
nd = n_elements(dec)
if nval ne nd then begin
   print,'BEST_SKYPOS error, bad dimensions of input (dec)'
   return,-1
endif
if np eq 3 then begin
   nw = n_elements(weight)
   if nval ne nw then begin
      print,'BEST_SKYPOS error, bad dimensions of input(weight)'
      return,-1
   endif
endif else weight = replicate(1., nval)

dr = !pi / 180

rsum = fltarr(3)
for i = 0, nval-1 do begin
   r = [cos(ra(i)*dr)*cos(dec(i)*dr),sin(ra(i)*dr)*cos(dec(i)*dr), sin(dec(i)*dr)]
   rsum = rsum + r*weight(i)
endfor

; normalize

norm = sqrt(total(rsum^2))
rsum = rsum / norm
ra_res = zero2pi(atan(rsum(1),rsum(0)))/dr
dec_res = asin(rsum(2))/dr

return, [ra_res,dec_res]


end
