pro boundaries, x, xlo, xhi,type=type
;
;  Procedure to define boundaries around each element of x
;
;   2003-04-04/NJW
;
if n_params() lt 2 then begin
   print,'Syntax: boundaries, x, xlo, xhi[, type=]'
   print,'   or   boundaries, x, bds[, type=]'
   print,'In the first case xlo and xhi will have same number of'
   print,'elements as x'
   print,'In the second case bds will have one more'
   print,'element than x'
   print,'Keyword    type   ''i'' (linear, default) or ''o'' (logarithmic)'
   return
endif

typ = 0 ; linear
if keyword_set(type) then begin
   if type eq 'o' then typ = 1 else begin
      if type ne 'i' then begin
         print,'Illegal keyword, proceed with type linear'
      endif
   endelse
endif

; Define boundaries

n = n_elements(x)
bds = fltarr(n+1)
if typ eq 0 then begin ; linear case
   for i = 1L, n-1 do bds(i) = 0.5*(x(i-1)+x(i))
   bds(0) = bds(1) - (x(1) - x(0))
   bds(n) = bds(n-1) + (x(n-1) - x(n-2))
endif else begin ; logarithmic case
   for i = 1L, n-1 do bds(i) = sqrt((x(i-1)*x(i)))
   bds(0) = bds(1) / (x(1) / x(0))
   bds(n) = bds(n-1) * (x(n-1) / x(n-2))
endelse

if n_params() eq 2 then begin
   xlo = bds
   return
endif else begin
   xlo = bds(0:n-1)
   xhi = bds(1:n)
endelse

end
