pro build_swid_time_table, topdir, dol_table, nrt=nrt
;
;  Build a table of start and stop IJD times of pointings
;
;     2004-01-23/NJW
;
if n_params() lt 2 then begin

   print,'Syntax: build_swid_time_table, topdir, dol_table[ ,/nrt]'
   print,'   Keyword /nrt to indicate Near Real Time data (use swg_prp.fits iso. swg.fits)'
   return

endif

; Check existence of previous version of table

get_exten_no, dol_table, file_table, extno
if file_test(file_table,/reg) then begin
   ;  Old version exists, append
   table_status = 1

   ; Special for this version
   print,'File exists, skip further action ...'
   return

endif else begin
   ;  No previous version, start over
   table_status = 0
endelse

; Get list of all SWGs below 'topdir'

swg_name = 'swg.fits'
;; swid_ver = '.001'
if keyword_set(nrt) then begin
   swg_name = 'swg_prp.fits'
;;    swid_ver = '.000'
endif
list = file_search(topdir,swg_name,count=nlist)
print,'Found '+stri(nlist)+' files by name of: '+swg_name
if nlist gt 0 then begin
   for i = 0, 6 < nlist do print,list(i)
endif
if nlist gt 0 then begin
   ;; remove files that are not ... swid_ver/swg.fits
   ; only keep files with highest version number
   ;; pos = strpos(list,swid_ver+'/swg')
   ;; w = where(pos gt 0, nw)
   ;; if nw gt 0 then list = list(w)
   ;; nlist = nw
   inlist = list(sort(list))
   deltwins_str, inlist, list
   nlist = n_elements(list)
   print,stri(nlist)+' files after filtering for latest version'
endif
;; if nlist gt 0 then begin
;;    ; remove certain SWIDs that give trouble
;;    pick_swid_str,list,swid_list
;;    black_list = ['011600630010','011600640010']
;;    nb = n_elements(black_list)
;;    for j = 0, nb-1 do begin
;;       w = where( swid_list ne black_list(j), nw )
;;       list = list(w)
;;       pick_swid_str,list,swid_list
;;    endfor
;;    nlist = nw
;;    print,stri(nw)+' files after filtering for blacklisted swids'
;; endif


if nlist eq 0 then begin
   print,'Sorry, no SWGs in and below '+topdir
   return
endif

tstart = dblarr(nlist)
tstop  = dblarr(nlist)
swid   = strarr(nlist)
ra_scx = dblarr(nlist)
dec_scx= dblarr(nlist)
ra_scz = dblarr(nlist)
dec_scz= dblarr(nlist)
posangle = dblarr(nlist)

for i = 0, nlist-1 do begin

   if i eq 6536 then continue
   print,list(i),i+1,' of', nlist
   hdr = headfits(list(i),ext=1)
   tstart(i) = fxpar(hdr,'TSTART')
   tstop(i) = fxpar(hdr,'TSTOP')
   swid(i) = fxpar(hdr,'SWID')
   ra_scx(i) = fxpar(hdr,'RA_SCX')
   dec_scx(i)= fxpar(hdr,'DEC_SCX')
   ra_scz(i) = fxpar(hdr,'RA_SCZ')
   dec_scz(i)= fxpar(hdr,'DEC_SCZ')
   posangle(i) = fxpar(hdr,'POSANGLE')

endfor

wrmfitscols, file_table,'SWID',swid,'TSTART',tstart,$
             'TSTOP',tstop,'RA_SCX',ra_scx,'DEC_SCX',dec_scx,$
             'RA_SCZ',ra_scz,'DEC_SCZ',dec_scz,$
             'POSANGLE',posangle

end
