function calc_iros_sx, jmx, revol, cflux, e_min, e_max, chatter=chatter
;
;    2005-05-25/NJW
;    2005-06-09/NJW Updated to increase flexibility
;        Now cflux, e_min, and e_max are 1D arrays
;
;   A program to calculate the Sx value for a source found in j_ima_iros
;
;   Get the appropriate ARF
;
if n_params() ne 5 then begin
   print,'Syntax: res = calc_iros_sx(jmx,revol,cflux,e_min,e_max[,chatter=])'
   print,' where cflux, e_min, and e_max are 1D 2 element arrays'
   print
   print,' res returns spectral slope, sx1, sx2, sx(2-10), sx(5-15)'
   print
endif

if not keyword_set(chatter) then chatter = 0

if chatter gt 2 then begin
   print,'calc_iros_sx jmx revol cflux: ', jmx, revol, cflux
   print,'        e_min e_max         : ', e_min, e_max
endif

spawn,'get_insta rmf '+stri(revol),result
if chatter gt 2 then print,'The RMF instance number is: ',result
insta = result(0)
rmf_name = '/home/njw/jemx/ic/rmf_grp/jmx'+stri(jmx)+'_rmf_grp_'+insta+'.fits'
rdfitscolc,rmf_name+'+4',energ_lo,'ENERG_LO',/sil
rdfitscolc,rmf_name+'+4',energ_hi,'ENERG_HI',/sil
rdfitscolc,rmf_name+'+4',arf,'SPECRESP',/sil
energ = 0.5*(energ_lo + energ_hi)
denerg = energ_hi - energ_lo

w1 = where(energ ge e_min(0) and energ le e_max(0), nw1)
w2 = where(energ gt e_min(1) and energ le e_max(1), nw2)
w3 = [w1,w2]
nw3 = n_elements(w3)
if chatter gt 3 then print,'nw1 nw2 nw3 = ', nw1, nw2, nw3

mindif = 1.e33
for alpha = 1.0, 3.5001, 0.1 do begin

   f = energ^(-alpha)
   integ1 = total(arf(w1)*f(w1)*denerg(w1))
   integ2 = total(arf(w2)*f(w2)*denerg(w2))
   integ3 = total(arf(w3)*f(w3)*denerg(w3))
   k1 = cflux(0) / integ1
   k2 = cflux(1) / integ2
   k3 = (cflux(0) + cflux(1)) / integ3
   if chatter gt 2 then print,'alpha k1 k2 k3 = ', alpha, k1, k2, k3
   ; It is expected that k1 eq k2 eq k3
   dif = abs(max([k1,k3])/min([k1,k3]) - 1) $
       + abs(max([k2,k3])/min([k2,k3]) - 1)
   if dif lt mindif then begin
      alpha_min = alpha
      k1_min = k1
      k2_min = k2
      k3_min = k3
      mindif = dif
   endif

endfor


sf1 = sflux(e_min(0),e_max(0),energ,k1*f)
sf2 = sflux(e_min(1),e_max(1),energ,k2*f)
sf3 = sflux(e_min(0),e_max(1),energ,k3*f)
sfn = sflux(2.,10.,energ,k3*f)
sfo = sflux(5.,15.,energ,k3*f)
strmin = string(e_min,format='(f4.1)')
strmax = string(e_max,format='(f4.1)')
if chatter gt 1 then begin
   print,'Resulting alpha: ', alpha_min
   print,'sf1('+strmin(0)+'-'+strmax(0)+') = ', sf1,' erg/cm2/s'
   print,'sf2('+strmin(1)+'-'+strmax(1)+') = ', sf2,' erg/cm2/s'
   print,'sf3('+strmin(0)+'-'+strmax(1)+') = ', sf3,' erg/cm2/s'
   print,'sfn(2-10) = ', sfn,' erg/cm2/s'
   print,'sfo(5-15) = ', sfo,' erg/cm2/s'
endif

return,[alpha_min,sf1,sf2,sfn,sfo]

end
