pro cat_compare, dol_cat_1, dol_cat_2, outfile=outfile, silent=silent, $
          names=names, reci=reci, min_err_rad=min_err_rad
;
;   2006-01-11/NJW   based on earlier version in /home/njw/work
;
if n_params() ne 2 then begin
   print,'Syntax: cat_compare, dol_cat_1, dol_cat_2'
   print,'     Keywords:'
   print,'            outfile :  will override default name: ''cat_compare_0000.txt'''
   print,'            silent  :  suppresses much terminal output'
   print,'            names   :  forces a comparison on source names'
   print,'            reci    :  forces a reciprocal test i.e. walking'
   print,'                       through CAT2 for coincidences in CAT1'
   print,'          min_err_rad : Minimum error radius to apply'
   return
endif

vb = 1 - keyword_set(silent)
if not keyword_set(outfile) then outfile = get_next_filename('cat_compare_????.txt')
openw, lun, outfile, /get_lun

if not keyword_set(min_err_rad) then min_err_rad = 0.0

cat1 = dol_cat_1
cat2 = dol_cat_2
printf,lun, '  Output file of ''cat_compare'', '+ndate(2)
printf,lun

printf,lun, 'CAT1: '+fullpath(cat1)
print,'Reading '+cat1+' ...'
rdfitscol,cat1,name1,'NAME', nrows=nrows1,/sil
rdfitscol,cat1,ra_obj1,'RA_OBJ',/sil
rdfitscol,cat1,dec_obj1,'DEC_OBJ',/sil
rdfitscol,cat1,err_rad1,'ERR_RAD',/sil
printf,lun,'           with '+stri(nrows1)+' sources'
is = sort(ra_obj1)
name1 = strtrim(name1(is),2)
ra_obj1 = ra_obj1(is)
dec_obj1 = dec_obj1(is)
err_rad1 = err_rad1(is)

printf,lun, 'CAT2: '+fullpath(cat2)
print,'Reading '+cat2+' ...'
rdfitscol,cat2,name2,'NAME',nrows=nrows2,/sil
rdfitscol,cat2,ra_obj2,'RA_OBJ',/sil
rdfitscol,cat2,dec_obj2,'DEC_OBJ',/sil
rdfitscol,cat2,err_rad2,'ERR_RAD',/sil
printf,lun,'           with '+stri(nrows2)+' sources'
is = sort(ra_obj2)
name2 = strtrim(name2(is),2)
ra_obj2 = ra_obj2(is)
dec_obj2 = dec_obj2(is)
err_rad2 = err_rad2(is)

if keyword_set(names) then begin

   print,'Checking names ...'
   printf,lun,'-----------------------------------------------------------'
   printf,lun,'         MATCHING SOURCE NAMES'
   printf,lun,'-----------------------------------------------------------'
   
   n_mult = 0
   n_coin = 0
   first = 1
   for i = 0, nrows1 - 1 do begin
   
      w = where( name2 eq name1(i), nw )
   
      if nw ge 1 then begin
         if vb then print,'Source '+name1(i)+' is found in both catalogs'
         ;* printf,lun,'         '+name1(i)
         if first then begin
            coin_names = name1(i)
            coin_num = nw
            first = 0
         endif else begin
            coin_names = [coin_names, name1(i)]
            coin_num = [coin_num, nw]
         endelse
         n_coin = n_coin + 1
      endif
   
      if nw gt 1 then begin
         print,'Source '+name1(i)+' (CAT1) is found '+stri(nw)+' times in CAT2'
         ;* printf,lun,'         is found '+stri(nw)+' times in CAT2'
         n_mult = n_mult + 1
         continue
      endif
   
   endfor
   
   if n_coin eq 0 then begin
      print,'No coincident names found.'
      printf,lun,'No coincident names found.'
   endif else begin

      if n_elements(coin_names) ne n_coin then begin
         print,'##3## Error!'
         free_lun,lun
         return
      endif
      is = sort(coin_names)
      coin_names = coin_names(is)
      coin_num   = coin_num(is)
      for i = 0, n_coin-1 do begin
         s = '                       '
         strput,s,coin_names(i),0
         if coin_num(i) gt 1 then strput,s,'('+stri(coin_num(i))+')',20
         printf,lun,'          '+s
      endfor
      print,stri(n_coin)+' coincidences of names.'
      printf,lun
      printf,lun,stri(n_coin)+' coincidences of names.'
   endelse

endif ; Terminate test for keyword 'names'

printf,lun,'-----------------------------------------------------------'
printf,lun,'                MATCHING SOURCE POSITIONS'
printf,lun,'-----------------------------------------------------------'
printf,lun,'In CAT1                                  In CAT2'

print,'Checking source positions ...'

n_coin = 0
first = 1
for i = 0, nrows1 - 1 do begin

   ; find cases where dist < err_rad1 + err_rad2
   ; or - equivalently : dist - err_rad2 < err_rad1


   dist = arcdist(ra_obj1(i), dec_obj1(i), ra_obj2, dec_obj2 )
   dista = dist - err_rad2
   w = where( dista lt (err_rad1(i) > min_err_rad) , nw ) 

   if nw gt 0 then begin
      n_coin = n_coin + 1
      if vb then begin
         print
         print,'Catalog 1 source: '+name1(i)+' '+ $
            string(ra_obj1(i),dec_obj1(i),format='(2f9.3)')+' matches the position of'
         for j = 0, nw-1 do begin
            print,'Catalog 2 source: '+name2(w(j))+' '+ $
               string(ra_obj2(w(j)),dec_obj2(w(j)),format='(2f9.3)')
         endfor
      endif
      printf,lun,name1(i), ra_obj1(i), dec_obj1(i), $
                 name2(w(0)), ra_obj2(w(0)), dec_obj2(w(0)), $
                     format='(a20,2f9.3,4x,a20,2f9.3)'
      if nw gt 1 then begin
         for j = 1, nw-1 do begin
            printf,lun, name2(w(j)), ra_obj2(w(j)), dec_obj2(w(j)), $
                           format='(42x,a20,2f9.3)'
         endfor
      endif
   endif else begin
      if first then begin
         aname = name1(i)
         ara = ra_obj1(i)
         adec = dec_obj1(i)
         first = 0
      endif else begin
         aname = [aname, name1(i)]
         ara = [ara, ra_obj1(i)]
         adec = [adec, dec_obj1(i)]
      endelse
   endelse

endfor

if n_coin eq 0 then print,'No coincident positions found.' else $
    print,stri(n_coin)+' coincidences of positions.'

n_in1_not_in2 = n_elements(aname)
printf,lun
printf,lun,'-----------------------------------------------------------'
printf,lun,'                SOURCES IN CAT1 BUT NOT IN CAT2'
printf,lun,'-----------------------------------------------------------'
for i = 0, n_in1_not_in2 - 1 do begin
   printf,lun,aname(i),ara(i),adec(i),format='(a20,2f9.3)'
endfor


n_coin = 0
first = 1
for i = 0, nrows2 - 1 do begin

   ; find cases where dist < err_rad1 + err_rad2
   ; or - equivalently : dist - err_rad1 < err_rad2

   dist = arcdist(ra_obj2(i), dec_obj2(i), ra_obj1, dec_obj1 )
   dista = dist - err_rad1
   w = where( dista lt (err_rad2(i) > min_err_rad), nw ) 

   if nw gt 0 then begin
      n_coin = n_coin + 1

      if keyword_set(reci) then begin

         if vb then begin
            print
            print,'Catalog 2 source: '+name2(i)+' '+ $
               string(ra_obj2(i),dec_obj2(i),format='(2f9.3)')+' matches the position of'
            for j = 0, nw-1 do begin
               print,'Catalog 1 source: '+name1(w(j))+' '+ $
                  string(ra_obj1(w(j)),dec_obj1(w(j)),format='(2f9.3)')
            endfor
         endif
         printf,lun,name2(i), ra_obj2(i), dec_obj2(i), $
                    name1(w(0)), ra_obj1(w(0)), dec_obj1(w(0)), $
                        format='(a20,2f9.3,4x,a20,2f9.3)'
         if nw gt 1 then begin
            for j = 1, nw-1 do begin
               printf,lun, name1(w(0)), ra_obj1(w(0)), dec_obj1(w(0)), $
                              format='(42x,a20,2f9.3)'
            endfor
         endif

      endif

   endif else begin
      if first then begin
         aname = name2(i)
         ara = ra_obj2(i)
         adec = dec_obj2(i)
         first = 0
      endif else begin
         aname = [aname, name2(i)]
         ara = [ara, ra_obj2(i)]
         adec = [adec, dec_obj2(i)]
      endelse
   endelse


endfor

if n_coin eq 0 then print,'No coincident positions found.' else $
    print,stri(n_coin)+' coincidences of positions.'

n_in2_not_in1 = n_elements(aname)
printf,lun
printf,lun,'-----------------------------------------------------------'
printf,lun,'                SOURCES IN CAT2 BUT NOT IN CAT1'
printf,lun,'-----------------------------------------------------------'
for i = 0, n_in2_not_in1 - 1 do begin
   printf,lun,aname(i),ara(i),adec(i),format='(a20,2f9.3)'
endfor

free_lun, lun

print,'The output has been written to: '+outfile

end
