pro cat_selfconsistency, dol_cat, mindist=mindist
;
;   2006-01-11/NJW   based on earlier version in /home/njw/work
;
if n_params() ne 1 then begin
   print,'Syntax: cat_selfconsistency, dol_cat[, mindist=]'
   print,' Keyword ''mindist'' will replace the err_rad when comparing positions'
   print,'  ''mindist'' is given in degrees'
   return
endif

print,'Reading '+dol_cat+' ...'
rdfitscol,dol_cat,name,'NAME', nrows=nrows,/sil
rdfitscol,dol_cat,ra_obj,'RA_OBJ',/sil
rdfitscol,dol_cat,dec_obj,'DEC_OBJ',/sil
rdfitscol,dol_cat,err_rad,'ERR_RAD',/sil

print,'Checking names ...'

namework = name
n_mult = 0
nm = 1
while nm gt 0 do begin

   w = where( stri(namework) eq stri(namework(0)), nw, complement=m, ncompl=nm )
   if nw ge 2 then begin
      print,'Source '+namework(0)+' is found '+stri(nw)+' times in '+dol_cat
      n_mult = n_mult + 1
   endif

   if nm gt 0 then namework = namework(m)

endwhile

if n_mult eq 0 then print,'No repeated names found.' else $
    print,stri(n_mult)+' cases of repeated names.'

print,'Checking source positions ...'

n_coin = 0
nm = 1
ra_work = ra_obj
dec_work = dec_obj
erad_work = err_rad
namework = name

while nm gt 0 do begin

   ; find cases where dist < err_rad1 + err_rad2
   ; or - equivalently : dist - err_rad2 < err_rad1

   dist = arcdist(ra_work(0), dec_work(0), ra_work, dec_work )
   if keyword_set(mindist) then begin
      w = where( dist lt mindist, nw, complement=m, ncompl=nm ) 
   endif else begin
      w = where( dist lt erad_work(0)+erad_work , nw, complement=m, ncompl=nm ) 
   endelse

   if nw gt 1 then begin
      n_coin = n_coin + 1
      print
      print,'Catalog source: '+namework(0)+' '+ $
         string(ra_work(0),dec_work(0),format='(2f8.3)')+' matches the position of'
      for j = 1, nw-1 do begin
         print,'                  '+namework(w(j))+' '+ $
            string(ra_work(w(j)),dec_work(w(j)),format='(2f8.3)')
      endfor
   endif

   if nm gt 0 then begin
      ra_work = ra_work(m)
      dec_work = dec_work(m)
      erad_work = erad_work(m)
      namework = namework(m)
   endif

endwhile

if n_coin eq 0 then print,'No coincident positions found.' else $
    print,stri(n_coin)+' coincidences of positions.'

end
