function cent2bds, array, log=log, bdslo=bdslo, bdshi=bdshi

; Return array with boundaries where the 'array' values are
; centers in the bins

;   NJW 2001-11-27
;   NJW 2005-11-15

if n_params() lt 1 then begin
   print,'Syntax: bds = cent2bds(array[,/log][,bdslo=][,bdshi=])'
   print,'  Keyword ''log'' forces ''logarithmic'' boundaries'
   print,'          ''bdslo'' returns low boundary limits'
   print,'          ''bdshi'' returns high boundary limits'
   return,-1
endif

n = n_elements(array)
res = fltarr(n+1)

if keyword_set(log) then begin
   res(1:n-1) = sqrt(array(0:n-2) * array(1:n-1))
   res(0) = res(1) / array(1) * array(0)
   res(n) = res(n-1) * array(n-1) / array(n-2)
endif else begin
   res(1:n-1) = 0.5*(array(0:n-2) + array(1:n-1))
   res(0) = res(1) - array(1) + array(0)
   res(n) = res(n-1) + array(n-1) - array(n-2)
endelse

bdslo = res(0:n-1)
bdshi = res(1:n)

return, res

end
