function centroide, array, xval, smo=smo, silent=silent, frac=frac
;
; Return centroide of distribution (should be peak shaped) in array
; Call : array   -  data
;      : xval - optional, if present x values
; Keyword 'silent' will suppress test output
; Keyword 'smo' will cause smoothing before calculation
; Keyword 'frac' is the fraction of the peak to where the data is used
;
if n_params() ne 2 then begin
   print,'Syntax: res = centroide( array, xval[,smo=][,/silent][,frac=])'
   return, -1.
endif

np = n_params()
b = array
length = n_elements(array)
if np lt 2 then xval = findgen(length)
if keyword_set(smo) then b = smooth(array,smo)
mm = max(b, index)
if keyword_set(frac) then c = mm*frac else c = mm*0.5
i = index
while (b(i) gt c) and (i gt 0 ) do i = i - 1
i1 = i
i = index
while (b(i) gt c) and (i lt length-1 ) do i = i + 1
i2 = i
if not keyword_set(silent) then begin
   print,'%CENTROIDE: peak between ', xval(i1), xval(i2)
endif

i = indgen(i2-i1+1) + i1
dx = xval(i) - xval(index)
return, xval(index) + total(dx*b(i))/total(b(i))
end
