function circ_area, dd, capr, r
;
; A function to calculate the overlap area between two circles
;
;  dd is an array giving distances between the two centers
;  capr is the radius of the (larger) circle
;  r    is the radius of the (smaller) circle
;
;  xcapr is the distance from the center of the larger circle
;        to the line between the two intersection points of the
;        two circles
;  xr    is equivalent to xcapr but referring to the smaller circle
;
;  acapr is the area of the larger circle inside the smaller circle
;  ar    is the area of the smaller circle inside the larger circle
;
;  Original version ~2000/NJW
;  2004-11-04/NJW updated to avoid crashes
;
; JEM-X parameters:
;
;* det_mask = 3385. ; mm
;* capr = 535./2
;* r    = 250./2

if n_params() ne 3 then begin
   print,'Syntax: area = circ_area( x_array, R, r )'
   return,-1
endif

; define area common to both circles

ndd = n_elements(dd)
area = replicate(!pi*r^2,ndd)

i2 = where(dd gt capr-r and dd lt capr+r, n2)
i3 = where(dd ge capr+r, n3)

if n2 gt 0 then begin

   d = dd(i2)
   xcapr = (capr^2 + d^2 - r^2)/(2.*d)
   t1 = !pi*capr^2/2
   t2 = capr^2 * asin(xcapr/capr)
   t3 = xcapr*sqrt(capr^2 - xcapr^2)
   xr = d - xcapr
   u1 = !pi*r^2/2
   u2 = r^2*asin(xr/r)
   u3 = xr * sqrt(r^2-xr^2)
   acapr = t1 - t2 - t3
   ar = u1 - u2 - u3
   area(i2) = ar + acapr

endif

if n3 gt 0 then area(i3) = 0

return, area

end
