function circ_area1, d, capr, r
;
; A function to calculate the overlap area between two circles
;
;  d is the distance between the two centers
;  capr is the radius of the (larger) circle
;  r    is the radius of the (smaller) circle
;
;  xcapr is the distance from the center of the larger circle
;        to the line between the two intersection points of the
;        two circles
;  xr    is equivalent to xcapr but referring to the smaller circle
;
;  acapr is the area of the larger circle inside the smaller circle
;  ar    is the area of the smaller circle inside the larger circle
;
; JEM-X parameters:
;
;* det_mask = 3385. ; mm
;* capr = 535./2
;* r    = 250./2

; define area common to both circles

if d gt capr+r then return, 0.
if d lt capr-r then return, !pi * r^2
   
xcapr = (capr^2 + d^2 - r^2)/(2.*d)
t1 = !pi*capr^2/2
t2 = capr^2 * asin(xcapr/capr)
t3 = xcapr*sqrt(capr^2 - xcapr^2)
xr = d - xcapr
u1 = !pi*r^2/2
u2 = r^2*asin(xr/r)
u3 = xr * sqrt(r^2-xr^2)
acapr = t1 - t2 - t3
ar = u1 - u2 - u3
a = ar+acapr
return, a
end
