function collbytq, v, g, peaksize
;
; Returns a byte array of same dimension as 'v' that
; must be a 2D byte array with '1' in a nonbroken
; area around the maximum in 'v'
; 'g' is the limit for a peak area
; 'peaksize' is the estimated box size to completely include a peak
;
sz = size(v)
if( sz(0) ne 2 ) then begin
   print,'collbyt: v is not 2D'
   return,-1
endif
nx = sz(1)
ny = sz(2)
m = bytarr(nx,ny)
mask = bytarr(6)
mask(0) = 14
mask(1) = 13
mask(2) = 11
mask(3) = 7
mask(4) = mask(0)
mask(5) = mask(1)
;
step = intarr(4,2)
step(0,*) = [1,0]
step(1,*) = [0,1]
step(2,*) = [-1,0]
step(3,*) = [0,-1]
;
mx = max(v,ij)
j = fix(ij/nx)
i = fix(ij - j*nx)
print,'Max of v : ',mx,' at (',i,',',j,')'
status = 0
if( mx le g ) then begin ; stop if there are no peaks
   print,'No more peaks - all values <= ',g
   return,-1
endif
;
; extract box around peak to speed up processing
;
corner = intarr(2)
bx = extrboxc(v,[i,j],[peaksize,peaksize],corner)
nx = peaksize
ny = peaksize
k = bytarr(nx,ny)
mbx = bytarr(nx,ny)
i = i - corner(0)
j = j - corner(1)
ij = nx * j + i
;
k(ij) = 15  ; All four directions: right,up,left,down, are possible
while( max(k,ij) gt 0.0 ) do begin ; continue as long as there are
                                  ; still possibilities
   j = fix(ij/nx)
   i = fix(ij - j*nx)
   if( i eq 0 ) then k(i,j) = k(i,j) and mask(2)
   if( i eq nx-1 ) then k(i,j) = k(i,j) and mask(0)
   if( j eq 0 ) then k(i,j) = k(i,j) and mask(3)
   if( j eq ny-1 ) then k(i,j) = k(i,j) and mask(1)
   ; print,'(i,j) = ', i, j
   mbx(i,j) = 1               ; pixel at (i,j) is included
   for idir = 0, 3 do begin ; search all directions
      ; print,'Start direction ', idir
      if( (k(i,j) and (not mask(idir) and 15)) gt 0 ) then begin
;                                         this direction is possible
         i1 = i + step(idir,0)
         j1 = j + step(idir,1)
         ; print,'Checking (i1,j1) = ', i1, j1
         if( k(i1,j1) gt 0 ) then begin ; I have been here already
            ; print,'I have been here ...'
            k(i,j) = k(i,j) and mask(idir)
            k(i1,j1) = k(i1,j1) and mask(idir+2)
         endif else begin      ; New pixel
            ; print,'New pixel ...'
            if( bx(i1,j1) gt g ) then begin ; to be included
               ; print,'is to be included'
               mbx(i1,j1) = 1
               k(i,j) = k(i,j) and mask(idir)
               k(i1,j1) = mask(idir+2)
            endif else begin   ; no more possibilities in this direction
               ; print,'Stop in this direction'
               k(i,j) = k(i,j) and mask(idir)
            endelse
         endelse
      endif
   endfor
endwhile
m(corner(0):corner(0)+peaksize-1,corner(1):corner(1)+peaksize-1) = mbx
return,m
end
