pro collect_dsp_spectra, source_path, njmx=njmx
;
;   Get several spectra combined from data jmxi_full_dsp.fits
;
;    2003-06-25/NJW, cloned from collect_spectra.pro
;

if n_params() lt 1 then begin
   print,'Syntax: collect_dsp_spectra, source_path[, njmx=]'
   print,'   source_path is a path under which all jmxi_full_dsp.fits files'
   print,'         can be found'
   print,'  Keyword   njmx   : JEMX instrument number (defaults to 2)'
   return
endif

numjemx = 2
if keyword_set(njmx) then numjemx = njmx
if numjemx ne 1 and numjemx ne 2 then begin
   print,'Illegal JEMX number'
   return
endif
snj = stri(numjemx)


print,'Start building list ..... (takes some time) .....'
spawn,'find '+source_path+' -name jmx'+snj+'_full_dsp.fits -print',list
; Avoid lines in 'list' that are not file names
p = strpos(list,'full_dsp')
w = where(p ge 0, nw)
if nw eq 0 then begin
   print,'No spectrum files found'
   return
endif
list = list(w)
nlist = nw
list = list(sort(list))

print,'-----------   files to be combined  -----------'
printl, list
print,'-----------        end of list      -----------'

ans = ''
read,'Do you wish to continue ? (y/n) ... ', ans
if strmid(ans,0,1) ne 'y' and strmid(ans,0,1) ne 'Y' then return

; Note if 'source_path' is absolute

first_char = strmid(source_path,0,1)

; Check presence of template spectral

if not file_test('jmx'+snj+'_coll_dsp.fits') then $
            spawn,'cp /home/njw/jemx/spectra/jmx'+snj+'_coll_dsp.fits .'

tot_spec = fltarr(256)
tot_err2 = fltarr(256)
tot_expo = 0.0

print,'Output logging data in ''collect_dsp_spectra.log'''
openw,lun,'collect_dsp_spectra.log',/get_lun

pick_swid_str, list, swidlist

for i = 0, nlist-1 do begin

   print,'Analyzing '+stri(i+1)+' of '+stri(nlist)
   printf,lun,'-------------------------------'
   printf,lun,list(i)
   rdfitscol,list(i)+'+1',exposure,'EXPOSURE',/sil

   tok = strsplit(list(i),'/',/extract)
   ntok = n_elements(tok)
   ; Find in which 'tok' the SWID is hidden
   jj = -1
   for j = 0, ntok-1 do begin
      if strlen(tok(j)) gt 12 then begin
         if strmid(tok(j),0,1) eq '0' and $
            strmid(tok(j),4,1) eq '0' and $
            strmid(tok(j),8,1) eq '0' then jj = j
      endif
   endfor

   ; Get the spectrum

   rdfitscol,list(i)+'+1',rate,'RATE',/sil
   rdfitscol,list(i)+'+1',stat_err,'STAT_ERR',/sil
   dataplot,findgen(256),rate(*,0),stat_err(*,0)

   if jj ge 0 then $
      xyouts,0.2,0.85,tok(jj),charsize=1.3,/norm
   xyouts,0.15,0.75,'Exposure '+string(exposure(0),format='(f5.0," s")'),charsize=1.3,/norm

   wait,1.


   tot_spec = tot_spec + reform(rate(*,0),256)*exposure(0)
   tot_err2 = tot_err2 + (reform(stat_err(*,0),256)*exposure(0))^2
   tot_expo = tot_expo + exposure(0)

endfor

free_lun,lun

tot_spec = tot_spec / tot_expo
tot_err  = sqrt(tot_err2) / tot_expo

dataplot,findgen(256),tot_spec,tot_err

;  Update standard file with collected spectrum

print,'New spectrum file: jmx'+snj+'_coll_dsp.fits'
fxbopen, unit, 'jmx'+snj+'_coll_dsp.fits', 1, access='RW'
fxbwrite, unit, float(tot_spec), 6, 1
fxbwrite, unit, float(tot_err), 7, 1
fxbfinish, unit

;  Update the checksum

spawn,'fchecksum jmx'+snj+'_coll_dsp.fits update=yes'



end
