pro collect_flxs, ref_sourceid, flx_path, timvals, fluxes, $
             flux_errors, ival=ival, silent=silent, numjemx=numjemx
;
;   Get IMA fluxes from data with time information
;
;    2004-02-05/JC (cloned from collect_lcs.pro)
;
if n_params() lt 5 then begin
   print,'Syntax: collect_flxs, ref_sourceid, flx_path, timvals, fluxes, $'
   print,'               flux_errors[,ival=][,numjemx=][,/silent]'
   print,'  keyword ''ival'' is energy interval starting with 0'
   print,'  keyword ''numjemx'' is JEM-X number (default is 2)'
   return
endif

if not keyword_setx(ival) then ival=0
vb = 1
if keyword_set(silent) then vb = 0

spawn,'find '+flx_path+' -name jmx1_srcl_res.fits -print',list
if getenv('USER') eq 'jerome' then list = list(1:*)

nlist = n_elements(list)
if nlist eq 0 then begin
   print,'No srcl_res files found'
   return
endif

first = 1

for i = 0, nlist-1 do begin

   if vb then print,'Searching'
   if vb then print,'    '+list(i)
   ; read the source identifications
   rdfitscol,list(i)+'+1',sourceid,'SOURCE_ID',/sil
   sourceid = strtrim(sourceid,2)
   ; locate the source
   w = where( sourceid eq ref_sourceid, n_w)
   if n_w ge 1 then begin
      if vb then print,ref_sourceid+' is present'
      j = w(0)
      
      ; Get the IJD
      hdr = headfits(list(i),ext=1)
      tstart = fxpar(hdr,'TSTART')
      tstop  = fxpar(hdr,'TSTOP')
      timval = 0.5*(tstart+tstop)
      if first then begin
         timvals = timval
      endif else begin
         timvals = [timvals, timval]
      endelse

      ; Get the flux etc.
      rdfitscol,list(i)+'+1',flux,'FLUX',/sil
      rdfitscol,list(i)+'+1',flux_error,'FLUX_ERR',/sil
      if first then begin
         fluxes = flux(ival,j)
         flux_errors = flux_error(ival,j)
         first = 0
      endif else begin
         fluxes = [fluxes,flux(ival,j)]
         flux_errors = [flux_errors,flux_error(ival,j)]
      endelse
   endif else begin
      print,'No '+ref_sourceid+' in these data!'
   endelse

endfor

is = sort(timvals)
timvals = timvals(is)
fluxes = fluxes(is)
flux_errors = flux_errors(is)


end
