pro collect_lcs, ref_sourceid, lc_path, timvals, rates, rate_errors, ival=ival, $
                 flist=flist, silent=silent
;
;   Get light curves from data
;
;    2003-03-24/NJW
;    2003-12-16/NJW Updated
;
if n_params() lt 5 then begin
   print,'Syntax: collect_lcs, ref_sourceid, lc_path, timvals, rates, $'
   print,'               rate_errors[,ival=][flist=][,/silent]'
   print,'  keyword ''ival'' is energy interval starting with 1'
   print,'  The keyword ''flist'' with a list (string array) will'
   print,'        override the given lc_path (2. argument)'
   return
endif

if not keyword_set(ival) then ival=1
vb = 1
if keyword_set(silent) then vb = 0

if keyword_set(flist) then list = flist else begin
   spawn,'find '+lc_path+' -name ''jmx?_src_lc.fits'' -print',list
   if getenv('USER') eq 'jerome' then list = list(1:*)
endelse

nlist = n_elements(list)
if nlist eq 0 then begin
   print,'No light curve files found'
   stop
endif else printl,list

first = 1

for i = 0, nlist-1 do begin

   if vb then print,'Searching'
   if vb then print,'    '+list(i)
   ; read the source identifications
   rdfitscol,list(i)+'+1',sourceid,'SOURCEID',/sil
   sourceid = strtrim(sourceid,2)
   ; locate the source
   w = where( sourceid eq ref_sourceid, n_w)
   if n_w ge 1 then begin
      if vb then print,ref_sourceid+' is present'
      j = w(ival-1) + 1
      ;ebm_get_num_children,list(i)+'+1',num_children
      ebm_get_child, list(i)+'+1', j, dol_lc

      ; Get the lightcurve

      rdfitscol,dol_lc,timval,'TIME',/sil
      rdfitscol,dol_lc,rate,'RATE',/sil
      rdfitscol,dol_lc,rate_error,'ERROR',/sil
      if first then begin
         timvals = timval
         rates = rate
         rate_errors = rate_error
         first = 0
      endif else begin
         timvals = [timvals,timval]
         rates = [rates,rate]
         rate_errors = [rate_errors,rate_error]
      endelse
   endif else begin
      print,'No '+ref_sourceid+' in these data!'
   endelse

endfor

is = sort(timvals)
timvals = timvals(is)
rates = rates(is)
rate_errors = rate_errors(is)


end
