pro colorshow, table=table, tcol=tcol
;
;  Display current colors
;   If keyword 'table' is given then this color table is loaded
;
; Load the color table if requested

if keyword_set(table) then loadct,table

ncol = !d.n_colors

; Define the text color; default is 255

text_color=255
if keyword_set(tcol) then text_color=tcol

if( !d.name eq 'X' ) then begin
   if !version.os eq 'linux' then begin
      window,0,xs=500,ys=600
   endif else begin
      window,0,xs=700,ys=1000
   endelse
endif
if( !d.name eq 'PS' ) then begin
   device,/color,xsize=17.,ysize=25.,yoffset=1.5,/portrait
   ncol = 30
endif


print,'The system supports '+strtrim(ncol,2)+' colors now'
if ncol gt 256 then begin
   print,'Reduced to 256'
   ncol = 256
endif

n_columns = (ncol-1)/32 + 1
n_rows = (ncol-1) / n_columns + 1

; inhibit drawing the axes
!x.style = 5
!y.style = 21
plot,[0.,1.],[0.,1.],/nodata
column_width = 0.8/n_columns
row_height = 0.8/n_rows
xv = column_width * 0.49 * [-1.,1.,1.,-1.,-1]
yv = row_height * 0.46 * [-1.,-1.,1.,1.,-1.]
c = 0
if keyword_set(table) then $
   xyouts,0.5,0.95,$
     string(table,format='("COLOR TABLE",i3)'),$
     color=text_color,size=2.5,alignment=0.5 $
   else xyouts,0.5,0.95,'CURRENT COLOR TABLE',$
     color=text_color,size=2.5,alignment=0.5
for column = 1L, n_columns do begin
   for row = 1L, n_rows do begin
      xc = 0.1 + (column-0.5)*column_width
      yc = 0.1 + (row-0.5)*row_height
      if c lt ncol then begin
         polyfill,xv+xc,yv+yc,color=c
         polyfill,0.3*xv+xc,0.4*yv+yc,color=0
         xyouts,xc,yc-0.1*row_height,$
            string(c,format='(i3)'),size=1.1,$
               alignment=0.5,color=text_color
      endif
      c = c + 1
   endfor
endfor
if( !d.name eq 'PS' ) then device,/close
end
