pro column_print, str_array, margin=margin, space=space, linelen=linelen
;
;   Print str_array in columns
;   str_array == [a,b,c,d,e,f,g]
;
;     a     d     f
;     b     e     g
;     c
;
;   2006-02-27/NJW
;
if n_params() lt 1 then begin
   print,'Syntax: column_print, str_array, margin=, space=, linelen='
   print,'   Defaults:  margin: 0,    space: 3,   linelen: 60'
   return
endif

if not keyword_setx(margin) then margin = 0
if not keyword_setx(space) then space = 3
if not keyword_set(linelen) then linelen = 60

n = n_elements(str_array)
maxlen = max(strlen(str_array)) + space

numcols = 1 > (linelen / maxlen)
numrows = ( n - 1 ) / numcols + 1

n_empty = numcols*numrows - n
last_row = intarr(numcols)
for i = 1, n_empty do last_row(numcols-i) = 1

ir = 0
ic = 0
arr = intarr(numrows, numcols) - 1

for i = 0, n-1 do begin
   arr(ir,ic) = i
   ir = ir + 1
   if ir gt numrows - 1 - last_row(ic) then begin
      ic = ic + 1
      ir = 0
   endif
endfor

for j = 0, numrows-1 do begin
   line = ' '
   for i = 0,linelen+maxlen+margin-2 do line = line + ' '
   for k = 0, numcols-1 do begin
      if arr(j,k) ge 0 then begin
         strput, line, str_array(arr(j,k)), margin+k*maxlen
      endif
   endfor
   print,strtrim(line)
endfor

end
