function comget,file,str,nval,int=int, long=long, dble=dble
;
; Reads an ASCII file 'file' searching for lines beginning with '//'
; followed by 'str' = xx.xx   e.g. :
;
;   // pressure = 1.3489e-11
;
;   IDL> pres = comget('myfile','pressure',nval)
;        returns an array of values where the keyword 'pressure'
;        is found. Returns a scalar if only one or zero values
;        are found
;
; Upon return 'nval' reports an error condition :
;   nval > 0   -> number of times found i.e. dimension of returned array
;   nval = 0  No such expression, returns -1.
;   nval = -1 File not found, returns -1.
;
;   2003-12-23/NJW (Updated; the function is much older)
;

if n_params() lt 3 then begin
   print,'Syntax: res = comget(file, str, nval[,/int /long /dble])'
   return, -1
endif

;  Check that the file exists

if not file_test(file,/reg) then begin
   nval = -1
   return, -1.0
endif

openr,lun,file,/get_lun
s = ' '
nval = 0
y = float(1.)
x = fltarr(1)
if keyword_set(int) then begin
   y = fix(1)
   x = intarr(1)
endif
if keyword_set(long) then begin
   y = long(1)
   x = lonarr(1)
endif
if keyword_set(dble) then begin
   y = double(1)
   x = dblarr(1)
endif

while not eof(lun) do begin
   readf,lun,s
   if( strmid(s,0,2) eq '//' ) then begin
      ; remove comment part
      cpos = strpos(s,';',2)
      if cpos gt 1 then s = strmid(s,0,cpos)

      pos = strpos(s,str,2) ; find position of search string
      if( pos ge 0 ) then begin    ; string has been found
         l = strlen(str)
         pe = strpos(s,'=',pos+l)
         if( pe ge 0 ) then begin  ; an equal sign has been found
            sb = strmid(s,2,pos-2)
            sa = strmid(s,pos+l,pe-pos-l)
            if strlen(strcompress(sa+sb,/r)) eq 0 then begin
               reads,strmid(s,pe+1,99),y
               if nval gt 0 then x = [x,y] else x(0) = y
               nval = nval + 1
            endif
         endif
      endif
   endif
endwhile
close,lun
free_lun,lun

if nval gt 0 then begin
   if nval gt 1 then return, x else return,x(0)
endif else return,-1

end
