function comput, file, str, new_arr, date=date
;
; Set up an ASCII file 'file' with lines beginning with '//'
; followed by 'str' (the keyword) = xx.xx   e.g. :
;
;   // pressure = 1.3489e-11
;
;   IDL> ierr = comput('myfile', 'pressure', new_arr)
;
; COMPUT returns the an error condition :
;   ierr > 0   -> number of times found i.e. dimension of returned array
;   ierr = 0  No such expression, returns -1.
;
if n_params() lt 3 then begin
   print,'Syntax: nput = COMPUT( file, keyword, new_arr[,/date])'
   return,-1
endif
sz = size(new_arr)
nn = n_elements(new_arr)

; open temporary file to store old keywords

openw,lunout,'####',/get_lun

file_exists = 0
on_ioerror, NO_FILE
openr,lunin,file,/get_lun
on_ioerror, NULL
file_exists = 1

; move old keywords to output file

line = ' '

repeat begin
   readf,lunin,line

   if strmid(line,0,2) eq '//' then begin
      printf,lunout,line
      remainder = 0
   endif else remainder = 1

endrep until eof(lunin) or remainder

; write new keyword(s) to output file

goto, CONTINUE
NO_FILE: print,'New file created : ', file
CONTINUE:

if keyword_set(date) then begin
   if nn gt 1 then st = 'lines' else st = 'line'
   printf,lunout,'//'
   printf,lunout,'// The '+st+' with keyword '+str+' added '+systime()
   printf,lunout,'//'
endif
for i = 0, nn-1 do printf,lunout,'// '+str+' = '+string(new_arr(i))

; move the rest of the input file to the output file

if file_exists then begin
   if remainder then begin
      printf,lunout,line
      while not eof(lunin) do begin
         readf,lunin,line
         printf,lunout,line
      endwhile
   endif
   close,lunin
   free_lun,lunin
endif

close,lunout
free_lun,lunout

; move #### file to input file

spawn,'mv #### '+file
return, nn
end
