function comreplace, file, str_keyw_in, new_arr
;
; Reads an ASCII file 'file' searching for lines beginning with '//'
; followed by 'str_keyw_in' = xx.xx   e.g. :
;
;   // pressure = 1.3489e-11
;
;   IDL> ierr = comreplace('myfile', 'pressure', new_arr)
;        replaces as many occurrences of keyword 'pressure' as there
;        are elements in 'new_arr' with these elements
;        returns an array of old values where the keyword 'pressure'
;        is found. Returns a scalar if only one or zero values
;        are found
;
; Upon return 'ierr' reports an error condition :
;   ierr > 0   -> number of times found i.e. dimension of returned array
;   ierr = 0  No such expression, returns -1.
;
if n_params() lt 3 then begin
   print,'Syntax: n = COMREPLACE(file,keyword,new_value(s))'
   return,-1.
endif
sz = size(new_arr)
nn = n_elements(new_arr)

strfile = read_slist(file,count=nlines)


s = ' '
ierr = 0

; go through input list searching for keyword occurrences

for lineno = 0L, nlines-1 do begin
   s = strtrim(strfile(lineno),2) ; get rid of leading and trailing blanks
   if( strmid(s,0,2) eq '//' and ierr lt nn ) then begin
      pos = strpos(s,str_keyw_in,2)
      if( pos ge 0 ) then begin    ; string has possibly been found
         pe = strpos(s,'=',pos+strlen(str_keyw_in))
         if( pe ge 0 ) then begin  ; an equal sign has been found
            str_keyw = strtrim(strmid(s,2,pe-2),2)
            if str_keyw eq str_keyw_in then begin
               strfile(lineno) = '// '+str_keyw_in+' = '+string(new_arr(ierr))
               ierr = ierr + 1
            endif
         endif
      endif
   endif
endfor

; write back to original file

write_slist, file, strfile


return, ierr
end
