pro cplot, filename, pr=pr, gv=gv, plstyle=plstyle, $
    det=det, sigma=sigma, ul=ul, value=value
;
; Show image in FITS file: filename in grey scale
; Assume standard coordinates in arcmin
; Keywords : pr        send to PS printer 'tek'
;            gv        display with ghostview
;            plstyle   a number that sets the plot-style
;            det       if set then detector image is assumed
;            sigma     gaussian convolution with sigma in pixels
;            ul        upper limit of image
;            value     (fraction) color of outside FOV regions
;

; Get number of colors in system

set_plot,'x'
window,30,xs=10,ys=10
plot,[0,1]
wdelete,30

ncolors = !d.n_colors
print,'Found ', ncolors,' colors'

im = readfits(filename,hdr)
szim = size(im)
if keyword_set(ul) then im = im < ul

; Convolve with Gaussian if requested

if keyword_set(sigma) then im = gauss_convol_2d(im,sigma,val='s',ks=10)
det_name = sxpar(hdr,'INSTRUME')
print,'Detector : ', det_name
to_ps = keyword_set(pr) or keyword_set(gv)
!p.position = [0.15,0.423,0.85,0.9]
if to_ps then begin
   print,'Setting plot device to PS'
   !p.font=0      ; set hardware fonts
   set_plot,'ps'
   device,xs=18.,ys=26.4,xoffset=1.5,yoffset=1.5,/portrait,/helvetica,/color
   imc = congrid(im,512,512)
endif else begin
   !p.font = -1   ; set normal fonts
   imc = congrid(im,420,420)
   window,xs=600,ys=880,/free
   ;* loadct,0
   to_ps = 0
   tv,replicate(ncolors-1,600,880)
endelse

sz = size(imc)
ix = sz(1)/2
iy = sz(2)/2
ir = min([ix,iy])
if keyword_set(value) then begin
   v = max(imc)*value
   imcc = circle(imc,ix,iy,ir,/blank,value=v)
endif else imcc = circle(imc,ix,iy,ir,/blank)

if not keyword_set(plstyle) then plstyle=1

case plstyle of
   1:   begin     ; Normal case
           imccp = bytscl(imcc,top=ncolors-2)
           f = 1.
        end
   2:   begin     ; wbstep/anticut
           imccp = wbstep(anticut(imcc),0.25)
           f = (ncolors-1)/255.
        end
   else : print,'Bad selection'
endcase
xrg = [-30.,30]
yrg = [-30.,30]
if keyword_set(det) then begin
   cdelt1 = sxpar(hdr,'CDELT1')
   cdelt2 = sxpar(hdr,'CDELT1')
   xrg = [-0.5,0.5]*szim(1)*cdelt1
   yrg = [-0.5,0.5]*szim(2)*cdelt2
endif
plot,[0,1],xr=xrg,yr=yrg,/noerase,color=0,/norm,/nodata
tv,imccp*f,$
     !x.window(0), !y.window(0),$
     xsize=!x.window(1)-!x.window(0),$
     ysize=!y.window(1)-!y.window(0),/norm
plot,[0,1],xr=xrg,yr=yrg,/noerase,color=0,/norm,/nodata
xyouts,.5,.95,'XSPECT simulation plot',color=0,/norm,$
       size=2,alignment=0.5
if keyword_set(det) then begin
   xyouts,.5,.91,'Detector Image',color=0,/norm,size=1.5,align=0.5
endif else begin
   xyouts,.48,.91,'N',color=0,/norm,size=1.7
   xyouts,.06,.65,'E',color=0,/norm,size=1.7
   xyouts,.87,.65,'W',color=0,/norm,size=1.7
endelse

; information lines

linpos = 0.35
linw   = 0.0225
xyouts,.15,linpos,'Unit of axes :',color=0,/norm
if keyword_set(det) then begin
   xyouts,.45,linpos,'mm',color=0,/norm
endif else begin
   xyouts,.45,linpos,'arcmin',color=0,/norm
endelse
linpos = linpos - linw
xyouts,.15,linpos,'Datafile : ',color=0,/norm
xyouts,.45,linpos,filename,color=0,/norm

; Center of field

;* ra_obj = ftg_keyw_e(filename,'RA_OBJ',nfound)
;* dec_obj = ftg_keyw_e(filename,'DEC_OBJ',nfound)
ra_obj = sxpar(hdr,'RA_OBJ')
dec_obj = sxpar(hdr,'DEC_OBJ')
radec,ra_obj,dec_obj,irh, irm, xrs, idd, idm, xds
ss = string(irh,irm,xrs,idd,idm,xds,format='(i3,i3,f5.1,i4,i4,f4.0)')
linpos = linpos - linw
xyouts,.15,linpos,'Center of field (J2000) :',color=0,/norm
xyouts,.45,linpos,ss,color=0,/norm

; Target source

linpos = linpos - linw
xyouts,.15,linpos,'Target source :',color=0,/norm
xyouts,.45,linpos,'NGC 12345678',color=0,/norm

; Observation dates

linpos = linpos - linw
xyouts,.15,linpos,'Observation dates :',color=0,/norm
date_obs = sxpar(hdr,'DATE-OBS')
xyouts,.45,linpos,date_obs,color=0,/norm

; Exposure time

;* tobs = ftg_keyw_e(filename,'LIVETIME',nfound)
tobs = sxpar(hdr,'LIVETIME',count=nfound)
if nfound lt 1 then tobs = sxpar(hdr,'XS-LIVTI',count=nfound)
if nfound lt 1 then tobs = -99.
ss = string(tobs,format='(f8.0," s")')
linpos = linpos - linw
xyouts,.15,linpos,'Exposure time :',color=0,/norm
xyouts,.45,linpos,ss,color=0,/norm

; Detector

linpos = linpos - linw
xyouts,.15,linpos,'Detector :',color=0,/norm
xyouts,.45,linpos,det_name,color=0,/norm

; Energy band - see if selection has been done

;* e1 = ftg_keyw_e(filename,'SELLO16',nfound)
e1 = sxpar(hdr,'SELLO16',count=nfound)
linpos = linpos - linw
if nfound eq 1 then begin
   e2 = sxpar(hdr,'SELHI16',count=nfound)
   xyouts,.15,linpos,'Energy band (keV) :',color=0,/norm
   xyouts,.45,linpos,string(e1,e2,format='(2f7.3," keV")'),color=0,/norm
endif else begin
   xyouts,.15,linpos,'No energy selection',color=0,/norm
endelse

; Date of plot

linpos = linpos - linw
xyouts,.15,linpos,'Date of plot :',color=0,/norm
xyouts,.45,linpos,systime(),color=0,/norm

; Convolution

linpos = linpos - linw
if keyword_set(sigma) then begin
xyouts,0.15,linpos,'Convolved, sigma :',color=0,/norm
xyouts,0.45,linpos,string(sigma,format='(f7.2," pixels")'),color=0,/norm
endif

if to_ps then begin
   device,/close
   if keyword_set(pr) then begin
      print,'Sending PS plot to ''tek'''
      spawn,'lpr -Ptek idl.ps'
   endif else begin
      print,'Start ghostview'
      spawn,'ghostview idl.ps &'
   endelse
   set_plot,'x'
   print,'Plot device is X again'
endif
end
