function create_line, e, sl, el, sigma
;
; Make a spectrum of lines given by arrays
; Returns the spectrum in ph /cm2 /s /keV
;
;  Call -  sl - line strength(s) in photons cm-2 s-1
;          el   line center(s) in keV
;        sigma  width(s) (=FWHM/2.355) in keV
;
;  2004-11-10/NJW, updated from much older version
;
n = n_elements(sl)
sq2 = sqrt(2.)
nen = n_elements(e)
ee = fltarr(nen)
ee(*) = e(*)
e = ee
f = e * 0.
eb = 0.5*(e + shift(e,1))
eb(0) = (3*e(0) - e(1))/2
eb = [eb,(3*e(nen-1) - e(nen-2))/2]
for i = 0, n-1 do begin
   j = where(e gt el(i)-5*sigma(i) and e lt el(i)+5*sigma(i))
   if( j(0) ne -1 ) then begin
      nj = n_elements(j)
      for k = 0, nj-1 do begin
         l = j(k)
         delta_e = eb(l+1) - eb(l)
         x2 = (eb(l+1) - el(i))/(sigma(i)*sq2)
         erx2 = erf(x2)
         x1 = (eb(l) - el(i))/(sigma(i)*sq2)
         erx1 = erf(x1)
         f(l) = f(l) + sl(i)*(erx2-erx1)/(delta_e*2)
      endfor
   endif
endfor
return,f
end
