pro curmark, result, data=data, normal=normal, device=device, npoints=npoints, $
             map=map, values=values, mfact=mfact, maxnum=maxnum, color=color, $
             silent=silent
;
;  Use cursor mark a number of points and return them in 'result'
;    X values : result(0,*)   Y values : result(1,*)
;
;  The coordinate system is specified with a keyword, (data, normal,
;      or device) - 'data' is default
;
;   Keyword 'npoints' returns the number of points (left mouse clicks)
;           'map'     is a 2D array displayed in the plot window
;           'values'  returns the map-values where clicked
;           'mfact'   is the image (map) magnification factor
;           'maxnum'  is the maximum number of points that can be returned
;                                     (default is 100)
;
sum = 0
if keyword_set(data) then sum = sum + 1
if keyword_set(normal) then sum = sum + 1
if keyword_set(device) then sum = sum + 1
if sum gt 1 then begin
   print,'%CURMARK: only one coordinate system can be specified'
   return
endif

if keyword_set(silent) then v = 0 else v = 1
if not keyword_set(color) then color = 0
if not keyword_set(maxnum) then maxnum = 100

; Setup array to hold the result

result = fltarr(2,maxnum)
np = 0
!err = 1

if keyword_set(map) then begin
   sz = size(map)
   maptype = sz(sz(0)+1)
   case maptype of
      2 : values = intarr(maxnum)
      3 : values = lonarr(maxnum)
      4 : values = fltarr(maxnum)
      5 : values = dblarr(maxnum)
    default : begin
              print,'Unacceptable type of map'
              return
              end
   endcase
endif


; annotation offset

dx = 0.01 / !x.s(1)
dy = 0.014 / !y.s(1)

if v then print,'Use left mouse button to indicate the next point ...'
if v then print,'Use right mouse button to terminate ...'

while !err ne 4 and np lt maxnum do begin
   if v then print,string(np+1,format='("Point no. ", i3," : ")')
   if sum eq 0 then begin ; No coordinate system keyword has been given
      cursor,xc,yc,/data
      xcdata = xc
      ycdata = yc
   endif else begin       ; Yes, a coordinate system keyword has been given
      if keyword_set(data) then begin
         cursor,xc,yc,/data
         xcdata = xc
         ycdata = yc
      endif
      if keyword_set(normal) then begin
         cursor,xc,yc,/normal
         res = convert_coord([xc,yc],/normal,/to_data)
         xcdata = res(0)
         ycdata = res(1)
      endif
      if keyword_set(device) then begin
         cursor,xc,yc,/device
         res = convert_coord([xc,yc],/device,/to_data)
         xcdata = res(0)
         ycdata = res(1)
         if keyword_set(mfact) then begin
            xc = xc / mfact
            yc = yc / mfact
         endif
         if keyword_set(map) then begin
            xcmap = xc
            ycmap = yc
            values(np) = map(xcmap,ycmap)
         endif
      endif
   endelse
   wait,0.3
   if !err ne 4 then begin
      if v then print,'                ', strtrim(xc,2), ' , ', strtrim(yc,2),$
      '   (',strtrim(xcdata,2),',',strtrim(ycdata,2),')'
      if keyword_set(map) and v then print,'   Value : ', values(np)
      oplot,[xcdata],[ycdata],psym=1,symsize=2,col=color
      fm = '(i1)'
      if( np gt 8 ) then fm = '(i2)'
      xyouts,xcdata+dx,ycdata+dy,string(np+1,format=fm),size=1.3,col=color
      result(0,np) = xc
      result(1,np) = yc
      np = np + 1
   endif else if v then print,'Leaving procedure CURMARK ...'
endwhile
npoints = np
if np gt 0 then begin
   result = result(*,0:np-1)
   if keyword_set(map) then values = values(0:np-1)
endif else begin
   result = 0.0
   if keyword_set(map) then values = 0.0
endelse

end
