pro curmpress, arr, filt_arr, npress
;
;  Takes 2xn array, removes the identical, contiguous
;  values. filt_arr is the result and npress
;  returns the number of identical values
;
;  Intended for marking the sources in a visual search
;  i.e. annotate a source with multiple clicks
;
;   2003-11-05/NJW
;
if n_params() ne 3 then begin
   print,'Syntax: curmpress, arr, filt_arr, npress'
   return
endif

sz = size(arr)
if sz(0) eq 0 then begin
   print,'%CURMPRESS: Scalar argument not accepted'
   return
endif
if sz(0) eq 1 then begin
   if n_elements(arr) ne 2 then begin
      print,'%CURMPRESS: Wrong argument dimension'
      return
   endif
   filt_arr = arr
   npress = intarr(1)+1
   return
endif
if sz(0) eq 2 then begin
   if sz(1) ne 2 then begin
      print,'Wrong argument dimension'
      return
   endif else begin
      n = sz(2)
      k = 0
      filt_arr = fltarr(2,1000)
      npress = intarr(1000) + 1

      for i = 0, n-1 do begin
         if i eq 0 then begin
            filt_arr(*,k) = arr(*,i)
            k = k + 1
         endif else begin
            if abs(arr(0,i) - arr(0,i-1)) gt 1.01 $
               or abs(arr(1,i) - arr(1,i-1)) gt 1.01 then begin
               filt_arr(*,k) = arr(*,i)
               k = k + 1
            endif else begin
               npress(k-1) = npress(k-1) + 1
            endelse
         endelse
      endfor
   endelse
endif

filt_arr = filt_arr(*,0:k-1)
npress = npress(0:k-1)

return
end
