pro dataplotf,x1,x,x2,y1,y,y2, xrange=xrg, yrange=yrg, psym=psym, itype=itype, _extra=e
;
; Lin-lin plot of datapoints with 'errorbars' in x-direction defined
; by start and stop arrays x1 and x2. Similarly
; in the y-direction the length of the error bars are given by
; lower and upper values y1 and y2
;
; The type of plot is indicated with the keyword 'itype'
;   itype = 0  :    x lin - y lin (default)
;   itype = 1  :    x lin - y log
;   itype = 2  :    x log - y lin
;   itype = 3  :    x log - y log
;
if( n_params() ne 6 ) then begin
   print,'dataplx, x1, x, x2, y1, y, y2[,keywords]'
   return
endif
nx = n_elements(x)
nx1 = n_elements(x1)
nx2 = n_elements(x2)
ny = n_elements(y)
ny1 = n_elements(y1)
ny2 = n_elements(y2)

; Check out of input

if( (nx ne nx1) or (nx ne nx2) or (nx ne ny) ) then begin
  print,'DATAPLOTF error: The arrays have different dimensions !'
  return
endif
if( (nx ne ny1) or (nx ne ny2) ) then begin
  print,'DATAPLOTF error: The arrays have different dimensions !'
  return
endif

; Set plot type

it = 0
if keyword_set(itype) then it = itype
xlog = 0
ylog = 0
if it gt 1 then xlog = 1
if (it mod 2) eq 1 then ylog = 1

iypos = where( y1 gt 0, n_iypos )

if not keyword_set(xrg) then begin
   if xlog then begin
      xmin = min(x1)^1.05 / max(x2)^0.05
      xmax = max(x2)^1.05 / min(x1)^0.05
   endif else begin
      xmin = min(x1) - 0.05 * (max(x2) - min(x1))
      xmax = max(x2) + 0.05 * (max(x2) - min(x1))
   endelse
   xrg = [xmin,xmax]
endif
if not keyword_set(yrg) then begin
   if ylog then begin
      if n_iypos gt 0 then begin
         ymin = min(y1(iypos))^1.05 / max(y2)^0.05
         ymax = max(y2)^1.05 / min(y1(iypos))^0.05
      endif else begin
         ymax = 1.3 * max(y2)
         ymin = 0.001 * ymax
      endelse
   endif else begin
      ymin = min(y1) - 0.05 * (max(y2) - min(y1))
      ymax = max(y2) + 0.05 * (max(y2) - min(y1))
   endelse
   yrg = [ymin,ymax]
endif

; Set up plot

if xlog then begin
   if ylog then begin 
      plot_oo,[1],[1],xr=xrg,yr=yrg,/nodata,_extra=e
   endif else begin
      plot_oi,[1],[1],xr=xrg,yr=yrg,/nodata,_extra=e
   endelse
endif else begin
   if ylog then begin 
      plot_io,[1],[1],xr=xrg,yr=yrg,/nodata,_extra=e
   endif else begin
      plot,[1],[1],xr=xrg,yr=yrg,/nodata,_extra=e
   endelse
endelse

; Do the plotting

for i = 0, nx-1 do begin
  oplot,[x1(i),x2(i)],[y(i),y(i)],_extra=e
  oplot,[x(i),x(i)],[y1(i),y2(i)],_extra=e
  if keyword_set(psym) then oplot,[x(i)],[y(i)],psym=psym,_extra=e
endfor
end
