pro dattim_sep, dattim, iyear, imonth, iday, ihour, iminute, fsecond
;
;  2003-01-27/NJW
;
;  Extract numbers from a (array of) date/time string (such as 2003-01-27T10:48:17) to
;
if n_params() ne 7 then begin
   print,'Syntax: dattim_sep, dattim, iyear, imonth, iday, ihour, iminute, fsecond'
   return
endif

first = 1

; Analyze input (array of) string(s) and check format

sz = size(dattim)
if sz(sz(0)+1) ne 7 then begin
   print,'1. argument is not of type string'
   return
endif
nelem = n_elements(dattim)

for i = 0, nelem-1 do begin

   curstr = strcompress(dattim(i),/remove_all)
   len = strlen(curstr)

   if len lt 13 then begin
      print,'#'+strtrim(i,2)+' '+dattim(i)+' invalid format (too short)'
      goto, next
   endif

;  Requirements   2002-11-16T23:45:56
;            or   2002-11-16T23:45
;            or   2002-11-16T23
;      One 'T', two '-'s

   ch = strmid(curstr,10,1)

   if ch ne 'T' then begin
      print,'#'+strtrim(i,2)+' '+dattim(i)+' invalid format (no ''T'' in pos 10)'
      goto, next
   endif

   ch = strmid(curstr,4,1)

   if ch ne '-' then begin
      print,'#'+strtrim(i,2)+' '+dattim(i)+' invalid format (no ''-'' in pos 4)'
      goto, next
   endif

   ch = strmid(curstr,7,1)

   if ch ne '-' then begin
      print,'#'+strtrim(i,2)+' '+dattim(i)+' invalid format (no ''-'' in pos 7)'
      goto, next
   endif

   year = strmid(curstr,0,4)

   if not is_digit(year) then begin
      print,'#'+strtrim(i,2)+' '+dattim(i)+' invalid format (year is not a number)'
      goto, next
   endif

   month = strmid(curstr,5,2)

   if not is_digit(month) then begin
      print,'#'+strtrim(i,2)+' '+dattim(i)+' invalid format (month is not a number)'
      goto, next
   endif

   day = strmid(curstr,8,2)

   if not is_digit(day) then begin
      print,'#'+strtrim(i,2)+' '+dattim(i)+' invalid format (day is not a number)'
      goto, next
   endif

   hour = strmid(curstr,11,2)

   if not is_digit(hour) then begin
      print,'#'+strtrim(i,2)+' '+dattim(i)+' invalid format (hour is not a number)'
      goto, next
   endif

   minute = '0'
   second = '0'

   if len ge 16 then begin ; The minute is given as well

      ch = strmid(curstr,13,1)
      if ch ne ':' then begin
         print,'#'+strtrim(i,2)+' '+dattim(i)+' invalid format (no '':'' in pos 13)'
         goto, next
      endif

      minute = strmid(curstr,14,2)

      if not is_digit(minute) then begin
         print,'#'+strtrim(i,2)+' '+dattim(i)+' invalid format (minute is not a number)'
         goto, next
      endif

      if len ge 19 then begin ; The second is given as well

         ch = strmid(curstr,16,1)
         if ch ne ':' then begin
            print,'#'+strtrim(i,2)+' '+dattim(i)+' invalid format (no '':'' in pos 13)'
            goto, next
         endif

         second = strmid(curstr,17,2)

         if not is_digit(second) then begin
            print,'#'+strtrim(i,2)+' '+dattim(i)+' invalid format (second is not a number)'
            goto, next
         endif

      endif

   endif

   if first then begin
      iyear = fix(year)
      imonth = fix(month)
      iday = fix(day)
      ihour = fix(hour)
      iminute = fix(minute)
      fsecond = float(second)
      first = 0
   endif else begin
      iyear = [iyear,fix(year)]
      imonth = [imonth,fix(month)]
      iday = [iday,fix(day)]
      ihour = [ihour,fix(hour)]
      iminute = [iminute,fix(minute)]
      fsecond = [fsecond,float(second)]
   endelse




   next:
endfor

end
