function dct_star, p, d
;
; Discrete Correlation Transform with star:
;   c_star = (1/M) * transpose(p-avg(p)) # (d-avg(d))
; where M is the number of datapoints (dimension of d)
;
; Li and Wu, 1994, Astroph. Space Sci. 215, 213.
;
;   p   is modulation function:  p # f = d   where
;   d   is measured data and f the object
;
sz = size(p)
if sz(0) ne 2 then begin
   print,'DCT: First argument must be 2D array'
   return, -1.
endif
m = n_elements(d)
if sz(1) ne m then begin
   print,'DCT: Number of rows in matrix must match size of vector'
   return, -1.
endif
a_prime = m * total(p*p,1) - total(p,1)^2
return, (m * transpose(p) # d - total(p,1) * total(d)) / a_prime
end
