function def_psf, dim, cntr, sigma
;
;  Define PSF for a square matrix. Functional shape is gaussian
;
;   2003-10-31/NJW
;
;   dim : matrix dimension (odd integer)
;   cntr : central position relative to midpoint of central pixel
;          with unit of a pixel (2-element float array)
;   sigma : sigma of gauss function (unit: pixel)
;
if n_params() lt 3 then begin
   print,'Syntax: psf = def_psf(dim, cntr, sigma)'
   return,-1
endif

if dim mod 2 ne 1 then begin
   print,'DEF_PSF error, dimension must be odd'
   return,-1
endif

if n_elements(cntr) ne 2 then begin
   print,'DEF_PSF error, ''cntr'' must be 2-element array'
   return,-1
endif

psf = fltarr(dim,dim)
ic = dim/2
for j = 0, dim-1 do begin
for i = 0, dim-1 do begin
   xlpe = i - ic - 0.5
   ylpe = j - ic - 0.5
   sum = 0.
   n = 0
   for y = 0.,1.0001,0.02 do begin
   for x = 0.,1.0001,0.02 do begin
      r = sqrt((xlpe + x - cntr(0))^2 + (ylpe + y -cntr(1))^2)
      v = exp(-0.5*(r/sigma)^2)
      sum = sum + v
      n = n + 1
   endfor
   endfor
   psf(i,j) = sum/n
endfor
endfor

return, psf

end
