pro disp_fits, filename_extno, image, pane=pane, cut=cut, surf=surf, $
               shad=shad, maxsiz=maxsiz, smo=smo
;
; Show image in FITS file: 'filename'
;
; If a third parameter is given, the image will be returned in that
;
;   Keywords :  (none)     gives ordinary tvscl
;               /cut    gives B/W display with wbstep(anticut)
;               /surf   gives surface representation
;               /shad   gives shade_surf representation
;             
if n_params() lt 1 then begin
   print,'Syntax: DISP_FITS, filename_extno [,>image], pane=, cut=, /surf, /shad,$'
   print,'                   maxsiz=, smo='
   retall
endif

; old version: fxread,filename,im

get_exten_no, filename_extno, filename, extno
im = readfits(filename, exten=extno)

; Return the image if the parameter has been given:
if n_params() ge 2 then image = im

sz = size(im)
if sz(0) ne 2 then begin
   print,'% DISP_FITS ERROR: Not a 2D image'
   retall
endif

ms = 800
if !version.os eq 'linux' then ms = 400
if keyword_set(maxsiz) then ms=maxsiz

md = max(sz(1:2))
fac = max([1, ms / md])
xd = fac * sz(1)
yd = fac * sz(2)
if keyword_set(shad) or keyword_set(surf) then begin
   xd = 600
   yd = 500
endif
pan = 0
if keyword_set(pane) then pan=pane

xscreen_size = 1300
yscreen_size = 1050
if !version.os eq 'linux' then begin
   xscreen_size = 1015
   yscreen_size = 740
endif
if !version.os eq 'Win32' then begin
   xscreen_size = 850
   yscreen_size = 600
endif


xposition = 0
if pan mod 2 eq 0 then xposition = xscreen_size - xd
if keyword_set(xpos) then xposition = xpos

yposition = yscreen_size - yd
if keyword_set(ypos) then yposition = ypos


window,pan,xs=xd,ys=yd,title=filename+string(fac,format='(" x",i3)'),$
       xp=xposition,yp=yposition

; Smooth if required

ims = im
if keyword_set(smo) then ims = smooth(1.0*im,smo,/edge)

if fac gt 1 then imc = congrid(ims,xd,yd) else imc = ims

nkeys = 0
if keyword_set(cut) then nkeys = nkeys + 1
if keyword_set(surf) then nkeys = nkeys + 1
if keyword_set(shad) then nkeys = nkeys + 1
if nkeys gt 1 then begin
   print,'% DISP_FITS ERROR: Only 1 keyword can be given'
   retall
endif
if nkeys eq 1 then begin
   if keyword_set(cut) then begin
      loadct,0
      tv,wbstep(anticut(imc),0.25)
   endif
   if keyword_set(surf) then surface,ims
   if keyword_set(shad) then shade_surf,ims
endif else tvscl, imc
end
