function dist2image,r,sb,npix=npix,rmax=rmax
;
; Make an image from a surface brightness distribution
;
;   Call:    r     Radii of annuli
;           sb     Surface brightness in each annulus
;
; Return:   image of distribution
;
;  Keywords:   npix  Number of pixels in image
;              rmax  Maximum radius
;
nr = n_elements(r)
print,'nr = ', nr
nsb = n_elements(sb)

;... Check for number of elements

if nr ne nsb+1 then begin
   print,'DIST2IMAGE: Size of arguments do not match'
   retall
endif

;... Get maximum of radius if not given

if keyword_set(rmax) then begin
   rmx = rmax
endif else begin
   print,'Max. radius in input: ', max(r)
   rmx = 0.0
   read,'Enter max. radius in image : ', rmx
endelse

;... Get number of pixels if not already given

if keyword_set(npix) then begin
   dim = npix
endif else begin
   dim = 0
   read,'Enter number of pixels : ', dim
endelse

image = fltarr(dim,dim)
p = 2. * rmx / dim
d2 = dim/2
; Conversion to (x,y) depends on whether dim is even or odd
extra = float(1 - dim + d2*2)/2.0

for i = 0, dim-1 do begin
   for j = 0, dim-1 do begin
      x = (i - d2 + extra)*p
      y = (j - d2 + extra)*p
      rad = sqrt(x^2 + y^2)
      if rad ge r(nr-1) then begin
         ;* print,i,j,x,y,rad,' Outside'
      endif else begin
         k = nr-1
         while rad lt r(k) and k gt 0 do k = k - 1
         ;* print,i,j,x,y,rad,k,sb(k)
         if k lt 0 or k ge nsb then begin
            print,'i,j,x,y,rad,k = ', i,j,x,y,rad,k
         endif else begin
            image(i,j) = sb(k)
         endelse
      endelse
   endfor
endfor
return,image
end
