pro distribute_cpu, process, argument_list
;
; Procedure to distribute a number of similar processes on
; the least used machines
;
; 'process' is a scalar string with process name
;
; 'argument_list' is a string array where each element is the
;                 argument string for a particular case of the process.
;                 The number of elements is also the number of
;                 times the process will be run.

n_arg = n_elements(argument_list) ; number of cases (jobs) to run
mach_list = strarr(n_arg)         ; list of machines assigned 
pid_list  = intarr(n_arg)         ; Process ID numbers
host = getenv('HOST')             ; Name of host machine

; Get last bit of process string i.e. 'program'
; in stead of '/user/local/special/program'

tok = reverse(str_sep(process,'/'))
short = tok(0)

machine = free_machines()
n_mach = n_elements(machine)

; Determine the number of rounds if there are requested
; more processes than there are available machines

n_rounds = fix((n_arg-1)/n_mach) + 1
remaining = n_arg

i_arg = 0
for i_round = 1, n_rounds do begin  ; Loop over rounds
   print,'************** Starting round ', i_round
   limit = min([remaining,n_mach])
   print,'remaining, n_mach, limit = ',remaining, n_mach, limit

   i_arg0 = i_arg

   for i_mach = 0, limit-1 do begin ; Loop over machines

      ; Initiate process on that machine
      mach_list(i_arg) = machine(i_mach)
      print,'Start process on ', machine(i_mach)
      if host eq machine(i_mach) then spawn,'nice '+process+$
                               ' '+argument_list(i_arg)+' &'$
           else spawn,'rsh '+machine(i_mach)+' nice '$
                       +process+' '+argument_list(i_arg)+' &'

      wait, 1.
      pid = get_pid(short,machine(i_mach))
      if pid eq -1 then begin
         print,'Problem starting process on ',machine(i_mach)
         print,' i_mach = ', i_mach
         retall
      endif
      pid_list(i_arg) = pid
      i_arg = i_arg + 1

   endfor   ; Now a batch has been started

   max_pid = 99999
   while max_pid gt 0 do begin  ; if true there is still one running
      wait,2.
      max_pid = -1
      for i_mach = 0, limit-1 do begin
         pid = get_pid(short,machine(i_mach))
         if pid gt 0 then begin
            if pid ne pid_list(i_arg0+i_mach) then begin
               print,'Process runs on '+machine(i_mach)+$
                     ' but with mismatching PID'
               pid = -1
            endif else begin
               print,process,' still running on ', machine(i_mach)
            endelse
         endif
         if pid gt max_pid then max_pid = pid
      endfor
   endwhile

   remaining = remaining - limit
endfor

end
