pro dither_around_pointing, coord1, coord2, roll_deg, gal=gal, patt=patt
;
; Procedure to produce dithering pointings around direction
; The result is written to file 'dither.output'
;
;   NJW/2002-01-16, based upon 'dither.pro'
;

if n_params() lt 3 then begin
   print,'Syntax: dither_around_pointing, coord1, coord2, roll_deg[,gal=gal][,patt=]'
   print,'   Coordinates in decimal degrees and in RA,DEC unless keyword gal is given'
   return
endif

dr = 0.0174533  ; degrees to radians

mode = 1
if keyword_set(patt) then mode = patt
if mode ne 1 and mode ne 2 then begin
   print,'Pattern must be 1 or 2'
   return
endif

; Define dithering pattern according to case

if mode eq 1 then begin
   az = findgen(6)*60*dr
   xdith = 2*dr*cos(az)
   ydith = 2*dr*sin(az)
   xdith = [0., xdith]
   ydith = [0., ydith]
endif

if mode eq 2 then begin
   xdith = xlingen(5,-2,2)
   xdith = [xdith,xdith,xdith,xdith,xdith]
   ydith = [replicate(-2.,5),replicate(-1.,5),$
            replicate( 0.0,5),replicate(1.0,5),replicate(2.0,5)]
   xdith = 2*dr*xdith
   ydith = 2*dr*ydith
endif
ndith = n_elements(xdith)

openw,lun,'dither.output',/get_lun

printf,lun,'//'
printf,lun,'//          '+systime()
printf,lun,'// ndith = ', ndith
printf,lun,'//'
printf,lun,'// coordsys = celestial'
printf,lun,'//'


if keyword_set(gal) then begin
   long = coord1
   lat = coord2
endif else begin
   glactc,coord1/15.,coord2,2000,long,lat,1
endelse

; Pointing position

glactc,r,d,2000,long,lat,2

ra_xd =  r*15.        ; degrees
dc_xd =  d            ; degrees
ra_x  = ra_xd * dr    ; radians
dc_x  = dc_xd * dr    ; radians
print,'Pointing in gal.coord : ', long, lat
printf,lun,'// pointing_gal  ', long, lat
printf,lun,'// pointing_cel  ', ra_xd, dc_xd
printf,lun,'// pointing_cel ', adstring(ra_xd, dc_xd)
printf,lun,'// roll_angle_deg ', roll_deg

teta_deg = roll_deg
teta = teta_deg * dr  ; radians - Roll Angle

;... reproduce effect of 'sky2fov'

;* print,'RA Dec x-sc'
;* print,ra_x/dr, dc_x/dr

; RA and Dec of two other axes: y and z

   ra_y = ra_x - atan(sin(teta), -sin(dc_x)*cos(teta))
   if ra_y lt 0. then ra_y = ra_y + 2*!pi
   dc_y = asin(cos(dc_x)*cos(teta))
;* print,'RA Dec y-sc'
;* print,ra_y/dr, dc_y/dr

   ra_z = ra_x - atan(cos(teta), sin(dc_x)*sin(teta))
   if ra_z lt 0. then ra_z = ra_z + 2*!pi
   dc_z = -asin(cos(dc_x)*sin(teta))
;* print,'RA Dec z-sc'
;* print,ra_z/dr, dc_z/dr

; Derive roll angle: teta

   teta_der = -atan(sin(dc_z), sin(dc_y))
;* print,'You got roll = ', teta_der/dr
;* print

; Pointing in EQ system

   x_eq = [cos(ra_x)*cos(dc_x), sin(ra_x)*cos(dc_x), sin(dc_x)]

; S/C Y-axis direction in EQ system

   y_eq = [sin(ra_x)*sin(teta)-sin(dc_x)*cos(ra_x)*cos(teta),$
        -cos(ra_x)*sin(teta)-sin(dc_x)*sin(ra_x)*cos(teta),$
        cos(dc_x)*cos(teta)]

; S/C Z-axis direction in EQ system

   z_eq = [sin(ra_x)*cos(teta)+sin(dc_x)*cos(ra_x)*sin(teta),$
        -cos(ra_x)*cos(teta)+sin(dc_x)*sin(ra_x)*sin(teta),$
        -cos(dc_x)*sin(teta)]

; Define transformation matrix

   omega = fltarr(3,3)
   omega(*,0) = x_eq
   omega(*,1) = y_eq
   omega(*,2) = z_eq

;* agemo = invert(omega)

   x_sc = [1.,0.0, 0.0]

   dit_th = fltarr(3,3)
   dit_az = fltarr(3,3)


; print,x_eq
; print,y_eq
; print,z_eq

; Go through dithering directions

for i = 0, ndith-1 do begin

   az = atan(ydith(i),xdith(i))
   th = sqrt(xdith(i)^2 + ydith(i)^2)

   ;print,'Dithering az = ', az,' deg'
   ;print,'Dithering th = ', th/dr,' deg'


   dit_th(1,1) = 1.
   dit_th(0,0) =  cos(th)
   dit_th(0,2) = -sin(th)
   dit_th(2,0) =  sin(th)
   dit_th(2,2) =  cos(th)
   dit_az(0,0) = 1.
   dit_az(1,1) =  cos(az)
   dit_az(1,2) = -sin(az)
   dit_az(2,1) =  sin(az)
   dit_az(2,2) =  cos(az)

   s_dit = omega # dit_az # (dit_th # x_sc)
   ra_s = atan(s_dit(1), s_dit(0))
   if ra_s lt 0 then ra_s = ra_s + 2*!pi
   ra_sd = ra_s / dr
   dc_s = asin(s_dit(2))
   dc_sd = dc_s / dr
   ;print,'Dithering position : ', ra_sd, dc_sd
   ;printf,lun,adstring(ra_sd, dc_sd)
   printf,lun,ra_sd, dc_sd

endfor


free_lun,lun
end
