pro dom2dattim, year, month, day_of_month, dattim
;
;  Convert Day-Of-Month to string  YYYY-MM-DDTHH:MM:SS
;   (to get IJD one can use  dattim2ijd conversion )
;
;  'year' and 'month' can either be scalars or arrays with the
;  same length as 'day_of_month'
;
;  if 50 <= year < 100 then year = year + 1900
;  if 0 <= year < 100 then year = year + 2000
;
;   2005-09-06/NJW
;
if n_params() lt 4 then begin
   print,'Syntax: dom2dattim, year, month, day_of_month, dattim'
   return
endif

dom = float(day_of_month)
iyear = fix(year)
imonth = fix(month)

ndom = n_elements(dom)
if ndom gt 1 then begin
   ; if not already in place then create arrays of same size as 'day_of_month'
   nyear = n_elements(iyear)
   if nyear ne 1 and nyear ne ndom then begin
      print,'''year'' must be a scalar or have same dimension as ''day_of_month'''
      return
   endif
   if nyear eq 1 then iyear = replicate( iyear, ndom)
   nmonth = n_elements(imonth)
   if nmonth ne 1 and nmonth ne ndom then begin
      print,'''month'' must be a scalar or have same dimension as ''day_of_month'''
      return
   endif
   if nmonth eq 1 then imonth = replicate( imonth, ndom)
endif

dattim = strarr(ndom)

for i = 0L, ndom-1 do begin
   kyear = iyear(i)
   if 50 le kyear and kyear lt 100 then kyear = kyear + 1900
   if  0 le kyear and kyear lt  50 then kyear = kyear + 2000
   str_year = string(kyear,format='(i4)')

   str_month = string( imonth(i), format='(i2.2)')

   iday = fix(dom(i))
   frac = (dom(i) - iday)*24.0
   hour = fix(frac)
   frac = (frac - hour)*60.0
   minute = fix(frac)
   frac = (frac - minute)*60.0
   second = fix(frac)

   str_day = string(iday,format='(i2.2)')
   str_hour = string(hour,format='(i2.2)')
   str_minute = string(minute,format='(i2.2)')
   str_second = string(second,format='(i2.2)')

   dattim(i) = str_year+'-'+str_month+'-'+str_day+'T'+str_hour+':'+str_minute+':'+str_second
endfor

end
