pro draw_arrow, x0, y0, x1, y1, sw, hw, hl
;
;    NJW/2002-08-30
;
if n_params() lt 7 then begin
   print,'Syntax: draw_arrow, x0, y0, x1, y1, sw, hw, hl'
   print,'  (x0,y0) start point in data coordinates'
   print,'  (x1,y1) end   point in data coordinates'
   print,'  sw   width of stem in normalized coordinates'
   print,'  hw   width of arrow head in normalized coordinates'
   print,'  hl   length of arrow head in normalized coordinates'
   return
endif

; find the aspect ratio:  ysize / xsize

devsz = convert_coord(1,1,/norm,/to_device)
aspect = devsz(1) / devsz(0)

; get start/end coordinates in normalized coordinates

p0norm = convert_coord(x0,y0,/to_normal)
p1norm = convert_coord(x1,y1,/to_normal)
p0norm(1) = p0norm(1) * aspect
p1norm(1) = p1norm(1) * aspect

length = sqrt((p0norm(0)-p1norm(0))^2 + (p0norm(1)-p1norm(1))^2)

om = atan(p1norm(0)-p0norm(0), p1norm(1)-p0norm(1))
omega = [[cos(om),-sin(om)],[sin(om),cos(om)]]

x_arrow_norm = [-sw/2,sw/2,sw/2,hw/2,0,-hw/2,-sw/2,-sw/2]
y_arrow_norm = [0,0,length-hl,length-hl,length,length-hl,length-hl,0]

arrow_norm = fltarr(2,n_elements(x_arrow_norm))
arrow_norm(0,*) = x_arrow_norm
arrow_norm(1,*) = y_arrow_norm

arrow_tilt = omega # arrow_norm
arrow_tilt(0,*) = arrow_tilt(0,*) + p0norm(0)
arrow_tilt(1,*) = arrow_tilt(1,*) + p0norm(1)

arrow_data = convert_coord(arrow_tilt(0,*),arrow_tilt(1,*)/aspect,/normal,/to_data)

oplot,arrow_data(0,*),arrow_data(1,*)

end

