pro dump_dsri_source, serial_no, reset=reset, flash=flash
;
;  Write a file with the contents of source from DSRI_CAT.fits
;
;  Define structure to hold all source information

common dump_com, cat, numrows

source = {   sourcename:'', ra:0.0, dec:0.0, nh:0.0, intenscode:'', $
             spectrcode:'', intens:0.0, param1:0.0, param2:0.0, serial:0L, $
             refernce:0, catalog:'', category:'', inbook:0}

if n_params() ne 1 then begin
   print,'Syntax: dump_dsri_source, serial_no[,rest=][,flash=]'
   return
endif

file_dsri_cat = '/home/njw/jsim/Catalogs/DSRI_CAT.fits[1]'
file_dsri_cat_flux = '/home/njw/jsim/Catalogs/DSRI_CAT_FLUX.fits[1]'
file_dsri_cat_ref = '/home/njw/jsim/Catalogs/DSRI_CAT_REF.fits[1]'
file_dsri_cat_iden = '/home/njw/jsim/Catalogs/DSRI_CAT_IDEN.fits[1]'


   ; Read the contents of 'DSRI_CAT.fits'
sz = size(cat)
if sz(0)+sz(1) eq 0 or keyword_set(reset) then begin  
errmsg = ''
rdfitscol,file_dsri_cat,sourcename,'SOURCENAME',err=errmsg
rdfitscol,file_dsri_cat,ra,'RA',err=errmsg
rdfitscol,file_dsri_cat,dec,'DEC',err=errmsg
rdfitscol,file_dsri_cat,nh,'NH',err=errmsg
rdfitscol,file_dsri_cat,intenscode,'INTENSCODE',err=errmsg
rdfitscol,file_dsri_cat,spectrcode,'SPECTRCODE',err=errmsg
rdfitscol,file_dsri_cat,intens,'INTENS',err=errmsg
rdfitscol,file_dsri_cat,param1,'PARAM1',err=errmsg
rdfitscol,file_dsri_cat,param2,'PARAM2',err=errmsg
rdfitscol,file_dsri_cat,serial,'SERIAL',err=errmsg
rdfitscol,file_dsri_cat,refernce,'REFERNCE',err=errmsg
rdfitscol,file_dsri_cat,catalog,'CATALOG',err=errmsg
rdfitscol,file_dsri_cat,category,'CATEGORY',err=errmsg
rdfitscol,file_dsri_cat,inbook,'INBOOK',err=errmsg
   
if errmsg ne '' then begin
   print,errmsg
   return
endif
   
numrows = n_elements(ra)

cat = replicate(source, numrows)
for i = 0, numrows-1 do begin
   cat(i).sourcename = sourcename(i)
   cat(i).ra = ra(i)
   cat(i).dec = dec(i)
   cat(i).nh = nh(i)
   cat(i).intenscode = intenscode(i)
   cat(i).spectrcode = spectrcode(i)
   cat(i).intens = intens(i)
   cat(i).param1 = param1(i)
   cat(i).param2 = param2(i)
   cat(i).serial = serial(i)
   cat(i).refernce = refernce(i)
   cat(i).catalog = catalog(i)
   cat(i).category = category(i)
   cat(i).inbook = inbook(i)
endfor
   
endif

serial = long(serial_no)

index = where( cat.serial eq serial, n_index)

if n_index ne 1 then begin
   print,'There are ', n_index,' sources matching serial number'
   return
endif

i = index(0)

if keyword_set(flash) then begin

   flash_src, cat(i), 0

endif else begin

   openw,lun,'src_no_'+strtrim(serial,2)+'.dat',/get_lun
   print
   print,'The output will be written to: ','src_no_'+strtrim(serial,2)+'.dat'
   print
   
   printf,lun,'//'
   printf,lun,'//       '+systime()
   printf,lun,'//'
   printf,lun,'// sourcename = ', cat(i).sourcename
   printf,lun,'// ra = ', cat(i).ra
   printf,lun,'// dec = ', cat(i).dec
   printf,lun,'// nh = ', cat(i).nh
   printf,lun,'// intenscode = ', cat(i).intenscode
   printf,lun,'// spectrcode = ', cat(i).spectrcode
   printf,lun,'// intens = ', cat(i).intens
   printf,lun,'// param1 = ', cat(i).param1
   printf,lun,'// param2 = ', cat(i).param2
   printf,lun,'// serial = ', cat(i).serial
   printf,lun,'// refernce = ', cat(i).refernce
   printf,lun,'// catalog = ', cat(i).catalog
   printf,lun,'// category = ', cat(i).category
   printf,lun,'// inbook = ', cat(i).inbook
   
   free_lun,lun
   
   print,'// sourcename = ', cat(i).sourcename
   print,'// ra = ', cat(i).ra
   print,'// dec = ', cat(i).dec
   print,'// nh = ', cat(i).nh
   print,'// intenscode = ', cat(i).intenscode
   print,'// spectrcode = ', cat(i).spectrcode
   print,'// intens = ', cat(i).intens
   print,'// param1 = ', cat(i).param1
   print,'// param2 = ', cat(i).param2
   print,'// serial = ', cat(i).serial
   print,'// refernce = ', cat(i).refernce
   print,'// catalog = ', cat(i).catalog
   print,'// category = ', cat(i).category
   print,'// inbook = ', cat(i).inbook

endelse
end
