pro duplot, x, y1, y2, share, ps1=ps1, ps2=ps2, yr1=yr1, yr2=yr2, $
     title=title, ytit1=ytit1, ytit2=ytit2,xtit=xtit
;
;  Plot two frames with common x-axis
;
;    2005-09-08/NJW
;
if n_params() ne 4 then begin
   print,'Syntax: duplot, x, y1, y2, share[, ps1=][, ps2=] $'
   print,'  [,yr1=][, yr2=][, title=][, ytit1=][, ytit2=][, xtit=]'
   print,'  ''share'' is the fraction of the plot window occupied by the upper plot'
   print,' y1 and y2 can be 2D arrays, where the first dimension must match'
   print,' the dimension of x. In that case y1(*,1 etc) will be shown as overplot'
   print,' Use e.g.  ynew = [[y1old],[y2old],[  ],...]'
   return
endif

!p.multi = [0,1,2]
maxx = max(x)
minx = min(x)
xwidth = maxx - minx
!x.range = [minx-0.05*xwidth,maxx+0.05*xwidth]

normxlow = 0.1
normxhigh = 0.95
normylow = 0.1
normyhigh = 0.95
yboarder = normyhigh - share*(normyhigh-normylow)
!p.position = [normxlow,yboarder,normxhigh,normyhigh]
nopl = 0 ; Number of overplots
sz = size(y1)
if sz(0) eq 2 then begin
   z = y1(*,0)
   nopl = sz(2)
   if keyword_set(ps1) then begin
      if n_elements(ps1) ne sz(2) then begin
         print,'Size of ps1 must match 2. dim of y1'
         return
      endif
      zps1 = ps1(0)
   endif
endif else begin
   z = y1
   if keyword_set(ps1) then zps1 = ps1
endelse
print,'--> nopl = ', nopl
plot,x,z,ps=zps1,yr=yr1,xstyle=7,title=title,ytit=ytit1
if nopl gt 1 then begin
   for i = 1, nopl-1 do begin
      if keyword_set(ps1) then oplot,x,y1(*,i),ps=ps1(i) $
             else oplot,x,y1(*,i)
   endfor
endif
axis,xaxis=1,xtickname=replicate(' ',60)
axis,xaxis=0,xtickname=replicate(' ',60)

; The scond plot

!p.position = [normxlow,normylow,normxhigh,yboarder]
plot,x,y2,ps=ps2,yr=yr2,ytit=ytit2, xtit=xtit

; reset

!p.multi = 0
!p.position = 0

end
