pro ebm_get_all_idxmembers, dol_of_og, swg_no, idx_name, $
               arr_file_extno, errmsg, count=count
;
; Get array of files with extension number of and idx member 
;
; Explanation:   *  signals a grouping table
;                #  signals a DS with no children
;
;    DOL_OG*
;       |
;       +--- DOL_SWG_IDX*
;                   |
;                   +--- DOL_SWG(1)*
;                            |
;                            +--- DOL_XXX_IDX*
;                            |        |
;                            |        +--- DOL_XXX_MEM#
;                            |        +--- DOL_XXX_MEM#
;                            | 
;                            +--- DOL_YYY_IDX*
;                            |        |
;                            |        +--- DOL_YYY_MEM#
;                            |        +--- DOL_YYY_MEM#
;  Call:  

num_params = n_params()
if num_params lt 4 then begin
   print,'Syntax: ebm_get_all_idxmembers, dol_of_og, swg_no, idx_name, $'
   print,'             arr_file_extno[, errmsg]'
   return
endif

; Open the monitor output file

openw,lun,'trace.out', /get_lun


printf,lun,'OG: ',dol_of_og

; Get DOL of SWG IDX; The only GROUPING-member of the OG is the SWG_IDX

ebm_get_child_by_name, dol_of_og, 'GROUPING', swg_idx_file_extno, errmsg
if errmsg ne '' then begin
   print,'##3## EBM_GET_CHILD error: ',errmsg
   return
endif

printf,lun,'SWG IDX: ',swg_idx_file_extno

; Get number of SWGs

ebm_get_num_children, swg_idx_file_extno, n_swg, errmsg
if errmsg ne '' then begin
   print,'##3## EBM_GET_NUM_CHILDREN error: ',errmsg
   return
endif

if n_swg lt swg_no then begin
   print,'##3## The requested SWG number does not exist'
   errmsg = 'The requested SWG number does not exist'
   return
endif

; Get DOL of SWG#'swg_no'

ebm_get_child, swg_idx_file_extno, swg_no, swg_file_extno, errmsg
if errmsg ne '' then begin
   print,'##3## EBM_GET_CHILD error: ',errmsg
   return
endif

printf,lun,'SWG : ',swg_file_extno

; Get number of children in the chosen SWG

ebm_get_num_children,swg_file_extno, n_children, errmsg
if errmsg ne '' then begin
   print,'##3## EBM_GET_NUM_CHILDREN error: ',errmsg
   return
endif

printf,lun,strtrim(n_children,2),' children in SWG#', strtrim(swg_no,2)

arr_file_extno = ''



if n_children gt 0 then begin




; Get DOLs of all children

rdfitscol,swg_file_extno,memnam,2,hdr=hdr_swg,/silent
rdfitscol,swg_file_extno,mempos,4,/silent
rdfitscol,swg_file_extno,memloc,5,/silent


; 1) Search for IDX = 'idx_name'. Find the ones that refer to grouping tables

res = where(strtrim(memnam,2) eq 'GROUPING', n_res)

printf,lun,strtrim(n_res,2),' of these are of type ''GROUPING'''

index = 0
found = 0
while index lt n_res and not found do begin

   ; Get the index table itself

   ebm_get_child, swg_file_extno, res(index)+1, child, errmsg
   if errmsg ne '' then begin
      print,'##3## EBM_GET_CHILD error: ',errmsg
      return
   endif

   printf,lun,'Child#', strtrim(res(index)+1,2),': ', child

   ;ebm_get_child, child, 1, grandchild, errmsg, grp=grpname, count=n_cand
   ebm_get_num_children, child, n_cand, errmsg, grpname=grpname
   if errmsg ne '' then begin
      print,'##3## EBM_GET_CHILD error: ',errmsg
      return
   endif

   ;printf,lun,'Grandchild#1: ', grandchild

   printf,lun,'GRPNAME of '+child+' is '+grpname
   if grpname eq idx_name then found = 1
   if not found then index = index + 1
endwhile

if found then begin
   if n_cand lt 1 then begin
      print,'IDX found but no elements'
      printf,lun,'IDX found but no elements'
      if num_params ge 5 then errmsg = 'IDX found but no elements'
      count = 0
      file_extno = '?'
      free_lun, lun
      return
   endif
   arr_file_extno = strarr(n_cand)
   count = n_cand

   for i = 1, n_cand do begin

      ebm_get_child, child, i, grandchild, errmsg
      if errmsg ne '' then begin
         print,'##3## GET_CHILD error: ', errmsg
         return
      endif
      if num_params ge 5 then errmsg = ''
      arr_file_extno(i-1) = grandchild
      print,'Found: '+grandchild
      printf,lun,'Found: '+grandchild
   endfor
endif else begin
   print,'No such DS found'
   printf,lun,'No such DS found'
   if num_params ge 5 then errmsg = 'No such DS found'
   file_extno = '?'
   count = 0
endelse



endif ; Terminate 'if there are any children'

free_lun,lun

end
   


