pro ebm_get_child, file_extno, child_no, outfile_extno, errmsg, $
                   count=count, grpname=grpname
;
;   Get the file with extension number for a given child
;   of a grouping table
;
;   Call:   file_extno   File name with extension number appended,
;                          e.g.  myfile.fits[6]
;                          Counting starts with 0 (zero) so that
;                          the primary HDU has extno 0
;           child_no     Number of child in grouping table
;                          Counting starts with 1 (one) so that
;                          the first child has number 1
;
;  Return:  outfile_extno  File name with extension number appended,
;                          Counting starts with 0 (zero)
;
;  Keywords:  count     If set, returns number of children in
;                                    called grouping table
;             grpname   If set, returns GRPNAME of called grouping table

np = n_params()
if n_params() lt 3 then begin
   print,'Syntax: ebm_get_child, file_extno, child_no, outfile_extno, $'
   print,'         [, errmsg][,count=][,grpname=]'
   return
endif

; Set returned value in case of malfunction:

outfile_extno = '?'
grpname = ''
count = -1

; Separate filename and extension number

if strmid(file_extno,0,1) eq '/' then doinit = 1 else doinit = 0
get_exten_no, file_extno, file, extno
tok = sep_filename(file)
n_tok = n_elements(tok)

; Make sure that the input is a grouping table

hdr = headfits(file,exten=extno)

extname = fxpar(hdr,'EXTNAME')
grpname = fxpar(hdr,'GRPNAME')

if extname ne 'GROUPING' then begin
   if np ge 4 then begin
      errmsg = 'Not a grouping table'
   endif else begin
      print,'EBM_GET_CHILD error: Not a grouping table'
   endelse
   return
endif

n_children = fxpar(hdr,'NAXIS2')

count = n_children

if n_children eq 0 then begin
   if np ge 4 then begin
      errmsg = 'No children in grouping table'
   endif else begin
      print,'EBM_GET_CHILD error: No children in grouping table'
   endelse
   return
end
if child_no gt n_children then begin
   if np ge 4 then begin
      errmsg = 'Child does not exist'
   endif else begin
      print,'EBM_GET_CHILD error: Requested child number does not'
      print,'                     exist in grouping table'
   endelse
   return
end

rdfitscol,file_extno, mempos, 4, /silent
rdfitscol,file_extno, memloc, 5, /silent

index = child_no - 1  ; difference in child counting and extension
                      ;   counting
outextno = mempos(index) - 1

if strlen(memloc(index)) eq 0 then begin ; in same file
   outfile = file
endif else begin ; filename given
   tok(n_tok-1) = strtrim(memloc(index),2)
   outfile = collate_path(tok,init=doinit)
endelse
outfile_extno = outfile+'['+strtrim(outextno,2)+']'

if np ge 4 then errmsg = ''

end
