pro ebm_get_idxmember, dol_of_og, swg_no, idx_name, $
              mem_no, file_extno, errmsg,silent=silent
;
; Get file with extension number of an idx member 
;
; Explanation:   *  signals a grouping table
;                #  signals a DS with no children
;
;    DOL_OG*
;       |
;       +--- DOL_SWG_IDX*
;                   |
;                   +--- DOL_SWG(1)*
;                            |
;                            +--- DOL_XXX_IDX*
;                            |        |
;                            |        +--- DOL_XXX_MEM#
;                            |        +--- DOL_XXX_MEM#
;                            | 
;                            +--- DOL_YYY_IDX*
;                            |        |
;                            |        +--- DOL_YYY_MEM#
;                            |        +--- DOL_YYY_MEM#
;  Call:  

np = n_params()
if np lt 5 then begin
   print,'Syntax: ebm_get_idxmember, dol_of_og, swg_no, idx_name, $'
   print,'             mem_no, file_extno[, errmsg][,/silent]'
   return
endif

; Open the monitor output file

openw,lun,'trace.out', /get_lun



; Get DOL of SWG IDX; The only member of the OG is the SWG_IDX

ebm_get_child, dol_of_og, 1, swg_idx_file_extno, errmsg
if errmsg ne '' then begin
   print,'##3## EBM_GET_CHILD error: ',errmsg
   return
endif

printf,lun,'SWG IDX: ',swg_idx_file_extno

; Get number of SWGs

ebm_get_child, swg_idx_file_extno, 1, dummy, errmsg, count=n_swg
if errmsg ne '' then begin
   print,'##3## EBM_GET_CHILD error: ',errmsg
   return
endif

if n_swg lt swg_no then begin
   print,'##3## The requested SWG number does not exist'
   errmsg = 'The requested SWG number does not exist'
   return
endif

; Get DOL of SWG#'swg_no'

ebm_get_child, swg_idx_file_extno, swg_no, swg_file_extno, errmsg
if errmsg ne '' then begin
   print,'##3## EBM_GET_CHILD error: ',errmsg
   return
endif

printf,lun,'SWG : ',swg_file_extno

; Get number of children in the chosen SWG

ebm_get_child, swg_file_extno, 1, dummy, $
          errmsg, count=n_children
if errmsg ne '' then begin
   print,'##3## EBM_GET_CHILD error: ',errmsg
   return
endif

printf,lun,strtrim(n_children,2),' children in SWG#', strtrim(swg_no,2)

; Get DOLs of all children

rdfitscol,swg_file_extno,memnam,2,hdr=hdr_swg,/silent
rdfitscol,swg_file_extno,mempos,4,/silent
rdfitscol,swg_file_extno,memloc,5,/silent


; 1) Search for IDX = 'idx_name'. Find the ones that refer to grouping tables

res = where(strtrim(memnam,2) eq 'GROUPING', n_res)

printf,lun,strtrim(n_res,2),' of these are of type ''GROUPING'''

i = 0
found = 0
while i lt n_res and not found do begin

   ; Get the index table itself

   ebm_get_child, swg_file_extno, res(i)+1, child, errmsg
   if errmsg ne '' then begin
      print,'##3## EBM_GET_CHILD error: ',errmsg
      return
   endif

   printf,lun,'Child#', strtrim(res(i)+1,2),': ', child

   ebm_get_child, child, 1, grandchild, errmsg, grp=grpname, count=n_cand
   if errmsg ne '' then begin
      print,'##3## EBM_GET_CHILD error: ',errmsg
      return
   endif

   printf,lun,'Grandchild#1: ', grandchild

   printf,lun,'GRPNAME of '+child+' is '+grpname
   if grpname eq idx_name then found = 1
   if not found then i = i + 1
endwhile

if found then begin
   if mem_no gt n_cand then begin
      print,'##3## Member#',strtrim(mem_no,2),' does not exist'
      errmsg = 'Member#'+strtrim(mem_no,2)+' does not exist'
      return
   endif

   ebm_get_child, child, mem_no, grandchild, errmsg
   if errmsg ne '' then begin
      print,'##3## GET_CHILD error: ', errmsg
      return
   endif
   if np ge 6 then errmsg = ''
   file_extno = grandchild
   if not keyword_set(silent) then print,'Found: '+grandchild
   printf,lun,'Found: '+grandchild
endif else begin
   print,'No such DS found'
   printf,lun,'No such DS found'
   if np ge 6 then errmsg = 'No such DS found'
   file_extno = '?'
endelse

free_lun,lun

end
   


