pro ebm_get_num_children, file_extno, num_children, errmsg, grpname=grpname
;
;   Get the number of children in a grouping table
;
;   Call:   file_extno   File name with extension number appended,
;                          e.g.  myfile.fits[6]
;                          Counting starts with 0 (zero) so that
;                          the primary HDU has extno 0
;   Return: num_children   Number of children in grouping table
;
;
;  Keywords:    grpname   If set, returns GRPNAME of called grouping table

np = n_params()
if n_params() lt 2 then begin
   print
   print,'Get the number of children in a FITS grouping table'
   print
   print,'Syntax: ebm_get_num_children, file_extno, num_children, $'
   print,'         [, errmsg][,grpname=]'
   print
   return
endif

; Set returned value in case of malfunction:


; Separate filename and extension number

get_exten_no, file_extno, file, extno
tok = sep_filename(file)
n_tok = n_elements(tok)

; Make sure that the input is a grouping table

fxbopen, unit, file, extno
hdr = fxbheader(unit)
fxbclose,unit

extname = fxpar(hdr,'EXTNAME')
grpname = fxpar(hdr,'GRPNAME')

if extname ne 'GROUPING' then begin
   if np ge 4 then begin
      errmsg = 'Not a grouping table'
   endif else begin
      print,'EBM_GET_CHILD error: Not a grouping table'
   endelse
   return
endif

num_children = fxpar(hdr,'NAXIS2')


end
