pro edit_cat_ref, refno
;
;  Edit a reference in the 'DSRI_CAT_REF.fits'
;

np = n_params()
if np eq 0 then begin
   print
   print,'If the file DSRI_CAT_REF_<ref#>.txt exists then it can be edited'
   print,'and then it will replace reference ref# in the DSRI_CAT_REF.fits table'
   print,'Otherwise it will be created with a call of print_cat_ref,ref#'
   print,'When editing the file make sure that the line length does not exceed 80'
   print,'Else the line will truncated'
   print
   return
endif


file_dsri_cat_ref = '/home/njw/jsim/Catalogs/DSRI_CAT_REF.fits[1]'
txt_filename = '/home/njw/jsim/Catalogs/DSRI_CAT_REF_'+strtrim(refno,2)+'.txt'

; check presence of text file

list = findfile(txt_filename, count=n_list)
if n_list ne 1 then begin
   print,'The file: '+txt_filename+' does not exist, create it.'
   print_cat_ref, refno, err=errmsg
   if errmsg ne '' then begin
      print,errmsg
      return
   endif
endif

spawn,'vi '+txt_filename

answer = ''
read,'Do you want to update DSRI_CAT_REF.fits ? (y/n) ... ', answer
if answer ne 'y' then begin
   print,'DSRI_CAT_REF.fits is unchanged'
   return
endif

list = read_slist(txt_filename)
n_list = n_elements(list)

if n_list lt 4 then begin
   print,'Input file: '+txt_filename+' has too few lines'
   return
endif

n_list = n_list - 3 ; first 3 lines do not belong to reference text

get_exten_no, file_dsri_cat_ref, filename, extno



errmsg = ''

rdfitscol,file_dsri_cat_ref,refernce,'REFERNCE',err=errmsg,/silent
rdfitscol,file_dsri_cat_ref,reftext,'REFTEXT',err=errmsg,/silent

; Locate the rows of the reference

sel = where( refernce eq refno, n_sel )

if n_sel eq 0 then begin
   print,'Reference number '+strtrim(refno,2)+' not found - terminate'
   return
endif

firstrow = sel(0) + 1

print
print,'Going to delete rows '+strtrim(firstrow,2)+' - '+strtrim(firstrow+n_sel-1,2)
for i = sel(0),sel(0)+n_sel-1 do begin
   print,reftext(i)
endfor
print
answer = ''
read,' Proceed ? ... ', answer

if answer ne 'y' then return

arg = 'fdelrow "'+file_dsri_cat_ref+'" '+strtrim(firstrow,2)+' '
arg = arg + strtrim(n_sel,2) + ' Y Y'
spawn,arg

; Get the current number of rows

fxbopen,unit,filename,extno,hdr
fxbclose,unit
numrows = fxpar(hdr,'NAXIS2')

; read the 

print,'Going to add ', n_list,' rows to file: DSRI_CAT_REF.fits'
arg = '/home/njw/jsim/add_rows/add_rows '
arg = arg + '"' + file_dsri_cat_ref + '" '
arg = arg + strtrim(n_list,2)
spawn,arg

fxbopen,unit,filename,extno,hdr,access='RW'
colnum_ref = fxbcolnum( unit, 'REFERNCE', err=errmsg)
if errmsg ne '' then print,'##9## errmsg: ', errmsg
colnum_sub = fxbcolnum( unit, 'SUBENTRY', err=errmsg)
if errmsg ne '' then print,'##10## errmsg: ', errmsg
colnum_txt = fxbcolnum( unit, 'REFTEXT', err=errmsg)
if errmsg ne '' then print,'##11## errmsg: ', errmsg


for row = 1, n_list do begin

   ;print,'##12## writing refno = ', refno,' to row# ', numrows+row
   fxbwrite, unit, fix(refno), colnum_ref, numrows+row, err=errmsg
   if errmsg ne '' then print,'##13## errmsg: ', errmsg

   ;print,'##14## writing row-1 = ', row-1,' to row# ', numrows+row
   fxbwrite, unit, row-1, colnum_sub, numrows+row, err=errmsg
   if errmsg ne '' then print,'##15## errmsg: ', errmsg

   ;print,'##16## writing list(row+2) = ', list(row+2),' to row# ', numrows+row
   buffer = list(row+2)
   fxbwrite, unit, buffer, colnum_txt, numrows+row, err=errmsg
   if errmsg ne '' then print,'##17## errmsg: ', errmsg

endfor

fxbfinish, unit, err=errmsg



end
