pro edit_srccat, incat, outcat
;
;  Interactively edit a source catalogue such as DSRI_CAT
;  but som updating is needed
;
npar = n_params()
if npar lt 1 then begin
   print,'Syntax: edit_srccat, name_of_input_catalog[, name_of_output_catalog]'
   return
endif

if npar gt 1 then begin
   spawn,'rm '+outcat
endif else begin
   outcat = 'tmp.fits'
endelse

xrg = [150., 100.]
yrg = [-20.,30.]
window,0,xs=800,ys=600

plot,[0,1],xr=xrg,yr=yrg,xtit='RA (2000) [deg]',ytit='DEC (2000) [deg]'

rdfitscol,incat+'[1]',sourcename,'SOURCENAME',/sil
rdfitscol,incat+'[1]',ra,'RA',/sil
rdfitscol,incat+'[1]',dec,'DEC',/sil
rdfitscol,incat+'[1]',nh,'NH',/sil
rdfitscol,incat+'[1]',intenscode,'INTENSCODE',/sil
rdfitscol,incat+'[1]',spectrcode,'SPECTRCODE',/sil
rdfitscol,incat+'[1]',intens,'INTENS',/sil
rdfitscol,incat+'[1]',param1,'PARAM1',/sil
rdfitscol,incat+'[1]',param2,'PARAM2',/sil

num_sources = n_elements(ra)
sizemax = 3.
sizemin = 0.1
fluxmax = 2.e-8
fluxmin = 2.e-11
bcoef = (sizemax - sizemin) / alog(fluxmax/fluxmin)
acoef = sizemax - bcoef*alog(fluxmax)
for i = 0, num_sources-1 do begin
   symsize = acoef + bcoef*alog(intens(i))
   oplot,[ra(i)],[dec(i)],ps=7,symsize=symsize
endfor

print,'The catalog has '+strtrim(num_sources,2)+' sources'

print
print,'Menu:'
print,' ... 1: Add new source'
print,' ... 2: Remove source'
print,' ... 3: Edit source properties'
print,' ... 4: Get angular distance between 2 sources'
print,' ... 5: Get a position on the sky'
print,' ... 6: Copy a source'
print,' ... 7: Move a source'
ans = 0
read,'Enter your choice : ... ', ans

if ans eq 1 then begin
   print,'Define position ...'
   curmark1,res
   newra = res(0)
   newdec = res(1)
   newname = ''
   read,'Enter source name : ... ', newname
   newnh = select_value(1.e19,1.e23,tit='Select NH',/o,unit='/cm2')
   newintenscode = 'SX '
   newspectrcode = 'PL '
   newintens = 2.e-11*select_value(2.,3000.,tit='Select intensity',/o,unit='mCrab')
   newparam1 = select_value(0.5,3.,tit='Select spectral parameter')
   newparam2 = 0.0
   sourcename = [sourcename,newname]
   ra = [ra,newra]
   dec = [dec,newdec]
   nh = [nh,newnh]
   intenscode = [intenscode,newintenscode]
   spectrcode = [spectrcode,newspectrcode]
   intens = [intens,newintens]
   param1 = [param1,newparam1]
   param2 = [param2,newparam2]
endif

if ans eq 2 $
   or ans eq 3 $
   or ans eq 6 $
   or ans eq 7 $
                    then begin ; Select the source
   print,'Select the source. Indicate the position ...'
   curmark1,res
   dist = arcdist(ra,dec,res(0),res(1),/deg)
   dum = min(dist,imin)
   def_sym,'c'
   oplot,[ra(imin)],[dec(imin)],ps=8,symsize=1.5
endif

if ans eq 2 then begin ; Remove the selected source
   all = indgen(n_elements(ra))
   w = where(all ne imin, n_w)
   if n_w eq 0 then begin
      print,'I refuse to remove the only source in the catalogue'
      return
   endif
   sourcename = sourcename(w)
   ra = ra(w)
   dec = dec(w)
   nh = nh(w)
   intenscode = intenscode(w)
   spectrcode = spectrcode(w)
   intens = intens(w)
   param1 = param1(w)
   param2 = param2(w)
endif

if ans eq 3 then begin ; Edit the source properties
   go_on = 1
   repeat begin

      code = flash_src_s(sourcename(imin), ra(imin), dec(imin), $
              nh(imin), intenscode(imin), spectrcode(imin), intens(imin), $
              param1(imin), param2(imin), 9)
      case code of
          'ex' : go_on = 0
          'sn' : begin
                 newname = ''
                 read,'New name : ... ', newname
                 sourcename(imin) = newname
                 end
          'ra' : begin
                 newra = 0.0
                 read,'New RA : ... ', newra
                 ra(imin) = newra
                 end
          'dc' : begin
                 newdec = 0.0
                 read,'New DEC : ... ', newdec
                 dec(imin) = newdec
                 end
          'nh' : begin
                 newnh = 0.0
                 read,'New NH : ... ', newnh
                 nh(imin) = newnh
                 end
          'ic' : begin
                 newintenscode = ''
                 read,'New intenscode : ... ', newintenscode
                 intenscode(imin) = newintenscode
                 end
          'sc' : begin
                 newspectrcode = ''
                 read,'New spectrcode : ... ', newspectrcode
                 spectrcode(imin) = newspectrcode
                 end
          'in' : begin
                 newintens = 0.0
                 read,'New intensity : ... ', newintens
                 intens(imin) = newintens
                 end
          'p1' : begin
                 newparam1 = 0.0
                 read,'New param1 : ... ', newparam1
                 param1(imin) = newparam1
                 end
          'p2' : begin
                 newparam2 = 0.0
                 read,'New param2 : ... ', newparam2
                 param2(imin) = newparam2
                 end
      endcase
   endrep until not go_on
endif

if ans eq 4 then begin ; Select the two sources
   print,'Select the first source. Indicate the position ...'
   curmark1,res
   dist = arcdist(ra,dec,res(0),res(1),/deg)
   dum = min(dist,imin1)
   def_sym,'c'
   oplot,[ra(imin1)],[dec(imin1)],ps=8,symsize=1.5
   print,'Select the second source. Indicate the position ...'
   curmark1,res
   dist = arcdist(ra,dec,res(0),res(1),/deg)
   dum = min(dist,imin2)
   def_sym,'c'
   oplot,[ra(imin2)],[dec(imin2)],ps=8,symsize=1.5
   adist = arcdist(ra(imin1),dec(imin1),ra(imin2),dec(imin2),/deg)
   if adist gt 1.0 then begin
      print,'The distance is '+ strtrim(adist,2)+ ' degrees'
   endif else begin
      print,'The distance is '+ strtrim(adist*60,2)+ ' arcmin'
   endelse
   return
endif

if ans eq 5 then begin
   curmark1
   return
endif

if ans eq 6 then begin  ;  Copy the source
   print,'Select the new position ...'
   curmark1,res
   newra = res(0)
   newdec = res(1)
   newname = ''
   read,'Enter source name : ... ', newname
   newnh = nh(imin)
   newintenscode = 'SX '
   newspectrcode = 'PL '
   newintens = intens(imin)
   newparam1 = param1(imin)
   newparam2 = 0.0
   sourcename = [sourcename,newname]
   ra = [ra,newra]
   dec = [dec,newdec]
   nh = [nh,newnh]
   intenscode = [intenscode,newintenscode]
   spectrcode = [spectrcode,newspectrcode]
   intens = [intens,newintens]
   param1 = [param1,newparam1]
   param2 = [param2,newparam2]
endif

if ans eq 7 then begin  ;  Move the source
   print,'Select the new position ...'
   curmark1,res
   ra(imin) = res(0)
   dec(imin) = res(1)
endif


;  Redraw and write the catalogue back to disk

wset,0
plot,[0,1],xr=xrg,yr=yrg,xtit='RA (2000) [deg]',ytit='DEC (2000) [deg]'
num_sources = n_elements(ra)
for i = 0, num_sources-1 do begin
   symsize = acoef + bcoef*alog(intens(i))
   oplot,[ra(i)],[dec(i)],ps=7,symsize=symsize
endfor

wrmfitscols,outcat,'SOURCENAME',sourcename, $
                   'RA',ra, $
                   'DEC',dec, $
                   'NH',nh, $
                   'INTENSCODE',intenscode, $
                   'SPECTRCODE',spectrcode, $
                   'INTENS',intens, $
                   'PARAM1',param1, $
                   'PARAM2',param2

if npar lt 2 then begin
   ans = ''
   read,'Do you want to save the changes ? ... ', ans
   if ans eq 'y' then begin
      spawn,'mv tmp.fits '+incat
      print,'The catalog: ', incat,' has now been updated'
   endif else begin
      print,'The changes are discarded'
   endelse
endif

end
