pro encircled_fraction, x, y, dist, fraction, center, radec=radec
;
;   2006-01-13/NJW
;
if n_params() ne 5 then begin
   print,'Syntax: encircled_fraction, x, y, dist, fraction, center[,/radec]'
   print,'  where x and y are position arrays (same dimension)'
   print,'  and dist and fraction are returned'
   print,'  ''center'' is either a string ''avg'' or an array'
   print,'  with two elements [x0,y0]'
   print,'  Keyword ''radec'' implies spherical geometry assuming'
   print,'  that the x and y arrays are in degrees.'
   return
endif

num = n_elements(x)
if num le 1 then begin
   print,'ENCIRCLED_FRACTION error, too few data points'
   return
endif
if num ne n_elements(y) then begin
   print,'ENCIRCLED_FRACTION error, mismatching array sizes'
   return
endif

sz = size(center)
if sz(sz(0)+1) eq 7 then begin
   a = strmid(center,0,3)
   if a eq 'avg' then begin
      if keyword_set(radec) then begin
         bestpos = best_skypos(x,y,fltarr(num)+1.)
         x0 = bestpos(0)
         y0 = bestpos(1)
      endif else begin
         x0 = avg(x)
         y0 = avg(y)
      endelse
   endif else begin
      print,'Illegal string value of ''center'''
      return
   endelse
endif else begin
   if sz(0) ne 1 or sz(1) ne 2 then begin
      print,'Illegal dimensions of ''center'''
      return
   endif else begin
      x0 = center(0)
      y0 = center(1)
   endelse
endelse

if keyword_set(radec) then begin
   dist = arcdist(x0,y0,x,y)
endif else begin
   dist = sqrt((x - x0)^2 + (y - y0)^2)
endelse
dist = [0.0,dist(sort(dist))]
fraction = indgen(num+1, /float) / num

end
