pro expand_array, a, newsize, n
;
;  Expand a 1D or 2D array in its nth dimension
;
;   2004-03-29/NJW
;   2005-03-21/NJW Update to include 1D arrays
;
if n_params() lt 3 then begin
   print,'Syntax: expand_array, a, newsize, n'
   print,'  ''a'' must be a 2D array and it will be changed to'
   print,'       newsize x n_original when n is 1 and to'
   print,'       n_original x newsize when n is 2'
   return
endif

sz = size(a)
if sz(0) ne 2 and sz(0) ne 1 then begin
   print,'EXPAND_ARRAY error: Input array must be 1D or 2D!'
   return
endif

;  Deal with 1D array

if sz(0) eq 1 then begin
   n = 1
   if sz(1) gt newsize then begin
      print,'EXPAND_ARRAY error: Input array cannot be shrunk!'
      return
   endif
   case sz(2) of
   2 : b = intarr(newsize)
   3 : b = lonarr(newsize)
   4 : b = fltarr(newsize)
   5 : b = dblarr(newsize)
   7 : b = strarr(newsize)
   else : begin
           print,'EXPAND_ARRAY error: Illegal array type'
           return
           end
   endcase
   b(0:sz(1)-1) = a
   a = b
   return
endif

; The 2D case is treated depending on value of 'n':

if n eq 1 then begin
   if sz(1) gt newsize then begin
      print,'EXPAND_ARRAY error: Input array cannot be shrunk!'
      return
   endif

   case sz(3) of
   2 : b = intarr(newsize, sz(2))
   3 : b = lonarr(newsize, sz(2))
   4 : b = fltarr(newsize, sz(2))
   5 : b = dblarr(newsize, sz(2))
   7 : b = strarr(newsize, sz(2))
   else : begin
           print,'EXPAND_ARRAY error: Illegal array type'
           return
           end
   endcase

   b(0:sz(1)-1,*) = a
endif else begin
   if sz(2) gt newsize then begin
   print,'EXPAND_ARRAY error: Input array cannot be shrunk!'
   return
   endif

   case sz(3) of
   2 : b = intarr(sz(1),newsize)
   3 : b = lonarr(sz(1),newsize)
   4 : b = fltarr(sz(1),newsize)
   5 : b = dblarr(sz(1),newsize)
   7 : b = strarr(sz(1),newsize)
   else : begin
            print,'EXPAND_ARRAY error: Illegal array type'
            return
          end
   endcase

   b(*,0:sz(2)-1) = a
endelse

a = b
return

end
