function extrbox, image, centerpos, edgesize, freeze=freeze, silent=silent, corners=corners
;
; Extract box around centerpos : centerpos+-edgesize/2 in image 'image'
;
; The box returned is of same type as 'image' if the box fits
; completely inside the image
;
;   2004-01-12/NJW  Updating a much older version
;
if( n_params() ne 3 ) then begin
   print,'Syntax: box = extrbox(image,centerpos,edgesize[,freeze=''size'' or =''pos''][,/silent])'
   print,'     Freezing the box size is the default choice'
   print,'     With keyword ''corners'' the corner pixels are returned as [x0,y0,x1,y1]'
   return,-1.
endif

if not keyword_set(freeze) then freeze = 'size'
f1 = strmid(freeze,0,1)
verb = 1
if keyword_set(silent) then verb = 0

szim = size(image)
if( szim(0) ne 2 ) then begin
   print,'Illegal number of dimensions in image ...'
   return,-1.
endif
sp = size(centerpos)
if( sp(0) ne 1 ) then begin
   print,'Illegal number of dimensions in centerpos ...'
   return,-1.
endif
if( sp(1) ne 2 ) then begin
   print,'Illegal length of centerpos ...'
   return,-1.
endif
sd = size(edgesize)
if( sd(0) ne 1 ) then begin
   print,'Illegal number of dimensions in edgesize ...'
   return,-1.
endif
if( sd(1) ne 2 ) then begin
   print,'Illegal length of edgesize ...'
   return,-1.
endif
if( szim(1) lt edgesize(0) ) then begin
   print,'Box too large in x direction ...'
   return,-1.
endif
if( szim(2) lt edgesize(1) ) then begin
   print,'Box too large in y direction ...'
   return,-1.
endif
;
i1 = intarr(2)
i2 = intarr(2)
xy = ['X','Y']
for k = 0,1 do begin ; test for box completely inside image
   m1 = (edgesize(k)-1)/2
   m2 = edgesize(k)-m1-1
   i1(k) = centerpos(k) - m1
   i2(k) = centerpos(k) + m2
   if( i2(k) gt szim(1+k)-1 ) then begin
      if f1 eq 's' then begin
         if verb then print,xy(k)+' center shifted '+stri(-(i2(k) - (szim(1+k)-1)))
         i1(k) = i1(k) - (i2(k) - (szim(1+k)-1))
      endif else begin
         if verb then print,xy(k)+' edge reduced with '+stri(-(i2(k) - (szim(1+k)-1)))
      endelse
      i2(k) = szim(1+k)-1
   endif
   if( i1(k) lt 0 ) then begin
      if f1 eq 's' then begin
         if verb then print,xy(k)+' center shifted '+stri(-i1(k) )
         i2(k) = i2(k) - i1(k)
      endif else begin
         if verb then print,xy(k)+' edge reduced with '+stri(-i1(k) )
      endelse
      i1(k) = 0
   endif
endfor
;
;  Extract the box
;
box = image(i1(0):i2(0), i1(1):i2(1))
if verb then begin
   print,'Corners x0,y0   x1,y1'
   print,i1(0),i1(1),i2(0),i2(1)
endif

corners = [i1(0),i1(1),i2(0),i2(1)]

return, box

end
