pro fbin, x1, x2, s, b, e, xn1, xn2, sn, bn, en, nsigma
;
; A rebinning procedure
;
; Call :
;  x1   array with lower bin boundaries
;  x2   array with upper bin boundaries
;  s    array with source counts
;  b    array with background counts
;  e    array with absolute errors
;
; Return :
;  xn1   array with lower bin boundaries
;  xn2   array with upper bin boundaries
;  sn    array with source counts
;  bn    array with background counts
;  en    array with absolute errors
;
; so that in all new bins  nsigma*en < sn
;
nx1 = n_elements(x1)
nx2 = n_elements(x2)
ns = n_elements(s)
nb = n_elements(b)
n_e = n_elements(e)
ierr = 0
if nx2 ne nx1 then ierr = 1
if ns  ne nx1 then ierr = 1
if nb  ne nx1 then ierr = 1
if n_e ne nx1 then ierr = 1
if ierr ne 0 then begin
   print,'% FBIN error - mismatching array dimensions'
   retall
endif

;... Define arrays for resulting spectrum

sn = fltarr(ns)
bn = fltarr(ns)
en = fltarr(ns)
xn1 = fltarr(ns)
xn2 = fltarr(ns)

;... prepare loop

k = 0
i = 0
while i lt ns do begin
   sn(k) = s(i)
   bn(k) = b(i)
   en(k) = e(i)
   xn1(k) = x1(i)
   xn2(k) = x2(i)
   while sn(k) lt nsigma*en(k) and i lt ns-1 do begin
      i = i + 1
      sn(k) = sn(k) + s(i)
      bn(k) = bn(k) + b(i)
      en(k) = sqrt(en(k)^2 + e(i)^2)
      xn2(k) = x2(i)
   endwhile
   k = k + 1
   i = i + 1
endwhile

sn = sn(0:k-1)
bn = bn(0:k-1)
en = en(0:k-1)
xn1 = xn1(0:k-1)
xn2 = xn2(0:k-1)

end
