function fgauss_convol_2d, array, s, val=val, ksize=ksize, silent=silent
;
;  Returns the 2D array 'array' convolved with a gaussian with a width
;  depending on the keyword 'val' : 'f' then 's' is FWHM
;                                   's' then 's' is sigma (st. dev.)
;                  Default is 's' (sigma)
;  The keyword ksize gives the size of the kernel (ksize x ksize)
;
;  The default is that ksize is sigma*6
;
if n_params() lt 2 then begin
   print,'fgauss_convol_2d,array,s,val=val,ksize=ksize,silent=silent'
   return, -1.
endif

sigma = s
if( keyword_set(val) ) then begin
   if( val eq 'f' ) then begin
      sigma = s/2.355
   endif
endif
      
sz = size(array)
if sz(1)*sz(2) mod 2 eq 0 then begin
   print,'Input array must have odd dimensions'
   return, -1
endif

n = min(sz(1:2))
ks = fix(sigma*6) > 3
if keyword_set(ksize) then ks = ksize
; make ks odd
ks = fix(ks)
ks = (ks/2)*2 + 1
x = distances(ks,ks,ks/2,ks/2)
kernel = exp(-0.5*(x/sigma)^2)
fk = fkernel(kernel/total(kernel),sz(1),sz(2))

if not keyword_set(silent) then begin
   sz = size(array)
   sz1 = string(sz(1),format='(i6)')
   sz2 = string(sz(2),format='(i6)')
   sks = string(ks,format='(i6)')
   print,'Convolving a '+sz1+' x'+sz2+' matrix with'
   print,'           a '+sks+' x'+sks+' size kernel'
   print,'using sigma = ', sigma,' pixels'
endif
return,fconvol(1.*array,fk)
end
