pro file_merge, file1, file2, outfile, col1=col1, col2=col2, str=str, num=num
;
;  Merge two files, each with increasing value in specified
;  column; must be compatible with the S-format standard
;  if column numbers are given
;
;  2004-07-18/NJW
;
if n_params() lt 3 then begin
	print,'Syntax: file_merge, file1, file2, outfile[, col1=][, col2=][, str=][, /num]'
	return
endif

if not file_test(file1,/reg) then begin
	print,'Could not open '+file1
	return
endif

if not file_test(file2,/reg) then begin
	print,'Could not open '+file2
	return
endif

lines1 = read_slist(file1,count=nlines1)
val1 = lines1
if keyword_set(col1) then begin
	if keyword_set(str) then begin
		rscol,file1,val1,col1,/str
	endif else begin
		rscol,file1,val1,col1,/dble
	endelse
endif else begin
	if keyword_set(num) then val1 = double(val1)
endelse

lines2 = read_slist(file2,count=nlines2)
val2 = lines2
if keyword_set(col2) then begin
	if keyword_set(str) then begin
		rscol,file2,val2,col2,/str
	endif else begin
		rscol,file2,val2,col2,/dble
	endelse
endif else begin
	if keyword_set(num) then val2 = double(val2)
endelse

openw,luout,outfile,/get_lun

if nlines1 gt 0 then more1 = 1 else more1 = 0
if nlines2 gt 0 then more2 = 1 else more2 = 0
index1 = 0
index2 = 0
while more1 or more2 do begin
	if more1 then v1 = val1(index1)
	if more2 then v2 = val2(index2)
	if more1 and more2 then begin
		if v1 lt v2 then begin
			printf,luout,lines1(index1)
			index1 = index1 + 1
			if index1 eq nlines1 then more1 = 0
		endif else begin
			printf,luout,lines2(index2)
			index2 = index2 + 1
			if index2 eq nlines2 then more2 = 0
		endelse
	endif else begin
		if more1 then begin
			printf,luout,lines1(index1)
			index1 = index1 + 1
			if index1 eq nlines1 then more1 = 0
		endif
		if more2 then begin
			printf,luout,lines2(index2)
			index2 = index2 + 1
			if index2 eq nlines2 then more2 = 0
		endif
	endelse
endwhile

free_lun,luout

end
