function filesize, filename, r=r
;
;----------------------------------------------------
;
; Return the size in bytes of the files that match
; the 'filename'. If the 'r' keyword is given 'filename'
; must be a directory name
;
; Niels J. Westergaard
;
;  Updated     981223 by NJW to include the subdirectories
;
;----------------------------------------------------
;
;  Separate section for including subdirectories. In this
;  case the 'find' program is used which gives a different
;  structure
;----------------------------------------------------
if n_params() lt 1 then begin
   print,'Syntax: nbytes = filesize(filename[,/r])'
   print,'        keyword ''r'' for including subdirectories'
   return, -1
endif
if keyword_set(r) then begin ;******************************
   ;
   ;  make list of files including file sizes
   ;
   spawn,'find . -name '+filename+' -type f -ls',list
   count = n_elements(list) - 2
   
   ; Return if no files have been found
    
   if count lt 1 then begin
      print,'No files found'
      return, 0L
   endif else list = list(2:*)
    
   len = strlen(list)
   some = 0
   
   print
   if count le 1 then begin
      if strlen(list(0)) eq 0 then begin
         print,'No files found'
      endif else begin
         print,'1 file found'
         some = 1
      endelse
   endif else begin
      print,count,' files found'
      some = 1
   endelse
   print
   ;----------------------------------------------------
   ;
   ;  extract the filesize from each entry in list
   ;  and do the summation
   ;
   sum = 0L
   if some then begin
      for i = 0,count-1 do begin
         str = strcompress(strtrim(list(i),2))
         tok = str_sep(str,' ')
         sum = sum + long(tok(6))
      endfor
   endif
   ;----------------------------------------------------
   ;
   ;  Separate section for not including subdirectories. In this
   ;  case the 'ls -l' program is used which gives a different
   ;  structure
   ;----------------------------------------------------
endif else begin  ;*****************************************
   ;
   ;  make list of files including file sizes
   ;
   spawn,'ls -l '+filename,list_in
   count = n_elements(list_in)
   
   ;  Return if no files have been found
   
   if count eq 0 then begin
      print,'No files found'
      return, 0L
   endif
   
   list = list_in
   len = strlen(list_in)
   some = 0
   
   ;  exclude all non-file information from list
   
   k = 0
   for i = 0, count-1 do begin
      ; very short length indicate no file information in entry
      if len(i) gt 20 then begin
         ; file information string begins with '-'
         if strmid(list_in(i),0,1) eq '-' then begin
            list(k) = list_in(i)
            k = k + 1
         endif else print,'Excluded: '+list_in(i)
      endif else print,'Excluded: '+list_in(i)
   endfor
   
   count = k ; update the count of files
   
   print
   if count le 1 then begin
      if strlen(list(0)) eq 0 then begin
         print,'No files found'
      endif else begin
         print,'1 file found'
         some = 1
      endelse
   endif else begin
      print,count,' files found'
      some = 1
   endelse
   print
   ;----------------------------------------------------
   ;
   ;  extract the filesize from each entry in list
   ;  and do the summation
   ;
   sum = 0L
   if some then begin
      for i = 0,count-1 do begin
         str = strcompress(strtrim(list(i),2))
         tok = str_sep(str,' ')
         sum = sum + long(tok(4))
      endfor
   endif

endelse ;**************************************************

print, sum/1.e6,' MB'

return, sum
end
