pro find_src_by_name, name, force=force, nlc=nlc, clog=clog, $
              catsrcname=catsrcname, skypos=skypos, silent=silent
;
;  Find the source(s) in gnrl_refr_cat_latest.fits that matches 'name'
;  or the catalog specified by keyword 'clog'
;
;  Define structure to hold all source information


common cat_com_v2, cat, num_entries_cat, dol_of_cat

source = {   name:'', ra_obj:0.0, dec_obj:0.0, spe_modl:'', $
             spe_npar:0, spe_pars:fltarr(10), $
             intens:0.0, category:'', catalogue:'' }




if n_params() ne 1 then begin
   print,'Syntax: find_src_by_name, name[, force=][,skypos=][,clog=] $'
   print,'                  [, catsrcname=]'
   print,'   The catalog content is stored in common area.'
   print,'   Keyword ''clog'' defines the catalog DOL'
   print,'   Keyword ''force'' forces rereading'
   print,'   Keyword ''skypos'' returns a two element array [ra,dec]'
   print,'   Keyword ''catsrcname'' returns the source name as given'
   print,'           in the catalog'
   return
endif

vb = 1 - keyword_set(silent)


; Find 'sourcemap.par' in current directory

if not file_test('sourcemap.par',/reg) then begin
   spawn,'cp /home/njw/jsim/Catalogs/sourcemap.par .'
endif

; Read the contents of catalog
 
cat_com_update, clog=clog

;  Remove spaces and change to lower case

name_lowcase = strlowcase(strcompress(name,/r))

; First search the catalog itself

cat_name_lowcase = strlowcase(strcompress(cat.name,/r))

res = where(strmatch(cat_name_lowcase, name_lowcase), n_res)
if n_res gt 0 then begin
   if vb then print,'  Results from '+dol_of_cat+' :'
   for i = 0, n_res-1 do begin
      if vb then begin
          print,string(cat(res(i)).name, cat(res(i)).ra_obj, $
             cat(res(i)).dec_obj, format='(a40,f10.4,f10.4)')
      endif
   endfor
   skypos = [-99.,-99.]
   catsrcname = ''
   if n_res eq 1 then begin
      skypos = [cat(res(0)).ra_obj, cat(res(0)).dec_obj]
      catsrcname = strtrim( cat(res(0)).name, 2 )
   endif
endif else begin
   print,'No match found in '+dol_of_cat
endelse

end
