function fitplane,im
;
; This function makes a least square fit through the 2D image 'im'
; and returns a 2D array with the best fit image
;
;  Minimize S = SUM( a*x + b*y + c - im(x,y))
;
;  Solve for a,b,c and return a*xx + b*yy + c
;
; NJW 940209
;
sz = size(im)
if( sz(0) ne 2 ) then begin
   print,'Function fitplane must have a 2D array as parameter'
   return,-1.
endif
nx = sz(1)
ny = sz(2)
x = findgen(nx)
y = findgen(ny)
u = fltarr(nx) + 1.
v = fltarr(ny) + 1.
xx = x # v
yy = u # y
uu = u # v
arr = fltarr(3,3)
b = fltarr(3)
arr(0,0) = total(xx^2)
arr(1,0) = total(xx*yy)
arr(2,0) = total(xx)
arr(0,1) = arr(1,0)
arr(1,1) = total(yy^2)
arr(2,1) = total(yy)
arr(0,2) = arr(2,0)
arr(1,2) = arr(2,1)
arr(2,2) = sz(4)  ; number of pixels
b(0) = total(xx*im)
b(1) = total(yy*im)
b(2) = total(im)
a = invert(arr) # b
print,'Resulting coefficients (a,b,c) :'
print,a
return, a(0)*xx + a(1)*yy + a(2)
end
