pro fits_arr2ascii, fits_ext, ascii_file
;
;   Convert FITS array to ASCII file in S-format
;
;   2004-08-20/NJW
;
if n_params() lt 2 then begin
   print,'Syntax: fits_arr2ascii, fits_ext, ascii_file'
   return
endif

get_exten_no, fits_ext, fits_file, extno

if strmid(fits_ext,0,1) ne '/' then $
   fits_ext = getenv('PWD')+'/'+fits_ext

arr = readfits( fits_file, hdr, exten=extno )

sz = size(arr)
if sz(0) ne 2 then begin
   print,'Not a 2D array, stop'
   return
endif

type = sz(sz(0)+1)
case type of
   2 : begin
	 mx = max(abs(arr))
	 ndig = floor(alog10(mx)+3.)
	 frmat = '('+stri(sz(1))+'i'+stri(ndig)+')'
       end
   3 : begin
	 mx = max(abs(arr))
	 ndig = floor(alog10(mx)+3.)
	 frmat = '('+stri(sz(1))+'i'+stri(ndig)+')'
       end
   4 : frmat = '('+stri(sz(1))+'e15.6)'
   5 : frmat = '('+stri(sz(1))+'e18.9)'
   else : begin
      print,'Data type '+stri(type)+' is not allowed'
      return
	end
endcase

openw,lun,ascii_file,/get_lun

printf,lun,'// Data taken from the following DOL:'
printf,lun,'// dol = '+fits_ext
printf,lun,'// time = '+ndate(2)

; Analyze header

nh = n_elements(hdr)
for i = 0, nh-1 do begin
   key = strtrim(strmid(hdr(i),0,8),2)
   if strlowcase(key) eq 'comment' or strlowcase(key) eq 'history' then begin
      printf,lun,'// '+hdr(i)
   endif else begin
      value = fxpar( hdr, key, comment=comment)
      sv = size(value)
      if sv(sv(0)+1) ne 7 then value = stri(value)
      printf,lun,'// '+key+' = '+value+' ; '+comment
   endelse
endfor

for i = 0L, sz(2)-1 do begin
   printf,lun,arr(*,i),format=frmat
endfor
free_lun, lun

end
