pro fits_keyw_copy, ext_in, ext_out, keyw1, keyw2, keyw3, keyw4
;
;   Copy up to four keywords from one FITS extension to another
;
;   2003-07-30/NJW
;
np = n_params()
if np lt 3 then begin
   print,'Syntax: fits_keyw_copy, ext_in, ext_out, keyw1, keyw2, ...'
   return
endif

get_exten_no, ext_in, file_in, next_in
get_exten_no, ext_out, file_out, next_out
hdr_in = headfits( file_in, exten=next_in )
hdr_out = headfits( file_out, exten=next_out )

; Loop over all requested keywords

nk = np - 2 ; Number of keyword parameters
keyw = [keyw1]

if nk gt 1 then keyw = [keyw, keyw2]
if nk gt 2 then keyw = [keyw, keyw3]
if nk gt 3 then keyw = [keyw, keyw4]

nkeys = n_elements(keyw)

for key = 1, nkeys do begin
   value = fxpar( hdr_in, keyw(key-1), comment=com, count=nfound )
   if nfound ne 1 then begin
      print,'Keyword '''+keyw(key-1)+''' not found in '+ext_in
   endif else begin
      v = fxpar( hdr_out, keyw(key-1), count=nf )
      if nf ne 1 then begin
         print,'WARNING ...'
         print,'Keyword '+keyw(key-1)+' not found in '+ext_out
         print,'This may cause problems if header size overflows the block size'
      endif
      fxaddpar, hdr_out, keyw(key-1), value, com
      modfits, file_out, 0, hdr_out, exten=next_out
   endelse
endfor

end
