pro fits_replace_col, file_extno, colname, coldata, firstrow
;
;  Replace the contents of a FITS binary table column with new values
;  without changing anything else
;
;   NJW/2003-08-19
;   2003-11-13/NJW small update
;
;  Vector columns:  First index is number of data values in each bin; the
;  second index is the row number
;

np = n_params()
if np lt 3 then begin
   print,'Syntax: fits_replace_col, file_extno, colname, coldata[, firstrow]'
   print
   print,'  If firstrow is not given the replacement will be for all rows'
   print,'  Else the rows will be replaced starting from firstrow (count from 1)'
   print
   return
endif

get_exten_no, file_extno, fitsname, extno


fxbopen, unit, fitsname, extno, header,access='RW'

nrows = fxpar(header, 'NAXIS2')
ncols = fxpar(header, 'TFIELDS')

errmsg = ''
col_number = fxbcolnum( unit, colname, errmsg=errmsg)
if errmsg ne '' then begin
   print,'FITS_REPLACE_COL: Column not found ('+errmsg+')'
   fxbfinish, unit
   return
endif

sz = size(coldata)
if np eq 3 then firstrow = 1

if firstrow + sz(sz(0)) - 1 gt nrows then begin
   print,'FITS_REPLACE_COL: Mismatch between existing number of rows and new array'
   fxbfinish, unit
   return
endif
if sz(0) lt 1 or sz(0) gt 2 then begin
   print,'FITS_REPLACE_COL: Illegal data structure of new column'
   print,'size(coldata): ', sz
   fxbfinish, unit
   return
endif

if sz(0) eq 2 then begin ; New column must have correct dimension
   dim_col = fxbdimen(unit,col_number)
   if dim_col ne sz(1) then begin
      print,'FITS_REPLACE_COL: Wrong dimension of new column'
      fxbfinish, unit
      return
   endif
endif


for i = 0L, sz(sz(0)) - 1 do begin
   row = firstrow + i
   if sz(0) eq 2 then begin
      fxbwrite, unit, coldata(*,i), col_number, row
   endif else begin
      fxbwrite, unit, coldata(i), col_number, row
   endelse
endfor

fxbfinish, unit


end
