pro fits_tab2ascii, fits_ext, ascii_file, pcount=pcount
;
;   Convert FITS binary table to ASCII file in S-format
;
;   2004-08-27/NJW
;   2006-01-11/NJW bug fix wrt. pcount as a variable and keyword
;
if n_params() lt 2 then begin
   print,'Syntax: fits_tab2ascii, fits_ext, ascii_file'
   print,'  This version works for tables without variable length'
   print,'  columns'
   print,'  If the PCOUNT/GCOUNT keywords are set you may proceed anyway'
   print,'  by setting pcount=''no'''
   return
endif

get_exten_no, fits_ext, fits_file, extno

if strmid(fits_ext,0,1) ne '/' then $
   fits_ext = getenv('PWD')+'/'+fits_ext

if file_test( fits_file, /reg ) then begin
   fxbopen, unit, fits_file, extno,'R'
endif else begin
   print,'Could not open '+fits_file
   return
endelse

hdr = headfits( fits_file, exten=extno )
ncols = fxpar( hdr,'TFIELDS')
nrows = fxpar( hdr,'NAXIS2')
pcountval = fxpar( hdr,'PCOUNT')
gcountval = fxpar( hdr,'GCOUNT')
if not keyword_set(pcount) then begin
   if pcountval ne 0 or gcountval ne 1 then begin
      print,'Found PCOUNT = '+stri(pcountval)
      print,'Found CCOUNT = '+stri(gcountval)
      print,'Illegal table!'
      fxbclose, unit
      return
   endif
endif

; Get data types in the columns

types = intarr(ncols)
fields = intarr(ncols)
nelems = intarr(ncols)
frmat  = strarr(ncols)
for i = 0, ncols-1 do begin
   tform = strtrim(fxpar(hdr,'TFORM'+stri(i+1)),2)
   p = strpos(tform,'A')
   if p ge 0 then begin
      types(i) = 7
      fields(i) = fix(strmid(tform,0,p))+1
      nelems(i) = 1
      indeff = ''
      for j = 0, fields(i)-2 do indeff = indeff+' '
   endif
   p = strpos(tform,'B')
   if p ge 0 then begin
      types(i) = 1
      fields(i) = 5
      nelems(i) = fix(strmid(tform,0,p))
      frmat(i) = '('+stri(nelems(i))+'i5)'
   endif
   p = strpos(tform,'I')
   if p ge 0 then begin
      types(i) = 2
      fields(i) = 7
      nelems(i) = fix(strmid(tform,0,p))
      frmat(i) = '('+stri(nelems(i))+'i7)'
   endif
   p = strpos(tform,'J')
   if p ge 0 then begin
      types(i) = 3
      fields(i) = 11
      nelems(i) = fix(strmid(tform,0,p))
      frmat(i) = '('+stri(nelems(i))+'i11)'
   endif
   p = strpos(tform,'E')
   if p ge 0 then begin
      types(i) = 4
      fields(i) = 15
      nelems(i) = fix(strmid(tform,0,p))
      frmat(i) = '('+stri(nelems(i))+'e15.6)'
   endif
   p = strpos(tform,'D')
   if p ge 0 then begin
      types(i) = 5
      fields(i) = 18
      nelems(i) = fix(strmid(tform,0,p))
      frmat(i) = '('+stri(nelems(i))+'e18.9)'
   endif
   if types(i) eq 0 then begin
      print,'Problem with data type in column '+stri(i+1)
      fxbclose,unit
      return
   endif
endfor

openw,lun,ascii_file,/get_lun

printf,lun,'// Data taken from the following DOL:'
printf,lun,'// dol = '+fits_ext
printf,lun,'// time = '+ndate(2)
fsum = 0
for i = 0, ncols-1 do begin
   fsum = fsum + nelems(i)*fields(i)
   printf,lun,'// endfield = ', fsum - 1
   printf,lun,'// numfield = ', nelems(i)
endfor

; Analyze header

nh = n_elements(hdr)
for i = 0, nh-1 do begin
   key = strtrim(strmid(hdr(i),0,8),2)
   if strlowcase(key) eq 'comment' or strlowcase(key) eq 'history' then begin
      printf,lun,'// '+hdr(i)
   endif else begin
      value = fxpar( hdr, key, comment=comment)
      sv = size(value)
      if sv(sv(0)+1) ne 7 then value = stri(value)
      printf,lun,'// '+key+' = '+value+' ; '+comment
   endelse
endfor


for row = 1L, nrows do begin
   line = ''
   for col = 1, ncols do begin
      fxbread, unit, data, col, row
      if types(col-1) eq 7 then begin
	 if strlen(data) eq 0 then data = indeff
	 line = line + ' ' + data
      endif else $
         line = line+string(data,format=frmat(col-1))
   endfor
   printf,lun,line
endfor

free_lun, lun
fxbclose,unit

end
