function fkernel, kernel, dim1, dim2
;
;   Returns the Fourier transform of 'kernel', a 2D array
;   of odd dimensions that holds the convolution kernel
;   padded to dimensions (dim1,dim2)
;
;   2005-03-31/NJW
;
if n_params() lt 3 then begin
   print,'Syntax: fk = fkernel( kernel, dim1, dim2 )
   return, -1
endif

sz = size(kernel)
if sz(0) ne 2 then begin
   print,'FKERNEL: First argument (kernel) must be 2D'
   return,-1
endif

if sz(1)*sz(2) mod 2 ne 1 then begin
   print,'FKERNEL: Kernel dimensions must be odd'
   return,-1
endif

if dim1*dim2 mod 2 ne 1 then begin
   print,'FKERNEL: Array dimensions must be odd'
   return,-1
endif

m1 = (sz(1)-1)/2
m2 = (sz(2)-1)/2
d1 = (dim1-1)/2
d2 = (dim2-1)/2
a = fltarr(dim1, dim2)
a(d1-m1:d1+m1,d2-m2:d2+m2) = kernel
a = shift(a,-d1,-d2)

return, fft(a,-1)

end
