function flatfield, image, sigma=sigma, type=type
;
; Simple flatfielding of an image with itself
;
;  2003-11-01/NJW
;
if n_params() lt 1 then begin
   print,'Syntax: newimage = flatfield(image[, sigma=][, type=]'
   print,'  Keyword ''type'''
   print,'             0 : simple gauss convolution subtraction'
   print,'             1 : 2 times gauss convolution subtraction'
   print,'             2 : 3 times gauss convolution subtraction'
   print,'  Default value for sigma is 5.0 pixels'
   return,-1
endif

if not keyword_set(sigma) then sigma = 5.

if not keyword_set(type) then type = 0

if type gt 2 then begin
   print,'%FLATFIELD error, type '+stri(type)+' is not allowed'
   return,-1
endif

flat1 = gauss_convol_2d(image,sigma)
dif1 = image - flat1
imw = image ; working copy

case type of
   0 : return, dif1
   1 : begin
        r = rms(dif1)
        w = where( abs(dif1) gt 2.*r, nw)
        if nw gt 0 then begin
           imw(w) = flat1(w)
           flat2 = gauss_convol_2d(imw, sigma)
           return, image - flat2
        endif else return, image - flat1
      end
   2 : begin
        r = rms(dif1)
        w = where( abs(dif1) gt 2.*r, nw)
        if nw gt 0 then begin
           imw(w) = flat1(w)
           flat2 = gauss_convol_2d(imw, sigma)
           dif2 = image - flat2
           dif2(w) = 0.
           r = rms(dif2)
           w = where( abs(dif2) gt 2.*r, nw)
           if nw gt 0 then begin
              imw(w) = flat2(w)
              flat3 = gauss_convol_2d(imw,sigma)
              return, image - flat3
           endif else return, image - flat2
        endif else return, image - flat1
      end
endcase
end
