function fold_gauss, e, f, sigma
;
; Fold a spectrum with a Gauss peak with a sigma, that may
; not be constant 
;
;  Call -  e : energy array
;          f : array with spectrum, same size as 'e'
;        sigma  : array with standard deviations, same size as 'e'
;
;  Return : folded spectrum
;
;     When ? /NJW
;      2003-08-29/NJW   updated

if n_params() ne 3 then begin
   print,'Syntax: f_folded = fold_gauss( e, f, sigma )'
   return,-1
endif

n = n_elements(e)
ee = fltarr(n)
ee(*) = e
sq2 = sqrt(2.)

; Define channel boundaries

eb = 0.5*(ee + shift(ee,1))
eb(0) = (3*ee(0) - ee(1))/2
eb = [eb,(3*ee(n-1) - ee(n-2))/2]
g = ee * 0.
for i = 0, n-1 do begin
   j = where(e gt ee(i)-5*sigma(i) and e lt ee(i)+5*sigma(i))
   if( j(0) ne -1 ) then begin
      nj = n_elements(j)
      norm = 0.
      sum = 0.
      for k = 0, nj-1 do begin
         l = j(k)
         delta_e = eb(l+1) - eb(l)
         x2 = (eb(l+1) - ee(i))/(sigma(i)*sq2)
         erx2 = erf(x2)
         x1 = (eb(l) - ee(i))/(sigma(i)*sq2)
         erx1 = erf(x1)
         w = erx2 - erx1
         sum = sum + f(l) * w
         norm = norm + w
      endfor
      g(i) = sum / norm
   endif
endfor

return,g

end
