function fold_gaussb, e_min, e_max, f, sigma
;
; Fold a spectrum with a Gauss peak with a sigma, that may
; not be constant 
;
;  Call -  e_min: lower energy channel boundaries
;          e_max: upper energy channel boundaries
;          f : array with spectrum, same size as 'e_min' with
;              counts per bin
;        sigma  : array with standard deviations, same size as 'e_min'
;
;  Return : folded spectrum
;
;     2003-08-29/NJW  built on fold_gauss

if n_params() ne 4 then begin
   print,'Syntax: f_folded = fold_gaussb( e_min, e_max, f, sigma )'
   return,-1
endif

n = n_elements(e_min)
if n ne n_elements(e_max) or n ne n_elements(f) or n ne n_elements(sigma) then begin
   print,'FOLD_GAUSSB error - mismatch between array dimensions'
   return,-1
endif

sq2 = sqrt(2.)

; Define channel boundaries

eb = [e_min, e_max(n-1)]
ee = 0.5*(e_min + e_max)
g = ee * 0.

for i = 0, n-1 do begin
   j = where(ee gt ee(i)-5*sigma(i) and ee lt ee(i)+5*sigma(i))
   if( j(0) ne -1 ) then begin
      nj = n_elements(j)
      norm = 0.
      sum = 0.
      for k = 0, nj-1 do begin
         l = j(k)
         delta_e = eb(l+1) - eb(l)
         x2 = (eb(l+1) - ee(i))/(sigma(i)*sq2)
         erx2 = erf(x2)
         x1 = (eb(l) - ee(i))/(sigma(i)*sq2)
         erx1 = erf(x1)
         w = erx2 - erx1
         sum = sum + f(l) * w
         norm = norm + w
      endfor
      g(i) = sum / norm
   endif
endfor

return,g

end
