pro fold_rmf, rmf_file, tag=tag
;
;   2003-08-29/NJW
;
;  Find FWHM/E as a function of energy in a given RMF GRP file
;
if n_params() ne 1 then begin
   print,'Syntax:  report_on_rmf, rmf_file'
   return
endif

;  Get the energy tables a the redistribution matrix itself

rdfitscol,rmf_file+'+2',energ_lo,'energ_lo',hdr=hdr2
rdfitscol,rmf_file+'+2',energ_hi,'energ_hi'
rdfitscol,rmf_file+'+2',matrix,'matrix'
rdfitscol,rmf_file+'+3',e_min,'e_min'
rdfitscol,rmf_file+'+3',e_max,'e_max'

; Extract the information

write_slist, 'output', fxpar(hdr2,'comment')
nphotons = comget('output','nphotons',ierr)
fano_factor = comget('output','fano_factor',ierr)

e = 0.5*(e_min+e_max)
de = e_max - e_min
energ = 0.5*(energ_lo + energ_hi)
denerg = energ_hi - energ_lo

; make arrays for plotting the result

expected_val = fltarr(1000)
found_val = fltarr(1000)
energy_val = fltarr(1000)

k = 0
for l = 80, 350, 10 do begin ; step over photon enegies

   energy = energ(l)
   sigma_nominal = 0.47*sqrt(energy)/2.355
   sigma_estimate = 1.5 * sigma_nominal
   estimate = [1.5*0.02/(sigma_estimate*sqrt(2*!pi)),energy,sigma_estimate]
   mat = total(matrix(*,l-1:l+1),2)/3
   xmat = rebin_pi2linear(mat,escal=xe)
   res = gaussfit(xe,xmat,a,nterms=3,estimate=estimate)
   plot,xe,xmat,xr=[energy-4*sigma_estimate,energy+4*sigma_estimate],ps=10
   oplot,xe,res,thick=3
   oplot,xe,estimate(0)*exp(-0.5*((xe-estimate(1))/estimate(2))^2),li=2

   expected_val(k) = 2.355 * sigma_nominal
   found_val(k) = 2.355 * a(2)
   energy_val(k) = energy

   wait,1
   k = k + 1

endfor

expected_val = expected_val(0:k-1)
found_val = found_val(0:k-1)
energy_val = energy_val(0:k-1)

; Plot to a file

plotfile = get_next_filename('rmfplot???.ps')
rps,file=plotfile
plot, energy_val, 100*expected_val/energy_val,yr=[0,50],$
  ytit='FWHM [%]',xtit='Energy [keV]',title=rmf_file
def_sym,'c'
oplot, energy_val, 100*found_val/energy_val,thick=5,ps=-8
legend,['Nominal','Actual'],linestyle=[0,0],thick=[1,5],pos=[.6,.85],charsize=1.5
xyouts,0.6,0.65,'Fano fac. ='+string(fano_factor,format='(f5.2)'),charsize=1.2,/norm
xyouts,0.6,0.58,'Num phot in ='+string(nphotons,format='(i7)'),charsize=1.2,/norm
if keyword_set(tag) then xyouts,0.6,0.51,tag,charsize=1.5,/norm
zps,/gv

end
