pro fold_spec_thru_rmf, intenscode, spectrcode, intens, nh, param1, $
          e_min, e_max, countspec, eli=eli, flx=flx
;
;  Make an X-ray spectrum and fold with the RMF of JEMX
;
;   NJW/2002-01-10
;   Updated 2003-06-14/NJW
;
if n_params() lt 8 then begin
   print,'Syntax: fold_spec_thru_rmf, intenscode, spectrcode, intens, nh, param1, $'
   print,'                             > e_min, e_max, countspec[,eli=][,flx=]'
   return
endif

;   Get the RMF data

grpname = '/home/njw/jemx/response_matrix/jmx1_rmf_grp_0003.fits+1'
ebm_get_child_by_name,grpname,'JMX1-FBDS-MOD',fbds_name
rdfitscol,fbds_name,e_min,'E_MIN',/sil
rdfitscol,fbds_name,e_max,'E_MAX',/sil

ebm_get_child_by_name,grpname,'JMX1-RMF.-RSP',rmf_name
rdfitscol,rmf_name,elo,'ENERG_LO',/sil
rdfitscol,rmf_name,ehi,'ENERG_HI',/sil
rdfitscol,rmf_name,matrix,'MATRIX',/sil
eline = 0.5*(elo + ehi)
eli = eline

ebm_get_child_by_name,grpname,'JMX1-AXIS-ARF',arf_name
rdfitscol,arf_name,arf,'SPECRESP',/sil

;   Generate the input spectrum

intenscode = strupcase(strtrim(intenscode,2))
spectrcode = strupcase(strtrim(spectrcode,2))

case spectrcode of
     'PL' : begin
             flux = eline^(-param1) * absorp(nh, eline)
            end
     'TB' : begin
             flux = (exp(-eline/param1) / eline) * absorp(nh, eline)
            end
     'DF' : begin
             dum = min(abs(eline-param1),index)
             flux = fltarr(n_elements(eline))
             flux(index) = 1.
             flux = flux * absorp(nh, eline)
            end
     default : begin
               print,'No such spectral model allowed: ', spectrcode
               return
               end
endcase

if intenscode eq 'SX' then begin
   if spectrcode ne 'DF' then begin
      sx = sflux(2.,10.,eline,flux)
      flux = flux * intens / sx
   endif else begin
      flux = flux * intens / (total(flux*(ehi-elo)*eline)*1.6e-9)
   endelse
endif else begin
   flux = flux * intens
endelse

flx = flux

line_counts = flux * (ehi - elo) * arf
countspec = matrix#line_counts

end
