function free_machines
;
; Function to check the usage of the machines
;  and return the names of the 'free' machines
;
machine = ['apollo','sas3','heao1','hakucho','einstein',$
           'tenma','astron','exosat','ariel']
host = getenv('HOST')
nm = n_elements(machine)
res = strarr(nm) ; Prepare output array
usage = fltarr(nm)

;
;... See which machines are alive
;
for m = 0, nm-1 do begin
   spawn,'/usr/sbin/ping '+machine(m),list
   print,list(0)
   reply = strpos(list(0),'alive')
   if reply eq -1 then machine(m) = 'dead'
endfor

;... Loop over Solaris machines in network

for m = 0, nm-1 do begin
   if machine(m) ne 'dead' then begin
      print,'-----------------------------------------------------'
      print,'               ',machine(m)
      print,'-----------------------------------------------------'

;   ... Run 'top' on the machine in question

      if machine(m) eq host then spawn,'top',list else $
             spawn,'rsh '+machine(m)+' top', list
      ;* print,list
      n = n_elements(list)
      print,n,' lines found in result of ''top'''

      if n gt 5 then begin  ; This indicates that the machine is
                            ; not useful, e.g. no more processes

;   ... Analyze the response. After line with 'PID' as the first
;           three characters the CPU usage is
;           given for each process. They are summed up except
;           if they are running with 'nice' > 10

         j = 0
         beginning = ' '
         while beginning ne 'PID' and j lt n-1 do begin
            list(j) = strtrim(strcompress(list(j)),1)
            beginning = strmid(list(j),0,3)
            j = j + 1
         endwhile
         print,'in search for ''PID'' j ended as ', j
;   ... get the column numbers from the names
         tok = str_sep(list(j-1),' ')
         posnice = where(tok eq 'NICE',nposnice)
         posnice = posnice(0)
         poscpu = where(tok eq 'CPU',nposcpu)
         poscpu = poscpu(0)
         ;* print,'NICE: ', posnice,'   CPU: ', poscpu
         ;* print,'Begin with j = ', j
         ;* print
;
         sum = 0.0
         for i = j,n-2 do begin
            list(i) = strtrim(strcompress(list(i)),1)
            tok = str_sep(list(i),' ') ; Split into items
            nice = fix(tok(posnice))
            ;* print,'Nice ', nice, ' fraction ', tok(poscpu)
            l = strlen(tok(poscpu))
            s = strmid(tok(poscpu),0,l-1) ; Strip the '%' sign
            if nice le 10 then sum = sum + float(s)
         endfor
         print,machine(m)+' Total usage : ', sum,'%'
         usage(m) = sum
      endif else usage(m) = 999.
   endif else usage(m) = 999.
endfor
print,'-----------------------------------------------------'
print,'               Termination'
print,'-----------------------------------------------------'

; Sort according to usage

isort = sort(usage)
machine = machine(isort)
usage = usage(isort)
print,'Machines: ',machine
print,'Usage: ',usage

; If all machines are busy all are suggested except those
; that are dead

nsuggest = 0
limit = 30.
while nsuggest eq 0 and limit lt 110. do begin
   suggest = where( usage lt 30., nsuggest)
   limit = limit + 10.
endwhile
print,'Final limit : ', limit

return, machine(suggest)
end
