pro ftzoom, name_in, name_out,zf=zf, ert=ert

; Procedure to extract piece of FITS image with celestial
; coordinates

if n_params() ne 2 then begin

   print,'Syntax: FTZOOM, name_in, name_out[,zf=][,ert=]'
   return

endif

get_exten_no, name_in, name_in_name, extno

zfac = 2.
if keyword_set(zf) then zfac = zf
print,'You are using zoom factor ', zfac
if keyword_set(ert) then et = 1 else et = 0   ; error tracking

; Retrieve input image

im = readfits(name_in_name, hdr, exten_no=extno)

szim = size(im)
crpix1 = sxpar(hdr, 'CRPIX1','CRPIX1 not found')
crpix2 = sxpar(hdr, 'CRPIX2','CRPIX2 not found')
if et then print,'Original crpix : ', crpix1, crpix2

; Display image

set_plot,'x'
window,0,xs=szim(1),ys=szim(2)
tvscl,im>0

print,'Use cursor to select zoom center : ...'
cursor, xc, yc,/device
xc = fix(xc+0.5)
yc = fix(yc+0.5)

print, 'Center : ', xc, yc
width_inx = szim(1)
width_iny = szim(2)

width_x = fix(width_inx / zfac + 0.5)
width_y = fix(width_iny / zfac + 0.5)
if et then print,'Zoom image width : ', width_x, width_y
x1 = xc - width_x/2
x2 = x1 + width_x - 1
y1 = yc - width_y/2
y2 = y1 + width_y - 1
if et then print,'(',x1,':',x2,',',y1,':',y2,')'

; Adjust extracted piece to stay inside the image

if x1 lt 0 then begin
   x2 = x2 - x1
   xc = xc - x1
   x1 = 0
endif
if y1 lt 0 then begin
   y2 = y2 - y1
   yc = yc - y1
   y1 = 0
endif
if x2 ge width_inx then begin
   x1 = x1 - (x2 - width_inx - 1)
   xc = xc - (x2 - width_inx - 1)
   x2 = width_inx - 1
endif
if y2 ge width_iny then begin
   y1 = y1 - (y2 - width_iny - 1)
   yc = yc - (y2 - width_iny - 1)
   y2 = width_iny - 1
endif
crpix1 = crpix1 - x1
crpix2 = crpix2 - y1
if et then print,'(',x1,':',x2,',',y1,':',y2,')'

; Output selected piece of image

om = im(x1:x2, y1:y2)
sxaddpar, hdr,'NAXIS1',width_x,'New size in x'
sxaddpar, hdr,'NAXIS2',width_y,'New size in y'
sxaddpar, hdr,'CRPIX1',crpix1,'New reference pixel i x'
sxaddpar, hdr,'CRPIX2',crpix2,'New reference pixel i y'
sxaddpar, hdr,'O_FILE',name_in,'Original file'
sxaddpar, hdr,'O_XCEN',xc,'X center in original file'
sxaddpar, hdr,'O_YCEN',yc,'Y center in original file'
sxaddpar, hdr,'PROGRAM','ftzoom','Program used for extraction'
writefits,name_out,om,hdr

end
