pro gain_plot, gain, time=time, outfile=outfile
;
;  Plotting gain as derived by using 'j_get_used_gain.pro'
;  Data are combined into 100 points and 5% and 95% curves
;  are shown as well
;
;  IJD time values will be returned in keyword 'time' if set
;  File 'outfile' will be updated with the results
;
;    2007-01-04/NJW
;

common gain_calc_plot, swid_com

n = n_elements(gain)

xtit = 'Index'
if keyword_set(time) then begin
   if n_elements(time) ne n then begin
      print,'Number of elements in ''time'' does not match gain elements'
      return
   endif
   t0 = fix(time(0))
   xtit='IJD - '+stri(t0)
endif

nblock = long(n) / 100

avg_gain = fltarr(100)
avg_gain_95 = fltarr(100)
avg_gain_05 = fltarr(100)
avg_time = dblarr(100)

for i = 0L, 99L do begin

   w = indgen(nblock,/long) + nblock*i
   gn = gain(w)
   if keyword_set(time) then avg_time(i) = avg(time(w)) else avg_time(i) = i
   gn = gn(sort(gn))
   avg_gain_95(i) = gn(0.95*nblock)
   avg_gain_05(i) = gn(0.05*nblock)
   avg_gain(i) = avg(gn(0.05*nblock:0.95*nblock))

endfor

plot,avg_time-t0, avg_gain, thick=3, yr=[15, 30], $
       ytit='PHA/keV',xtit=xtit,charsize=1.2, $
       title='JMX1 gain '+swid_com
oplot, avg_time-t0, avg_gain_05
oplot, avg_time-t0, avg_gain_95

if keyword_set(outfile) then begin
   hdr = ['// '+systime(),'// SWID = '+swid_com]
   wstab,outfile,hdr,avg_time,avg_gain,avg_gain_05,avg_gain_95, $
           /app,fmt='f12.6'
endif

end
