pro galplanemap, rep=rep
;
; Originally Program sourcemap
;
;
; Draw a map of sources in a section of the galactic plane
;
;  Keyword: rep  : repeat previous plot
;


common cat_com, cat, num_entries_cat, dol_of_cat

;  Install the 'parameter' file: galplanemap.par if it does not exist in the
;  current directory

list = findfile('galplanemap.par',count=n_list)

if n_list ne 1 then begin
   if !version.os eq 'Win32' then par_template = 'c:\jsim\Catalogs\galplanemap.par'
   if !version.os eq 'sunos' then par_template = '/home/njw/jsim/Catalogs/galplanemap.par'
   par = read_slist(par_template)
   write_slist, 'galplanemap.par', par
endif

gps = 0

repeet = 0
if keyword_set(rep) then repeet = 1
;          The spelling is intended. Else there is a conflict with
;          the IDL statement 'repeat'

celest = 0 ; default celestial system is 'galactic'

xtitstr = 'Gal. Long. [deg]'
ytitstr = 'Gal. Lat.  [deg]'

openw,lout,'output',/get_lun

;   Prepare to avoid writing text on top of each other

n_boxes = 0
boxes = fltarr(4,300) ; each row is a box of text in normal coordinates
xtnormv = fltarr(300) ; save values when two passes are required
ytnormv = fltarr(300) ; save values when two passes are required

; Get name of input catalogue file


szin = size(dol_of_cat)
if szin(0)+szin(1) eq 0 then begin
   old_catalogue = ''
endif else begin
   input_catalogue = dol_of_cat
   old_catalogue = input_catalogue
endelse

if repeet then begin
   input_catalogue = comgets('galplanemap.par','input_catalogue',ierr)
endif else begin
   input_catalogue = get_pars('galplanemap.par','input_catalogue')
endelse
read_again = 0
if input_catalogue ne old_catalogue then read_again = 1

; Read the contents of the catalogue

sz = size(cat)
if sz(0)+sz(1) eq 0 or read_again then read_catalog, input_catalogue, n_in_input_cat

;   Choose the limits of galactic longitude

answer = ''

gl_lim1 = 0.0
gl_lim2 = 0.0
gb_max = 0.0

print,'The galactic longitude and latitude in decimal degrees'
if repeet then gl_lim1 = comget('galplanemap.par','gl_lim1',ierr)$
else gl_lim1 = get_par('galplanemap.par','gl_lim1')

if repeet then gl_lim2 = comget('galplanemap.par','gl_lim2',ierr)$
else gl_lim2 = get_par('galplanemap.par','gl_lim2')

if repeet then gb_max = comget('galplanemap.par','gb_max',ierr)$
else gb_max = get_par('galplanemap.par','gb_max')

; Get the center of field in celestial coordinates

;glactc,ra_cen_hour,dc_cen,2000,gl_cen,gb_cen,2
;ra_cen = ra_cen_hour * 15.0




;    Make sure that the limits are between 0 and 360 deg for the longitude

if gl_lim1 lt 0.0 then gl_lim1 = gl_lim1 + 360.
if gl_lim2 lt 0.0 then gl_lim2 = gl_lim2 + 360.

;    Make sure that gl_lim2 > gl_lim1

if gl_lim2 lt gl_lim1 then begin ; swap the two values
   swap = gl_lim1
   gl_lim1 = gl_lim2
   gl_lim2 = swap
endif

;   Always choose the smallest of the two intervals

inside = 1
gl_size = gl_lim2 - gl_lim1
if gl_size gt 180. then begin
   inside = 0
   gl_size = 360. - gl_size
endif

;dither_around_pointing,ra_cen,dc_cen,0.0,patt=2





if repeet then limit = comget('galplanemap.par','limit',ierr)$
else limit = get_par('galplanemap.par','limit')


if repeet then sourcetype = comgets('galplanemap.par','sourcetype',ierr) $
else begin
sourcetype = comgets('galplanemap.par','sourcetype',ierr)
print,'Choose an X-ray source type.'
print,'Type of sources (''any'' to get all independently of type) [',$
               strtrim(sourcetype,2),']'
read,'                                  New source type : ... ', answer
if answer eq '' then begin
   print,'The sourcetype is: ', sourcetype
endif else begin
   sourcetype = answer
   ierr = comreplaces('galplanemap.par','sourcetype', sourcetype)
endelse
endelse
sourcetype = strupcase(sourcetype)


c = cat.catalog
ndd = 9999
print,'  Catalogues in the data base:'
while ndd gt 0 do begin
   print,'           ',c(0)
   nam = strtrim(c(0),2)
   dd = where(strpos(c,nam) lt 0,ndd)
   if ndd gt 0 then c = c(dd)
endwhile



if repeet then catalogsel = comgets('galplanemap.par','catalogue',ierr) $
else begin
catalogsel = comgets('galplanemap.par','catalogue',ierr)
print,'Choose an X-ray source catalogue.'
print,'Catalogue (''any'' to get all independently of type) [',$
               strtrim(catalogsel,2),']'
read,'                                  New catalogue : ... ', answer
if answer eq '' then begin
   print,'The catalogue is: ', catalogsel
endif else begin
   catalogsel = answer
   ierr = comreplaces('galplanemap.par','catalogue', catalogsel)
endelse
endelse
catalogsel = strupcase(catalogsel)




if repeet then plotheader = comgets('galplanemap.par','plotheader',ierr) $
else begin
plotheader = comgets('galplanemap.par','plotheader',ierr)
print,'Plot header [',strtrim(plotheader,2),']'
read,'                     New header : ... ', answer
if answer eq '' then begin
   print,'The header is: ', plotheader
endif else begin
   plotheader = answer
   ierr = comreplaces('galplanemap.par','plotheader', plotheader)
endelse
endelse


;   Ask for LABELS

if repeet then labels = comgets('galplanemap.par','labels',ierr) $
else begin
   labels = comgets('galplanemap.par','labels',ierr)
   print,'Do you want labels in the plot? [',strtrim(labels,2),']'
   read,'                                : ... ', answer
   if answer eq '' then begin
      print,'Labels ?  : ', labels
   endif else begin
      labels = strmid(answer,0,1)
      ierr = comreplaces('galplanemap.par','labels', labels)
   endelse
endelse



;   Additional points EXTRALIST

if repeet then extralist = comgets('galplanemap.par','extralist',ierr) $
else begin
extralist = comgets('galplanemap.par','extralist',ierr)
print,'Filename with extra plot points e.g. sources [',strtrim(extralist,2),']'
read,'                                : ... ', answer
if answer eq '' then begin
   if extralist eq 'none' or extralist eq '' then begin
      print,'No extra points included'
   endif else begin
      print,'Including points from: ', extralist
   endelse
endif else begin
   extralist = answer
   ierr = comreplaces('galplanemap.par','extralist', extralist)
endelse
endelse

extrapoints = 0
if extralist ne 'none' and extralist ne '' then begin

   extrapoints = 1
   rstab,extralist, exc1, exc2, nrows=n_extra
   cosys = comgets(extralist, 'coordsys', ierr)

   ;  if same coordinate system as plot then do nothing
   ;  else make appropriate conversion

   if cosys eq 'celestial' then begin
      for i = 0, n_extra-1 do begin
         glactc,exc1(i)/15.,exc2(i),2000,zlx,zbx,1
         exc1(i) = zlx
         exc2(i) = zbx
      endfor
   endif

endif




;   Add pointings  POINTINGS

if repeet then pointings = comgets('galplanemap.par','pointings',ierr) $
else begin
pointings = comgets('galplanemap.par','pointings',ierr)
print,'Filename with INTEGRAL pointings [',strtrim(pointings,2),']'
read,'                                : ... ', answer
if answer eq '' then begin
   if pointings eq 'none' or pointings eq '' then begin
      print,'No INTEGRAL pointings included'
   endif else begin
      print,'Including pointings from: ', pointings
   endelse
endif else begin
   pointings = answer
   ierr = comreplaces('galplanemap.par','pointings', pointings)
endelse
endelse

add_pointings = 0
if pointings ne 'none' and pointings ne '' then begin

   add_pointings = 1
   rstab,pointings, pntc1, pntc2, nrows=n_pnt
   cosys = comgets(pointings, 'coordsys', ierr)

   ;  if same coordinate system as plot then do nothing
   ;  else make appropriate conversion

   if cosys eq 'celestial' then begin
      for i = 0, n_pnt-1 do begin
         glactc,pntc1(i)/15.,pntc2(i),2000,zlx,zbx,1
         pntc1(i) = zlx
         pntc2(i) = zbx
      endfor
   endif

   print,'Calling mk_gps_sensitivity function ...'
   imarr = mk_gps_sensitivity( gb_max, gl_lim1, gl_lim2, inside, pntc1, pntc2)

endif


max_point_size = 1.6
min_point_size = 0.3

intens = cat.intens
name = cat.sourcename
category = cat.category
catalog = cat.catalog
ra   = cat.ra
dec  = cat.dec


selection = where(intens gt limit * 2.e-11 , n_selection )
if n_selection le 0 then begin
   print,'  -- no sources above intens limit !'
   return
endif

intens = intens(selection)
name = name(selection)
ra = ra(selection)
dec = dec(selection)
category = category(selection)
catalog = catalog(selection)

if sourcetype ne 'ANY' then begin ; select on source type
   search = strpos(category, sourcetype)
   selection = where( search ge 0 , n_selection )
   if n_selection eq 0 then begin
      print,'No sources in this category: ', sourcetype
      return
   endif
   intens = intens(selection)
   ra = ra(selection)
   name = name(selection)
   dec = dec(selection)
   category = category(selection)
   catalog = catalog(selection)
endif

if catalogsel ne 'ANY' then begin ; select on catalogue
   search = strpos(catalog, catalogsel)
   selection = where( search ge 0 , n_selection )
   if n_selection eq 0 then begin
      print,'No sources in this catalogue: ', catalogsel
      return
   endif
   intens = intens(selection)
   ra = ra(selection)
   name = name(selection)
   dec = dec(selection)
   category = category(selection)
   catalog = catalog(selection)
endif

n = n_elements(intens)

gl = fltarr(n) ;  galactic longitude
gb = fltarr(n) ;  galactic latitude

acoef = (max_point_size - min_point_size) / alog10(1000.)
bcoef = min_point_size - acoef * alog10(limit * 2.e-11)

for i = 0, n-1 do begin
   glactc,ra(i)/15.,dec(i),2000,zl,zb,1
   if zl lt 0.0 then zl = zl + 360.     ; avoid values < 0
   gl(i) = zl
   gb(i) = zb
endfor

;   Do the selection based on position

if inside then begin
   selection = where( gl gt gl_lim1 and gl lt gl_lim2 and abs(gb) lt gb_max, n_selection)
endif else begin
   selection = where( gl gt gl_lim2 or gl lt gl_lim1 and abs(gb) lt gb_max, n_selection)
endelse
if n_selection eq 0 then begin
   print,'No sources in galactic plane section '
   return
endif
intens = intens(selection)
name = name(selection)
ra = ra(selection)
dec = dec(selection)
category = category(selection)
catalog = catalog(selection)
gl = gl(selection)
gb = gb(selection)

; Define common coordinates

x = gl
y = gb

n = n_selection

; Sort according to second coordinate

isort = sort(y)
intens = intens(isort)
name = name(isort)
x = x(isort)
y = y(isort)
category = category(isort)
catalog = catalog(isort)
ra = ra(isort)
dec = dec(isort)
gl = gl(isort)
gb = gb(isort)
point_size = acoef * alog10(intens) + bcoef

;--------------------------------------------------------
;
;   The selection of sources is finished and the plotting
;   can start
;
;--------------------------------------------------------

n_pass = 1
if !d.name eq 'PS' then n_pass = 2

for i_pass = 1, n_pass do begin

printf,lout
printf,lout,'Start pass ', i_pass
printf,lout


if !d.name eq 'PS' then begin
   !p.font = 0
   xsize = 38.
   ysize = xsize * 2. * gb_max / gl_size
   if ysize gt 22. then begin
      xsize = xsize * 22. / ysize
      ysize = 22.
   endif
   xoffset = (30. - ysize)/2
   yoffset = xsize/2 + 21.
   device,/landscape,xsize=xsize,ysize=ysize,xoffset=xoffset,yoffset=yoffset
   device,/times
   height = 600.
   csiz = 0.7
endif else begin
   !p.font = -1
   xsize = 1400
   ysize = xsize * 2. * gb_max / gl_size
   if ysize gt 600 then begin
      xsize = xsize * (600. / ysize)
      ysize = 600
   endif
   window,0,xsize=xsize,ysize=ysize
   height = 12.
   csiz = 1.0
endelse

!p.position = [0.1,0.1,0.95,0.95]

def_sym,'c',/fill
if inside then begin
   xra = [gl_lim2,gl_lim1]
endif else begin
   xra = [gl_lim1,gl_lim2-360.]
endelse
yra = [-gb_max,gb_max]

; Shift sources with X 180 -> 360 to negative if
; plot range requires it

if xra(1) lt 0 then begin
   h = where(x gt 180, n_h)
   if n_h gt 0 then x(h) = x(h) - 360
   if extrapoints then begin
      h = where(exc1 gt 180, n_h)
      if n_h gt 0 then exc1(h) = exc1(h) - 360
   endif
   if add_pointings then begin
      h = where(pntc1 gt 180, n_h)
      if n_h gt 0 then pntc1(h) = pntc1(h) - 360
   endif
endif

; Shift sources with X 0 -> 180 to 360 +  if
; plot range requires it

;if xra(0) gt 360 then begin
;   h = where(x lt 180, n_h)
;   if n_h gt 0 then x(h) = x(h) + 360
;   if extrapoints then begin
;      h = where(exc1 lt 180, n_h)
;      if n_h gt 0 then exc1(h) = exc1(h) + 360
;   endif
;endif

plot, x, y, xr=xra, yr=yra, xtitle=xtitstr, $
     ytitle=ytitstr, title=plotheader, /nodata, charsize=1.3,$
     yticklen=0.01, xstyle=1, ystyle=17
;*   ,$ color=4

oplot, xra,[0,0],li=2
if extrapoints then begin
   def_sym,'c'
   oplot,exc1,exc2,psym=8,symsize=1.5
endif
if add_pointings then begin
   oplot,pntc1,pntc2,psym=7,symsize=0.8
endif
plotname,'galplanemap'
plotsign

; prepare writing found sources to file
; but only in pass 1

if i_pass eq 1 then begin


   ; Initial loop to protect the data points from text

   for i = 0, n-1 do begin
      res = convert_coord([x(i),y(i)],/data,/to_normal)
      ; protect the data point:
      boxes(0,n_boxes) = res(0) - 0.01
      boxes(2,n_boxes) = res(0) + 0.01
      boxes(1,n_boxes) = res(1) - 0.01
      boxes(3,n_boxes) = res(1) + 0.01
      ;* drawbox,boxes(*,n_boxes)
      n_boxes = n_boxes + 1
   endfor

endif ; check for pass 1

for i = 0, n-1 do begin
   name(i) = strtrim(strcompress(name(i)),2)
   def_sym,'c',/fill
   oplot,[x(i)], [y(i)],psym=8,symsize=point_size(i) ;*  ,color=3

   if i_pass eq 1 then begin

   ; Find empty region for label

   printf,lout,'Search for region for ', i,': ',name(i)
   res = convert_coord([x(i),y(i)],/data,/to_normal)
   xtnorm = res(0)
   ytnorm = res(1)
   printf,lout,'Data point (norm) : ', xtnorm, ytnorm
   found = 0
   xtnorm_ok = 0.12  ; default label position if no better place is found
   ytnorm_ok = 0.90
   while not found and xtnorm gt 0.12 do begin
   while not found and ytnorm lt 0.9 do begin
      ytnorm = ytnorm + 0.02
      if !d.name ne 'PS' then begin
         textbox, xtnorm, ytnorm, name(i), boxt,$
                /notext,/normal,charheight=height
      endif else begin
         textbox, xtnorm, ytnorm, name(i), boxt,$
                /normal,charheight=height
      endelse
   ; make sure that textbox does not exceed frame
      while boxt(2) gt 0.95 do begin
         xtnorm = xtnorm - 0.01
         if !d.name ne 'PS' then begin
            textbox, xtnorm, ytnorm, name(i), boxt,$
                   /notext,/normal,charheight=height
         endif else begin
            textbox, xtnorm, ytnorm, name(i), boxt,$
                   /normal,charheight=height
         endelse
      endwhile

      printf,lout,'Try box: ', boxt

      ; test for overlap with previous boxes

      found = 1
      for j = 0, n_boxes-1 do begin
         if boxoverlap( boxt, boxes(*,j) ) then found = 0
      endfor
      if found then begin
         printf,lout,'This box worked'
         xtnorm_ok = xtnorm
         ytnorm_ok = ytnorm
      endif else begin
         printf,lout,'Nix - try again'
      endelse
   endwhile
   xtnorm = xtnorm - 0.02
   ytnorm = res(1)
   endwhile

   printf,lout,'While loop has terminated'
   if found then printf,lout,'A solution was found' else $
                    printf,lout,'No empty space'

   xtnormv(i) = xtnorm_ok  ; save value for pass 2
   ytnormv(i) = ytnorm_ok  ; save value for pass 2

   endif ; check for pass 1

   if i_pass eq 2 then begin
      xtnorm_ok = xtnormv(i)    ;  retrieve values found in pass 1
      ytnorm_ok = ytnormv(i)    ;  retrieve values found in pass 1
   endif

   if labels eq 'y' then begin

   textbox,xtnorm_ok,ytnorm_ok,name(i),boxt,/normal,charheight=height
   ;* drawbox, boxt
   boxes(*,n_boxes) = boxt
   n_boxes = n_boxes + 1
   uline = convert_coord([boxt(0),boxt(2)],[boxt(1),boxt(1)],/normal,/to_data)
   oplot,uline(0,0:1),uline(1,0:1)
   oplot,[avg(uline(0,0:1)),x(i)],[uline(1,0),y(i)]

   endif ; Terminate test for labels wanted

   ; Update plot with limit and symbols

   limsym = convert_coord([0.58,0.775],[0.15,0.15],/norm,/to_data)
   siz1 = acoef*alog10(2.e-11) + bcoef
   siz2 = acoef*alog10(2.e-8) + bcoef
   ; oplot,[limsym(0,0)],[limsym(1,0)],psym=8,symsize=siz1
   ; oplot,[limsym(0,1)],[limsym(1,1)],psym=8,symsize=siz2
   ; xyouts,0.6,0.14,'1 mCrab',/norm,charsize=1.3
   ; xyouts,0.8,0.14,'1 Crab',/norm,charsize=1.3
   str_limit = string(limit,format='(f6.1)')
   if limit lt 0.1 then str_limit = string(limit,format='(f6.3)')

   xyouts,0.12,0.14,'Lower limit: '+strtrim(str_limit,2)+' mCrab',/norm,$
                     charsize=csiz
   xyouts,0.12,0.17,'Source category: '+sourcetype, /norm,charsize=csiz
   xyouts,0.12,0.20,'Source catalog: '+catalogsel, /norm,charsize=csiz
   xyouts,0.12,0.23,'Input catalog: '+input_catalogue, /norm,charsize=csiz



   if i_pass eq 1 then begin

      ;print,i,' ',strtrim(name(i),2),' ',ra(i),dec(i),gl(i),gb(i),intens(i)
      ;print,strtrim(name(i),2),intens(i),ra(i),dec(i),gl(i),gb(i), $
      ;      format='(a20,e10.2,4f8.2)'
      name1 = strtrim(name(i),2)
      nameparts = str_sep(name1,' ')
      name2 = str_join(nameparts,'~')

     if !d.name eq 'PS' then device,/close

   endif ; end check for pass 1
endfor

endfor ; Terminate the loop over the two passes

;  Add the countours here in order not to change the plotting
;  coordinate conversion

if add_pointings then contour,imarr,/noerase,xstyle=5,ystyle=21,$
             levels=[7,10,20,50,200], c_labels=[1,1,1,1,1]

if !d.name eq 'PS' then device,/close

;free_lun,lun
free_lun,lout

end
