function gauss_convol_2d,a,s,val=val,ksize=ksize
;
;  Returns the 2D array 'a' convolved with a gaussian with a width
;  depending on the keyword 'val' : 'f' then 's' is FWHM
;                                   's' then 's' is sigma (st. dev.)
;  The keyword ksize gives the size of the kernel (ksize x ksize)
;
;  The default is that ksize is dim(a)/4
;
if( not keyword_set(val) ) then begin
   print,'Keyword f or s must be set'
   return,-1.
endif
if( val eq 'f' ) then begin
   print,'Assume that FWHM is input'
   sigma = s/2.355
endif else if( val eq 's' ) then begin
   print,'Assume that sigma is given'
   sigma = s
endif else begin
   print,'Wrong keyword'
   return,-1.
endelse
sz = size(a)
n = min(sz(1:2))
ks = n/4
if keyword_set(ksize) then ks = ksize
; make ks odd
ks = fix(ks)
ks = (ks/2)*2 + 1
x = distances(ks,ks,ks/2,ks/2)
kernel = exp(-0.5*(x/sigma)^2)
return,convol(a,kernel,total(kernel),/edge)
end
