pro get_aeff, file_name, e, aeff, aeff_arr
;
; Procedure to produce on-axis effective area
;
; Call : filename  :  name of telescope FITS file from output
;                     of the program 'rt_setup_tel.x'
;        e         :  array with energy values in keV
; Return :  aeff   :  array with effective area at energies 'e'
;           aeff_arr : for each mirror shell

;  Read the  telescope parameters by using general IDL-FITS
;  I/O routines

fxbopen, mylun, file_name, 1
hdr = fxbheader(mylun)
fxbread, mylun, rp, 1
fxbread, mylun, rq, 2
fxbread, mylun, alpha, 5
fxbclose, mylun

n = n_elements(rp)
num_e = n_elements(e)
aeff_arr = fltarr(num_e,n)
;     first index steps in energy
;    second index steps in mirror number

; Extract the shield from the FITS header

shield = fxpar(hdr,'SHIELD')

; get the geometric area

area = (!pi * (rp+rq) - shield)*(rp-rq)/100 ; in cm2
aeff = fltarr(num_e)
for i = 0, num_e-1 do begin
   r = rcoef_au(replicate(e(i),n),alpha)
   aeff_arr(i,*) = area * r^2
   aeff(i) = total(area * r^2)
endfor
end
