pro get_exten_no, fits_name_extno_in, fits_name, extno, tuborg=tuborg, $
         noresolve=noresolve
;
;  Separate the file name and
;  the extension number from a (FITS) file name
;  ending with [12] or +12
;  [EXTNAME] will also work is fits_name_extno is the correct path
;
;  ca. 2002-06-15/NJW
;  2005-08-04/NJW updated to cope with the name.fits[EXTNAME] convention
;
if n_params() lt 3 then begin
   print,'Syntax: get_exten_no, fits_name_extno, > fits_name, >extno $'
   print,'                 [/noresolve][,/tuborg]'
   print,'  Includes resolution of text e.g. [EXTNAME] to ext number'
   print,'        Keyword ''tuborg'' analyses for {123} i.s.o. [12]'
   print,'        Keyword ''noresolve'' prevents text resolving'
   return
endif

fits_name_extno = strtrim( fits_name_extno_in, 2)

len = strlen(fits_name_extno)
pos = len - 1
str_exten_no = ''
begchar = keyword_set(tuborg) ? '{' : '['
endchar = keyword_set(tuborg) ? '}' : ']'

last = strmid(fits_name_extno,pos,1)

if last eq endchar or is_digit(last) then begin ; Still possible

   case last of

      endchar : begin ; Expects   [123] or [EXTNAME]
             ; look for [ or { character
             p = strpos(fits_name_extno,begchar,/reverse_search)
             if p lt 0 then begin
                extno = 0
                fits_name = fits_name_extno
                str_exten = ''
             endif else begin
                str_exten = strmid(fits_name_extno,p+1,pos-p-1)
                ;* print,'str_exten: ', str_exten
                fits_name = strmid(fits_name_extno,0,p)
                if is_digit(str_exten) then begin
                   extno = fix(str_exten)
                endif else begin
                   extno = -1
                   if not keyword_set(noresolve) then begin
                      nlastext = nfits_extens(fits_name)
                      for i = 0, nlastext do begin
                         hdr = headfits(fits_name,exten=i)
                         extname = strtrim(fxpar(hdr,'EXTNAME',count=npar),2)
                         if npar gt 0 then begin
                            if extname eq strtrim(strupcase(str_exten),2) then begin
                               extno = i
                               break
                            endif
                         endif
                      endfor
                   endif
                endelse
             endelse
             

          end

      else : begin ; Expects +123
             flag = 1
             while flag do begin
                char = strmid(fits_name_extno,pos,1)
                if is_digit(char) then str_exten_no = char+str_exten_no $
                                  else flag = 0
                pos = pos - 1
             endwhile
             if char eq '+' then begin
               extno = fix(str_exten_no)
               fits_name = strmid(fits_name_extno,0,pos+1)
               str_exten = strmid(fits_name_extno,pos+2,999)
            endif else begin
               extno = 0
               fits_name = fits_name_extno
               str_exten = ''
            endelse


          end

   endcase

endif else begin
   extno = 0
   fits_name = fits_name_extno
   str_exten = ''
endelse

if keyword_set(noresolve) then extno = str_exten

end
