pro get_jemx_bkg, e, dxb_countrate, ibkg_countrate, bkg_countrate, $
         qeff=qeff, period=period, njmx=njmx
;
;   Original version 001030/NJW
;   Version of 030701/NJW  Reworked with background inside 105 mm radius
;   based on Jerome Chenevez's background results
;
;
;  The quantum efficiency (1.5 bar) is returned as a keyword
;
if n_params() lt 4 then begin
   print,'Syntax: get_jemx_bkg, <e, >dxb_ctrate, >ibkg_ctrate, $'
   print,'       >bkg_ctrate[,qeff=][, period=][,njmx=]'
   print,'       rates are in cts/s/keV/cm2'
   print,' Keyword     qeff:     returns the QE'
   print,'           period:     1 for period before 2003-02-27'
   print,'           period:     2 for period after  2003-02-27 (default)'
   print,'             njmx:     number of JMX unit (defaults to 2)'
   return
endif

;-----------------------------------------
;
;    Definition of loss and other constants
;
lambda_a = 0.06   ; loss due to dead anodes
lambda_d = 0.12   ; loss due to deadtime
lambda_r = 0.12   ; loss due to finite resolution

area = !pi * 10.5^2 ; cm2 - used detector area
;
;-----------------------------------------
;
;   Get the electronic efficiency
rscol,'/home/njw/jemx/imod_grp/elec_eff_pha_060202.scm', pha, 1, /sil
rscol,'/home/njw/jemx/imod_grp/elec_eff_pha_060202.scm', eeff, 2, /sil
epha = pha / 17. ; Assuming that the gain is 17 PHAchannels/keV


;rstab,'/home/njw/jsim/dat/jqe_1_5bar.dat',e_q,qt,/silent

if !version.os ne 'sunos' then begin
   print,'This procedure has not been adapted to this OS: ', !version.os
   return
endif

numjemx = 2
if keyword_set(njmx) then numjemx = njmx
sjmx = stri(numjemx)

ptime = 2
if keyword_set(period) then ptime = period
if ptime eq 2 then begin
   rmf_grp = '/r6/jemx/ic/rmf_grp/jmx'+sjmx+'_rmf_grp_0035.fits+1'
   ;bkg_dol = '/home/njw/jemx/background/FF82_coll_dsp.fits+1'
   ;bkg_dol = '/home/njw/work/jmx1_bkg_r105_0372.fits+1'
   bkg_dol = '/home/njw/work/jemx_0001_spe.fits+1'
endif else begin
   rmf_grp = '/home/njw/jemx/response_matrix/jmx'+sjmx+'_rmf_grp_0004.fits+1'
   bkg_dol = '/home/njw/jemx/background/3C273_coll_dsp.fits+1'
endelse

print,'----------------------------------------------------'
print,'  get_jemx_bkg for JMX='+sjmx+' called with'
print,' RMF: ', rmf_grp
print,' BKG: ', bkg_dol
print,'----------------------------------------------------'

ebm_get_child_by_name,rmf_grp,'JMX'+sjmx+'-AXIS-ARF',arf
ebm_get_child_by_name,rmf_grp,'JMX'+sjmx+'-FBDS-MOD',fbds
ebm_get_child_by_name,rmf_grp,'JMX'+sjmx+'-RMF.-RSP',redist

rdfitscol,arf,energ_lo,'energ_lo',/sil
rdfitscol,arf,energ_hi,'energ_hi',/sil
rdfitscol,arf,specresp,'specresp',/sil

rdfitscol,fbds,e_min,'e_min',/sil
rdfitscol,fbds,e_max,'e_max',/sil
em = 0.5*(e_min + e_max)
dem = e_max - e_min

rdfitscol,redist,matrix,'matrix',/sil

eline = 0.5*(energ_lo + energ_hi)
deline = energ_hi - energ_lo
w = where(eline gt 34.5)
tmp_qeff = specresp /( 490. * 0.24) ; Area and mask open fraction
tmp_qeff(w) = tmp_qeff(w) * 0.38 ; disregard the escape

eeff = interpol(eeff, epha, eline)
qeff = interpol(tmp_qeff, eline, e)
;   The open mask fraction and collimator has been included here
specresp_eeff = specresp * eeff

dxb_flux = 7.877 * eline^(-1.29) * exp(-eline/41.13) * 0.0142; [ph/cm2/s/keV]
;   Expression based on Gruber et al., ApJ 520, 124 (1999)
;* dxb_flux = 10.1 * eline^(-1.424) * exp(-eline/54.2) * 0.0142; [ph/cm2/s/keV]
;   Expression based on Comastri (Taormina) JEMX Notebook 27/10 2000)
;                   solid angle is 0.0142 sr (JEMX Notebook 8/10 1999)

;dxb_countrate = dxb_flux * qeff * (1 - lambda_a)*(1 - lambda_d)
dxb_countrateperbin = dxb_flux * deline * specresp_eeff * (1 - lambda_a)*(1 - lambda_d)
dxb_countspec = (matrix#dxb_countrateperbin) / area

dxb_countrate = interpol(dxb_countspec/dem, em, e)

;rstab,'/home/njw/0idl/JEMX/Sensitivity/bkg_2mmfe.dat', $
;              e2,b2_mo,c3,b2_fe,c5,/silent

rdfitscol, bkg_dol, rate, 'rate', /sil

bkg_countrate = interpol( rate/dem, em, e) / area

ibkg_countrate = bkg_countrate - dxb_countrate

end
