pro get_kwrds_from_tpl, tpl_filename, kwrds, values, comments, $
                        count=count, hilev=hilev
;
;  This is a procedure to extract the keywords from a CFITSIO (DAL)
;  template file
;
;  NJW/010620
;
if n_params() lt 4 then begin
   print,'Syntax: get_kwrds_from_tpl, tpl_filename, kwrds, $'
   print,'        values, comments[,count=][,/hilev]'
   print
   print,'  The keyword ''hilev'' will filter out the basic keywords'
   print,'  such as XTENSION, BITPIX, NAXIS?, EXTNAME'
   return
endif

list = read_slist(tpl_filename,count=n_list)

if n_list lt 1 then begin
   print,'Problem with ', tpl_filename
   return
endif

kwrds = strarr(1000)
values = strarr(1000)
comments = strarr(1000)

if keyword_set(hilev) then hi=1 else hi=0

next = 0

for i = 0, n_list-1 do begin

   ; analyze the line

   line = list(i)

   ; discard all '#'s and what follows

   pos = strpos(line,'#')
   if pos ge 0 then line = strmid(line, 0, pos)

   ;  Still some characters left ?

   if strlen(line) gt 0 then begin

      ; remove superfluous blanks

      line = strtrim(strcompress(line),2)

      ; find first space

      pos = strpos(line,' ')

      if pos ge 0 then begin

         kw = strmid(line,0,pos)
         line = strmid(line,pos+1,9999)

         ; The keyword value may be a string enclosed in ' ' or " "

         i_got_val = 0

         posp1 = strpos(line,'''')
         if posp1 ge 0 then begin ; this could be a pair

            posp2 = strpos(line,'''',posp1+1)
            if posp2 gt 0 then begin ; it is indeed a pair
               val = strmid(line,posp1+1,posp2-posp1-1)
               i_got_val = 1
            endif
         endif
         posp1 = strpos(line,'"')
         if posp1 ge 0 then begin ; this could be a pair

            posp2 = strpos(line,'"',posp1+1)
            if posp2 gt 0 then begin ; it is indeed a pair
               val = strmid(line,posp1+1,posp2-posp1-1)
               i_got_val = 1
            endif
         endif

         if i_got_val then begin

            com = strmid(line,posp2+1,9999)

         endif else begin

            ; find next space

            pos2 = strpos(line,' ')

            if pos2 ge 0 then begin

               val = strmid(line,0,pos2)
               com = strmid(line,pos2+1,9999)

            endif else begin ; Terminate 'if there is a second space'

               val = line
               com = ''

            endelse

         endelse

         ; remove preceding '/' from comment if present

         com = strtrim(com,2)
         pos3 = strpos(com,'/')
         if pos3 eq 0 then com = strtrim(strmid(com,1,9999),2)


      endif else begin ; Terminate 'if there is a space'

         kw = line
         val = ''
         com = ''

      endelse

      ; now check if keyword makes any sense

      case kw of

          '' : include = 0
          'TTYPE' : include = 0
          'TFORM' : include = 0
          'TUNIT' : include = 0
          'XTENSION' : if hi then include = 0 else include = 1
          'BITPIX' : if hi then include = 0 else include = 1
          'NAXIS' : if hi then include = 0 else include = 1
          'NAXIS1' : if hi then include = 0 else include = 1
          'NAXIS2' : if hi then include = 0 else include = 1
          'NAXIS3' : if hi then include = 0 else include = 1
          'EXTNAME' : if hi then include = 0 else include = 1
          else : include = 1

      endcase

      if include then begin

         kwrds(next) = kw
         values(next) = val
         comments(next) = com
         next = next + 1

      endif

   endif ; Terminate 'if there are any characters left in the line'

endfor

count = next
kwrds = kwrds(0:next-1)
values = values(0:next-1)
comments = comments(0:next-1)

return

end
