pro get_pointing_for_swid, id, ra_scx, dec_scx, posangle,map=map,errmsg=errmsg
;
;   2003-02-05/NJW
;
if n_params() ne 4 then begin
   print,'Syntax: get_pointing_for_swid, id, >ra, >dec, >posangle[,/map][,errmsg=]'
   print,'   where ''id'' is a 12 character string (SWID) or'
   print,'   a integer array with 3 elements: [REV,PID,sub]'
   return
endif

errmsg = ''
sz = size(id)
ok = 0
if sz(0) eq 1 and sz(1) eq 1 then begin
   id = id(0)
   sz = size(id)
endif
if sz(0) eq 0 and sz(1) eq 7 then begin ; case of swid string
   if strlen(id) eq 12 then begin
      revstr = strmid(id,0,4)
      swid = id
      ok = 1
   endif
endif
if sz(0) eq 1 and sz(1) eq 3 and (sz(2) eq 2 or sz(2) eq 3) then begin
   revstr = string(id(0),format='(i4.4)')
   pidstr = string(id(1),format='(i4.4)')
   if id(2) le 0 then begin
      substr = '0010'
   endif else begin
      substr = string(id(2),format='(i4.4)')
   endelse
   swid = revstr+pidstr+substr
   ok = 1
endif

if not ok then begin
   print,'GET_POINTING_FOR_SWID: illegal id argument'
   errmsg = 'illegal id argument'
   return
endif

if !version.os eq 'sunos' then begin
   point_dir = '/r6/jemx/pointings/'
endif
if !version.os eq 'linux' then begin
   if getenv('HOSTNAME') eq 'njw-notebook.spacecenter.dk' then begin
      point_dir = '/home/njw/r6/pointings/'
   endif else point_dir = '/r6/jemx/pointings/'
endif
if !version.os eq 'Win32' then begin
   point_dir = 'f:\r6\jemx\pointings\'
endif

filename = 'pointings_'+revstr+'p.dat'

; check for existence of file

if not file_test(point_dir+filename,/regular) then begin
   print,point_dir+filename,' was not found'
   errmsg = 'pointing file not found'
   return
endif

rscol,point_dir+filename,swid_list,1,/str,/sil
rscol,point_dir+filename,ra,2,/sil
rscol,point_dir+filename,dec,3,/sil
rscol,point_dir+filename,roll,4,/sil

w = where( swid_list eq swid, nw )
if nw eq 0 then begin
   print,'SWID '+swid+' was not found'
   errmsg = 'SWID '+swid+' was not found'
   return
endif

ra_scx = ra(w(0))
dec_scx = dec(w(0))
posangle = roll(w(0))

if keyword_set(map) then begin
   n = comreplace('sourcemap.par','ra_cen',ra_scx)
   n = comreplace('sourcemap.par','dc_cen',dec_scx)
   n = comreplaces('sourcemap.par','plotheader','Pointing '+swid)
endif

return

end


