function get_revol_no, time, frac=frac
;
;   Use /r6/jemx/integral_history/revolution_latest.fits to return
;   revolution number for a given time
;
;   The time parameter can be given as IJD or as string 'YYYY-MM-DDTHH:MM:SS'
;
;   2004-06-04/NJW
;   2005-08-16/NJW updated with fractional result
;
if n_params() lt 1 then begin
   print,'Syntax: revol_no = get_revol_no( time[,/frac] )'
   print,'   ''time'' can be given as IJD or as string ''YYYY-MM-DDTHH:MM:SS'''
   print,' Keyword ''frac'' makes the function return revolution with fraction'
   print
   return, -1
endif

; Determine the type of input

sz = size(time)
if sz(sz(0)+1) eq 7 then dattim2ijd, time, ijd else ijd = time

dol = '/r6/jemx/integral_history/revolution_latest.fits+1'

rdfitscol,dol, revol_no, 'REVOLUTION',/sil
revol_no = fix(revol_no)
rdfitscol,dol, time_perigee, 'TIME_PERIGEE',/sil
nrev = n_elements(revol_no)

; The TIME_PERIGEE refers to the beginning of the revolution

if ijd lt time_perigee(0) then return, -1  ;  Before INTEGRAL mission

w = where( time_perigee lt ijd, nw )

n = max(w)
if n+1 eq nrev then begin
   ; extrapolated prediction for perigee nrev+1
   tl = 2*time_perigee(nrev-1) - time_perigee(nrev-2)
   if ijd lt tl then return, max(revol_no) else return,-1
endif else begin
   if keyword_set(frac) then begin
      fraction = (ijd - time_perigee(n)) $
         / (time_perigee(n+1) - time_perigee(n))
      return,revol_no(n) + fraction
   endif
   return, revol_no(n)
endelse

end


