function get_swid_from_time, time
;
;   Use /r6/jemx/integral_history/revolution_latest.fits to return
;   revolution number for a given time
;   Then look up the appropriate pointing table to get the SWID
;
;   The time parameter can be given as IJD or as string 'YYYY-MM-DDTHH:MM:SS'
;
;   2004-06-14/NJW
;
if n_params() lt 1 then begin
   print,'Syntax: swid = get_swid_from_time( time )'
   print,'   ''time'' can be given as IJD or as string ''YYYY-MM-DDTHH:MM:SS'''
   print
   return, -1
endif

; Determine the type of input

sz = size(time)
if sz(sz(0)+1) eq 7 then dattim2ijd, time, ijd else ijd = time

no_revol = get_revol_no( time )
revol_str = string(no_revol,format='(i4.4)')

base = ''
if 'njw-notebook' eq getenv('HOSTNAME') then base = '/mnt/win_f'

file = base+'/r6/jemx/pointings/pointings_'+revol_str+'p.dat'

rscol,file,swids,1,/str,/sil
rscol,file,ijds,6,/dble,/sil

w = where( ijds lt ijd, nw )

if nw eq 0 then return,'none' else return,swids(max(w))

end


