pro getfit, filebase, tex=tex, outfil=outfil, fullname=fullname
;
;  Extract power law fitting parameters from XSPEC logfile
;  Keyword 'tex' for LaTeX format output
;
;  Made for /r4/njw/Htex/jemx_spec_cal
;
;   2004-06-03/NJW
;

if n_params() lt 1 then begin
   print,'Syntax: getfit, filebase[,/fullname][,/tex][,outfil=]'
   print,'   assumes filename: filebase.log, except if keyword ''fullname'' is set'
   print,'   outputs into filebase.out except if keyword ''outfil'' is given,'
   print,'   then this file will be used for output in appending mode'
   return
endif

;file = 'jmx1_xspec_0044_0014.log'
logfile = filebase
if not keyword_set(fullname) then logfile = logfile+'.log'
if keyword_set(outfil) then begin
   outfile=outfil
   flag = 1
   openw,lun,outfile,/get_lun,/append
endif else begin
   outfile = filebase+'.out'
   flag = 0
   openw,lun,outfile,/get_lun
endelse


doc = read_slist(logfile)

; Search for presence of "PhoIndex"

p = strpos(doc,'PhoIndex')
w = where(p ge 0, nw)

; Loop over all possible lines

for i = 0, nw-1 do begin
   line = strmid(doc(w(i)),p(w(i)),999)
   tok = strsplit(strcompress(line),' ',/extract)
   ntok = n_elements(tok)
   if ntok ge 4 then begin ; possibility

      ; extract value (with error) of PhoIndex

      val = float(tok(1))
      if abs(val-1) lt 1.e-4 then continue
      acc = float(tok(3))
      print,'PhoIndex = ', val, acc

      ; extract value (with error) of norm(alization)

      lnext = doc(w(i)+1)
      pn = strpos(lnext,'norm')
      lnext = strmid(lnext,pn,999)
      tkn = strsplit(strcompress(lnext),' ',/extract)
      ntkn = n_elements(tkn)
      norm = float(tkn(1))
      dnorm = float(tkn(3))
      print,'norm = ', norm, dnorm
      if keyword_set(tex) then begin
         printf,lun,'// '+ logfile
         printf,lun,val,acc,format='("$\alpha$ = ",f4.2,"$\pm$",f4.2,"\hspace{3mm}")'
         printf,lun,norm,dnorm,format='("norm = ",f5.2,"$\pm$",f4.2,"\hspace{3mm}")'
      endif

      ; extract value of reduced Chi-square

      lnext = doc(w(i)+6)
      pn = strpos(lnext,'Reduced chi-squared')
      if pn lt 0 then begin
         print,'*** '+lnext
         return
      endif
      lnext = strmid(lnext,pn,999)
      tkn = strsplit(strcompress(lnext),' ',/extract)
      ntkn = n_elements(tkn)
      chi = float(tkn(3))
      print,'chi2_r = ', chi
      if keyword_set(tex) then begin
         printf,lun,chi,format='("$\chi^2_r = ",f4.2,"$")'
      endif else begin
         if flag then printf,lun,'// '+ logfile
         printf,lun,val,acc,norm,dnorm,chi,format='(f8.3,f8.3,f9.3,f8.3,f8.3)'
      endelse
   endif
endfor

free_lun, lun
end
