function getfitf, filebase, fullname=fullname, errmsg=errmsg, silent=silent
;
;  Extract power law fitting parameters from XSPEC logfile
;
;   2005-08-05/NJW cloned from getfit.pro
;

if n_params() lt 1 then begin
   print,'Syntax: res = getfitf( filebase[,/fullname][,errmsg=][,/silent])'
   print,'   assumes filename: filebase.log, except if keyword ''fullname'' is set'
   print,'   Returns array [photidx,photidx_err,normfit,normfit_err,chi2red]'
   return,-1
endif

logfile = filebase
if not keyword_set(fullname) then logfile = logfile+'.log'
errmsg = ''
vb = 1 - keyword_set(silent)

doc = read_slist(logfile)

; Search for presence of "PhoIndex"

p = strpos(doc,'PhoIndex')
w = where(p ge 0, nw)

; Loop over all possible lines

for i = 0, nw-1 do begin
   line = strmid(doc(w(i)),p(w(i)),999)
   tok = strsplit(strcompress(line),' ',/extract)
   ntok = n_elements(tok)
   if ntok ge 4 then begin ; possibility

      ; extract value (with error) of PhoIndex

      val = float(tok(1))
      if abs(val-1) lt 1.e-4 then continue
      acc = float(tok(3))
      if vb then print,'PhoIndex = ', val, acc

      ; extract value (with error) of norm(alization)

      lnext = doc(w(i)+1)
      pn = strpos(lnext,'norm')
      lnext = strmid(lnext,pn,999)
      tkn = strsplit(strcompress(lnext),' ',/extract)
      ntkn = n_elements(tkn)
      norm = float(tkn(1))
      dnorm = float(tkn(3))
      if vb then print,'norm = ', norm, dnorm

      ; extract value of reduced Chi-square

      found = 0
      for u = 2,7 do begin
         lnext = doc(w(i)+u)
         pn = strpos(lnext,'Reduced chi-squared')
         if pn ge 0 then begin
            lnext = strmid(lnext,pn,999)
            tkn = strsplit(strcompress(lnext),' ',/extract)
            ntkn = n_elements(tkn)
            chi = float(tkn(3))
            if vb then print,'chi2_r = ', chi
            found = 1
            break
         endif
      endfor

      if not found then begin
         if vb then print,'*** '+lnext
         errmsg = '*** '+lnext
         return,-1
      endif

      res = fltarr(5)
      res(0) = val
      res(1) = acc
      res(2) = norm
      res(3) = dnorm
      res(4) = chi
   endif
endfor

return, res

end
