function grab_coords_reg, filename, text=text, n_text=n_text
;
;  Grab the coordinates from a SaoImage region file
;
;  An array is returned: res(3,*) where res(0,*) are
; the right ascensions and res(1,*) the declinations
; and res(2,*) the circle radii (0 (zero) if not found)
;
; Keyword 'text' will return a structure with text
; information
;
;  So far only 'circle' works
;
;   2004-03-02/NJW
;   2004-05-26/NJW updated to get text as well
;

t_elem = { ra:0.0, dec:0.0, name:'' }

if n_params() lt 1 then begin
   print,'Syntax: res = grab_coords_reg(filename[, text=][, n_text=])'
   return, -1
endif

reg = read_slist(filename,count=nlines)

;----------  LOOP for circle information ---------

first = 1
for i = 0, nlines-1 do begin

   line = strtrim(reg(i),2)
   ; skip if first character is '#'
   if strmid(line,0,1) eq '#' then continue

   ; look for 'circle'
   pos = strpos(line,'circle')
   if pos lt 0 then continue    ; skip - no 'circle'

   bpos = strpos(line,'(',pos)
   cpos = strpos(line,',',bpos)
   ra = float(strmid(line,bpos+1,cpos-bpos-1))
   cposd = strpos(line,',',cpos+1)
   dec = float(strmid(line,cpos+1,cposd-cpos-1))
   bposr = strpos(line,')',cposd+1)
   rad = float(strmid(line,cposd+1,bposr-cposd-1))

   if first then begin
      ra_arr = [ra]
      dec_arr = [dec]
      rad_arr = [rad]
      first = 0
   endif else begin
      ra_arr = [ra_arr,ra]
      dec_arr = [dec_arr,dec]
      rad_arr = [rad_arr,rad]
   endelse

endfor

if not first then begin
   n = n_elements(ra_arr)
   res = fltarr(3,n)
   res(0,*) = ra_arr
   res(1,*) = dec_arr
   res(2,*) = rad_arr
endif else res = -1


;----------  LOOP for text information ---------

first_t = 1
for i = 0, nlines-1 do begin

   line = strtrim(reg(i),2)
   ; skip if first character is '#'
   if strmid(line,0,1) eq '#' then continue

   ; look for 'text'
   pos = strpos(line,'text')
   if pos lt 0 then continue    ; skip - no 'text'

   bpos = strpos(line,'(',pos)
   cpos = strpos(line,',',bpos)
   ra = float(strmid(line,bpos+1,cpos-bpos-1))
   bposd = strpos(line,')',cpos+1)
   dec = float(strmid(line,cpos+1,bposd-cpos-1))
   bposn = strpos(line,'{',bposd+1)
   bposo = strpos(line,'}',bposn+1)
   name = strmid(line,bposn+1,bposo-bposn-1)

   if first_t then begin
      ra_tarr = [ra]
      dec_tarr = [dec]
      name_arr = [name]
      first_t = 0
   endif else begin
      ra_tarr = [ra_tarr,ra]
      dec_tarr = [dec_tarr,dec]
      name_arr = [name_arr,name]
   endelse

endfor

if not first_t then begin
   n_text = n_elements(ra_tarr)
   text = replicate(t_elem,n_text)
   text(*).ra = ra_tarr
   text(*).dec = dec_tarr
   text(*).name = name_arr
endif else begin
   text=-1
   n_text = 0
endelse



return, res

end

