pro grid_on_sphere, step, radius_sel, outfile, numjemx, revselection
;
;  Construct a grid on the sphere with a unit distance of 'step' [deg].
;   with JMX data in revolutions as selected by 'revselection'
;
;      2006-11-27/NJW
;      2006-11-29/NJW, corrected to exclude revolution 286 (not public yet)
;
if n_params() ne 5 then begin
   print,'Syntax: grid_on_sphere, step, radius_sel, outfile, numjemx, revselection'
   print,'    ''outfile'' should be given with no ''.scm'' extension'
   print,'          step [deg]'
   print,'          radius_sel [deg]'
   print,'       revselection e.g. ''170-285,287-295,300'''
   return
endif

n = fix(359./step)+1
stp = 360. / n
d_alpha0 = stp
d_delta0 = stp
delta = 0.0
n = 0L
a_prev = 0.0
d_prev = 0.0
swid_list = outfile+'_swids.scm'
openw, lun, outfile+'.scm',/get_lun

headinfo= ['// date = '+ndate(2),$
           '// revselection = '+revselection, $
           '// numjemx = '+string(numjemx)]
write_slist, swid_list, headinfo
for i = 0, n_elements(headinfo)-1 do begin
   printf,lun,headinfo(i)
endfor

while delta lt 90.0 - 0.5*d_delta0 do begin
   alpha = 0.0
   d_alpha = d_alpha0 / cos(delta*!pi/180.0)
   while alpha lt 360.0 - 0.5*d_alpha0 do begin
      if numjemx eq 1 then begin
         find_swid_radec, alpha, delta, radius_sel, rev=revselection, $
                 jemx=1,list=list,/nof,/sil,mod1='F'
      endif else begin
         find_swid_radec, alpha, delta, radius_sel, rev=revselection, $
                 jemx=2,list=list,/nof,/sil,mod2='F'
      endelse
      nlist = n_elements(list)
      if nlist eq 1 then begin
         if list eq '' then nlist = 0
      endif
      if nlist gt 0 then begin
         strblock = ['// block = '+string(n),$
                     '// alpha = '+string(alpha), $
                     '// delta = '+string(delta)]
         write_slist,swid_list, strblock,/append
         write_slist,swid_list, list,/append
      endif
      print, n, alpha, delta, nlist, format='(i8,f10.3,f10.3,i10)'
      printf,lun, n, alpha, delta, nlist, format='(i8,f10.3,f10.3,i10)'
      n = n + 1
      if delta gt 0.0 then begin
         if numjemx eq 1 then begin
            find_swid_radec, alpha, -delta, radius_sel, rev=revselection, $
                    jemx=1,list=list,/nof,/sil,mod1='F'
         endif else begin
            find_swid_radec, alpha, -delta, radius_sel, rev=revselection, $
                    jemx=2,list=list,/nof,/sil,mod2='F'
         endelse
         nlist = n_elements(list)
         if nlist eq 1 then begin
            if list eq '' then nlist = 0
         endif
         if nlist gt 0 then begin
            strblock = ['// block = '+string(n),$
                        '// alpha = '+string(alpha), $
                        '// delta = '+string(-delta)]
            write_slist,swid_list, strblock,/append
            write_slist,swid_list, list,/append
         endif
         print, n, alpha, -delta, nlist, format='(i8, f10.3,f10.3,i10)'
         printf,lun, n, alpha, -delta, nlist, format='(i8, f10.3,f10.3,i10)'
         n = n + 1
      endif
      alpha = alpha + d_alpha
   endwhile
   delta = delta + d_delta0
endwhile

print,'n = ', n

free_lun, lun

end
