close,2
openw,2,'output'
;
; main program for XSPECT sensitivity calculations
; Generate sensitivity curve in the style of Stewart/Wells
;
;  1) get relevant arrays
;           a) Effective area of XSPECT
rstab,'/a/srg-inf/Curr970218/effarea729c',eaeff,aeff
printf,2,'0.4 mm foil telescope'
;           b) Quantum efficiences of detector
rstab,'/a/srg-inf/Curr970218/quantum_efficiency.hepc',eqhepc,qhepc
hpw = 3.0 ; arcmin
fraction = 0.5  ; fraction of counts in search cell
printf,2,hpw,format='("HPW = ",f3.1," arcmin")'
;
; set up energy scale
e = xloggen(100, 2.0, 25.)
deltae = 2*0.33*sqrt(e)  ; Delta-e (keV) source detection interval
printf,2,'Detection band is twice the FWHM resolution'
;
;           d) Define DXB (extra galactic part)
fdxb = 11.*e^(-1.46) * absorp(5.e20,e) ; phot/cm2/s/keV/ster
;
;    Define Crab spectrum for reference
fcrab = 9.7*e^(-2.1) * absorp(3.e21,e)
;
;           e) Cell area and solid angle
comega = 3.14 * ((hpw/2.) / 3438.)^2
; Unit is steradians
acell  = comega * 800.^2 ; cm2
printf,2,comega,acell,format='("Omega = ",e11.2," sr. Acell = ",e11.2," cm2")'
;
aeff = tabnewx(eaeff,aeff,e)
qhepc = tabnewx(eqhepc,qhepc,e)
flim = e
fp = 1.e-3  ; particle background (cts/s/cm2/keV)
;
; sample plot commands
!p.title = 'XSPECT/HEPC sensitivity'
!y.title = 'Flux (phot. cm!u-2!n s!u-1!n keV!u-1!n)'
!x.title = 'Energy (keV)'
plot_oo,e,flim,thick=2.0,yr=[1.e-7,1.e-2],/nodata
oplot,e,fdxb*comega,linestyle=1
oplot,e,1.e-3*fcrab,linestyle=3
oplot,e,1.e-4*fcrab,linestyle=3
oplot,e,1.e-5*fcrab,linestyle=3
oplot,e,1.e-6*fcrab,linestyle=3
plotsign
plotnumber,34
xyouts,6.,8.0e-3,'HPW = '+strmid(strtrim(hpw,2),0,3)+' arcmin',charsize=1.5
xyouts,6.,4.0e-3,'5!4r!3 detection',charsize=1.5
xyouts,6.,2.0e-3,'0.66!9r!3E keV detection band',charsize=1.5
xyouts,6.,1.0e-3,'0.65 correction applied',charsize=1.5
xyouts,e(55),1.1e-3*fcrab(55),'mCrab',size=1.7
xyouts,e(53)*0.6,1.1e-6*fcrab(53),'!4l!3Crab',size=1.7
xyouts,2.5,4.e-7,'DXB',size=1.8
for i = 3,5 do begin
   tobs = 10.^i  ; observation time in sec
   np = tobs * acell * fp * deltae
   nd = tobs * comega * fdxb * aeff * qhepc * deltae
   nsrc = 5. * sqrt(4.+np+nd)
   flim = nsrc / (fraction * tobs * aeff*qhepc * deltae)
   for j = 0, n_elements(e)-1  do begin
      printf,2,e(j),flim(j),format='(2e12.3)'
   endfor
   oplot,e,flim,thick=2.0
   tekst = string(i,format='("10!u",i1,"!n s")')
   xyouts,e(20),flim(20)*1.2,tekst,size=1.5
endfor
close,2
end
