pro histo, y, h, x, minval=minval, binsize=binsize, maxval=maxval,$
                         nbins=nbins,silent=silent
;
; Returns the histogram of values 'y' in variable 'h'
; and the corresponding x values in 'x'
;

;... Give calling sequence if number of parameters is incorrect

if n_params() ne 3 then begin
   print,'HISTO, y, h, x, minval=minval, binsize=binsize, maxval=maxval, nbins=nbins'
   print,' Input data: ''y'', returns histogram in ''h'' and scale in ''x'''
   print,'Keyword ''silent'' will quench the screen output'
   retall
endif

vb = 1 - keyword_set(silent)

szn = size(minval)
szx = size(maxval)
szb = size(binsize)
sznv = size(nbins)
defn = 0
defx = 0
defb = 0
defnv = 0
if total(szn(0:1)) gt 0 then defn = 1
if total(szx(0:1)) gt 0 then defx = 1
if total(szb(0:1)) gt 0 then defb = 1
if total(sznv(0:1)) gt 0 then defnv = 1

thecase = defn + 2*defx + 4*defb + 8*defnv

case thecase of
   0 : begin                     ; no keywords set
          if vb then print,'Case 0: no keywords'
          h = 1.0 * histogram(y)
          bs = 1.
          minval = min(y)
          maxval = max(y)
       end
   1 : begin                     ; minimum set
          if vb then print,'Case 1: minval set'
          h = 1.0 * histogram(1.0*y,min=minval)
          bs = 1.
          maxval = max(y)
       end
   2 : begin                     ; maximum set
          if vb then print,'Case 2: maxval set'
          h = 1.0 * histogram(1.0*y,max=maxval)
          minval = min(y)
          bs = 1.
       end
   3 : begin                     ; minimum and maximum set
          if vb then print,'Case 3: minval and maxval set'
          h = 1.0 * histogram(1.0*y,min=minval,max=maxval)
          bs = 1.
       end
   4 : begin                     ; binsize set
          if vb then print,'Case 4: binsize set'
          h = 1.0 * histogram(1.0*y,binsize=binsize)
          minval = min(y)
          maxval = max(y)
          bs = binsize
       end
   5 : begin                     ; binsize and minimum set
          if vb then print,'Case 5: minval and binsize set'
          h = 1.0 * histogram(1.0*y,binsize=binsize,min=minval)
          bs = binsize
          maxval = max(y)
       end
   6 : begin                     ; binsize and maximum set
          if vb then print,'Case 6: maxval and binsize set'
          h = 1.0 * histogram(1.0*y,binsize=binsize,max=maxval)
          minval = min(y)
          bs = binsize
       end
   7 : begin                     ; binsize, minimum, and maximum set
          if vb then print,'Case 7: minval, maxval, and binsize set'
          h = 1.0 * histogram(1.0*y,binsize=binsize,min=minval,max=maxval)
          bs = binsize
       end
   8 : begin                     ; number of bins set
          if vb then print,'Case 8: nbins set'
          minval = min(y)
          maxval = max(y)
          bs = (maxval - minval) / nbins
          h = 1.0 * histogram(1.0*y,binsize=bs)
       end
   9 : begin                     ; number of bins and minimum set
          if vb then print,'Case 9: minval and nbins set'
          maxval = max(y)
          bs = (maxval - minval) / nbins
          h = 1.0 * histogram(1.0*y,binsize=bs,max=maxval)
       end
  10 : begin                     ; number of bins and maximum set
          if vb then print,'Case 10: maxval and nbins set'
          minval = min(y)
          bs = (maxval - minval) / nbins
          h = 1.0 * histogram(1.0*y,binsize=bs,max=maxval)
       end
  11 : begin                     ; number of bins and minimum
                                 ;     and maximum set
          if vb then print,'Case 11: minval, maxval, and nbins set'
          bs = (maxval-minval)/nbins
          h = 1.0 * histogram(1.0*y,binsize=bs,min=minval,max=maxval)
       end
  12 : begin                     ; number of bins and binsize set
          if vb then print,'Case 12: binsize and nbins set'
          minval = min(y)
          bs = binsize
          maxval = minval + nbins*bs
          h = 1.0 * histogram(1.0*y,min=minval,max=maxval,binsize=binsize)
       end
  13 : begin                     ; number of bins and binsize
                                 ;     and minimum set
          if vb then print,'Case 13: minval, binsize, and nbins set'
          bs = binsize
          maxval = minval + bs*nbins
          h = 1.0 * histogram(1.0*y,binsize=binsize,min=minval,max=maxval)
       end
  14 : begin                     ; number of bins and binsize
                                 ; and maximum set
          if vb then print,'Case 14: maxval, binsize, and nbins set'
          bs = binsize
          minval = maxval - bs*nbins
          h = 1.0 * histogram(1.0*y,binsize=binsize,min=minval,max=maxval)
       end
  15 : begin                     ; number of bins and binsize,
                                 ; minimum, and maximum set
          if vb then print,'Case 15: minval, maxval, binsize, and nbins set'
          bs = binsize
          if abs(maxval - nbins*bs - minval) gt 1.e-5 then begin
             print,'%HISTO error - overdetermined mismatching input'
             h = -1
             x = -1
             return
          endif
          h = 1.0 * histogram(1.0*y,binsize=binsize,min=minval,max=maxval)
       end
   default : print,'Impossible value'
endcase

x = findgen(n_elements(h))*bs + minval + 0.5*bs
if vb then print,'minval = ', minval,'  maxval = ', maxval,'  binsize = ', bs
if vb then print,'Number of elements in returned histogram : ', n_elements(h)


end
