pro ijd2dattim, ijd, dattim
;
;  Conversion of IJD in Terrestrial Time to a UTC string
;  in format YYYY-MM-DDThh:mm:ss
;  The difference of 64.184 s (or 65.184 s after 2005-12-31T23:59:60,
;    66.184 s after 2008-12-31T23:59:60, 67.184 s after 2012-06-30T23:59:60)

;  is taken care of
;
;   2006-12-20/NJW Updated with conversion TT to UTC
;
if n_params() lt 2 then begin
   print,'Syntax: ijd2dattim, ijd, dattim'
   return
endif

if ijd lt 0.1 then begin
   print,'Does not work for IJD = ',ijd
   return
endif

days_in_month = [31,28,31,30,31,30,31,31,30,31,30,31]

t_dif_s = 64.184d0
;   end of 2005
if ijd gt 2192.0007428704d0 then t_dif_s = 65.184d0
;   end of 2008
if ijd gt 3288.0007544444d0 then t_dif_s = 66.184d0
;   mid 2012
if ijd gt 4565.0007660185d0 then t_dif_s = 67.184d0

t_dif_ijd = t_dif_s / 86400.d0

ijd_utc = ijd - t_dif_ijd
dat = '2000-01-01T00:00:00'

; Get year

for year = 2001, 2099 do begin

   str_year = string(year,format='(i4.4)')
   strput,dat,str_year,0
   dattim2ijd,dat,t
   if t gt ijd then break

endfor

year = year - 1
str_year = string(year,format='(i4.4)')
strput,dat,str_year,0
if year mod 4 eq 0 then days_in_month(1) = 29 ; leap year

; Get month

for month = 1, 12 do begin

   str_month = string(month,format='(i2.2)')
   strput,dat,str_month,5
   dattim2ijd,dat,t
   if t gt ijd then break

endfor

month = month - 1
str_month = string(month,format='(i2.2)')
strput,dat,str_month,5

; Get day

for day = 1, days_in_month(month-1) do begin

   str_day = string(day,format='(i2.2)')
   strput,dat,str_day,8
   dattim2ijd,dat,t
   if t gt ijd then break

endfor

day = day - 1
str_day = string(day,format='(i2.2)')
strput,dat,str_day,8

frac = ijd_utc - floor(ijd_utc)
h = frac * 24
hour = fix(h)
m = (h - hour) * 60
minute = fix(m)
s = (m - minute) * 60
second = fix(s)

str_hour = string(hour,format='(i2.2)')
strput,dat,str_hour,11

str_minute = string(minute,format='(i2.2)')
strput,dat,str_minute,14

str_second = string(second,format='(i2.2)')
strput,dat,str_second,17

dattim = dat

end
