pro image_src_cts, im, zoom=zoom
;
;    NJW 2002-09-27
;
if n_params() lt 1 then begin
   print,'Syntax: image_src_cts,image[,zoom=]'
   print,'      where the keyword ''zoom'' gives the zoom factor'
   print,'      If not given it will be requested'
   return
endif

disp,im,f
;
;   Define the zoom
;
print,'Point to the zoom center ...'
curmark1,xy,/device
xzoom = fix(xy(0))/f
yzoom = fix(xy(1))/f

; Get the zoom factor if not given as keyword

if keyword_set(zoom) then zfac = float(zoom) else begin
   zfac = '1'
   read,'Enter zoom factor : ... ', zfac
   if zfac eq '' then zfac = 1.0 else zfac = float(zfac)
endelse

sz = size(im)
limit = float(min((sz(1:2)-1)/2))
if zfac gt limit then begin
   zfac = limit
   print,'The zoom factor has been adjusted to: ', zfac
endif

nx = fix(sz(1)/(2*zfac))
ny = fix(sz(2)/(2*zfac))

x1 = xzoom - nx
x2 = xzoom + nx
overshoot = sz(1) - x2
if overshoot lt 0 then begin
   x1 = x1 + overshoot
   x2 = x2 + overshoot
endif
undershoot = x1
if undershoot lt 0 then begin
   x1 = x1 - x1
   x2 = x2 - x1
endif

y1 = yzoom - ny
y2 = yzoom + ny
overshoot = sz(1) - y2
if overshoot lt 0 then begin
   y1 = y1 + overshoot
   y2 = y2 + overshoot
endif
undershoot = y1
if undershoot lt 0 then begin
   y1 = y1 - y1
   y2 = y2 - y1
endif

imzoom = im(x1:x2,y1:y2)

disp,imzoom,ff

;  First mark the source pixels

print,'Mark the source pixels ...'
curmark,srcpix,/device,npoints=n_srcpix
srcpix = fix(srcpix)/ff

source_counts = 0.
for i = 0, n_srcpix-1 do begin
   source_counts = source_counts + imzoom(srcpix(0,i),srcpix(1,i))
endfor
print,'Number of source counts:  ', source_counts

;  Then mark the background rectangular area

print,'Mark the lower left corner for background ...'
curmark1,lole,/device
print,'Mark the upper right coner for background ...'
curmark1,upri,/device
x1 = fix(lole(0))/ff
x2 = fix(upri(0))/ff
y1 = fix(lole(1))/ff
y2 = fix(upri(1))/ff
bkg_counts = 0.
n_bkg_pixels = 0
for i = x1,x2 do begin
   for j = y1,y2 do begin
      w = where(srcpix(0,*) eq i and srcpix(1,*) eq j, n_w)
      if n_w eq 0 then begin
         bkg_counts = bkg_counts + imzoom(i,j)
         n_bkg_pixels = n_bkg_pixels + 1
      endif
   endfor
endfor
print,'Number of bkg counts (total) :  ', bkg_counts
print,'Number of bkg counts per pixel: ', bkg_counts / n_bkg_pixels
print,'Corrected number of source counts : ', source_counts - n_srcpix*bkg_counts/n_bkg_pixels


end
