pro image_src_cts_a, im, zoom=zoom, n_ann=n_ann, outfile=outfile
;
;    NJW 2002-09-30
;
if n_params() ne 1 then begin
   print,'Syntax: image_src_cts_a,image[,zoom=][,n_ann=][, outfile=]'
   print,'      where the keyword ''zoom'' gives the zoom factor'
   print,'      If not given it will be requested'
   print,'      The keyword ''n_ann'' gives the number of annuli'
   print,'      The default value is 15'
   return
endif

if keyword_set(outfile) then begin
   openw,lun,outfile,/get_lun
   wf = 1
   printf,lun,'//  Result of image_src_cts_a     '+systime()
endif else wf = 0

disp,im,f

;
;  Define the number of annuli
;
n_annuli = 15
if keyword_set(n_ann) then n_annuli = n_ann
if wf then printf,lun,'// n_annuli = ',n_annuli

;
;   Define the zoom
;
print,'Point to the zoom center ...'
curmark1,xy,/device
xzoom = fix(xy(0))/f
yzoom = fix(xy(1))/f

; Get the zoom factor if not given as keyword

if keyword_set(zoom) then zfac = float(zoom) else begin
   zfac = '1'
   read,'Enter zoom factor : ... ', zfac
   if zfac eq '' then zfac = 1.0 else zfac = float(zfac)
endelse

sz = size(im)
limit = float(min((sz(1:2)-1)/2))
if zfac gt limit then begin
   zfac = limit
   print,'The zoom factor has been adjusted to: ', zfac
endif

nx = fix(sz(1)/(2*zfac))
ny = fix(sz(2)/(2*zfac))

x1 = xzoom - nx
x2 = xzoom + nx
overshoot = sz(1) - x2
if overshoot lt 0 then begin
   x1 = x1 + overshoot
   x2 = x2 + overshoot
endif
undershoot = x1
if undershoot lt 0 then begin
   x1 = x1 - x1
   x2 = x2 - x1
endif

y1 = yzoom - ny
y2 = yzoom + ny
overshoot = sz(1) - y2
if overshoot lt 0 then begin
   y1 = y1 + overshoot
   y2 = y2 + overshoot
endif
undershoot = y1
if undershoot lt 0 then begin
   y1 = y1 - y1
   y2 = y2 - y1
endif

imzoom = im(x1:x2,y1:y2)

disp,imzoom,ff

;  First mark the (central) source pixel

print,'Mark the central source pixel ...'
curmark1,srcpix,/device
x_srcpix = fix(srcpix(0))/ff
y_srcpix = fix(srcpix(1))/ff

;  Then mark the radius of the background area

print,'Mark a point on the circle for the background determination ...'
curmark1,peri,/device

x1 = peri(0)/ff
y1 = peri(1)/ff

bkg_radius = sqrt((x1 - x_srcpix)^2 + (y1 - y_srcpix)^2)
s = fix(bkg_radius + 0.5)
sel = imzoom(x_srcpix-s:x_srcpix+s, y_srcpix-s:y_srcpix+s)
csel = rebin(sel,3*(2*s+1),3*(2*s+1),/sample) / 9

if wf then begin
   printf,lun,'// bkg_radius = ', bkg_radius
   printf,lun,'// dimension = ', 3*(2*s+1)
endif

disp,csel
disp,smooth(csel,3,/edge),/pa

; New central pixel

m = 3*s + 1

r_arr = xlingen( n_annuli, 2., 3*s+1)
ann = fltarr(n_annuli)
apix = ann

for i = 0, 6*s+2 do begin
for j = 0, 6*s+2 do begin
   radius = sqrt((1.0*i - m)^2 + (1.0*j - m)^2)
   for k = 0, n_annuli-1 do if radius lt r_arr(k) then goto,break
   break:
   if k lt n_annuli then begin
      ann(k) = ann(k) + csel(i,j)
      apix(k) = apix(k) + 1.
   endif
endfor
endfor

annppix = ann / apix
plot,r_arr,annppix,ps=10,xtit='Pixels',ytit='Cts/pixel'
if wf then begin
   printf,lun,'// block = 1'
   for i = 0, n_annuli-1 do begin
      printf,lun,r_arr(i),annppix(i),apix(i),format='(3f12.5)'
   endfor
   printf,lun,'// block = 2'
endif

; Make fit to background

r_mean = fltarr(n_annuli)
r_mean(0) = r_arr(0)*0.5
for i = 1,n_annuli-1 do r_mean(i) = 0.5*(r_arr(i-1)+r_arr(i))

xfit = xlingen(50,0.,max(r_arr))
for i = 1, n_annuli/2 do begin
   w = indgen(n_annuli-i) + i
   n_w = n_elements(w)
   res = fit_stdparabola(r_mean(w),annppix(w),xfit,yfit,sum=sum)
   print,i,res,'reduced sum=',sum/n_w
   oplot,xfit,yfit,li=2
   q = where( xfit gt min(r_mean(w)) and xfit lt max(r_mean(w)) )
   oplot,xfit(q),yfit(q),thick=2

   src = indgen(i+1)
   src_cts_tot = total(ann(src) - yfit(src)*apix(src))
   print,'Total source: ', src_cts_tot
   if wf then printf,lun,i,src_cts_tot,sum/n_w,format='(i12,2f12.5)'
endfor

if wf then free_lun,lun

end
