function inside_triangle, point, coords, errmsg=errmsg
;
;  Determine if a point is inside a given triangle
;
;  (x,y) for point is point(0),point(1)
;
;  coords(0,0) = x0, coords(0,1) = x1, coords(0,2) = x2
;  coords(1,0) = y0, coords(1,1) = y1, coords(1,2) = y2
;
;   2004-08-12/NJW
;
if n_params() lt 2 then begin
	print,'Syntax: res = inside_triangle(point,coords[,errmsg=])'
	print,'        point is a two element array'
	print,'        coords is a 2x3 element array with triangle'
	print,'   keyword ''errmsg'' returns empty string when OK'
	return,0
endif

errmsg = ''

ax = coords(0,1) - coords(0,0)
ay = coords(1,1) - coords(1,0)
bx = coords(0,2) - coords(0,0)
by = coords(1,2) - coords(1,0)
cx = point(0) - coords(0,0)
cy = point(1) - coords(1,0)

det = cx*(by-ay) - cy*(bx-ax)
if abs(det) lt 1.e-6 then begin
   errmsg = 'Degenerate triangle'
   return,0
endif

detq = bx*(by-ay) - by*(bx-ax)
detr = cx*by - cy*bx

q = detq / det
r = detr / det

if 0. lt r and r lt 1.0 and q gt 1. then return, 1

return, 0

end
