function is_in_polygon, polygon, refpoint, point
;
;  Determine whether the point 'point' is inside the
;  polygon 'polygon' when definition is that the
;  reference point 'refpoint' is inside the polygon
;
;  'polygon' must be a 2D array (2,*)
;
sz = size(polygon)
if sz(0) ne 2 then begin
   print,'Polygon array must be 2D - terminate!'
   return, 0
endif
if sz(1) ne 2 then begin
   print,'First polygon dimension must be 2 - terminate!'
   return, 0
endif
nvertices = sz(2)

; Increase size of polygon so that last point == first point

pol = fltarr(2,nvertices+1)
pol(*,0:nvertices-1) = polygon
pol(*,nvertices) = polygon(*,0)


; Get number of intersections of the line refpoint -> point
; with sides in polygon

n_intersections = 0
for i = 0, nvertices-1 do begin
   if intersect(refpoint,point, $
     [pol(0,i),pol(1,i)],[pol(0,i+1),pol(1,i+1)]) $
       then n_intersections = n_intersections + 1
endfor

return, (n_intersections+1) mod 2

end
