function is_real, str
;
;  Returns 1 if string only contains digits
;  plus perhaps a preceding sign
;  a dot (decimal point), the letter 'e' or 'E'
;  and another sign
;
;  NJW/010620
;
sz = size(str)
if sz(0) ne 0 or sz(1) ne 7 then begin
   print,'IS_REAL error, unacceptable argument'
   return, 0
endif

st = strtrim(str,2)
on_ioerror,L1
val = double(st)

; Passed the first test

; Test 2: empty string ?

len = strlen(st)
if len eq 0 then return, 0

; Test 3: two or more dots

p1 = strpos(st,'.')
if p1 ge 0 then begin
   p2 = strpos(st,'.',p1+1)
   if p2 gt 0 then return, 0
endif

; Test 4: first character is +, -, or a digit

first_is_sign = 0
if strmid(st,0,1) eq '+' or strmid(st,0,1) eq '-' then begin
   st = strmid(st,1,9999)
   first_is_sign = 1
endif

if not is_digit(strmid(st,0,1)) $
   and strmid(st,0,1) ne '.' then return, 0

; Test 5: all characters must be valid number characters

if not is_valid_nchar(st) then return, 0

; Test 6: No more than one sign is allowed after first character

len = strlen(st)
nsign = 0
for i = 0, len-1 do begin
   c = strmid(st,i,1)
   if c eq '-' or c eq '+' then nsign = nsign + 1
endfor

if nsign gt 1 then return, 0

; Passed test 6

return, 1

L1: return, 0

end
