pro j_comp_image, sim_name, imsize=imsize, rad=rad
;
; make map of JEMX exposure for a series of pointings
;

if n_params() lt 1 then begin
   print,'Syntax: j_comp_image, sim_name[,imsize=][,rad=]
   print,'    Image size (imsize) is in degrees. Default: 15 deg.'
   print,'    Maximum radius (rad) is in degrees. Default: No limitation'
   return
endif

deg2rad = 0.0174532925
;
; Get rid of old files

name_comp_image = '/r4/njw/RSIM0/'+sim_name+'/comp_image.fits'
name_comp_exposure = '/r4/njw/RSIM0/'+sim_name+'/comp_exposure.fits'

spawn,'\rm '+name_comp_image
spawn,'\rm '+name_comp_exposure

;
; Define limiting radius    CDLT = 0.066666667
;
rad_index2 = 500.*500. ; default value
if keyword_set(rad) then begin
   cdlt = 0.06666667
   rad_index2 = (rad / cdlt)^2
endif

;
; Define pointing of 'super-instrument'
;

;  Take observation pointing as center

fxbopen,unit,'/r4/njw/RSIM0/'+sim_name+'/'+sim_name+'.fits',1,obshdr

ra_pnt_si  = fxpar(obshdr,'RA_OBS')    ; decimal degrees
dec_pnt_si = fxpar(obshdr,'DEC_OBS')  ; decimal degrees
num_pointings = fxpar(obshdr,'NUMPOINT')

roll_si = 0.00   ; degrees
ra_x = ra_pnt_si * deg2rad
dc_x = dec_pnt_si * deg2rad
teta = roll_si * deg2rad

; Pointing in EQ system
 
x_eq = [cos(ra_x)*cos(dc_x), sin(ra_x)*cos(dc_x), sin(dc_x)]
 
; S/C Y-axis direction in EQ system
 
y_eq = [-sin(ra_x)*cos(teta)-sin(dc_x)*cos(ra_x)*sin(teta),$
        cos(ra_x)*cos(teta)-sin(dc_x)*sin(ra_x)*sin(teta),$
        cos(dc_x)*sin(teta)]
 
; S/C Z-axis direction in EQ system
 
z_eq = [sin(ra_x)*sin(teta)-sin(dc_x)*cos(ra_x)*cos(teta),$
        -cos(ra_x)*sin(teta)-sin(dc_x)*sin(ra_x)*cos(teta),$
        cos(dc_x)*cos(teta)]
 
; Define transformation matrix
 
omega_si = fltarr(3,3)
omega_si(*,0) = x_eq
omega_si(*,1) = y_eq
omega_si(*,2) = z_eq
is_agemo = transpose(omega_si)

; Get image size

xsize = 15. ; degrees
ysize = 15. ; degrees
if keyword_set(imsize) then begin
   xsize = imsize
   ysize = imsize
endif
xdim_si = 400
ydim_si = 400
xpixsize_deg = xsize/xdim_si
ypixsize_deg = ysize/ydim_si
xrefpix = xdim_si/2
yrefpix = ydim_si/2

image_si = fltarr(xdim_si, ydim_si)
exposure = fltarr(xdim_si, ydim_si)
;
; Inititate plotting
;
set_plot,'x'
window,0,xs=xdim_si,ys=ydim_si,title='Image'
window,1,xs=xdim_si,ys=ydim_si,title='Exposure'

; Prepare FITS file for result

fxhmake,hdr_im_si,image_si
fxaddpar,hdr_im_si,'CDELT1',-xpixsize_deg,'Pixelsize in degrees'
fxaddpar,hdr_im_si,'CDELT2',ypixsize_deg,'Pixelsize in degrees'
fxaddpar,hdr_im_si,'CRPIX1',xrefpix,'Reference pixel'
fxaddpar,hdr_im_si,'CRPIX2',yrefpix,'Reference pixel'
fxaddpar,hdr_im_si,'CRVAL1',ra_pnt_si,'Reference value'
fxaddpar,hdr_im_si,'CRVAL2',dec_pnt_si,'Reference value'
fxaddpar,hdr_im_si,'CTYPE1','RA---TAN','Coordinate system'
fxaddpar,hdr_im_si,'CTYPE2','DEC--TAN','Coordinate system'
fxaddpar,hdr_im_si,'CROTA2',0.00,'Rotation angle in degrees'

; Find the images (in celestial coordinates) that may contribute
; 

list = strarr(num_pointings)
for i = 0, num_pointings-1 do begin
   istr = string(i+1,format='(i4.4)')
   list(i) = '/r4/njw/RSIM0/'+sim_name+'/'+sim_name+'_9001'+istr+'0001.fits'
endfor

list = [list, list]

extno = [replicate(14,num_pointings), replicate(15,num_pointings)]

for l = 0,n_elements(list)-1 do begin
   
   ; open JEMX image file
   
   print,'Image now : ',list(l)
   keyname = 'FILEIN'+strtrim(l+1,2)
   fxaddpar,hdr_im_si,keyname,list(l),'File added'

   imf = readfits(list(l),hdr,ext=extno(l))

   naxis1 = fxpar(hdr,'NAXIS1')
   naxis2 = fxpar(hdr,'NAXIS2')
   ra_pnt = fxpar(hdr,'CRVAL1')
   dec_pnt = fxpar(hdr,'CRVAL2')
   roll_pnt = fxpar(hdr,'ROLL_PNT')
   cdelt1 = fxpar(hdr,'CDELT1')
   cdelt2 = fxpar(hdr,'CDELT2')
   crpix1 = fxpar(hdr,'CRPIX1')
   crpix2 = fxpar(hdr,'CRPIX2')
   crval1 = fxpar(hdr,'CRVAL1')
   crval2 = fxpar(hdr,'CRVAL2')
   
   ; Define transformation matrix
   
   ra_x = ra_pnt * deg2rad
   dc_x = dec_pnt * deg2rad
   teta = roll_pnt * deg2rad
   
   ; Pointing in EQ system
    
   x_eq = [cos(ra_x)*cos(dc_x), sin(ra_x)*cos(dc_x), sin(dc_x)]
 
   ; S/C Y-axis direction in EQ system
 
   y_eq = [-sin(ra_x)*cos(teta)-sin(dc_x)*cos(ra_x)*sin(teta),$
        cos(ra_x)*cos(teta)-sin(dc_x)*sin(ra_x)*sin(teta),$
        cos(dc_x)*sin(teta)]
 
   ; S/C Z-axis direction in EQ system
 
   z_eq = [sin(ra_x)*sin(teta)-sin(dc_x)*cos(ra_x)*cos(teta),$
        -cos(ra_x)*sin(teta)-sin(dc_x)*sin(ra_x)*cos(teta),$
        cos(dc_x)*cos(teta)]
 
    
   ; Define transformation matrix
    
   omega = fltarr(3,3)
   omega(*,0) = x_eq
   omega(*,1) = y_eq
   omega(*,2) = z_eq
   
   ; Step through pixels and find where they belong in
   ; the super-instrument
   
   for i = 0,naxis1-1 do begin
      for j = 0,naxis2-1 do begin

         if (i-100.)^2 + (j-100.)^2  lt  rad_index2 then begin


       ;-- get angles relative to satellite axes
         xa = (i-crpix1)*cdelt1 ; degrees
         ya = (j-crpix2)*cdelt2 ; degrees
         sy = sin(xa * deg2rad)
         sz = sin(ya * deg2rad)
         sx = sqrt(1. - sy^2 - sz^2)
         s = [sx,sy,sz]
         seq = omega # s
         ra = atan(seq(1),seq(0)) / deg2rad
         dec = asin(seq(2)) / deg2rad
         ;* print,adstring(ra,dec)
   ; Where does this pixel belong in the super-instrument ?
         s_si = is_agemo # seq
         xa_si = asin(s_si(1)) / deg2rad
         ya_si = asin(s_si(2)) / deg2rad
         di_si = fix(xa_si/xpixsize_deg)
         dj_si = fix(ya_si/ypixsize_deg)
         if xa_si lt 0 then di_si = di_si - 1
         if ya_si lt 0 then dj_si = dj_si - 1
         i_si = xrefpix - di_si ; reverse direction
                           ; for proper plotting
         j_si = dj_si + yrefpix
   
         factor = thruput_instr(xa*60., ya*60.) ; angles must be arcmin
         if i_si ge 0 and i_si lt xdim_si and $
            j_si ge 0 and j_si lt ydim_si     then begin
             image_si(i_si,j_si) = image_si(i_si,j_si) + imf(i,j)
             exposure(i_si,j_si) = exposure(i_si,j_si) + factor
         endif

         endif ; Terminate 'if radius lt 3 deg'

      endfor
   endfor
   wset,0
   tvscl,image_si>0
   wset,1
   tvscl,exposure
endfor

; Dump to FITS files

writefits,name_comp_image,image_si,hdr_im_si
writefits,name_comp_exposure,exposure,hdr_im_si



end
