pro j_estimate_spectrum, dol_of_og, num_jemx, num_source
;
;----------------------------------
;  This seems to be a procedure from before 2004-04-13 related
;  to some simulation stuff
;     2007-01-18/NJW
;-----------------------------------
; 
if n_params() lt 3 then begin
   print,'Syntax: j_estimate_spectrum, dol_of_og, num_jemx, num_source
   return
endif



; The SWG index table is the only (or first) child of the OG:

ebm_get_child,dol_of_og,1,swg_idx,errmsg

; Get the SWG's

ebm_get_child,swg_idx,1,swg,errmsg,count=n_swg

if n_swg eq 1 then begin
   print,'There is a single SWG in the OG'
endif else begin
   print,'There are '+strtrim(n_swg,2)+' SWGs in the OG'
endelse

i_swg = 1

if n_swg gt 1 then begin
   read,'   Enter your choice: ... ', i_swg
endif

; Get the DOL of the appropriate SWG:

ebm_get_child,swg_idx, i_swg, swg,errmsg

; Get the eventlist for the requested instrument:

ebm_get_child_by_name, swg,'JMX'+strtrim(num_jemx,2)+'-EVTS-PHO',evntlist,errmsg

rdfitscol,evntlist,energy,'ENERGY',/sil
rdfitscol,evntlist,source_id,'SOURCE_ID',/sil
source_id = fix(source_id)


n_evts = n_elements(energy)

; Define energy boundaries:

nch = 70
ebnds = xloggen(nch+1,2.5,50.)

eb1 = ebnds(0:nch-1)
eb2 = ebnds(1:nch)

; Determine the source id numbers present:

method_1 = 0

if method_1 then begin

   is = sort(source_id)
   ar = source_id(is)

   u = uniq(ar)
   src = ar(u)

   n_src = n_elements(src)

endif else begin       ; use instead method 2

   src = intarr(12)
   n_src = 0
   for isrc = 0, 10 do begin
      iw = where( source_id eq isrc, n_isrc)
      if n_isrc gt 0 then begin
         src(n_src) = isrc
         n_src = n_src + 1
      endif
   endfor

; test for instrument background

   iw = where(source_id eq 9999, n_isrc)
   if n_isrc gt 0 then begin
      src(n_src) = 9999
      n_src = n_src + 1
   endif

   src = src(0:n_src-1)

endelse
print, n_src,' sources have been identified'
print, src

spec_array = fltarr(nch,n_src)

; Sort the events into the channels

n_spill = 0L

print,'Sorting ', n_evts,' events into energy bins'
for i = 0L, n_evts-1 do begin
   if ((i+1L) mod 10000) eq 0 then print, ((i+1L)*100.)/n_evts,'% done'
   e = energy(i)
   id = source_id(i)
   index = where(src eq id)

   if e lt eb1(0) or e gt eb2(nch-1) then begin
      n_spill = n_spill + 1
   endif else begin

      if e ge eb1(nch-1) then begin
         j1 = nch-1
      endif else begin
         j1 = 0
         j2 = nch - 1
         repeat begin
            j = (j1 + j2)/2
            if eb1(j) lt e then j1 = j
            if eb1(j) ge e then j2 = j
         endrep until (j2 - j1 eq 1)
         spec_array(j1,index(0)) = spec_array(j1,index(0)) + 1
      endelse

   endelse

endfor
print,'Spill over: ', n_spill

background = 0.25*(spec_array(*,0) + spec_array(*,n_src-1))
dxb_background = 0.25*spec_array(*,0)
ibg_background = 0.25*spec_array(*,n_src-1)
source_spectrum = spec_array(*,num_source) + background
err_source_spectrum = sqrt(source_spectrum)
model_background = smooth(background,7,/edge)

; Plot the counts

if !d.name ne 'PS' then window,0,tit='source and background'
!p.title = '3C 273, JEMX 1000 s simulation'
!x.title = 'Energy [keV]'
!y.title = 'Counts'
dataplotf,eb1,sqrt(eb1*eb2),eb2,source_spectrum-err_source_spectrum,$
      source_spectrum,source_spectrum+err_source_spectrum,$
      yr=max(source_spectrum)*[0.02,1],itype=3
oplot,sqrt(eb1*eb2),model_background,li=2
oplot,sqrt(eb1*eb2),smooth(dxb_background,7,/edge),li=3
oplot,sqrt(eb1*eb2),smooth(ibg_background,7,/edge),li=4

if !d.name eq 'PS' then erase

y = source_spectrum - model_background
y1 = y - err_source_spectrum
y2 = y + err_source_spectrum

if !d.name ne 'PS' then window,1,tit='Source with subtracted background'

dataplotf,eb1,sqrt(eb1*eb2),eb2,y1,y,y2,itype=2
   
if !d.name eq 'PS' then erase

; Make plots of counts/keV

if !d.name ne 'PS' then window,2,tit='source and background'
!p.title = '3C 273, JEMX 1000 s simulation'
!x.title = 'Energy [keV]'
!y.title = 'Counts/keV'
de = eb2 - eb1
dataplotf,eb1,sqrt(eb1*eb2),eb2,(source_spectrum-err_source_spectrum)/de,$
      source_spectrum/de,(source_spectrum+err_source_spectrum)/de,$
      yr=max(source_spectrum/de)*[0.02,1],itype=3
oplot,sqrt(eb1*eb2),model_background/de,li=2
oplot,sqrt(eb1*eb2),smooth(dxb_background,7,/edge)/de,li=3
oplot,sqrt(eb1*eb2),smooth(ibg_background,7,/edge)/de,li=4
if !d.name eq 'PS' then erase

y = (source_spectrum - model_background)/de
y1 = y - err_source_spectrum/de
y2 = y + err_source_spectrum/de

if !d.name ne 'PS' then window,3,tit='Source with subtracted background'
dataplotf,eb1,sqrt(eb1*eb2),eb2,y1,y,y2,itype=2
end
