pro j_find_coverage_radec, ra0, dec0, tvals, nstat, $
	rev=rev, tstart=tstart, tstop=tstop, chatter=chatter
;
if n_params() lt 4 then begin
   print,'Syntax: j_find_coverage_radec, ra0, dec0, >tvals, >nstat[, rev=][,tstart=][,tstop=]'
   print,'     Returns two 4-element arrays: tvals and nstat'
   print,'     tvals(0) will contain the total elapsed time weighted with vignetting'
   print,'     nstat(0) will contain the total number of pointings inside 6 degrees'
   print,'     with index 1: values for distance less than 2 deg'
   print,'     with index 2: values for distance gt 2 and lt 4 deg'
   print,'     with index 3: values for distance gt 3 and lt 6 deg'
   print
   print,'   Keywords:'
   print,'             rev:    Either scalar integer or 2 element integer'
   print,'                     array with min and max revolution number'
   print,'             tstart: Time in IJD for start of interval'
   print,'             tstop:  Time in IJD for end of interval'
   print,'             chatter:  Level of verbosity (max is 5)'
   return
endif
;
;  Initialize
;
if keyword_set(tstart) then tbegin = tstart else tbegin = 0.0d0
if keyword_set(tstop) then tend = tstop else tend = 1.0d9

tvals = fltarr(4)
nstat = intarr(4)

if !version.os eq 'sunos' then begin
   dir_point = '/r2/jemx/pointings/'
endif
if !version.os eq 'linux' then begin
   dir_point = '/mnt/win_f/r2/jemx/pointings/'
endif

chat = 0
if keyword_set(chatter) then chat = chatter
if chat gt 0 then print,'j_find_coverage_radec called with radec = ', ra0, dec0
;
; Get list of pointing files
;

if keyword_set(rev) then begin
   nrev = n_elements(rev)
   if nrev eq 1 then begin
      revstr=string(rev,format='(i4.4)')
   endif else begin
      revstr = '{'
      for i = rev(0), rev(1) do begin
         revstr = revstr+string(i,format='(i4.4)')
         if i lt rev(1) then revstr = revstr+',' else revstr = revstr+'}'
      endfor
   endelse
   print,'revstr = ', revstr
   pf_list = file_search(dir_point+'pointings_'+revstr+'p.dat',count=npf_list)
endif else begin
   pf_list = file_search(dir_point+'pointings_allp.dat',count=npf_list)
endelse

if npf_list eq 0 then begin
   print,'j_find_coverage_radec: No pointing file within specified range'
   return
endif

if chat gt 0 then print,'Found ', npf_list,' pointing files'

for ipf_list = 0, npf_list-1 do begin

   rscold,pf_list(ipf_list),swid,1,/str,/sil
   rscold,pf_list(ipf_list),ra,2,/sil
   rscold,pf_list(ipf_list),dec,3,/sil
   rscold,pf_list(ipf_list),posangle,4,/sil
   rscold,pf_list(ipf_list),ut,5,/str,/sil
   rscold,pf_list(ipf_list),ijd,6,/sil
   rscold,pf_list(ipf_list),telapse,7,/sil
   rscold,pf_list(ipf_list),mode1,8,/str,/sil
   rscold,pf_list(ipf_list),mode2,9,/str,/sil

   dist = arcdist(ra0, dec0, ra, dec, /deg)


   w = where( dist lt 6.0 and (mode1 eq 'F' or mode2 eq 'F'), nw)

   if nw eq 0 then continue


   swid_all = swid(w)
   ra_all = ra(w)
   dec_all = dec(w)
   posangle_all = posangle(w)
   ut_all = ut(w)
   ijd_all = ijd(w)
   telapse_all = telapse(w)
   mode1_all = mode1(w)
   mode2_all = mode2(w)
   dist_all = dist(w)

   vign = 1. - dist_all/6.0
   tvals(0) = tvals(0) + total(telapse_all * vign)
   nstat(0) = nstat(0) + nw
   w1 = where( dist_all lt 2.0, nw1 )
   if nw1 gt 0 then begin
      tvals(1) = tvals(1) + total(telapse_all(w1) * vign(w1))
      nstat(1) = nstat(1) + nw1
   endif
   w1 = where( dist_all ge 2.0 and dist_all lt 4.0, nw1 )
   if nw1 gt 0 then begin
      tvals(2) = tvals(2) + total(telapse_all(w1) * vign(w1))
      nstat(2) = nstat(2) + nw1
   endif
   w1 = where( dist_all ge 4.0 , nw1 )
   if nw1 gt 0 then begin
      tvals(3) = tvals(3) + total(telapse_all(w1) * vign(w1))
      nstat(3) = nstat(3) + nw1
   endif


endfor



end
