pro j_get_find_res_sources, dol_of_og, $
                        radec=radec, outfile=outfile
;
;   2005-03-17/NJW  Cloned from j_get_srcl_res_sources
;
;
if n_params() lt 1 then begin
   print,'Syntax: j_get_find_res_sources, dol_of_og $'
   print,'        [, radec=][, outfile=]'
   print,'  ''radec'' is the chosen source position (3 element array: RA, Decl, radius)'
   print,'                            all units in degrees (3 arcmin = 0.05 deg)'
   return
endif

if not keyword_set(outfile) then outfile='outfile'

openw,lun,outfile,/get_lun
printf,lun,'// Output from j_get_find_res_sources '+systime()
printf,lun,'// Input DOL: '+dol_of_og
printf,lun,'//'
printf,lun,'// Column 1: E_MIN (keV)'
printf,lun,'// Column 2: E_MAX (keV)'
printf,lun,'// Column 3: RA (deg)'
printf,lun,'// Column 4: Decl (deg)'
printf,lun,'// Column 5: DETSIG'
printf,lun,'// Column 6: Offaxis angle (deg)'
printf,lun,'// Column 7: 100 x COSY_JMX'
printf,lun,'// Column 8: 100 x COSZ_JMX'
printf,lun,'// Column 9: Peaksize (cts)'
printf,lun,'//'
free_lun, lun

get_exten_no, dol_of_og, ogfile, ogext
if not file_test(ogfile,/reg) then begin
   print,'File: '+ogfile+' was not found'
   return
endif

src_sel = 0
if keyword_set(radec) then begin
   sz = size(radec)
   if sz(0) ne 1 or sz(1) ne 3 then begin
      print,'Warning: radec keyword has improper dimension and will be ignored'
   endif else begin
      src_sel = 1
      ra_src = radec(0)
      dec_src = radec(1)
      rad_sel = radec(2)
   endelse
endif

; Determine whether this is an OG or spectral file

oghdr = headfits(ogfile,exten=ogext)
strnumjemx = strtrim(fxpar(oghdr, 'INSTRUME'),2)
strj = strmid(strnumjemx,3,1)

extname = fxpar(oghdr, 'extname')
print,'EXTNAME = ', extname

if extname eq 'GROUPING' then begin

   ; Get the SWG IDX table
   ebm_get_child,dol_of_og,1,swg_idx,errmsg
   if errmsg ne '' then begin
      print,'##3##'
      print,errmsg
      return
   endif

   ; Get number of SWGs
   ebm_get_num_children, swg_idx, num_swgs, errmsg
   if errmsg ne '' then begin
      print,'##5##'
      print,errmsg
      return
   endif

   ; Loop over the SWGs to get FIND_RES

   first = 1
   for iswg = 1, num_swgs do begin
      ebm_get_all_idxmembers, dol_of_og, iswg,'JMX'+strj+'-FIND-RES-IDX', $
                 dol_arr, errmsg, count=n_members
      if errmsg ne '' then begin
         print,'##6## iswg = ', iswg
         print,errmsg
         return
      endif

      if n_members eq 0 then begin
         print,'No FIND-RES in swg#'+stri(iswg)
         continue
      endif

      printl,dol_arr

      for mem = 0, n_members-1 do begin

         get_exten_no, dol_arr(mem), fileres, extres
         hdr = headfits(fileres,ext=extres)
         e_min = fxpar(hdr,'E_MIN')
         e_max = fxpar(hdr,'E_MAX')

         rdfitscol, dol_arr(mem), rain,'RA_OBJ', nrows=nrows,/sil
         if nrows ge 1 then begin

            ; define array for storing and writing results
            resarr = fltarr(nrows,9)

            ; get offaxis angle
            print,'dolres: ', dol_arr(mem)
            h = ['// '+dol_arr(mem)]
            pick_swid_str,dol_arr(mem),swid
            get_pointing_for_swid,swid,ra_scx,dec_scx,roll
            rdfitscol,dol_arr(mem),decin,'DEC_OBJ',/sil
            rdfitscol,dol_arr(mem),detsigin,'DETSIG',/sil
            rdfitscol,dol_arr(mem),peaksize,'PEAKSIZE',/sil
            rdfitscol,dol_arr(mem),cosy,'COSY_JMX',/sil
            rdfitscol,dol_arr(mem),cosz,'COSZ_JMX',/sil

            offaxis = arcdist( rain, decin, ra_scx, dec_scx)
            print,'RA:', rain
            print,'DEC:', decin
            print,'DETSIG:', detsigin
            resarr(*,0) = e_min
            resarr(*,1) = e_max
            resarr(*,2) = rain
            resarr(*,3) = decin
            resarr(*,4) = detsigin
            resarr(*,5) = offaxis
            resarr(*,6) = cosy*100
            resarr(*,7) = cosz*100
            resarr(*,8) = peaksize
            nw = 1 ; assure writing of results when no source is selected
            if src_sel then begin ; Check if selected source is present
               r = arcdist(rain,decin, ra_src, dec_src)
               w = where(r lt rad_sel, nw)
               if nw gt 0 then resarr = resarr(w,*)
            endif
            
            if nw then wsmatrix, outfile, h, resarr, /app, fm='f10.3'
         endif else begin
            print,'No sources found'
         endelse

      endfor

   endfor

endif else begin
   print,'This is not an OG'
   return
endelse

print,'The output is found in: ', outfile

end


