function j_get_jarc_raw, swid, jemxnum, nrt=nrt
;
;   Return the path to jmxi_events.fits for given 12 digit SWID
;   and JEMX number in the lin6 JEMX rev_2 archive
;   If the file exists in gzipped version it will be unzipped
;
;   2005-11-16/NJW
;
if n_params() lt 2 then begin
   print,'Syntax: file = j_get_jarc_raw( SWID, jemxNum[, /nrt] )'
   print,'   Keyword ''nrt'' will cause the lin6/data/nrt to be used'
   return,''
endif

sz = size(swid)
if sz(0) ne 0 then begin
   print,'Only scalar string is allowed as SWID'
   return,''
endif
if sz(1) ne 7 then begin
   print,'SWID is not a string'
   return,''
endif
len = strlen(swid)
if len ne 12 then begin
   print,'The length of SWID is not 12 as it must be'
   return,''
endif
revol = strmid(swid,0,4)

if keyword_set( nrt ) then begin

   revdir = '/nfs/lin6/data/nrt/scw/'+revol
   if not file_test( revdir,/dir ) then begin
      print,'Cannot find directory '+revdir
      return,''
   endif
   arcdir = revdir+'/'+swid+'.000/jmx'+stri(jemxnum)+'/raw'
   if not file_test( arcdir,/dir ) then begin
      print,'Cannot find directory '+arcdir
      return,''
   endif
   fname = 'jmx'+stri(jemxnum)+'_raw.fits'
   if file_test(arcdir+'/'+fname+'.gz',/reg) then begin
      print,'Gunzip '+arcdir+'/'+fname+'.gz'
      spawn,'gunzip '+arcdir+'/'+fname+'.gz'
   endif
   if file_test(arcdir+'/'+fname,/reg) then begin
      return,arcdir+'/'+fname
   endif else begin
      print,'Cannot find '+arcdir+'/'+fname
      return,''
   endelse

endif else begin

   revdir = '/nfs/lin6/data/arc/rev_2/scw/'+revol
   if not file_test( revdir,/dir ) then begin
      print,'Cannot find directory '+revdir
      return,''
   endif
   arcdir = revdir+'/'+swid+'.001'
   if not file_test( arcdir,/dir ) then begin
      print,'Cannot find directory '+arcdir
      return,''
   endif
   fname = 'jmx'+stri(jemxnum)+'_events.fits'
   if file_test(arcdir+'/'+fname+'.gz',/reg) then begin
      print,'Gunzip '+arcdir+'/'+fname+'.gz'
      spawn,'gunzip '+arcdir+'/'+fname+'.gz'
   endif
   if file_test(arcdir+'/'+fname,/reg) then begin
      return,arcdir+'/'+fname
   endif else begin
      print,'Cannot find '+arcdir+'/'+fname
      return,''
   endelse

endelse




end
