pro j_get_pi_spectrum, full_cor_file, exposure_in, eb1, eb2, $
      rate, stat_err, perbin=perbin, expo=expo, radiuslimit=radiuslimit, $
      statuslimit=statuslimit
;
;   2005-11-03/NJW
;   2007-01-19/NJW, updated with keywords radiuslimit and statuslimit
;
;   Return spectrum per s per keV unless keyword perbin is set
;
if n_params() lt 6 then begin
   print,'Syntax: j_get_spectrum, full_cor_file, exposure_in, eb1, eb2, rate, stat_err
   print,'  ''exposure_in'' can either be a scalar or a DOL with keyword EXPOSURE'
   print,'  Keyword ''perbin'' for getting a spectrum per bin'
   print,'  Keyword ''expo'' returns the used exposure time'
   return
endif

if not file_test(full_cor_file,/reg) then begin
   print,'Cannot find: '+full_cor_file
   return
endif

sz = size(exposure_in)
type = sz(sz(0)+1)
if type eq 7 then begin
   get_exten_no, exposure_in, exposure_file, numext
   if not file_test(exposure_file,/reg) then begin
      print,'Could not find: '+exposure_file
      return
   endif
   hdr = headfits( exposure_file, ext=numext )
   exposure = fxpar( hdr, 'EXPOSURE', count=n )
   if n eq 0 then begin
      print,'Warning, EXPOSURE keyword not found, set to 1000.0'
      exposure = 1000.0
   endif
endif else exposure = exposure_in
print,'Value of EXPOSURE: '+stri(exposure)+' s'
expo = double(exposure)

if not keyword_set(statuslimit) then statuslimit = 32768L
if not keyword_set(radiuslimit) then radiuslimit = 125.0
rdfitscol,full_cor_file+'+1',fullpi,'PI',/sil,nrows=n_evts
rdfitscol,full_cor_file+'+1',status,'STATUS',/sil
rdfitscol,full_cor_file+'+1',detx,'DETX',/sil
rdfitscol,full_cor_file+'+1',dety,'DETY',/sil

; Do the selection

w = where( status le statuslimit, nw )
if nw eq 0 then begin
   print,'No events survived the selection on status (limit ='+stri(statuslimit)+')'
   return
endif
fullpi = fullpi(w)
radius = sqrt(detx(w)^2 + dety(w)^2)
w = where( radius le radiuslimit, nw )
if nw eq 0 then begin
   print,'No events survived the selection on radius (limit ='+stri(radiuslimit)+')'
   return
endif
fullpi = fullpi(w)
n_evts = nw

; Define PI boundaries:

ebm_get_child_by_name,'/r6/jemx/ic/imod_grp/jmx1_imod_grp_0093.fits+1', $
      'JMX1-FBDS-MOD', dol_fbds
rdfitscol, dol_fbds, e_min,'e_min',/sil
rdfitscol, dol_fbds, e_max,'e_max',/sil

eb1 = e_min
eb2 = e_max

rate = fltarr(256)

for i = 0L, n_evts-1 do begin
   rate(fullpi(i)) = rate(fullpi(i)) + 1.0
endfor
stat_err = sqrt(rate)

rate = rate / exposure
stat_err = stat_err / exposure

if not keyword_set(perbin) then begin
   rate = rate / ( e_max - e_min )
   stat_err = stat_err / ( e_max - e_min )
endif


end
