pro j_get_spectrum, spe_filename, eb1, eb2, rate, stat_err, $
       srcnum=srcnum, exposure=exposure, perbin=perbin
;
;   Get a spectral rate array from a spectral file
;
;     NJW/2002-07-25
;     NJW/2005-11-02, reworked from original version
;
if n_params() lt 5 then begin
   print,'Syntax: j_get_spectrum, spe_filename, >eb1, >eb2, >rate, >stat_err'
   print,''
   print,'   The default result is rate per s per keV'
   print,''
   print,'   The keyword ''perbin'' causes the output to be rate per s per bin'
   print,'   The exposure time can be obtained by giving keyword ''exposure'''
   print,'   The source number (row number) can be given by keyword ''srcnum'''
   return
endif

common j_spectrum, spectral_file, origin

if not file_test(spe_filename,/reg) then begin
   print,'Could not find: '+spe_filename
   return
endif

hdr = headfits( spe_filename, exten=1)
nrows = fxpar(hdr,'NAXIS2')

is_phaii = 1
if nrows eq 256 then begin
   print,'This is a PHAI type file'
   is_phaii = 0
   nsources = 1
   exposure = fxpar(hdr,'EXPOSURE',count=n)
   if n eq 0 then begin
      print,'No EXPOSURE keyword found, reset to 1000.'
      exposure = 1000.
   endif
endif else begin
   print,'This is a PHAII type file'
   nsources = nrows
endelse

rdfitscol,spe_filename+'+1',rate_in,'rate',/sil
rdfitscol,spe_filename+'+1',stat_err_in,'stat_err',/sil


; Define energy boundaries:

rmfgroup = '/r6/jemx/ic/rmf_grp/jmx1_rmf_grp_0036.fits+1'
ebm_get_child_by_name,rmfgroup,'JMX1-FBDS-MOD',fbds_name
rdfitscol,fbds_name,e_min,'E_MIN',/sil,errmsg=errmsg
rdfitscol,fbds_name,e_max,'E_MAX',/sil,errmsg=errmsg
if errmsg ne '' then begin
   print,errmsg
   return
endif
nch = n_elements(e_min)

eb1 = e_min
eb2 = e_max

if keyword_set(srcnum) then begin
   if srcnum gt nsources then begin
      print,'Requested source number does not exist'
      return
   endif
endif else srcnum = 1

rate = rate_in(*,srcnum-1)
stat_err = stat_err_in(*,srcnum-1)

if not keyword_set(perbin) then begin
   rate = rate / (e_max - e_min)
   stat_err = stat_err / (e_max - e_min)
endif

end
