pro j_get_src_spectrum, dol_of_og, number_swg, srcid, eb1, eb2, $
                        rate, stat_err, plot=plot
;
;   NJW/2002-06-28
;   2003-06-15/NJW updated to get data spectra
;
;
if n_params() lt 7 then begin
   print,'Syntax: j_get_src_spectrum, dol_of_og, number_swg, srcid, $'
   print,'        >eb1, > eb2, >rate, >stat_err'
   print,'  ''number_swg'' starts from 1'
   print,'  If ''number'' is zero or less than zero then all spectra are returned'
   return
endif

common j_spectrum, spectral_file, origin

get_exten_no, dol_of_og, ogfile, ogext
l = file_search( ogfile, /test_regular, count=nl)
if nl ne 1 then begin
   print,'File: '+ogfile+' was not found'
   return
endif

; Determine whether this is an OG or spectral file

oghdr = headfits(ogfile,exten=ogext)
strnumjemx = strtrim(fxpar(oghdr, 'INSTRUME'),2)
strj = strmid(strnumjemx,3,1)

extname = fxpar(oghdr, 'extname')
print,'EXTNAME = ', extname

if extname eq 'GROUPING' then begin

   ebm_get_child,dol_of_og,1,swg_idx,errmsg
   if errmsg ne '' then begin
      print,'##3##'
      print,errmsg
      return
   endif
   ebm_get_child,swg_idx,1,swg,errmsg,count=n_swg
   if errmsg ne '' then begin
      print,'##4##'
      print,errmsg
      return
   endif
   if number_swg gt n_swg then begin
      print,'Warning: requested swg number exceeds existing'
      return
   endif
   ebm_get_child,swg_idx,number_swg,swg,errmsg,count=n_swg
   if errmsg ne '' then begin
      print,'##5##'
      print,errmsg
      return
   endif
   
   ; Now we have the SWG - then find spectral information
   
   ebm_get_child_by_name,swg,'JMX'+strj+'-SRCL-SPE',dol_spec,errmsg
   if errmsg ne '' then begin
      print,'##5##'
      print,errmsg
      return
   endif
   
   get_exten_no, dol_spec, file_spec, specext

endif else begin
   dol_spec = dol_of_og
endelse

rdfitscol,dol_spec,rates,'RATE',/sil
rdfitscol,dol_spec,stat_errs,'STAT_ERR',/sil
sz = size(rates)
if sz(0) eq 2 then n_spectra = sz(2) else n_spectra = 1

; Determine if source is given by name or number

sz = size(srcid)
type = sz(sz(0)+1)

if type eq 7 then begin
   w = where(srcid eq rowid, nw)
   if nw eq 0 then begin
      print,'Warning: did not find '+srcid
      print,'These exist: ', rowid
      return
   endif else number = w(0)+1
endif else number = srcid

if number gt n_spectra then begin
   print,'This number of spectrum does not exist'
   return
endif

if number gt 0 then begin
   rate = rates(*,number-1)
   stat_err = stat_errs(*,number-1)
endif else begin
   rate = rates
   stat_err = stat_errs
endelse



; Define energy boundaries:

rmfgroup = '/home/njw/jemx/response_matrix/jmx'+strj+'_rmf_grp_0003.fits+1'
ebm_get_child_by_name,rmfgroup,'JMX'+strj+'-FBDS-MOD',fbds_name
rdfitscol,fbds_name,eb1,'E_MIN',/sil,errmsg=errmsg
rdfitscol,fbds_name,eb2,'E_MAX',/sil,errmsg=errmsg
if errmsg ne '' then begin
   print,'##7##'
   print,errmsg
   return
endif

if keyword_set(plot) then begin
   rebin = indgen(200-45)+45
   e = 0.5*(eb1(rebin)+eb2(rebin))
   de = eb2(rebin) - eb1(rebin)
   dataplot,e,rate(rebin)/de, stat_err(rebin)/de,itype=3, /xbar
endif

end


