pro j_get_srcl_res_sources, dol_of_og, $
                        radec=radec, outfile=outfile, list=list
;
;   NJW/2004-01-09
;   2004-10-28/NJW  Updated to separate a given source by position
;   2006-08-02/NJW  Updated to accept a list for JMXi-SRCL-RES files
;
;
if n_params() lt 1 then begin
   print,'Syntax: j_get_srcl_res_sources, dol_of_og $'
   print,'        [, radec=][, outfile=][list=]'
   print,'  ''radec'' is the chosen source position (3 element array: RA, Decl, radius).'
   print,'                            All units in degrees (3 arcmin = 0.05 deg).'
   print,'  ''list'' is a string array variable with a list of SRCL-RES files or DOLs.'
   print,'      When it is given then ''dol_of_og'' is ignored.
   return
endif

if not keyword_set(outfile) then outfile='outfile'

openw,lun,outfile,/get_lun
printf,lun,'// Output from j_get_srcl_res_sources '+systime()
printf,lun,'// Input DOL: '+dol_of_og
printf,lun,'//'
printf,lun,'// Column 1: RA (deg)'
printf,lun,'// Column 2: Decl (deg)'
printf,lun,'// Column 3: DETSIG'
printf,lun,'// Column 4: Offaxis angle (deg)'
printf,lun,'// Column 5: 100 x COSY_JMX'
printf,lun,'// Column 6: 100 x COSZ_JMX'
printf,lun,'// Column 7+: Flux values (cts/s)'
printf,lun,'//'
free_lun, lun

use_dol_of_og = 1
if keyword_set(list) then begin
   use_dol_of_og = 0
endif

if use_dol_of_og then begin
   get_exten_no, dol_of_og, ogfile, ogext
   if not file_test(ogfile,/reg) then begin
      print,'File: '+ogfile+' was not found'
      return
   endif

   ; Determine whether this is an OG or something else

   oghdr = headfits(ogfile,exten=ogext)
   strnumjemx = strtrim(fxpar(oghdr, 'INSTRUME'),2)
   strj = strmid(strnumjemx,3,1)

   extname = fxpar(oghdr, 'extname')
   print,'EXTNAME = ', extname

   if extname ne 'GROUPING' then begin
      print,'Cannot be an OG - terminate'
      return
   endif
endif

src_sel = 0
if keyword_set(radec) then begin
   sz = size(radec)
   if sz(0) ne 1 or sz(1) ne 3 then begin
      print,'Warning: radec keyword has improper dimension and will be ignored'
   endif else begin
      src_sel = 1
      ra_src = radec(0)
      dec_src = radec(1)
      rad_sel = radec(2)
   endelse
endif

if use_dol_of_og then begin

   ; Get the SWG IDX table
   ebm_get_child,dol_of_og,1,swg_idx,errmsg
   if errmsg ne '' then begin
      print,'##3##'
      print,errmsg
      return
   endif

   ; Get number of SWGs
   ebm_get_num_children, swg_idx, num_swgs, errmsg
   if errmsg ne '' then begin
      print,'##5##'
      print,errmsg
      return
   endif

   ; Loop over the SWGs to get SRCL_RES

   first = 1
   for iswg = 1, num_swgs do begin
      ebm_get_child,swg_idx,iswg,swg,errmsg
      if errmsg ne '' then begin
         print,'##6## iswg = ', iswg
         print,errmsg
         return
      endif

      print,swg

      ebm_get_child_by_name, swg, 'JMX'+strj+'-SRCL-RES', dolres, errmsg
      if errmsg ne '' then begin
         print,'##7## iswg = ', iswg
         print,errmsg
         continue
      endif

      if first then begin
         list = dolres
         first = 0
      endif else begin
         list = [list, dolres]
      endelse

   endfor

endif

nfiles = n_elements(list)
first = 1

for i = 0, nfiles-1 do begin

   dolres = list(i)
   get_exten_no, dolres, fileres, extres
   if extres eq 0 then begin
      extres = 1
      dolres = dolres+'+1'
   endif

   hdr = headfits(fileres,ext=extres)
   nebin = fxpar(hdr,'EBIN_NUM')

   rdfitscol,dolres,rain,'RA_OBJ', nrows=nrows,/sil
   if nrows ge 1 then begin

      ; define array for storing and writing results
      resarr = fltarr(nrows,nebin+6)

      ; get offaxis angle
      print,'dolres: ', dolres
      h = ['// '+dolres]
      pick_swid_str,dolres,swid
      get_pointing_for_swid,swid,ra_scx,dec_scx,roll
      rdfitscol,dolres,decin,'DEC_OBJ',/sil
      rdfitscol,dolres,detsigin,'DETSIG',/sil
      rdfitscol,dolres,namein,'NAME',/sil
      rdfitscol,dolres,fluxin,'FLUX',/sil
      rdfitscol,dolres,cosy,'COSY_JMX',/sil
      rdfitscol,dolres,cosz,'COSZ_JMX',/sil
      fluxin = transpose(fluxin)
      if first then begin
         rdfitscol,dolres,e_minin,'E_MIN',/sil
         rdfitscol,dolres,e_maxin,'E_MAX',/sil
         for i = 0, nebin - 1 do begin
            h = [h,'// e_min = '+string(e_minin(i,0))]
            h = [h,'// e_max = '+string(e_maxin(i,0))]
         endfor
         first = 0
      endif
      offaxis = arcdist( rain, decin, ra_scx, dec_scx)
      print,'Source name(s): ', namein
      print,'RA:', rain
      print,'DEC:', decin
      print,'DETSIG:', detsigin
      resarr(*,0) = rain
      resarr(*,1) = decin
      resarr(*,2) = detsigin
      resarr(*,3) = offaxis
      resarr(*,4) = cosy*100
      resarr(*,5) = cosz*100
      resarr(*,6:5+nebin) = fluxin(*,0:nebin-1)
      nw = 1 ; assure writing of results when no source is selected
      if src_sel then begin ; Check if selected source is present
         r = arcdist(rain,decin, ra_src, dec_src)
         w = where(r lt rad_sel, nw)
         if nw gt 0 then resarr = resarr(w,*)
         for kk = 0, nw-1 do h = [h,'// sourcename = '+namein(w(kk))]
      endif else for kk = 0, nrows-1 do h = [h,'// sourcename = '+namein(kk)]
            
      if nw then wsmatrix, outfile, h, resarr, /app, fm='f10.3'
   endif else begin
      print,'No sources found'
   endelse

endfor

print,'The output is found in: ', outfile

end


