pro j_plot_spectrum, eb1, eb2, rate_array, err_array, source_id_in, itype=itype, rebin=rebin
;
;  eb1 : lower energy boundaries
;  eb2 : upper energy boundaries
;  rate_array : counts per channel per s; array rate_array(bins, spec#)
;  source_id : scalar or array
;
;     This procedure is tied to the procedure: j_get_spectrum.pro
;

common j_spectrum, spectral_file, origin

if n_params() lt 3 then begin
   print,'Syntax: j_plot_spectrum, eb1, eb2, rate_array, err_array, source_id $'
   print,'            [,itype=][,rebin=]'
   return
endif

sz = size(rate_array)
sze = size(err_array)
if sz(0) ne 2 and sz(0) ne 1 then begin
   print,'J_PLOT_SPECTRUM: The spectral array has bad dimensions'
   return
endif

if sz(0) ne sze(0) or sz(1) ne sze(1) or sz(2) ne sze(2) then begin
   print,'J_PLOT_SPECTRUM: Mismatch of dimensions in rate and err arrays'
   return
end


if n_elements(eb1) ne n_elements(eb2) then begin
   print,'The channel boundary arrays have different number of elements'
   return
endif

if sz(0) eq 2 then begin
   nchan = sz(1)
   nspec = sz(2)
endif else begin
   nchan = sz(1)
   nspec = 1
endelse

if n_elements(eb1) ne nchan then begin
   print,'The number of channel boundaries does not match spectral array'
   return
endif

;  Extract the spectrum or do the addition
;  Errors are added quadratically

source_id = source_id_in
nnn = source_id
str_source_id = 'SOURCE_ID = '
if origin eq 'src' then begin
   str_source_id = 'SOURCE# '
   source_id = source_id - 1 ; because source counting starts with 1
endif

sz = size(source_id)
if sz(0) eq 0 then begin
   if source_id eq 9999 then source_id = nspec - 1
   spec = rate_array(*,source_id)
   erra = err_array(*,source_id)
   str_source_id = str_source_id+strtrim(nnn,2)
endif else begin
   nadd = n_elements(source_id)
   for i = 0, nadd-1 do begin
      if source_id(i) eq 9999 then source_id(i) = nspec - 1
      if i eq 0 then begin
         spec = rate_array(*,source_id(0))
         erra = err_array(*,source_id(0))
         str_source_id = str_source_id+strtrim(nnn(0),2)
      endif else begin
         spec = spec + rate_array(*,source_id(i))
         erra = sqrt(erra^2 + err_array(*,source_id(i))^2)
         str_source_id = str_source_id+'+'+strtrim(nnn(i),2)
      endelse
   endfor
endelse

!x.title = 'Energy [keV]'
!y.title = 'Counts keV!u-1!n s!u-1!n'
!p.title = str_source_id

;  Make rebinning if required

e1 = eb1
e2 = eb2
if keyword_set(rebin) then rebin_spectrum,e1,e2,spec,erra,rebin


plus = where( spec gt 0, n_plus)
zorn = where( spec le 0, n_zorn)

if n_zorn gt 0 then erra(zorn) = 0.
y1 = (spec-erra) / (e2 - e1)
y2 = (spec+erra) / (e2 - e1)
y = spec / (e2 - e1)

if !d.name eq 'X' then window,0,title='Source #'

ity = 2
if keyword_setx(itype) then ity = itype

dataplotf,e1,sqrt(e1*e2),e2,y1,y,y2,itype=ity
plotsign
plotname,'j_plot_spectrum'
xyouts,0.15,0.92,spectral_file,/norm,charsize=0.8
   

end
