pro j_put_spectrum, rate_array, err_array, exposure, source_id_in, filename
;
;  Put spectrum into a file similar to the result of 'j_src_spectra' so that it can
;  be understood by XSPEC
;
;  rate_array : counts per channel per s; array rate_array(bins, spec#)
;  source_id : scalar or array
;
;     This procedure is tied to the procedure: j_get_spectrum.pro
;

common j_spectrum, spectral_file, origin

if n_params() lt 5 then begin
   print,'Syntax: j_put_spectrum, rate_array, err_array, exposure, source_id, filename'
   print,'  It is assumed that rate_array and err_array have dimension 256xN'
   return
endif

sz = size(rate_array)
sze = size(err_array)
if sz(0) ne 2 and sz(0) ne 1 then begin
   print,'J_PUT_SPECTRUM: The spectral array has bad dimensions'
   return
endif

if sz(0) ne sze(0) or sz(1) ne sze(1) or sz(2) ne sze(2) then begin
   print,'J_PUT_SPECTRUM: Mismatch of dimensions in rate and err arrays'
   return
end


if sz(0) eq 2 then begin
   nchan = sz(1)
   nspec = sz(2)
endif else begin
   nchan = sz(1)
   nspec = 1
endelse

if 256 ne nchan then begin
   print,'J_PUT_SPECTRUM: The number of channels is not 256'
   return
endif

;  Extract the spectrum or do the addition
;  Errors are added quadratically

source_id = source_id_in
nnn = source_id
str_source_id = 'SOURCE_ID = '
if origin eq 'src' then begin
   str_source_id = 'SOURCE# '
   source_id = source_id - 1 ; because source counting starts with 1
endif

sz = size(source_id)
if sz(0) eq 0 then begin
   if source_id eq 9999 then source_id = nspec - 1
   spec = rate_array(*,source_id)
   erra = err_array(*,source_id)
   str_source_id = str_source_id+strtrim(nnn,2)
endif else begin
   nadd = n_elements(source_id)
   for i = 0, nadd-1 do begin
      if source_id(i) eq 9999 then source_id(i) = nspec - 1
      if i eq 0 then begin
         spec = rate_array(*,source_id(0))
         erra = err_array(*,source_id(0))
         str_source_id = str_source_id+strtrim(nnn(0),2)
      endif else begin
         spec = spec + rate_array(*,source_id(i))
         erra = sqrt(erra^2 + err_array(*,source_id(i))^2)
         str_source_id = str_source_id+'+'+strtrim(nnn(i),2)
      endelse
   endfor
endelse

spec_num = [1]
rowid = 'N/A'
for i = strlen(rowid),31 do rowid = rowid+' '
rowid = [rowid]
channel = reform([indgen(256)+1],256,1)
rate = reform(spec,256,1)
stat_err = reform(erra,256,1)
sys_err = reform(fltarr(256),256,1)
quality = reform(intarr(256),256,1)
backfile = ' '
for i = strlen(backfile),159 do backfile = backfile+' '
backfile = [backfile]
backscal = [double(0)]
ancrfile = '/home/njw/jemx/response_matrix/JMX1-RMF.-GRP.fits'
for i = strlen(ancrfile),159 do ancrfile = ancrfile+' '
ancrfile = [ancrfile]
exposure = [double(exposure)]
telapse = exposure
ontime = exposure
deadc = [double(0)]
tfirst = deadc
tlast = deadc
evt_type = [0]
; Add XSPEC required keywords
fxaddpar,kwds,'TELESCOP','INTEGRAL','Required for XSPEC'
fxaddpar,kwds,'INSTRUME','JMX1','Required for XSPEC'
fxaddpar,kwds,'CHANTYPE','PI','Required for XSPEC'
fxaddpar,kwds,'HDUCLASS','OGIP','Required for XSPEC'
fxaddpar,kwds,'HDUCLAS1','SPECTRUM','Required for XSPEC'
fxaddpar,kwds,'HDUCLAS2','NET','Required for XSPEC'
fxaddpar,kwds,'HDUCLAS3','RATE','Required for XSPEC'
fxaddpar,kwds,'HDUVERS','1.2.0','Required for XSPEC'
fxaddpar,kwds,'CORRFILE','none','Required for XSPEC'
fxaddpar,kwds,'CORRSCAL',1.0,'Required for XSPEC'
fxaddpar,kwds,'POISSERR','False','Required for XSPEC'
fxaddpar,kwds,'AREASCAL',1.0,'Required for XSPEC'
fxaddpar,kwds,'RESPFILE','home/njw/jemx/response_matrix/JMX1-RMF.-GRP.fits[1]','R for XSPEC'

wrmfitscols,filename,'SPEC_NUM',spec_num,'ROWID',rowid,'CHANNEL',channel,$
   'RATE',rate,'STAT_ERR',stat_err,'SYS_ERR',sys_err,'QUALITY',quality,$
   'BACKFILE',backfile,'BACKSCAL',backscal,kwds=kwds

wrnewfitscol,filename+'+1','ANCRFILE',ancrfile,'EXPOSURE',exposure
wrnewfitscol,filename+'+1','TELAPSE',telapse,'ONTIME',ontime
wrnewfitscol,filename+'+1','DEADC',deadc,'TFIRST',tfirst
wrnewfitscol,filename+'+1','TLAST',tlast,'EVT_TYPE',evt_type

end
