function j_thruput, off_axis_angle, radius_lim, omega, circ_area=circ_area
;
;  Calculates the throughput of JEMX for a pointing at
;  off_axis_angle [deg] with an angle 'omega' [deg]
;  with respect to a collimator grid direction
;
;   NJW  970221
;   2006-09-08/NJW Updated to handle detector radius limit
;
if n_params() ne 3 then begin
   print,'Syntax: fraction = j_thruput( off_axis_angle, radius_lim, omega )'
   print,'    Keyword circ_area returns the fractional detector area'
   return,-1
endif

; --- off axis angle

alpha = off_axis_angle * !pi / 180.  ; converted to radians

; --- area of the two circles

d = tan(alpha) * 3401.                     ; Det-Mask
f = circ_area1(d, 267.5, radius_lim) / (!pi * radius_lim^2)
circ_area = f
;* print,'rel. circ area = ', f

; --- through collimator

q = (57./6.6) * tan(alpha)
;* print,'q = ', q
t = (1 - q * cos(omega*!pi/180)) * (1. - q * sin(omega*!pi/180))
;* print,' thru coll = ', t

return, f * t > 0

end
