pro jconv_coord, ra_scx, dec_scx, roll, ra_src, dec_src, cosy_src, cosz_src,$
     to_eq=to_eq, to_sc=to_sc,verbose=verbose
;
; Procedure to perform coordinate transformations
;
;   000726/NJW
;
; At input: all angles are given in degrees
;           cosy_src and cosz_src have no unit
;

if n_params() lt 7 then begin
   print,'Syntax: jconv_coord, ra_scx, dec_scx, roll, ra_src,'
   print,'             dec_src, cosy_src, cosz_src,/to_eq,/to_sc[,/verbose]'
   return
endif

; Check presence and number of keywords

control = 0
if keyword_set(to_eq) then begin
   control = 1
endif
if keyword_set(to_sc) then begin
   control = control + 1
   to_eq = 0
endif
if control ne 1 then begin
   print,'JCONV_COORD error, zero or two ''to_'' keywords'
   return
endif


dr = !pi / 180  ; degrees to radians

ra_scx_rad = ra_scx * dr
dec_scx_rad = dec_scx * dr
roll_rad = roll * dr

if not to_eq then begin
   ra_src_rad = ra_src * dr
   dec_src_rad = dec_src * dr
endif

; Pointing direction: x-axis

; RA and Dec of two other axes: y and z

ra_scy_rad = ra_scx_rad - atan(-cos(roll_rad), -sin(dec_scx_rad)*sin(roll_rad))
if ra_scy_rad lt 0. then ra_scy_rad = ra_scy_rad + 2*!pi

dec_scy_rad = asin(cos(dec_scx_rad)*sin(roll_rad))

ra_scz_rad = ra_scx_rad - atan(sin(roll_rad), -sin(dec_scx_rad)*cos(roll_rad))
if ra_scz_rad lt 0. then ra_scz_rad = ra_scz_rad + 2*!pi
dec_scz_rad = -asin(-cos(dec_scx_rad)*cos(roll_rad))

if keyword_set(verbose) then begin
   print,'RA,DEC of SC Y-axis: ', ra_scy_rad/dr, dec_scy_rad/dr
   print,'RA,DEC of SC Z-axis: ', ra_scz_rad/dr, dec_scz_rad/dr
endif

; Pointing in EQ system

x_eq = [cos(ra_scx_rad)*cos(dec_scx_rad), $
        sin(ra_scx_rad)*cos(dec_scx_rad), $
        sin(dec_scx_rad)]

; SC Y-axis direction in EQ system

y_eq = [-sin(ra_scx_rad)*cos(roll_rad) $
              - sin(dec_scx_rad)*cos(ra_scx_rad)*sin(roll_rad),$
         cos(ra_scx_rad)*cos(roll_rad) $
              - sin(dec_scx_rad)*sin(ra_scx_rad)*sin(roll_rad),$
         cos(dec_scx_rad)*sin(roll_rad)]

; SC Z-axis direction in EQ system

z_eq = [sin(ra_scx_rad)*sin(roll_rad) $
              - sin(dec_scx_rad)*cos(ra_scx_rad)*cos(roll_rad),$
        -cos(ra_scx_rad)*sin(roll_rad) $
              - sin(dec_scx_rad)*sin(ra_scx_rad)*cos(roll_rad),$
         cos(dec_scx_rad)*cos(roll_rad)]


;

if to_eq then begin

   ; Define transformation matrix

   omega = fltarr(3,3)
   omega(*,0) = x_eq
   omega(*,1) = y_eq
   omega(*,2) = z_eq

   s_sc = fltarr(3)
   s_sc(1) =   cosy_src
   s_sc(2) =   cosz_src
   s_sc(0) = sqrt(1. - s_sc(1)^2 - s_sc(2)^2)

   s_eq = omega # s_sc

   dec_src_rad = asin(s_eq(2))
   ra_src_rad = zero2pi(atan(s_eq(1),s_eq(0)))

   dec_src = dec_src_rad / dr
   ra_src = ra_src_rad / dr

endif else begin

   ; Define transformation matrix

   omega = fltarr(3,3)
   omega(0,*) = x_eq
   omega(1,*) = y_eq
   omega(2,*) = z_eq

   s_eq = fltarr(3)
   s_eq(0) = cos(ra_src_rad) * cos(dec_src_rad)
   s_eq(1) = sin(ra_src_rad) * cos(dec_src_rad)
   s_eq(2) = sin(dec_src_rad)

   s_sc = omega # s_eq

   cosy_src =  s_sc(1)
;   z_src = -s_sc(2) * 60 / dr  ; ad hoc change  000727/NJW
   cosz_src =  s_sc(2)  ; changed back  020213/NJW

endelse

return

end
