pro jsim_statistics, swg_extno, osim=osim
;
;  Find the number of counts from each source etc.
;  in the structure '-FULL-COR'
;

if n_params() ne 1 then begin
   print,'Syntax: jsim_statistics, swg_extno'
   return
endif

get_exten_no, swg_extno, fswg, extno

; Get the exposure time

hdr = headfits(fswg,exten=extno)
telapse = fxpar(hdr,'TELAPSE')

; Setup the output file

pos = strpos(fswg,'.fits')
swg_base_name = strmid(fswg,0,pos)

outname = swg_base_name+'.stat'

openw,lun,outname,/get_lun

printf,lun,'//'
printf,lun,'// Statistics for SWG: ', swg_extno
printf,lun,'//'
printf,lun,'// telapse = ', telapse,' ; s'
printf,lun,'//'

for jemxnum = 1, 2 do begin

   strjemx = 'JMX'+strtrim(jemxnum,2)

   block = 100*jemxnum
   printf,lun,'//'
   printf,lun,'// ---- ',strjemx,' -----'
   printf,lun,'//'
   printf,lun,'//  block = ', block
   block = block + 1

   ebm_get_child_by_name, swg_extno, strjemx+'-FULL-COR',$
            cor_ds, errmsg
   if errmsg ne '' then begin
      print,'No '+strjemx+'-FULL-COR found - terminate.'
      goto, close_file_and_return
   endif

;-   ebm_get_child_by_name, swg_extno, strjemx+'-SPEC-NJW',$
;-            spc_ds, errmsg

   if keyword_set(osim) then begin
      ebm_get_child_by_name, swg_extno, strjemx+'-SRCL-CAT',$
            cat_ds, errmsg
   endif else begin  ;  Assume that generated by DSRI JSIM
      ebm_get_child_by_name, swg_extno, 'OSIM-SRCL-GRP',$
            intermediate, errmsg, /bygrp
      ebm_get_child_by_name, intermediate, 'OSIM-JSIM-SRC',$
            cat_ds, errmsg
   endelse

   printf,lun,'// FULL-COR: ', cor_ds
;-   printf,lun,'// SPEC-NJW: ', spc_ds

; Get the greyfilter value

   get_exten_no, cor_ds, corfile, cor_extno
   greyfilter = fxpar(headfits(corfile,exten=cor_extno),'GREYFILT')
   printf,lun,'// greyfilter = ', greyfilter
   
   rdfitscol,cor_ds,energy,'ENERGY'
   rdfitscol,cor_ds,source_id,'SOURCE_ID'
   
;-   rdfitscol,spc_ds,dum,'CHANMIN',hdr=hdr
   
;-   nsrc = fxpar(hdr,'NUMSRCS')
   
   if keyword_set(osim) then begin
      rdfitscol,cat_ds,ra,'RA_OBJ'
      rdfitscol,cat_ds,dec,'DEC_OBJ'
      ;rdfitscol,cat_ds,scy,'SC_Y'
      ;rdfitscol,cat_ds,scz,'SC_Z'
      scy = ra*0 - 1.0
      scz = scy
      printf,lun,'// JMXi-SRCL-CAT: ',cat_ds
   endif else begin
      rdfitscol,cat_ds,ra,'RA'
      rdfitscol,cat_ds,dec,'DEC'
      rdfitscol,cat_ds,scy,'SC_Y'
      rdfitscol,cat_ds,scz,'SC_Z'
      printf,lun,'// OSIM-JSIM-SRC: ',cat_ds
   endelse
   
   nsrc_cat = n_elements(ra)
   
   printf,lun,'// n_sources = ', nsrc_cat

   nbins = 5
   e1   = [3., 6., 10., 16., 3.]
   e2   = [6., 10., 16., 30., 16.]

   
   dxb = where( source_id eq 0, n_dxb)
   ibkg = where( source_id eq 9999, n_ibkg)

   printf,lun,'// block = ', block
   block = block + 1
   printf,lun,'// lo_e_limit =  3.0 ;  keV'
   printf,lun,'// hi_e_limit =  100.0 ;  keV'
   if jemxnum le 1 then begin
      printf,lun,'// Column 1: Source ID number'
      printf,lun,'// Column 2: RA(2000) dec. deg.'
      printf,lun,'// Column 3: DEC(2000) dec. deg.'
      printf,lun,'// Column 4: SC_Y [arcmin]'
      printf,lun,'// Column 5: SC_Z [arcmin]'
      printf,lun,'// Column 6: Number of source counts'
   endif

   printf,lun,-1,0.,0.,0.,0.,n_ibkg
   printf,lun, 0,0.,0.,0.,0.,n_dxb
   
   for i = 1, nsrc_cat do begin
      j = i - 1
      src = where( source_id eq i, n_cts)
      printf,lun,i,ra(j),dec(j), scy(j), scz(j), n_cts
   endfor

   for ibin = 0, nbins-1 do begin

      esel = where(energy ge e1(ibin) and energy lt e2(ibin), n_esel)

      sid = source_id(esel)
      erg = energy(esel)

      dxb = where( sid eq 0, n_dxb)
      ibkg = where( sid eq 9999, n_ibkg)
      printf,lun,'// block =', block
      block = block + 1
      printf,lun,'// lo_e_limit =  ', e1(ibin)
      printf,lun,'// hi_e_limit =  ', e2(ibin)

      printf,lun,-1,0.,0.,0.,0.,n_ibkg
      printf,lun, 0,0.,0.,0.,0.,n_dxb
   
      for i = 1, nsrc_cat do begin
         j = i - 1
         src = where( sid eq i, n_cts)
         printf,lun,i,ra(j),dec(j), scy(j), scz(j), n_cts
      endfor

   endfor

   
endfor ; end loop over jemx units

close_file_and_return:

free_lun,lun

end
