pro jsim_vs_input, swg_base_name, find_extno, noplot=noplot
;
; Compare simulation results with input data
;

if n_params() lt 2 then begin
   print,'Syntax: JSIM_VS_INPUT, swg_base_name, find_extno'
   return
endif


extno = find_extno
str_extno = strtrim(extno,2)

out_file = swg_base_name+'_'+str_extno+'.svi'

fhdr = headfits(swg_base_name+'.fits',exten=find_extno)
shdiden = fxpar(fhdr,'SHDIDEN')
mindetlv = fxpar(fhdr,'MINDETLV')

openw,lun,out_file,/get_lun

printf,lun,'//            ', systime()
printf,lun,'// Report on: ', swg_base_name+'.fits+'+str_extno
printf,lun,'// shdiden = ', shdiden

swg_file = swg_base_name+'.fits'

; 1)  Find satellite pointing and roll

rdfitscol,swg_file+'[1]',memloc,5,hdr=hdr,/sil
ra_scx = fxpar(hdr,'RA_SCX')
dec_scx = fxpar(hdr,'DEC_SCX')
roll = fxpar(hdr,'DROLLANG')

printf,lun,'// RA_SCX = ',ra_scx
printf,lun,'// DEC_SCX = ',dec_scx
printf,lun,'// DROLLANG = ', roll
printf,lun,'//'
printf,lun,'//    List of the input sources:'
printf,lun,'// block = -1'
printf,lun,'// #       RA          DEC         Sx         NH         param'

; 2)  Find the input source list

; Use SWG grouping table as entrance; the location of
;  the srcl index table is already known

tok = sep_filename(swg_file)
n_tok = n_elements(tok)
;- swg_base_name = tok(n_tok-1) ; save for later use
tok(n_tok-1) = strtrim(memloc(1),2)
srcl_file = collate_path(tok,/i)

; Get location of the jsrc list

rdfitscol,srcl_file+'[1]',memloc1,5,hdr=hdr1,/sil
tok(n_tok-1) = strtrim(memloc1(0),2)
jsrc_file = collate_path(tok,/i)

; Read the input source data

errmsg = ''
rdfitscol,jsrc_file+'[1]',ra_input,1,err=errmsg,/sil
rdfitscol,jsrc_file+'[1]',dec_input,2,err=errmsg,/sil
;- rdfitscol,jsrc_file+'[1]',sc_y_input,3,err=errmsg,/sil
;- rdfitscol,jsrc_file+'[1]',sc_z_input,4,err=errmsg,/sil
rdfitscol,jsrc_file+'[1]',nh_input,5,err=errmsg,/sil
rdfitscol,jsrc_file+'[1]',icode_input,6,err=errmsg,/sil
rdfitscol,jsrc_file+'[1]',scode_input,7,err=errmsg,/sil
rdfitscol,jsrc_file+'[1]',sx_input,8,err=errmsg,/sil
rdfitscol,jsrc_file+'[1]',parm1_input,9,err=errmsg,/sil,nrows=nrows

if nrows eq 0 then begin
   printf,lun,'//  No input sources found'
   n_input_srcs = 0
endif else begin
   sz = size(ra_input)
   if sz(0) eq 0 then ra_input = replicate(ra_input,1)
   sz = size(dec_input)
   if sz(0) eq 0 then dec_input = replicate(dec_input,1)

   n_input_srcs = n_elements(ra_input)
   for i = 0, n_input_srcs-1 do begin
      printf,lun,i,ra_input(i),dec_input(i),sx_input(i),$
            nh_input(i), parm1_input(i),$
            format='(i5,2f12.5, 2e12.3, f12.5)'
   endfor
endelse

; 3)  Get the derived source positions and intensities

dol_of_find = swg_base_name+'.fits['+strtrim(find_extno,2)+']'
rdfitscol,dol_of_find,ra_der,'RA_OBJ',hdr=hdr2,/sil
rdfitscol,dol_of_find,dec_der,'DEC_OBJ',/sil
rdfitscol,dol_of_find,det_lev_der,'DETSIG',/sil
rdfitscol,dol_of_find,peak_der,'PEAKSIZE',err=errmsg,/sil,nrows=nrows
if errmsg ne '' then print,errmsg
e_min = fxpar(hdr2,'E_MIN')
e_max = fxpar(hdr2,'E_MAX')
telapse = fxpar(hdr2,'TELAPSE')
n_der = nrows

printf,lun,'//'
printf,lun,'// e_min = ', e_min, ' ; keV'
printf,lun,'// e_max = ', e_max, ' ; keV'
printf,lun,'// telapse = ', telapse, ' ; seconds'
printf,lun,'//'
printf,lun,'// Sources found by j_ima_src_find in the RSTI image:'
printf,lun,'//'
printf,lun,'// block = 0'

if n_der gt 0 then begin

   printf,lun,'//'
   printf,lun,'// #    RAfound      DECfound     peak       det-level   Off-axis'

   for i = 0, n_der-1 do begin
      offaxis = arcdist(ra_der(i),dec_der(i),ra_scx,dec_scx,/deg)
      printf,lun,i,ra_der(i),dec_der(i),peak_der(i),det_lev_der(i),offaxis,$
                  format='(i5,2f12.5,3f12.3)'
   endfor
endif else begin
   printf,lun,'//'
   printf,lun,'// No sources above detection level ', mindetlv
endelse

; Plot inputs

want_to_plot = 1
if keyword_set(noplot) then want_to_plot = 0
if want_to_plot then begin
   xr = [ra_scx+6.0/cos(dec_scx*!pi/180.),$
         ra_scx-6.0/cos(dec_scx*!pi/180.)]
   yr = [dec_scx-6.0, dec_scx+6.0]
   ;-- xr = [max(ra_input)+0.3,min(ra_input)-0.3]
   !p.title = swg_file+'['+str_extno+']'
   !x.title = 'RA (2000)'
   !y.title = 'DEC (2000)'
   plot, ra_input, dec_input, ps=1,xr=xr,yr=yr,/nodata
   oplotsiz, ra_input, dec_input,sx_input,ps=1,zn=1.5,zx=5

   ; and add derived sources

   if n_der gt 0 then begin
     def_sym,'c'
     oplotsiz,ra_der,dec_der,det_lev_der,ps=8,zn=1.5,zx=5
   endif
endif

; Step through the derived (found) sources

if n_der gt 0 then begin
   for i = 0, n_der-1 do begin

      printf,lun,'// Found source #'+strtrim(i,2), ra_der(i), dec_der(i)
      printf,lun,'// block = ', i+1
      printf,lun,'// identified with following input sources:'
      printf,lun,'// #   RAinput   DECinput  dist(arcmin) padding...'

      ; find input sources that are very close

      dist = arcdist(ra_input,dec_input,ra_der(i),dec_der(i),/deg)
      candidates = where(dist lt 0.05, n_cand)
      if n_cand gt 0 then begin
         for j = 0, n_cand-1 do begin
            k = candidates(j)
            printf,lun,k,ra_input(k),dec_input(k),dist(k)*60,$
                   ;-     sc_y_input(k), sc_z_input(k),$
                              0.,  0., $
                        format='(i5,5f12.5)'
         endfor
      endif else printf,lun,'//       No candidate found'


   endfor
endif

free_lun,lun
end
