pro jsim_vs_inputa, swg_base_name, rsti_extno, find_extno, noplot=noplot,$
                        pressure=pressure
;
; Compare simulation results with input data
;

if n_params() lt 2 then begin
   print,'Syntax: SIM_VS_INPUT, swg_base_name, rsti_extno, find_extno $'
   print,'                      [,/noplot][,pressure=]'
   return
endif

crit_det_lev = 10.5

extno = rsti_extno
str_extno = strtrim(extno,2)

swg_file = swg_base_name+'.fits'
dol_of_swg = swg_file+'[1]'

; Get the JMXi-FIND-RES-IDX table

out_file = swg_base_name+'_'+str_extno+'.svi'

openw,lun,out_file,/get_lun

printf,lun,'//            ', systime()
printf,lun,'// Report on: ', swg_base_name+'.fits+'+str_extno


; 1)  Find satellite pointing and roll

rdfitscol,swg_file+'[1]',memloc,5,hdr=hdr
ra_scx = fxpar(hdr,'RA_SCX')
dec_scx = fxpar(hdr,'DEC_SCX')
roll = fxpar(hdr,'DROLLANG')
if keyword_set(pressure) then begin
   printf,lun,'// pressure = ', pressure
endif

printf,lun,'// RA_SCX = ',ra_scx
printf,lun,'// DEC_SCX = ',dec_scx
printf,lun,'// DROLLANG = ', roll
printf,lun,'//'
printf,lun,'//    List of the input sources:'
printf,lun,'// block = -1'
printf,lun,'// #       RA          DEC         Sx         NH         param'

; 2)  Find the input source list

; Use SWG grouping table as entrance; the location of
;  the srcl index table is already known

tok = sep_filename(swg_file)
n_tok = n_elements(tok)
;- swg_base_name = tok(n_tok-1) ; save for later use
tok(n_tok-1) = strtrim(memloc(1),2)
srcl_file = collate_path(tok,/i)

; Get location of the jsrc list

rdfitscol,srcl_file+'[1]',memloc1,5,hdr=hdr1
tok(n_tok-1) = strtrim(memloc1(0),2)
jsrc_file = collate_path(tok,/i)

; Read the data

errmsg = ''
rdfitscol,jsrc_file+'[1]',ra_input,1,err=errmsg
rdfitscol,jsrc_file+'[1]',dec_input,2,err=errmsg
;- rdfitscol,jsrc_file+'[1]',sc_y_input,3,err=errmsg
;- rdfitscol,jsrc_file+'[1]',sc_z_input,4,err=errmsg
rdfitscol,jsrc_file+'[1]',nh_input,5,err=errmsg
rdfitscol,jsrc_file+'[1]',icode_input,6,err=errmsg
rdfitscol,jsrc_file+'[1]',scode_input,7,err=errmsg
rdfitscol,jsrc_file+'[1]',sx_input,8,err=errmsg
rdfitscol,jsrc_file+'[1]',parm1_input,9,err=errmsg
sz = size(ra_input)
if sz(0) eq 0 then ra_input = replicate(ra_input,1)
sz = size(dec_input)
if sz(0) eq 0 then dec_input = replicate(dec_input,1)

n_input_srcs = n_elements(ra_input)
for i = 0, n_input_srcs-1 do begin
   printf,lun,i,ra_input(i),dec_input(i),sx_input(i),$
         nh_input(i), parm1_input(i),$
         format='(i5,2f12.5, 2e12.3, f12.5)'
endfor

; 3)  Get the derived source positions and intensities

ebm_get_all_idxmembers,
;- fs_file = collate_path(tok,/i)
rstab,fs_file,n,ax,ay, sc_y_der, sc_z_der,$
             peak_der, bkg_lev, stdev_der, det_lev,nrows=nrows
if nrows gt 0 then begin
   i = where(det_lev gt crit_det_lev, n_der)
endif else begin
   n_der = 0
endelse
if n_der gt 0 then begin
   sc_y_der = sc_y_der(i)
   sc_z_der = sc_z_der(i)
   peak_der = peak_der(i)
   bkg_lev  = bkg_lev(i)
   stdev_der = stdev_der(i)
   det_lev = det_lev(i)

   ra_der = fltarr(n_der)
   dec_der = ra_der

   printf,lun,'//'
   printf,lun,'// Sources found in the RSTI image:'
   printf,lun,'// block = 0'
   printf,lun,'//'
   printf,lun,'// #    RAfound      DECfound     peak     bkg-level    det-level'

   for i = 0, n_der-1 do begin
      jconv_coord, ra_scx, dec_scx, roll, ra_src,$
               dec_src, sc_y_der(i), sc_z_der(i), /to_eq
      ra_der(i) = ra_src
      dec_der(i) = dec_src
      printf,lun,i,ra_src,dec_src,peak_der(i),bkg_lev(i),det_lev(i),$
                  format='(i5,2f12.5,3f12.3)'
   endfor
endif else begin
   printf,lun,'// No sources above detection level ', crit_det_lev
endelse

; Plot inputs

want_to_plot = 1
if keyword_set(noplot) then want_to_plot = 0
if want_to_plot then begin
   xr = [ra_scx+6.0/cos(dec_scx*!pi/180.),$
         ra_scx-6.0/cos(dec_scx*!pi/180.)]
   yr = [dec_scx-6.0, dec_scx+6.0]
   ;-- xr = [max(ra_input)+0.3,min(ra_input)-0.3]
   !p.title = swg_file+'['+str_extno+']'
   !x.title = 'RA (2000)'
   !y.title = 'DEC (2000)'
   plot, ra_input, dec_input, ps=1,xr=xr,yr=yr,/nodata
   oplotsiz, ra_input, dec_input,sx_input,ps=1,zn=1.5,zx=5

   ; and add derived sources

   if n_der gt 0 then begin
     def_sym,'c'
     oplotsiz,ra_der,dec_der,det_lev,ps=8,zn=1.5,zx=5
   endif
endif

; Step through the derived (found) sources

if n_der gt 0 then begin
   for i = 0, n_der-1 do begin

      printf,lun,'// Found source #'+strtrim(i,2), ra_der(i), dec_der(i)
      printf,lun,'// block = ', i+1
      printf,lun,'//    sc_y = ', sc_y_der(i)
      printf,lun,'//    sc_z = ', sc_z_der(i)
      printf,lun,'// identified with following input sources:'
      printf,lun,'// #   RAinput   DECinput  dist(arcmin) padding...'

      ; find input sources that are very close

      dist = arcdist(ra_input,dec_input,ra_der(i),dec_der(i),/deg)
      candidates = where(dist lt 0.05, n_cand)
      if n_cand gt 0 then begin
         for j = 0, n_cand-1 do begin
            k = candidates(j)
            printf,lun,k,ra_input(k),dec_input(k),dist(k)*60,$
                   ;-     sc_y_input(k), sc_z_input(k),$
                              0.,  0., $
                        format='(i5,5f12.5)'
         endfor
      endif else printf,lun,'//       No candidate found'


   endfor
endif

free_lun,lun
end
