pro list_pointings, rev, datadir=datadir, outdir=outdir, chat=chat
;
;   2002-11-20/NJW
;
;   2003-04-10/NJW Updated with JMX1 & 2 modes
;   2003-04-22/NJW Updated by removing keyword 'data'
;   2003-05-27/NJW Updated to produce both files at once
;                  and directly in /r2/jemx/pointings
;   2003-08-06/NJW Updated with keywords to define input directory
;                  and/or output directory
;   2006-01-26/NJW Updated with keyword 'chat' for debugging output
;
if n_params() ne 1 then begin
   print,'Syntax: list_pointings, rev[, datadir=][, outdir=]'
   print,'   Arg: rev is revolution number (integer)'
   print,'   Keywords: datadir  is directory for input data'
   print,'              outdir  is directory for output data'
   return
endif

if keyword_set(chat) then chat = 1 else chat = 0

revstr = string(fix(rev),format='(i4.4)')

; Define default directory for input data

datapath = '/r6/jemx/sci_data/pvphase/nrt/ops_1/scw/'+revstr+'/'

if keyword_set(datadir) then begin
   datapath = app_slash(datadir)
endif

if chat then print,'Searching in: '+datapath

mode_arr = ['F','H','R','T','S','*']
ra_scx_prev = 0.0
dec_scx_prev = 0.0
first = 1
prev_empty = 0

; Define default directory for output data

outpath = '/r6/jemx/pointings/'

if keyword_set(outdir) then begin
   outpath = app_slash(outdir)
endif

outname_d = outpath + 'pointings_'+revstr+'d.dat'
outname_p = outpath + 'pointings_'+revstr+'p.dat'

if chat then begin
   print,'The output is directed to: ', outname_d
   print,'                   and to: ', outname_p
endif

; Remove files if they exist already

if file_test(outname_d,/reg) then spawn,'/bin/rm '+outname_d
if file_test(outname_p,/reg) then spawn,'/bin/rm '+outname_p

; First part: produce the list of all pointings, slews, and others

openw,lun_d,outname_d,/get_lun
openw,lun_p,outname_p,/get_lun

; Short header in output file

printf,lun_d,'//       List of pointings with JEMX raw/prp data or HK data'
printf,lun_d,'//'
printf,lun_d,'//          Extracted with /home/njw/jemx/analysis/list_pointings.pro'
printf,lun_d,'//'
printf,lun_d,'//  SWID          RA      DEC    POSANGLE      UT first        IJD     TELAPSE MODE12'
printf,lun_d,'//              (deg)    (deg)    (deg)          pack         (day)     (s)'
printf,lun_d,'//'

printf,lun_p,'//       List of pointings with JEMX raw/prp data or HK data'
printf,lun_p,'//'
printf,lun_p,'//          Extracted with /home/njw/jemx/analysis/list_pointings.pro'
printf,lun_p,'//'
printf,lun_p,'//  SWID          RA      DEC    POSANGLE      UT first        IJD     TELAPSE MODE12'
printf,lun_p,'//              (deg)    (deg)    (deg)          pack         (day)     (s)'
printf,lun_p,'//'

; Save current directory

curdir = getenv('PWD')

cd,datapath

;* spawn,'find . -type d -name ''0*'' -print',list
;* if chat then begin
;*    print,'  Result of initial search for SCWs :'
;*    printl, list
;* endif
;* list = list(2:*)
;* list = list(sort(list))
;* swg = strmid(list,2,12)
;* if chat then print, swg

swgfile_list = file_search('*','swg_prp.fits',/test_reg, count = nlist )
if chat then begin
   if nlist eq 0 then begin
      print,'No swg_prp.fits files were found, try swg.fits'
   endif
endif
if nlist eq 0 then begin
   swgfile_list = file_search('*','swg.fits',/test_reg, count = nlist )
   if chat then begin
      if nlist eq 0 then begin
         print,'No swg.fits files were found, I give UP!'
         return
      endif
   endif
endif

if chat then begin
   print,' The following swg_prp or swg files have been found:'
   printl, swgfile_list
endif

for i = 0, nlist-1 do begin
   ;* swgfile = list(i)+'/swg_prp.fits'
   swgfile = swgfile_list(i)
   pick_swid_str, swgfile, swid
   hdr = headfits(swgfile,ext=1)
   ra_scx = fxpar(hdr,'RA_SCX')
   dec_scx = fxpar(hdr,'DEC_SCX')
   posangle = fxpar(hdr,'POSANGLE')
   ertfirst = fxpar(hdr,'ERTFIRST')
   dattim2ijd, ertfirst, ijd
   tstart = fxpar(hdr,'TSTART')
   tstop  = fxpar(hdr,'TSTOP')
   telapse  = fxpar(hdr,'TELAPSE')
   jmx1mode = fxpar(hdr,'JMX1MODE')
   index1 = jmx1mode - 41
   if index1 lt 0 or index1 gt 4 then index1 = 5
   jmx2mode = fxpar(hdr,'JMX2MODE')
   index2 = jmx2mode - 41
   if index2 lt 0 or index2 gt 4 then index2 = 5
   if not first then begin
      dist = arcdist(ra_scx, dec_scx, ra_scx_prev, dec_scx_prev, /deg)
      if dist gt 3.0 then begin
         printf,lun_d
         if not prev_empty then begin
            printf,lun_p
            prev_empty = 1
         endif
      endif
   endif
   first = 0
   ra_scx_prev = ra_scx
   dec_scx_prev = dec_scx
   printf,lun_d,swid,ra_scx,dec_scx,posangle,ertfirst,ijd,telapse,$
       mode_arr(index1), mode_arr(index2),$
       format='(a12,f10.4,f9.4,f9.3,a21,f10.4,f7.0,2x,a1,2x,a1)'
   if strmid(swid,11,1) eq '0' then begin
      printf,lun_p,swid,ra_scx,dec_scx,posangle,ertfirst,ijd,telapse,$
          mode_arr(index1), mode_arr(index2),$
          format='(a12,f10.4,f9.4,f9.3,a21,f10.4,f7.0,2x,a1,2x,a1)'
      prev_empty = 0
   endif
endfor

free_lun,lun_d
free_lun,lun_p

; cd to original directory

cd, curdir

; Change write permission to include group

spawn,'chmod 664 '+outname_d
spawn,'chmod 664 '+outname_p



return

end


