pro list_pointingsx, rev, datadir=datadir, outdir=outdir
;
;   2003-08-06/NJW Updated with keywords to define input directory
;                  and/or output directory
;
if n_params() ne 1 then begin
   print,'Syntax: list_pointingsx, rev[, datadir=][, outdir=]'
   print,'  List pointings from swg_idx FITS file'
   print,'   Arg: rev is revolution number (integer)'
   print,'   Keywords: datadir  is directory for input data'
   print,'              outdir  is directory for output data'
   return
endif

revstr = string(fix(rev),format='(i4.4)')

; Define default directory for input data

datapath = '/r2/jemx/sci_data/pvphase/nrt/ops_1/scw/'+revstr+'/'

if keyword_set(datadir) then begin
   datapath = app_slash(datadir)
endif

mode_arr = ['F','H','R','T','S','*']
ra_scx_prev = 0.0
dec_scx_prev = 0.0
first = 1
prev_empty = 0

; Define default directory for output data

outpath = '/r2/jemx/pointings/'

if keyword_set(outdir) then begin
   outpath = app_slash(outdir)
endif

outname_i = outpath + 'pointings_'+revstr+'i.dat'

print,'The output is directed to: ', outname_i

; First part: produce the list of all pointings, slews, and others

openw,lun_i,outname_i,/get_lun

; Short header in output file

printf,lun_i,'//       List of pointings with JEMX raw/prp data or HK data'
printf,lun_i,'//'
printf,lun_i,'//          Extracted with /home/njw/jemx/analysis/list_pointings.pro'
printf,lun_i,'//'
printf,lun_i,'//  SWID          RA      DEC    POSANGLE      UT first        IJD     TELAPSE MODE12'
printf,lun_i,'//              (deg)    (deg)    (deg)          pack         (day)     (s)'
printf,lun_i,'//'

; Save current directory

curdir = getenv('PWD')

cd,datapath

; Find all files with name 'swg_idx_jmx2.fits'

spawn,'find . -type f -name swg_idx_jmx2.fits -print',list

if n_elements(list) le 2 then begin
   print,'Sorry, no swg_idx_jmx2.fits was found under '+datapath
   return
endif

list = list(2:*)
nlist = n_elements(list)

list = list(sort(list))

k = 0
for i = 0, nlist-1 do begin

   printf,lun_i,'//   '+list(i)
   rdfitscol,list(i)+'+1',ra_scx,'RA_SCX',nrows=nrows
   rdfitscol,list(i)+'+1',dec_scx,'DEC_SCX'
   rdfitscol,list(i)+'+1',swid,'SWID'
   rdfitscol,list(i)+'+1',posangle,'POSANGLE'
   rdfitscol,list(i)+'+1',ertfirst,'ERTFIRST'
   rdfitscol,list(i)+'+1',tstart,'TSTART'
   rdfitscol,list(i)+'+1',tstop,'TSTOP'
   rdfitscol,list(i)+'+1',telapse,'TELAPSE'
   rdfitscol,list(i)+'+1',jmx1mode,'JMX1MODE'
   rdfitscol,list(i)+'+1',jmx2mode,'JMX2MODE'

   for j = 0, nrows-1 do begin
      dattim2ijd, ertfirst(j), ijd
      index1 = jmx1mode(j) - 41
      if index1 lt 0 or index1 gt 4 then index1 = 5
      index2 = jmx2mode(j) - 41
      if index2 lt 0 or index2 gt 4 then index2 = 5
      if not first then begin
         dist = arcdist(ra_scx(j), dec_scx(j), ra_scx_prev, dec_scx_prev, /deg)
         if dist gt 3.0 then begin
            printf,lun_i
            if not prev_empty then begin
               printf,lun_i
               prev_empty = 1
            endif
         endif
      endif
      first = 0
      ra_scx_prev = ra_scx(j)
      dec_scx_prev = dec_scx(j)
      printf,lun_i,swid(j),ra_scx(j),dec_scx(j),posangle(j),ertfirst(j),ijd,telapse(j),$
          mode_arr(index1), mode_arr(index2),$
          format='(a12,f10.4,f9.4,f9.3,a21,f10.4,f7.0,2x,a1,2x,a1)'
         prev_empty = 0
   endfor
endfor

free_lun,lun_i

; cd to original directory

cd, curdir

; Change write permission to include group

spawn,'chmod 664 '+outname_i



return

end


