;
; Main program for testing the direct demodulation method of Li & Wu
;
plt = 0                        ; logical variable for plot
n = 100                         ; Number of object points
f = fltarr(n) + 50.           ; object (such as spectrum)
f(n/2) = 500.                  ;  spectral line
f(2*n/3) = 300.                  ;  spectral line
fmin = 200.                    ; minimum line strength to find
bkg = 10.
m = 100                         ; Number of data points
p = fltarr(m,n)                ; Modulation matrix

for j = 0, n-1 do begin
   for i = 0, m-1 do begin
      p(i,j) = 1. / (abs(j-i)^2 +3.)
   endfor
endfor

if plt then !p.multi = [0, 3, 3]

; A)

if plt then plot,f,psym=10,yr=[-200,600]

; B)

dc = p # f + bkg                ; Simulated data, No noise
if plt then plot,dc,psym=10,yr=[-100,800]

; C)

noise_rms = 25. + dc*0
d = (dc + randomn(seed,m)*noise_rms ) > 0 ; Simulated data with noise
if plt then plot,d,psym=10,yr=[-100,800]
chi2r_d = chi2(dc, d, noise_rms) / m
if plt then xyouts,m/6,500,'!4v!3!u2!n = '+string(chi2r_d)
wtab,'dd.dat', dc, d
comadd,'dd.dat','chi2r_d', chi2r_d, ierr

; D)

c = dct(p,d)
if plt then plot,c,psym=10

; E)

c_star = dct_star(p,d)
if plt then plot,c_star,psym=10

; Clean the data to get background.

db = d
c_starb = c_star
while max(c_starb) gt fmin do begin
   fstrong = max(c_starb, is)              ; find strongest line
   fs = fltarr(n)
   fs(is) = fstrong
   db = db - p # fs
   c_starb = dct_star(p, db)
   if plt then oplot,c_starb,psym=10,linestyle=2
endwhile
if plt then oplot,c_starb,psym=10,thick=3
cb = dct(p, db)
wtab,'cc.dat', c, c_star, cb, c_starb

; F)

;  f_solve = invert(p) # d
;  if plt then plot,f_solve,psym=10,yr=[-200,600]
if plt then plot,d,psym=10,yr=[-100,800]
if plt then oplot,db,psym=10,thick=2
; if plt then xyouts,m/6,500,$
;   '!4v!3!u2!n = '+string(chi2(dc,p#f_solve,noise_rms)/m)
chi2r_db = chi2(dc, db, noise_rms) / m
if plt then xyouts,m/6,500,$
    '!4v!3!u2!n = '+string(chi2r_db)
comadd,'dd.dat','chi2r_db', chi2r_db, ierr

; F-1 ) Solve with Gauss-Seidel method with smoothing constraint
;       for background in object

pp = transpose(p) # p
alpha = 0.5
niter_max = 200
fb = f*0
gauss_seidel, 10, pp, cb, fb, alpha, qx, niter_max, smooth=20.

; Normal equations

; G)
f_ne = invert(pp) # c
if plt then plot,f_ne,psym=10,yr=[-200,600]
chi2r_f_ne = chi2(dc, p#f_ne, noise_rms) / m
if plt then xyouts,m/6,500,$
    '!4v!3!u2!n = '+string(chi2r_f_ne)
comadd,'dd.dat','chi2r_f_ne', chi2r_f_ne, ierr

; L=2 correlation
; H)
p2 = transpose(pp) # pp
c2 = transpose(pp) # c
f_ne2 = invert(p2) # c2
if plt then plot,f_ne2, psym=10,yr=[-200,600]
chi2r_f_ne2 = chi2(dc,p#f_ne2, noise_rms) / m
if plt then xyouts,m/6,500,$
    '!4v!3!u2!n = '+string(chi2r_f_ne2)
comadd,'dd.dat','chi2r_f_ne2', chi2r_f_ne2, ierr

; I)

alpha = 0.5
niter_max = 200
f_ne_gs = f_ne * 0
gauss_seidel, 10, pp, c, f_ne_gs, alpha, qx, niter_max
f_ne_gs = f_ne_gs * total(d) / total(f_ne_gs)
if plt then plot,f_ne_gs,psym=10,yr=[-200,600]
chi2r_f_ne_gs = chi2(dc,p#f_ne_gs, noise_rms) / m
if plt then xyouts,m/6,500,$
    '!4v!3!u2!n = '+string(chi2r_f_ne_gs)
comadd,'dd.dat','chi2r_f_ne_gs', chi2r_f_ne_gs, ierr

wtab,'ff.dat', f, f_ne, fb, f_ne_gs
end
