function low_order_poly_fit, x, y, nmax, yfit=yfit, rel_lim=rel_lim, chi2=chi2
;
;  Returns a polynomial fit to y(x) of lowest possible order up to nmax
;
;   2004-11-10/NJW
;
;  Do polynomial fits of increasing order until the relative change
;  in the Chi-square value is less than 'rel_lim' (default value is 0.2)
;
;-------------------------------------------------------
;
if n_params() ne 3 then begin
   print,'Syntax: r = low_order_poly_fit( x, y, nmax[, yfit=][, rel_lim=][, chi2=])'
   print,'  Keywords: returns ''yfit'' and ''chi2'''
   print,'            ''rel_lim'' defines limit for relative chi2 change'
   return,-1
endif

if not keyword_set(rel_lim) then rel_lim = 0.2

;
;  Establish reference first order fit
;
rp = poly_fit( x, y, 1, yfit=yfitp )
c2p = total((y-yfitp)^2)
chi2 = [c2p]

;
;  Upgrade the polynomial order until limit is reached
;

for n = 2,nmax do begin

   r = poly_fit( x, y, n, yfit=yfit )
   c2 = total((y-yfit)^2)
   chi2 = [chi2,c2]
   if abs((c2 - c2p)/c2p) lt rel_lim then break
   c2p = c2
   yfitp = yfit
   rp = r

endfor

yfit = yfitp
return, rp

end
