function makeimageu,imdim,xval,yval,xr=xr,yr=yr,w=w,update=update
;
;  2003-09-16/NJW (updated)
;
; Make 2D image (a 2D histogram) from array of x values
;  and one of y values with optional weights
;
; The array can be updated using keyword 'update'. The input
; array must match 'imdim'
;
if( n_params() lt 3 ) then begin
   print,'makeimageu,imdim,xval,yval[,xr=][,yr=][,w=w][,update=image]'
   return,-1.
endif

index = size(imdim)
if( index(0) ne 1 or index(1) ne 2 ) then begin
   print,'Incorrect number of dimensions for image'
   return,-1.
endif
nx = n_elements(xval)
if( nx ne n_elements(yval) ) then begin
   print,'Not matching number of dimensions in call'
   return,-1.
endif
;
if not keyword_set(w) then w = xval*0. + 1.
if n_elements(w) ne nx then begin
	print,'Incorrect number of elements in weight factor array'
	return,-1.
endif

if keyword_set(update) then begin
   im = update
   szim = size(im)
   if szim(1) ne imdim(0) or szim(2) ne imdim(1) then begin
      print,'MAKEIMAGE error - index mismatch'
      return, -1.
   endif
endif else begin
   im = fltarr(imdim(0),imdim(1))
endelse

; Definition of limits

if keyword_set(xr) then begin
	xmin = xr(0)*1.0
	xmax = xr(1)*1.0
endif else begin
	xmin = min(xval)*1.0
	xmax = max(xval)*1.0
endelse
if keyword_set(yr) then begin
	ymin = yr(0)*1.0
	ymax = yr(1)*1.0
endif else begin
	ymin = min(yval)*1.0
	ymax = max(yval)*1.0
endelse
dx = (xmax - xmin) / imdim(0)
dy = (ymax - ymin) / imdim(1)

for i = 0L,nx-1 do begin
   ix = ((xval(i) - xmin) / dx)
   if ix ge 0 and ix lt imdim(0) then begin
      iy = ((yval(i) - ymin) / dy)
      if iy ge 0 and iy lt imdim(1) then im(ix,iy) = im(ix,iy) + w(i)
   endif
endfor
return,im
end
