function map_fits_file, filename
;
;  Return a structure array with EXTNAME, EXTVERS, XTENSION
;  for each FITS extension
;
;   2004-03-25/NJW
;

if n_params() lt 1 then begin
   print,'Syntax: str_array = map_fits_file(filename)'
   return,-1
endif

if not file_test(filename,/reg) then begin
   print,'File not found: '+filename
   return,-1
endif

resu = { extname:'', extvers:0, xtension:''}

n_exts = nfits_extens(filename) ; number of last extension
res = replicate(resu,n_exts+1)

for i_ext = 0, n_exts do begin

   hdr = headfits(filename,ext=i_ext)
   extn = fxpar(hdr,'EXTNAME',count=nmatch)
   if nmatch eq 0 then res(i_ext).extname = '' else res(i_ext).extname = extn
   extv = fxpar(hdr,'EXTVERS',count=nmatch)
   if nmatch eq 0 then res(i_ext).extvers = -1 else res(i_ext).extvers = extv
   xten = fxpar(hdr,'XTENSION',count=nmatch)
   if nmatch eq 0 then res(i_ext).xtension = '' else res(i_ext).xtension = xten

endfor

return, res

end
