pro meka_line, e1, e2, kt, abun, num_line, eline, eps
;
; procedure for MEKA plasma emission calculations
;           returning line id's, line energies and emissivity
;
;   Call :   e1   : lower energy limit (keV)
;            e2   : upper energy limit (keV)
;            kt   : electron temperature in keV
;          abun   : relative metal abundance factor (1 - solar)
;
;   Return : num_line : line number as in 'lineparn.dat'
;            eline    : fltarr with energies in keV
;            eps      : emissivity in phot cm3 / s
;
npar = n_params()
if npar ne 7 then begin
   print,'meka_line, e1, e2, kt, abun, num_line, eline, eps'
   retall
endif
program = '/d/njw/meka_code/bin/line_emis'
params = string(e1, e2, kt, abun,$
         format='(2f7.3,2f8.4)')
print,program+params
spawn,program+params,result
sz = size(result)
if sz(0) eq 0 then begin
   num_line = 0
   eline = -1.
   eps = 0.
endif else begin
   nlines = n_elements(result)
   res = fltarr(3,nlines)
   reads,result,res
   num_line = fix(res(0,*))
   eline    = res(1,*)
   eps      = res(2,*)
endelse
end
