pro mid_ed_profile, n_meas, xprof, yprof, ymin=ymin, ymax=ymax, $
	init=init, outfile=outfile
;
;    Additional MIDI software
;
;    2004-07-11/NJW
;
if n_params() lt 1 then begin
	print,'Syntax: mid_ed_profile, n_meas, xprof, yprof[,ymin=][,ymax=]'
	print,'       [,/init][,outfile=]'
	return
endif

;* n_meas = n_elements(nbeatpm)

xbars = findgen(n_meas + 1)
if not keyword_set(ymin) then ymin = 0.0
if not keyword_set(ymax) then ymax = 1.0

if keyword_set(init) then begin
	xprof = [0.d0]
	yprof = [0.5]*(ymin + ymax)
endif else begin ; do some checks
	n = n_elements(xprof)
	if xprof(0) gt 0.d0 then print,'Warning: does not start with zero'
	if xprof(n-1) gt double(n_meas) then print,'Warning: exceeds number of measures'
	w = where(yprof gt ymax, nw)
	if nw gt 0 then begin
		yprof(w) = ymax
		print,'Warning: '+stri(nw)+' values adjusted to ymax'
	endif
	w = where(yprof lt ymin, nw)
	if nw gt 0 then begin
		yprof(w) = ymin
		print,'Warning: '+stri(nw)+' values adjusted to ymin'
	endif
endelse


xmin = -0.5
xmax = 3.5
mid_setup_win, xmin, xmax, ymin, ymax, /init

repeat begin

	ans = 'non'
	mid_setup_win, xmin, xmax, ymin, ymax
	xprof(0) = 0.0
	mid_oplot,xprof,yprof,n_meas
	oplot,xprof,yprof,ps=2
	w = where( xbars gt xmin and xbars lt xmax, nw)
	for i = 0, nw-1 do begin
		oplot,[xbars(w(i)),xbars(w(i))],ymin + [0.2,1]*(ymax - ymin)
	endfor

	while ans eq 'non' do begin
		curmark1, curpos
		ans = mid_choice( curpos )
		if ans eq 'fin' then goto, checkout
		if ans eq 'adv' then begin
			xmin = xmin + 1
			xmax = xmax + 1
		endif
		if ans eq 'del' then begin
			curmark1,curpos
			dist = abs(curpos(0) - xprof)
			dmin = min(dist,i)
			n = n_elements(xprof)
			if i eq 0 then begin
				xprof = xprof(1:*)
				yprof = yprof(1:*)
			endif else if i eq n-1 then begin
				xprof = xprof(0:n-2)
				yprof = yprof(0:n-2)
			endif else begin
				xprof = [xprof(0:i-1),xprof(i+1:*)]
				yprof = [yprof(0:i-1),yprof(i+1:*)]
			endelse
		endif
		if ans eq 'mov' then begin
			curmark1,curpos
			dist = abs(curpos(0) - xprof)
			dmin = min(dist,i)
			n = n_elements(xprof)
			if i eq 0 then begin
				xprof = [curpos(0),xprof(1:*)]
				yprof = [curpos(1),yprof(1:*)]
			endif else if i eq n-1 then begin
				xprof = [xprof(0:n-2),curpos(0)]
				yprof = [yprof(0:n-2),curpos(1)]
			endif else begin
				xprof = [xprof(0:i-1),curpos(0),xprof(i+1:*)]
				yprof = [yprof(0:i-1),curpos(1),yprof(i+1:*)]
			endelse
		endif
		if ans eq 'non' then begin
			; add a new point
			n = n_elements(xprof)
			xxprof = [xprof,9.99d99]
			i = 0
			while i lt n and xxprof(i) lt curpos(0) do i = i + 1
			if i eq 0 then begin
				xprof = [curpos(0),xprof]
				yprof = [curpos(1),yprof]
			endif else if i eq n then begin
				xprof = [xprof,curpos(0)]
				yprof = [yprof,curpos(1)]
			endif else begin
				xprof = [xprof(0:i-1),curpos(0),xprof(i:*)]
				yprof = [yprof(0:i-1),curpos(1),yprof(i:*)]
			endelse
			xprof(0) = 0.0
			mid_oplot,xprof,yprof,n_meas
			oplot,xprof,yprof,ps=2
		endif
	endwhile
endrep until 0

checkout:

xprof(0) = 0.0
if keyword_set(outfile) then begin
	hdr = ['//    '+systime(),'// n_meas = '+stri(n_meas),'//']
	wstab,outfile,hdr,xprof,yprof,fm='f14.7'
endif

end

