function mid_get_event, line, tsig=tsig
;
;  Additional MIDI software
;
;   2004-07-12/NJW
;

common mid_last_mbt, last_mbt
common mid_settings, timesig, ntickpq
common mid_filestreams, lun, luout, kount_in, kount_out
common mid_line_buffer, nline_buffer, line_buffer

mbt_arr = intarr(3)

event = { mbt: '', tpos: double(0), type:'', att1:'', att2:'', $
	ival1:0, ival2:long(0), val2:'', text:'' }

if n_params() lt 1 then begin
	print,'Syntax: event = mid_get_event(line)'
	event.mbt = 'noevent'
	return,event
endif
tok = strsplit(line, '|', /extract)
ntok = n_elements(tok)
if ntok lt 2 then begin
	event.mbt = 'noevent'
	return,event
endif

sz = size(last_mbt)
if sz(0)+sz(1) ne 0 then begin
	lat = strsplit(last_mbt,':',/extract)
	mbt_arr(0) = fix(lat(0))
	mbt_arr(1) = fix(lat(1))
	mbt_arr(2) = fix(lat(2))
endif

mbt = strcompress(tok(0),/remove)
if strlen(mbt) eq 0 then mbt = last_mbt else begin
	t = strsplit(mbt,':',/extract)
	nt = n_elements(t)
	if nt eq 1 then begin
		mbt = lat(0)+':'+lat(1)+':'+t(0)
		mbt_arr(2) = fix(t(0))
	endif
	if nt eq 2 then begin
		mbt = lat(0)+':'+t(0)+':'+t(1)
		mbt_arr(1) = fix(t(0))
		mbt_arr(2) = fix(t(1))
	endif
	if nt eq 3 then begin
		mbt_arr(0) = fix(t(0))
		mbt_arr(1) = fix(t(1))
		mbt_arr(2) = fix(t(2))
	endif
endelse

last_mbt = mbt

mid_get_tsig, mbt_arr(0), nbeatpm, beatval

mid_mbt_real, mbt, tpos, nbeatpm, beatval, ntickpq, /to_tpos

event.mbt = mbt
event.tpos = tpos
event.type = strlowcase(strtrim(tok(1),2))
event.att1 = ''
event.att2 = ''
event.ival1 = 0
event.ival2 = long(0)
event.val2 = ''
event.text = ''

if event.type eq 'key sig' then begin
	event.att1 = strtrim(tok(2),2)
	return, event
endif
if event.type eq 'end of track' then begin
	return, event
endif
if event.type eq 'time sig' and keyword_set(tsig) then begin
	s = strtrim(tok(2),2)
	q = strsplit(s,'/',/extract)
	print,'Time sig: ', s
	prints,q(0)
	prints,q(1)
	print,'mbt_arr(0) = ', mbt_arr(0)
	if mbt_arr(0) eq 1 then begin
		timesig(0,1) = fix(q(0))
		timesig(0,2) = fix(q(1))
	endif else begin
		sz = size(timesig)
		n = sz(1)
		aux = intarr(n+1,3)
		aux(0:n-1,*) = timesig
		timesig = aux
		timesig(n,0) = mbt_arr(0)
		timesig(n,1) = fix(q(0))
		timesig(n,2) = fix(q(1))
	endelse

	tok(2) = strcharrepl(strtrim(tok(2),2),'/','0')
	tok(2) = 'timesig='+tok(2)
endif
if ntok gt 2 then begin
	s = strtrim(tok(2),2)
	peq = strpos(s,'=')
	if peq ge 0 then begin
		vals = strsplit(s,'=',/extract)
		event.att1 = strtrim(vals(0),2)
		if is_digit(vals(1)) then event.ival1 = fix(vals(1))
	endif else begin
		event.att1 = s
		event.ival1 = 0
	endelse
endif
if ntok gt 3 then begin
	s = strtrim(tok(3),2)
	peq = strpos(s,'=')
	if peq ge 0 then begin
		vals = strsplit(s,'=',/extract)
		event.att2 = strtrim(vals(0),2)
		if is_digit(vals(1)) then event.ival2 = long(vals(1))
	endif else begin
		event.att2 = s
		event.ival2 = 0
	endelse
endif

if event.type eq 'track name' or $
	event.type eq 'device name' or $
	event.type eq 'text' then begin

	ntlines = (event.ival1 - 1)/11 + 1
	nline_buffer = ntlines
	line_buffer = strarr(nline_buffer)
	tline = ''
	for i = 0, ntlines-1 do begin
		readf,lun,tline
		line_buffer(i) = tline
		kount_in = kount_in + 1
		plt = strpos(tline,'<')
		pgt = strpos(tline,'>')
		if i eq 0 then event.text = strmid(tline,plt+1,pgt-plt-1) $
			else event.text = event.text + strmid(tline,plt+1,pgt-plt-1)
	endfor
endif

return, event

end
