pro mid_mbt_real, mbt, tpos, nbeatpm, beatval, ntickpq, $
	to_mbt=to_mbt, to_tpos=to_tpos
;
;  Part of additional software for MIDI package with
;  www.borg.com  MIDI assenbler/disassembler
;
;  2004-07-11/NJW
;
;  'mbt' is Measure|beat|tick
;  'tpos' is position in time
;  'nbeatpm' is number of beats per measure
;  'beatval' is value of beat (2 for semitones, 4 for quarters, 8 for quavers, etc)
;  'ntickpq' is number of ticks per quarter
;
if n_params() lt 5 then begin
   print,'Syntax: mid_mbt_real, mbt, tpos, nbeatpm, $'
   print,'      beatval, ntickpq[,/to_mbt][,/to_tpos]'
   return
endif

if not keyword_set(to_mbt) and not keyword_set(to_tpos) then begin
   print,'A keyword indicating direction MUST be set, either'
   print,' ''to_mbt'' or ''to_tpos'''
   return
endif

ntickpb = (ntickpq * 4) / beatval

if keyword_set(to_mbt) then begin

   m = floor(tpos) + 1
   r = tpos - m + 1
   b = floor(r * nbeatpm) + 1
   s = r - (b - double(1))/nbeatpm
   t = floor(s * ntickpb * nbeatpm)

   mbt = stri(m) + ':' + stri(b) + ':' + stri(t)

   return

endif else begin

   tok = strsplit( strcompress(mbt,/remove),':.', /extract)
   tpos = double(tok(0))-1 + (double(tok(1)) - 1)/nbeatpm $
	   + double(tok(2))/(ntickpb * nbeatpm)

   return

endelse

end
