pro mid_mod_disam, filename, vel_profile, trnum, verb=verb
;
;  Additional MIDI software
;
;   2004-07-12/NJW
;

if n_params() lt 3 then begin
	print,'Syntax: mid_mod_disam, filename, vel_profile, trnum $'
	print,'                         [,verb=][,trnum=] $'
	print,'   filename: name of .txt file'
	print,'   vel_profile: velocity profile file'
	print
	print,'   Keywords:    verb  - verbosity 0 - 5'
	print,'                trnum - track number'
	return
endif

common mid_settings, timesig, ntickpq
common mid_filestreams, clun, cluout, kount_in, kount_out
common mid_line_buffer, nline_buffer, line_buffer

; The structure 'ev':
;      ev.mbt      - measure/beat/tick  time indication
;      ev.tpos     - floating point time indication
;      ev.type     - string with event type
;      ev.att1     - string with first attribute
;      ev.att2     - string with second attribute
;      ev.ival1    - integer with first value
;      ev.ival2    - long with second value
;      ev.val2     - string with second value
;      ev.text     - string with text


nbeatpm = 4 ; default value that will be changed later
beatval = 4 ; default value that will be changed later
timesig = reform([1,nbeatpm,beatval],1,3)
nline_buffer = 0
line_buffer = ''

if not file_test(filename,/reg) then begin
	print,'File not found: ', filename
	return
endif

if not keyword_set(verb) then verb = 0

;  Read the velocity profile

rstab, vel_profile, tprof, vprof

openr,lun,filename,/get_lun
clun = lun

; Construct new output filename

pos = strpos(filename,'.txt',/reverse_search)
if strlen(filename) gt 8 then begin ; test for xxx_123.txt type
	if strmid(filename,pos-4,1) eq '_' $
		and is_digit(strmid(filename,pos-3,3)) then pos = pos - 4
endif
fileout = strmid(filename,0,pos)
list = file_search( fileout+'_???.txt',/test_regular,count=nlist)
if nlist eq 0 then begin
	fileout = fileout+'_001.txt'
endif else begin
	list = list(sort(list))
	no = fix(strmid(list(nlist-1),pos+1,3))
	snew = string(no+1,format='(i3.3)')
	fileout = fileout+'_'+snew+'.txt'
endelse
print,'Output file: ',fileout
openw,luout,fileout,/get_lun
cluout = luout
openw,lulog,'mid.log',/get_lun

kount_in = 0L
kount_out = 0L
line = ''
readf,lun,line
if strmid(line,0,4) ne 'MThd' then begin
	print,'Not a MThd MIDI disassembled file, quit!'
	free_lun,lun
	free_lun,luout
	return
endif
kount_in = kount_in + 1
mid_get_keyval, line, 'format', iform
mid_get_keyval, line, '# of tracks', ntracks
mid_get_keyval, line, 'division', ntickpq
printf,luout,line
kount_out = kount_out + 1
if verb gt 4 then print,'LINE '+stri(kount_in)+': ',line
if verb gt 0 then print,'Division = ', ntickpq

track = -1

while not eof(lun) do begin
	readf,lun,line
	kount_in = kount_in + 1
	if verb gt 4 then print,'LINE '+stri(kount_in)+': ',line
	s = strlowcase(line)

	; Look for indication of track number and extract its value

	p = strpos(s,'track')
	q = strpos(s,'#')
	if p ge 0 and q ge p+5 then begin
		snum = ''
		i = 1
		while is_digit(strmid(line,q+i,1)) do begin
			snum = snum+strmid(line,q+i)
			i = i + 1
		endwhile
		track = fix(snum)
		printf,luout,line
		kount_out = kount_out + 1
		if verb gt 0 then print,'*** reading track # ', stri(track)
		continue
	endif

	; Analyzing a line with an event

	ev = mid_get_event(line)
	if verb gt 3 then print,'TYPE: ', ev.type
	mid_log_event, lulog, ev

	;  Section for changing information

	if track eq trnum then begin
		if ev.type eq 'Note On' then print,'Change this one'
	endif

	; Output line

	printf,luout,line
	kount_out = kount_out + 1

	; See if line was followed by a number of text lines
	;   (stored in common buffer) and output them if present

	if nline_buffer gt 0 then begin
		for i = 0, nline_buffer-1 do begin
			printf,luout,line_buffer(i)
			kount_out = kount_out+1
		endfor
		nline_buffer = 0
	endif
endwhile

free_lun,luout
free_lun,lun
free_lun,lulog

print,'Number of input lines: ', kount_in
print,'Number of output lines: ', kount_out

end
