pro mid_tempo, filename, verb=verb, newtempo=newtempo
;
;  Additional MIDI software
;
;  Global change of tempo events or insert new ones
;  Works with the assumption that all tempo settings and
;  changes happen in track #0 (zero)
;
;   2004-07-19/NJW, cloned from 'mid_mod_disam.pro'
;

if n_params() lt 1 then begin
	print,'Syntax: mid_tempo, filename[,verb=] $'
	print,'          , newtempo='
	print,'   Keywords:    verb  - verbosity 0 - 5'
	print,'                newtempo - file with new tempo events'
	return
endif

common mid_settings, timesig, ntickpq
common mid_filestreams, clun, cluout, kount_in, kount_out
common mid_line_buffer, nline_buffer, line_buffer

sz = size(timesig)
if sz(0) ne 2 or sz(2) ne 3 then begin
	print,'Timesig in common not set correctly'
	print,'Did you run mid_settings ? Else do!'
	return
endif

trnum = -1

nline_buffer = 0
line_buffer = ''

if not file_test(filename,/reg) then begin
	print,'File not found: ', filename
	return
endif

if not keyword_set(verb) then verb = 0

if keyword_set(newtempo) then begin
	tmpevs = mid_mk_tempo_eventlist(newtempo,count=ntmpevs)
	rscol,newtempo,tpos2,1,/dble
	if ntmpevs gt 0 then more2 = 1 else more2 = 0
	trnum = 0
	i2 = 0
endif

openr,lun,filename,/get_lun
clun = lun

; Construct new output filename

pos = strpos(filename,'.txt',/reverse_search)
if strlen(filename) gt 8 then begin ; test for xxx_123.txt type
	if strmid(filename,pos-4,1) eq '_' $
		and is_digit(strmid(filename,pos-3,3)) then pos = pos - 4
endif
fileout = strmid(filename,0,pos)
list = file_search( fileout+'_???.txt',/test_regular,count=nlist)
if nlist eq 0 then begin
	fileout = fileout+'_001.txt'
endif else begin
	list = list(sort(list))
	no = fix(strmid(list(nlist-1),pos+1,3))
	snew = string(no+1,format='(i3.3)')
	fileout = fileout+'_'+snew+'.txt'
endelse
print,'Output file: ',fileout
openw,luout,fileout,/get_lun
cluout = luout

kount_in = 0L
kount_out = 0L
line = ''
readf,lun,line
if strmid(line,0,4) ne 'MThd' then begin
	print,'Not a MThd MIDI disassembled file, quit!'
	free_lun,lun
	free_lun,luout
	return
endif
kount_in = kount_in + 1
mid_get_keyval, line, 'format', iform
mid_get_keyval, line, '# of tracks', ntracks
mid_get_keyval, line, 'division', ntickpq
printf,luout,line
kount_out = kount_out + 1
if verb gt 4 then print,'LINE '+stri(kount_in)+': ',line
if verb gt 0 then print,'Division = ', ntickpq

track = -1

while not eof(lun) do begin
	readf,lun,line
	kount_in = kount_in + 1
	if verb gt 4 then print,'LINE '+stri(kount_in)+': ',line
	s = strlowcase(line)
	p = strpos(s,'track')
	q = strpos(s,'#')
	if p ge 0 and q ge p+5 then begin
		snum = ''
		i = 1
		while is_digit(strmid(line,q+i,1)) do begin
			snum = snum+strmid(line,q+i)
			i = i + 1
		endwhile
		track = fix(snum)
		printf,luout,line
		kount_out = kount_out + 1
		if verb gt 0 then print,'*** reading track # ', stri(track)
		continue
	endif
	ev = mid_get_event(line)
	if verb gt 3 then print,'TYPE: ', ev.type

	;  Section for changing information

	if track eq 0 then begin
		if ev.type eq 'tempo' then continue
		if more2 then begin
			if ev.tpos lt tpos2(i2) then begin
				printf,luout,line
				kount_out = kount_out + 1
				if nline_buffer gt 0 then begin
					for i = 0, nline_buffer-1 do begin
						printf,luout,line_buffer(i)
						kount_out = kount_out+1
					endfor
					nline_buffer = 0
				endif
			endif else begin
				printf,luout,tmpevs(i2)
				i2 = i2 + 1
				if i2 eq ntmpevs then more2 = 0
			endelse
		endif else begin
			printf,luout,line
			kount_out = kount_out + 1
			if nline_buffer gt 0 then begin
				for i = 0, nline_buffer-1 do begin
					printf,luout,line_buffer(i)
					kount_out = kount_out+1
				endfor
				nline_buffer = 0
			endif
		endelse
		continue
	endif

	printf,luout,line
	kount_out = kount_out + 1
	if nline_buffer gt 0 then begin
		for i = 0, nline_buffer-1 do begin
			printf,luout,line_buffer(i)
			kount_out = kount_out+1
		endfor
		nline_buffer = 0
	endif
endwhile

free_lun,luout
free_lun,lun

print,'Number of input lines: ', kount_in
print,'Number of output lines: ', kount_out

end
