pro mix_events, masterfile, fract_master, mixinfile, fract_mixin
;
; Routine to replace the masterfile rows with a fraction of the
; original rows and a fraction of the mix-in rows from mixinfile
;
; The assumption of the current version is that the arrays are
; found in ext#1
;
;   2005-03-03/NJW
;
if n_params() lt 4 then begin
	print,'Syntax: mix_events, masterfile, fract_master, mixinfile, fract_mixin'
	return
endif

if not file_test(masterfile,/reg) then begin
	print,'Masterfile:', masterfile,' is missing'
	return
endif
if not file_test(mixinfile,/reg) then begin
	print,'Mixinfile:', mixinfile,' is missing'
	return
endif

; Do a backup of the masterfile if no previous backup exists

masterfile_backup = masterfile+'.orig'
if not file_test(masterfile_backup,/reg) then begin
	print,'Makes a backup of the masterfile in ', masterfile_backup
	spawn,'cp '+masterfile+' '+masterfile_backup
endif

fxbopen,unit,masterfile,1
n_cols = fxbcolnum(unit, 0)
colnames = strarr(n_cols)
for i = 0, n_cols-1 do colnames(i) = fxbcolname(unit,i+1)
print,colnames
fxbclose,unit

if n_cols ge 1 then rdfitscol,masterfile+'+1',c1,1,nrows=nrows_mas,/sil
if n_cols ge 2 then rdfitscol,masterfile+'+1',c2,2,/sil
if n_cols ge 3 then rdfitscol,masterfile+'+1',c3,3,/sil
if n_cols ge 4 then rdfitscol,masterfile+'+1',c4,4,/sil

fxbopen,unit,mixinfile,1
if n_cols ne fxbcolnum(unit, 0) then begin
	print,'Different number of columns in the two files'
	fxbclose,unit
	return
endif
for i = 0, n_cols-1 do begin
	if colnames(i) ne fxbcolname(unit,i+1) then begin
		print,'Mismatching column name in col# '+stri(i+1)
		fxbclose,unit
		return
	endif
endfor
fxbclose,unit

if n_cols ge 1 then rdfitscol,mixinfile+'+1',d1,1,nrows=nrows_mix,/sil
if n_cols ge 2 then rdfitscol,mixinfile+'+1',d2,2,/sil
if n_cols ge 3 then rdfitscol,mixinfile+'+1',d3,3,/sil
if n_cols ge 4 then rdfitscol,mixinfile+'+1',d4,4,/sil

; Do the selection in the master by random numbers

if fract_master lt 1.0 then begin
	p = randomu(seed, nrows_mas)
	w = where(p lt fract_master, nw)
	if n_cols ge 1 then c1 = c1(w)
	if n_cols ge 2 then c2 = c2(w)
	if n_cols ge 3 then c3 = c3(w)
	if n_cols ge 4 then c4 = c4(w)
endif

; Do the selection in the mix-in by random numbers

if fract_mixin lt 1.0 then begin
	p = randomu(seed, nrows_mix)
	w = where(p lt fract_mixin, nw)
	if n_cols ge 1 then d1 = d1(w)
	if n_cols ge 2 then d2 = d2(w)
	if n_cols ge 3 then d3 = d3(w)
	if n_cols ge 4 then d4 = d4(w)
endif

if n_cols ge 1 then c1 = [c1,d1]
if n_cols ge 2 then c2 = [c2,d2]
if n_cols ge 3 then c3 = [c3,d3]
if n_cols ge 4 then c4 = [c4,d4]

nrows_out = n_elements(c1)

fxbghostcpy, masterfile, 'x_x_x_x', nrows_out
spawn,'mv x_x_x_x '+masterfile

if n_cols ge 1 then fits_replace_col, masterfile+'+1', colnames(0), c1
if n_cols ge 2 then fits_replace_col, masterfile+'+1', colnames(1), c2
if n_cols ge 3 then fits_replace_col, masterfile+'+1', colnames(2), c3
if n_cols ge 4 then fits_replace_col, masterfile+'+1', colnames(3), c4

print,'mix_events: The job is done!'

end
