pro mix_evts_shds, dol_master_shd, fract_master, dol_mixin_shd, fract_mixin, $
           n_master_evts=n_master_evts, n_mixin_evts=n_mixin_evts
;
; Routine to replace the master shadowgram with a fraction of
; itself plus a fraction of the mix-in shadowgram
;
;
;   2005-03-04/NJW
;   2005-03-18/NJW Updated with keywords for number of events
;
if n_params() lt 4 then begin
   print,'Syntax: mix_evts_shds, dol_master_shd, fract_master, dol_mixin_shd, fract_mixin'
   print,'    Optional keywords: n_master_evts=, n_mixin_evts= return number of events'
   return
endif

get_exten_no, dol_master_shd, masterfile, extno_master

if not file_test(masterfile,/reg) then begin
   print,'Masterfile:', masterfile,' is missing'
   return
endif

get_exten_no, dol_mixin_shd, mixinfile, extno_mixin

if not file_test(mixinfile,/reg) then begin
   print,'Mixinfile:', mixinfile,' is missing'
   return
endif

; Do a backup of the masterfile if no previous backup exists

masterfile_backup = masterfile+'.orig'
if not file_test(masterfile_backup,/reg) then begin
   print,'Makes a backup of the masterfile in ', masterfile_backup
   spawn,'cp '+masterfile+' '+masterfile_backup
endif

shd_master = readfits( masterfile, ext=extno_master)
shd_mixin = readfits( mixinfile, ext=extno_mixin)

n_master_evts = total(shd_master) * fract_master
n_mixin_evts = total(shd_mixin) * fract_mixin

szmas = size(shd_master)
szmix = size(shd_mixin)
if cmparr(szmas, szmix) ne 0 then begin
   print,'Size master: ', szmas
   print,'Size  mixin: ', szmix
   print,'     Different! so skip further action.'
   return
endif

result = fract_master * shd_master + fract_mixin * shd_mixin

rewrite_fits_image, dol_master_shd, result


print,'mix_evts_shds: The job is done!'

end
