pro mk_a_recon_macro, help=help, extnum=extnum, maxnum=maxnum, rev=rev, note=note
;
;  Go through all shadowgrams in /r6/jemx/njw/survey/shd and see
;  if corresponding image file in /r6/jemx/njw/survey/skyimages exists.
;  If not, then add to to-do list
;
;  Keywords: extnum - only this extension number will be put in macro
;            maxnum - stops when this number is exceeded
;
;  2004-03-03/NJW
;

if keyword_set(help) then begin
   print,'mk_a_recon_macro, /help, extnum=, maxnum=,rev='
   print,'  extnum : Define selected extension number in shadowgram file'
   print,'  maxnum : Maximum number of shadowgrams in ''mac2'''
   print,'  rev    : Specifies revolution number'
   print,'  note   : Specifies that the result is for ''njw-notebook'''
   return
endif

base = '/r6/jemx/njw/survey/'
base1 = base
if keyword_set(note) then base1 = '/mnt/win_f'+base

selstr = '_'
if keyword_set(rev) then begin
   revstr = string(fix(rev),format='(i4.4)')
   selstr = '_'+revstr
endif

shd_list = file_search(base+'shd/shd2'+selstr+'*fits',/test_reg,count=n_shd_list)

if n_shd_list eq 0 then begin
   print,'No shadowgram files!'
   return
endif

if not keyword_set(maxnum) then maxnum = 32767

; Open file with macro

macname = 'mac2'
if keyword_set(note) then macname = 'mac2_note'
openw,lun,macname,/get_lun

k = 0

for loop = 0, n_shd_list-1 do begin

   num_exts = nfits_extens(shd_list(loop))
   if num_exts lt 2 then begin
      print,shd_list(loop)+' contains no useful data'
      continue
   endif

   extlo = 1
   exthi = num_exts
   if keyword_set(extnum) then begin
      extlo = extnum
      exthi = extnum
   endif

   if exthi gt num_exts then continue

   ;   Following 3 lines prepare names for njw-notebook
   tok = strsplit( shd_list(loop), '/', /extract)
   shd_name_rem = '/mnt/r6jemx/'+collate_path(tok(2:*))
   shd_name_loc = '/mnt/win_f/'+collate_path(tok)
   first = 1


   for i = extlo, exthi do begin
      hdr = headfits(shd_list(loop),ext=i)
      extname = fxpar(hdr,'extname')
      if extname eq 'JMX2-EVTS-SHD' then begin ; found a shadowgram
         ; check for corresponding image file
         pick_swid_str,shd_list(loop), swid
         imfile = base+'skyimages/si2_'+swid+'_'+stri(i)+'.fits'
         imfile1 = base1+'skyimages/si2_'+swid+'_'+stri(i)+'.fits'
         if not file_test(imfile,/reg) then begin
            s1 = 'a_recon dol_shd='+shd_list(loop)+'+'+stri(i)
            s1n = 'a_recon dol_shd='+shd_name_loc+'+'+stri(i)
            s2 = ' dim_sel=0 outfile=\!'+imfile1
            ; Reserve this image file in order to avoid recalculation
            ; assuming that what is put in 'mac2' will actually be done
            ; A clean up (removal of empty files) of /r6/jemx/njw/survey/skyimages
            ; might be required from time to time

            spawn,'touch '+imfile

            ; if for njw-notebook and first time for this shd enter copy statement
            if keyword_set(note) and first then begin
               printf,lun,'cp '+shd_name_rem+' '+shd_name_loc
               first = 0
            endif
            if keyword_set(note) then begin
               printf,lun,s1n+s2
            endif else begin
               printf,lun,s1+s2
            endelse
            k = k + 1
         endif
      endif
   endfor

   if k ge maxnum then break

endfor

free_lun,lun

if k eq 0 then begin
   print,'No outstanding shadowgrams with current selection'
endif else begin
   print,k,' lines put into '''+macname+''''
endelse

end
