;
;   Main program to produce a vignetting FITS file for a_recon skyimages
;
;   2004-03-03/NJW
;
vign = readfits_keydef('/home/njw/jemx/imod_grp/jmx2_imod_grp_0034.fits', $
                   'EXTNAME','JMX2-VIGN-MOD', hdr=hdr)

crpix1 = fxpar(hdr,'crpix1')
crpix2 = fxpar(hdr,'crpix2')
cdelt1 = fxpar(hdr,'cdelt1')
cdelt2 = fxpar(hdr,'cdelt2')
crval1 = fxpar(hdr,'crval1')
crval2 = fxpar(hdr,'crval2')

local_crpix1 = 825./2
local_crpix2 = 825./2

; These values might be finetuned if the collimator
; isn't precisely aligned with the boresight

vign_arr = fltarr(825,825)

iarr = indgen(825) + 1 ;  Use FITS pixel convention
cosy_jmx = (iarr - local_crpix2) / 3107.
jpix = floor((cosy_jmx - crval2)/cdelt2 + crpix2 + 0.5) - 1 ; back to IDL convention
cosx_jmx = (iarr - local_crpix1) / 3107.
ipix = floor((cosx_jmx - crval1)/cdelt1 + crpix1 + 0.5) - 1 ; back to IDL convention

for j = 0L, 824 do begin

   for i = 0L, 824 do begin

      if ipix(i) ge 0 and ipix(i) lt 256 and $
         jpix(j) ge 0 and jpix(j) lt 256 then begin
               vign_arr(i,j) = vign(ipix(i),jpix(j))
      endif

   endfor

endfor

fits_make_prim,'a_vignetting.fits'
fxhmake_im,vhdr,vign_arr,/extend,/date
fxaddpar,vhdr,'cdelt1',(180/!pi)/3107.,'[deg] Pixel size'
fxaddpar,vhdr,'cdelt2',(180/!pi)/3107.,'[deg] Pixel size'
fxaddpar,vhdr,'crpix1',local_crpix1,'[pixel] Reference pixel'
fxaddpar,vhdr,'crpix2',local_crpix2,'[pixel] Reference pixel'
fxaddpar,vhdr,'crval1',0.,'[deg] Reference coordinate'
fxaddpar,vhdr,'crval2',0.,'[deg] Reference coordinate'


writefits,'a_vignetting.fits', vign_arr, vhdr, /append

end
