function mk_gps_sensitivity, gb_max, gl_lim1, gl_lim2, inside, gl_arr, gb_arr
;
;  Return an array that displays the JEMX sensitivity
;
;  All is in galactic coordinates (degrees)
;
;  gl_arr and gb_arr are the pointings
;
;  It is assumed that  0 <= gl_lim1 < gl_lim2
;
if n_params() lt 6 then begin
   print,$
  'Syntax: imarr = mk_gps_sensitivity( gb_max, gl_lim1, gl_lim2, inside, gl_arr, gb_arr)'
   return,-1
endif


pixel_size_init = 0.4 ; deg
gl_size = gl_lim2 - gl_lim1
if not inside then gl_size = 360. - gl_size

nxpix = fix(gl_size/pixel_size_init + 0.5)
pixel_size_x = gl_size / nxpix
nypix = fix(2.*gb_max/pixel_size_init + 0.5)
pixel_size_y = 2.*gb_max / nypix

imarr = fltarr(nxpix, nypix) + 9999.  ;  Sensitivity array, expressed in mCrab
n_pointings = n_elements(gl_arr)

for ypix = 0, nypix-1 do begin
for xpix = 0, nxpix-1 do begin
   if inside then x = gl_lim2 - xpix*pixel_size_x else x = gl_lim1 - xpix*pixel_size_x
   y = -gb_max + ypix*pixel_size_y
   for k = 0, n_pointings - 1 do begin
      dist = arcdist(gl_arr(k),gb_arr(k),x,y,/deg)
      sensitivity = exp(1.805 + 0.01697*dist^3)
      imarr(xpix,ypix) = 1./sqrt(imarr(xpix,ypix)^(-2) + sensitivity^(-2))
   endfor
endfor
endfor

return, imarr

end

