pro mk_jiir_fits_source_cat, srcl_res_list, cat_name, chatter=chatter
;
; Extract information from SRCL-RES files and organize in a FITS file
;
;   2005-05-24/NJW  Cloned from mk_issw_fits_cat.pro
;
if n_params() lt 2 then begin
   print,'Syntax: mk_jiir_fits_source_cat, srcl_res_list, cat_name[,chatter=]'
   print,' ''srcl_res_list'' is an IDL string array and it must contain'
   print,'  full paths to the SRCL-RES files'
   return
endif

if not keyword_set(chatter) then chatter = 0

nlist = n_elements(srcl_res_list)

cursize = 500
ra_out = fltarr(cursize)
dec_out = fltarr(cursize)
swid_out = strarr(cursize)
detsig_out = fltarr(cursize)
err_rad_out = fltarr(cursize)
name_out = strarr(cursize)
offaxis_out = fltarr(cursize)
azimuth_out = fltarr(cursize)
flux_out = fltarr(16,cursize)
flux_err_out = fltarr(16,cursize)
e_min_out = fltarr(16,cursize)
e_max_out = fltarr(16,cursize)
exposure_out = fltarr(cursize)
ebin_num_out = intarr(cursize)
jemx_num_out = intarr(cursize)
cosy_jmx_out = fltarr(cursize)
cosz_jmx_out = fltarr(cursize)


nsources = 0L
kount = 0L
for loop = 0L, nlist-1 do begin
   ; Get detected sources
   ; 1) see if there are any at all
   hdr = headfits(srcl_res_list(loop),ext=1)
   naxis2 = fxpar(hdr,'NAXIS2')
   exposure = fxpar(hdr,'EXPOSURE')
   deadc = fxpar(hdr,'DEADC')  ; get applied correction factor
   instrume = stri(fxpar(hdr,'INSTRUME',count=n_instrume))
   ebin_num = fxpar(hdr,'EBIN_NUM',count=n_ebin_num)
   swid = fxpar(hdr,'SWID')
   if chatter gt 3 then begin
      print,'File: '+srcl_res_list(loop)
      print,'NAXIS2 = ', naxis2,', EXPOSURE = ',exposure,', DEADC = ', deadc
      print,'INSTRUME = ', instrume,', EBIN_NUM = ',ebin_num,', SWID = ', swid
   endif
   nsources = nsources + naxis2
   if naxis2 gt 0 then begin
      rdfitscol,srcl_res_list(loop)+'+1',name,'NAME'
      rdfitscol,srcl_res_list(loop)+'+1',ra,'RA_OBJ',/sil
      rdfitscol,srcl_res_list(loop)+'+1',dec,'DEC_OBJ',/sil
      rdfitscol,srcl_res_list(loop)+'+1',e_min,'E_MIN',/sil
      rdfitscol,srcl_res_list(loop)+'+1',e_max,'E_MAX',/sil
      rdfitscol,srcl_res_list(loop)+'+1',flux,'FLUX',/sil
      rdfitscol,srcl_res_list(loop)+'+1',flux_err,'FLUX_ERR',/sil
      rdfitscol,srcl_res_list(loop)+'+1',detsig,'DETSIG',/sil
      rdfitscol,srcl_res_list(loop)+'+1',err_rad,'ERR_RAD',/sil
      rdfitscol,srcl_res_list(loop)+'+1',cosy_jmx,'COSY_JMX',/sil
      rdfitscol,srcl_res_list(loop)+'+1',cosz_jmx,'COSZ_JMX',/sil
      off_axis = sqrt(cosy_jmx^2 + cosz_jmx^2) * 180./!pi
      azi_muth = zero2pi(atan(cosz_jmx, cosy_jmx)) * 180./!pi

      for i = 0, naxis2-1 do begin

         ; expand arrays when required
         if kount eq cursize then begin
            cursize = cursize + 500
            expand_array, ra_out, cursize, 2
            expand_array, dec_out, cursize, 2
            expand_array, swid_out, cursize, 2
            expand_array, name_out, cursize, 2
            expand_array, offaxis_out, cursize, 2
            expand_array, azimuth_out, cursize, 2
            expand_array, detsig_out, cursize, 2
            expand_array, err_rad_out, cursize, 2
            expand_array, flux_out, cursize, 2
            expand_array, flux_err_out, cursize, 2
            expand_array, e_min_out, cursize, 2
            expand_array, e_max_out, cursize, 2
            expand_array, exposure_out, cursize, 2
            expand_array, jemx_num_out, cursize, 2
            expand_array, ebin_num_out, cursize, 2
            expand_array, cosy_jmx_out, cursize, 2
            expand_array, cosz_jmx_out, cursize, 2
         endif
         ra_out(kount) = ra(i)
         dec_out(kount) = dec(i)
         swid_out(kount) = swid
         name_out(kount) = name(i)
         offaxis_out(kount) = off_axis(i)
         azimuth_out(kount) = azi_muth(i)
         cosy_jmx_out(kount) = cosy_jmx(i)
         cosz_jmx_out(kount) = cosz_jmx(i)
         detsig_out(kount) = detsig(i)
         err_rad_out(kount) = err_rad(i)
         exposure_out(kount) = exposure
         if instrume eq 'JMX1' then jemx_num_out(kount) = 1 else jemx_num_out(kount) = 2
         ebin_num_out(kount) = ebin_num
         for ie = 0, ebin_num-1 do begin
            flux_out(ie,kount) = flux(ie,i)
            flux_err_out(ie,kount) = flux_err(ie,i)
            e_min_out(ie,kount) = e_min(ie,i)
            e_max_out(ie,kount) = e_max(ie,i)
         endfor
         kount = kount + 1

      endfor

   endif
endfor

if kount eq 0 then begin
   print,'Sorry, no sources found in your selection'
   return
endif

; Shrink arrays to actually used size

ra_out = ra_out(0:kount-1)
dec_out = dec_out(0:kount-1)
detsig_out = detsig_out(0:kount-1)
err_rad_out = err_rad_out(0:kount-1)
swid_out = swid_out(0:kount-1)
name_out = name_out(0:kount-1)
offaxis_out = offaxis_out(0:kount-1)
azimuth_out = azimuth_out(0:kount-1)
cosy_jmx_out = cosy_jmx_out(0:kount-1)
cosz_jmx_out = cosz_jmx_out(0:kount-1)
flux_out = flux_out(*,0:kount-1)
flux_err_out = flux_err_out(*,0:kount-1)
e_min_out = e_min_out(*,0:kount-1)
e_max_out = e_max_out(*,0:kount-1)
exposure_out = exposure_out(0:kount-1)
jemx_num_out = jemx_num_out(0:kount-1)
ebin_num_out = ebin_num_out(0:kount-1)

wrmfitscols, cat_name, $
      'SWID',swid_out, $
      'NAME',name_out,$
      'RA_OBJ',ra_out, $
      'DEC_OBJ',dec_out, $
      'DETSIG',detsig_out, $
      'ERR_RAD',err_rad_out, $
      'OFFAXIS',offaxis_out, $
      'AZIMUTH',azimuth_out, $
      'FLUX',flux_out, $
      'FLUX_ERR',flux_err_out, $
      'E_MIN',e_min_out, $
      'E_MAX',e_max_out, $
      'EXPOSURE',exposure_out, $
      'EBIN_NUM',ebin_num_out, $
      'JEMX_NUM',jemx_num_out, $
      'IMGX',cosy_jmx_out*2291.8302 + 255.0, $
      'IMGY',cosz_jmx_out*2291.8302 + 255.0

      ; 60./(0.0174533 * 1.5) = 2291.8302


end
