pro mk_mplusbt, outfile, arr, xtab, ytab, ztab
;
;  Write a matrix to a FITS file together with tables
;  for the coordinate axes as FITS binary table extensions
;
;  The number of extension depends upon the number of
;  dimenstions of 'arr' and the number of parameters
;
;   Call    :    outfile     filename for new FITS file
;                arr         data array
;                xtab        table with 1. axis coordinates
;                ytab        table with 2. axis coordinates
;              [ ztab        table with 3. axis coordinates]

;... Check the parameter consistency

sz = size(arr)
np = n_params()
if np eq 0 then begin
   print,'mk_mplusbt,outfile,arr,xtab,ytab[,ztab]'
   retall
endif
if sz(0) lt 2 or sz(0) gt 3 then begin
   print,'MK_MPLUSBT input error: The data array must be 2D or 3D'
   retall
endif
if np ne sz(0)+2 then begin
   print,'MK_MPLUSBT input error: The dimensionality of the'
   print,'  data array ('+strtrim(sz(0),2)+') does not match'$
       + ' the number of tables ('+strtrim(np-2,2)+')'
   retall
endif

nx = n_elements(xtab)
if sz(1) ne nx then begin
   print,'MK_MPLUSBT input error: The data array 1. dimension ('$
        +strtrim(sz(1),2)+') does'
   print,'           not match the length of ''xtab'' ('$
        +strtrim(nx,2)+')'
   retall
endif

ny = n_elements(ytab)
if sz(2) ne ny then begin
   print,'MK_MPLUSBT input error: The data array 2. dimension ('$
        +strtrim(sz(2),2)+') does'
   print,'           not match the length of ''ytab'' ('$
        +strtrim(ny,2)+')'
   retall
endif
if sz(0) eq 3 then begin
   nz = n_elements(ztab)
   if sz(3) ne nz then begin
      print,'MK_MPLUSBT input error: The data array 3. dimension ('$
           +strtrim(sz(3),2)+') does'
      print,'           not match the length of ''ztab'' ('$
           +strtrim(nz,2)+')'
      retall
   endif
endif

; Make primary header:

fxhmake, hdr, arr
fxaddpar, hdr,'EXTEND','T','Extensions will exist'

; Write data to file

fxwrite,outfile, hdr, arr

; Start defining binary extension #1:

; Make basic extension header:

fxbhmake, xhdr, nx, 'xtable'

; Define data type

fxbaddcol,index,xhdr,xtab(0),'XVALUE','Comment'

; Put header at end of file:

fxbcreate,unit,outfile,xhdr

; Write the column to the file

for j = 0, nx-1 do begin
   fxbwrite,unit,xtab(j),index,j+1
endfor

;... and close the file

fxbfinish,unit

;... Repeat procedure for ytab

; Start defining binary extension #2:

; Make basic extension header:

fxbhmake, xhdr, ny, 'ytable'

; Define data type

fxbaddcol,index,xhdr,ytab(0),'YVALUE','Comment'

; Put header at end of file:

fxbcreate,unit,outfile,xhdr

; Write the column to the file

for j = 0, ny-1 do begin
   fxbwrite,unit,ytab(j),index,j+1
endfor

if sz(0) eq 3 then begin

   ;... Repeat procedure for ztab

   ; Start defining binary extension #3:

   ; Make basic extension header:

   fxbhmake, xhdr, nz, 'ztable'

   ; Define data type

   fxbaddcol,index,xhdr,ztab(0),'ZVALUE','Comment'

   ; Put header at end of file:

   fxbcreate,unit,outfile,xhdr

   ; Write the column to the file

   for j = 0, nz-1 do begin
      fxbwrite,unit,ztab(j),index,j+1
   endfor

endif

;... and close the file

fxbfinish,unit
end

