pro mk_sfres_batch, help=help, maxnum=maxnum, rev=rev
;
;  Make list of all tar files in /r6/jemx/njw/survey/sfres
;  Get list of survey SWIDs
;  If not, then add to to-do list
;
;  Keywords:    maxnum - stops when this number is exceeded
;               rev    - selected revolution number
;               help   - prints help on screen
;
;  2004-03-10/NJW
;

if keyword_set(help) then begin
   print,'mk_sfres_batch, /help, maxnum=,rev='
   print,'  maxnum : Maximum number of SWIDs in ''mac4'''
   print,'  rev    : Specifies revolution number (integer or 4-digit string)'
   print,'  Help   : Prints help on screen'
   return
endif

base = '/r6/jemx/njw/survey/'
basel = '/r6/jemx/pointings/'
if 'njw-notebook' eq getenv('HOSTNAME') then begin
   base = '/mnt/win_f'+base
   basel = '/mnt/win_f'+basel
endif

selstr = ''
if keyword_set(rev) then begin
   revstr = string(fix(rev),format='(i4.4)')
   selstr = revstr
endif

sfres_list = file_search(base+'sfres/'+selstr+'*tar',/test_reg,count=n_sfres_list)

if not keyword_set(maxnum) then maxnum = 32767

; Get list of survey SWIDs

swid_pv = read_slist(basel+'swids_of_group_pv.list')
; avoid the ones before revolution 6
for j = 1,5 do begin
   rev_pv = strmid(swid_pv,0,4)
   jstr = string(j,format='(i4.4)')
   w = where( rev_pv ne jstr, nw )
   if nw gt 0 then swid_pv = swid_pv(w)
endfor
   
swid_sv = read_slist(basel+'swids_of_group_survey.list')
swid_v = [swid_pv, swid_sv]

pick_swid_str, sfres_list, swid_sfres

if keyword_set(rev) then begin

   ; Extract the ones that comply with keyword 'rev'

   rev_v = strmid(swid_v,0,4)

   w = where(rev_v eq revstr, nw)

   if nw eq 0 then begin
      print,'No SWIDs in survey from revolution '+revstr
      return
   endif else print,stri(nw)+' SWIDs existing in pv/survey'

   swid_v = swid_v(w)

endif

; Filter out the 'done' ones

swid_todo = filter_done( swid_sfres, swid_v )

n_swid_todo = n_elements(swid_todo)

if n_swid_todo eq 0 then begin
   if keyword_set(rev) then begin
      print,'The job is done for revolution '+revstr+', none left do do!'
      return
   endif else begin
      print,'The job is done, none left do do!'
      return
   endelse
endif

n = maxnum
if n_swid_todo lt maxnum then n = n_swid_todo

; Make file with batch of SWIDs

write_slist, 'sfres_batch.list', swid_todo(0:n-1)

print,'sfres_batch.list has been created with '+stri(n)+' entries'

; Create ghost files assuming that the ones listed will be done

for i = 0, n-1 do spawn,'touch '+base+'sfres/'+swid_todo(i)+'.tar'


end
