pro mk_unique_issw_cat, njmx, ecode, chat=chat
;
;  Make the 'unique catalog' /home/njw/jemx/survey/j{1/2}surcat4_unique_{ecode}.fits
;  where a source only appears once from the 'j{1/2}surcat4_{ecode}.fits' catalogue
;
;  2004-03-29/NJW  Cloned from /home/njw/jemx/jmx_src_cat/mk_unique_cat.pro
;  2004-09-24/NJW  Updated for 'j{1/2}surcat4'
;
;  Define structure to hold all source information
;
;
if n_params() lt 2 then begin
   print,'Syntax: mk_unique_issw_cat, njmx, ecode[,chat=]'
   return
endif

estr = stri(ecode)
jstr = 'j'+stri(njmx)

max_num_entries = 100000L
max_num_findings = 2000

if not keyword_set(chat) then chat = 3

logfile = get_next_filename('log???')
openw,lun,logfile,/get_lun

bascat = '/home/njw/jemx/survey/'
if !version.os eq 'linux' then begin
   if getenv('HOST') ne 'lin6' then bascat = '/mnt/win_f'+bascat
endif
dol_surcat4_n = bascat+jstr+'surcat4_'+estr+'.fits[1]'

printf,lun,'JCAT: ', dol_surcat4_n


; Read the contents of 'j{1/2}surcat4_n.fits'

errmsg = ''
print,'Reading '+dol_surcat4_n+' ...'
rdfitscol,dol_surcat4_n,swid,'SWID',err=errmsg,/sil
rdfitscol,dol_surcat4_n,name,'NAME',err=errmsg,/sil
rdfitscol,dol_surcat4_n,ra_obj,'RA_OBJ',err=errmsg,/sil
rdfitscol,dol_surcat4_n,dec_obj,'DEC_OBJ',err=errmsg,/sil
rdfitscol,dol_surcat4_n,ncounts,'NCOUNTS',err=errmsg,/sil
rdfitscol,dol_surcat4_n,peaksize,'PEAKSIZE',err=errmsg,/sil
rdfitscol,dol_surcat4_n,detsig,'DETSIG',err=errmsg,/sil
rdfitscol,dol_surcat4_n,offaxis,'OFFAXIS',err=errmsg,/sil

; Avoid negative DETSIG

detsig = detsig > 0.01

if errmsg ne '' then begin
   print,errmsg
   return
endif

num_entries_cat = n_elements(ra_obj)
if chat gt 2 then print,'##0## num_entries_cat = ', num_entries_cat
printf,lun,'num_entries_cat = ', num_entries_cat
ismarked = intarr(num_entries_cat)


; Define names for the unique catalog

if !version.os eq 'linux' then begin
   dol_unique_cat = '/mnt/win_f/r6/jemx/catalogs/surcat4_unique_'+estr+'.fits[1]'
endif
if !version.os eq 'sunos' then begin
   dol_unique_cat = '/home/njw/jemx/survey/'+jstr+'surcat4_unique_'+estr+'.fits[1]'
endif
get_exten_no, dol_unique_cat, file_unique_cat, extuc
printf,lun,'DOL Unique cat: ', dol_unique_cat
printf,lun,'File Unique cat: ', file_unique_cat


; Read the contents of the DSRI_CAT

if !version.os eq 'linux' then begin
   dol_dsri_cat = '/mnt/win_f/r6/jemx/catalogs/DSRI_CAT_002.fits+1'
endif
if !version.os eq 'sunos' then begin
   dol_dsri_cat = '/r6/jemx/catalogs/DSRI_CAT_002.fits+1'
endif
printf,lun,'DOL DSRI cat: ', dol_dsri_cat

rdfitscol,dol_dsri_cat,srcname_dsri,'SOURCENAME',/sil,nrows=n_dc
rdfitscol,dol_dsri_cat,ra_obj_dsri,'RA',/sil
rdfitscol,dol_dsri_cat,dec_obj_dsri,'DEC',/sil
rdfitscol,dol_dsri_cat,category_dsri,'CATEGORY',/sil

; Read the contents of the ISDC reference catalog

if !version.os eq 'linux' then begin
   dol_isdc_cat = '/mnt/win_f/r6/jemx/catalogs/gnrl_refr_cat_0014.fits+1'
endif
if !version.os eq 'sunos' then begin
   dol_isdc_cat = '/r6/jemx/catalogs/gnrl_refr_cat_0014.fits+1'
endif
printf,lun,'DOL ISDC cat: ', dol_isdc_cat
rdfitscol,dol_isdc_cat,source_id_isdc,'SOURCE_ID',/sil,nrows=n_ic
rdfitscol,dol_isdc_cat,name_isdc,'NAME',/sil
rdfitscol,dol_isdc_cat,ra_obj_isdc,'RA_OBJ',/sil
rdfitscol,dol_isdc_cat,dec_obj_isdc,'DEC_OBJ',/sil

; Read the contents of the NL combined catalog

if !version.os eq 'linux' then begin
   dol_nlcomb_cat = '/mnt/win_f/r6/jemx/catalogs/cat_combine_02.fits+1'
endif
if !version.os eq 'sunos' then begin
   dol_nlcomb_cat = '/r6/jemx/catalogs/cat_combine_02.fits+1'
endif
printf,lun,'DOL nlcomb cat: ', dol_nlcomb_cat
rdfitscol,dol_nlcomb_cat,name_nlcomb,'SOURCENAME',/sil,nrows=n_nlc
rdfitscol,dol_nlcomb_cat,ra_obj_nlcomb,'RA',/sil
rdfitscol,dol_nlcomb_cat,dec_obj_nlcomb,'DEC',/sil

;  Prepare arrays for saving unique data

ra_obj_uniq = fltarr(max_num_entries)
dec_obj_uniq = fltarr(max_num_entries)
srcname1_uniq = strarr(max_num_entries)
srcname2_uniq = strarr(max_num_entries)
srcname3_uniq = strarr(max_num_entries)
srcid_uniq = strarr(max_num_entries)
pos_list_int = lonarr(max_num_entries)
len_list_int = lonarr(max_num_entries)

list_int = lonarr(num_entries_cat)
list_uno = lonarr(num_entries_cat)

;  Walk through JEMX catalog sources


num = num_entries_cat
ra = ra_obj
dec = dec_obj

cur = 0L
uniq_no = 0L
ans = ''
dum = where( ismarked eq 0, num ) ; Get number of unmarked findings

while num gt 0 do begin

   uniq_no = uniq_no + 1L

   if uniq_no eq max_num_entries then begin
      print,'More unique sources than allowed for! Terminate.'
      return
   endif

   ; Find the 'findings' that can be identified with current one

   r = arcdist(ra(cur), dec(cur), ra, dec, /deg)
   w = where( r le 0.05 and ismarked eq 0, n_w)
   m = where( r gt 0.05 or  ismarked eq 1, n_m)
   bestpos = [ra(cur), dec(cur)]

   if chat gt 4 then print,'uniq_no = ', uniq_no,' 1. n_w = ', n_w

   if n_w eq 0 then begin
      print,'Mark ##1##'
      print,'cur = ',cur,' uniq_no = ', uniq_no
      print,'n_w = ', n_w,'  n_m = ', n_m
      goto, faultexit
   endif

   if n_w gt 1 then begin ; Try to iterate if it makes sense

      repeat begin  ; See if better position will change selection

         w_previous = w

         weight = detsig(w)
         if max(weight) le 0.0 then begin
            weight = replicate(1., n_w)
            print,'DETSIG problem with input source cur = ', cur
            print,'                and  uniq_no = ', uniq_no
            printf,lun,'DETSIG problem with input source cur = ', cur
            printf,lun,'                and  uniq_no = ', uniq_no
         endif

         bestpos = best_skypos( ra(w), dec(w), weight )

         r = arcdist( bestpos(0), bestpos(1), ra, dec, /deg )
         w = where( r le 0.05 and ismarked eq 0, n_w)
         m = where( r gt 0.05 or  ismarked eq 1, n_m)

         if chat gt 4 then print,'uniq_no = ', uniq_no,' 2. n_w = ', n_w

         if n_w eq 0 then begin
            print,'Mark ##2##'
            print,'cur = ',cur,' uniq_no = ', uniq_no
            print,'n_w = ', n_w,'  n_m = ', n_m
            goto, faultexit
         endif

      endrep until cmparr(w, w_previous) eq 0

   endif

   ; Now we have a new unique source

   list_uno(w) = uniq_no

   ; Save values to storage arrays

   ra_obj_uniq(uniq_no-1) = bestpos(0)
   dec_obj_uniq(uniq_no-1) = bestpos(1)
   len_list_int(uniq_no-1) = n_w
   if uniq_no eq 1 then begin
      pos_list_int(uniq_no-1) = 0
   endif else begin
      pos_list_int(uniq_no-1) = pos_list_int(uniq_no-2) $
	   + len_list_int(uniq_no-2)
   endelse
   list_int(pos_list_int(uniq_no-1):$
	   pos_list_int(uniq_no-1)+n_w-1) = w

   ; Try to identify in DSRI catalog
   
   r = arcdist(ra(cur), dec(cur), ra_obj_dsri, dec_obj_dsri,/deg)
   near = sort(r)
   if r(near(0)) lt 0.05 then begin
	   srcname1 = srcname_dsri(near(0))
   endif else begin
	   srcname1 = 'not in DSRI cat'
   endelse


   ; Try to identify in ISDC gnrl_refr catalog
   
   r = arcdist(ra(cur), dec(cur), ra_obj_isdc, dec_obj_isdc,/deg)
   near = sort(r)
   if r(near(0)) lt 0.05 then begin
	   srcname2 = name_isdc(near(0))
	   srcid = source_id_isdc(near(0))
   endif else begin
	   srcname2 = 'not in ISDC cat'
	   srcid = 'not in ISDC cat'
   endelse


   ; Try to identify in NL combine catalog
   
   r = arcdist(ra(cur), dec(cur), ra_obj_nlcomb, dec_obj_nlcomb,/deg)
   near = sort(r)
   if r(near(0)) lt 0.05 then begin
	   srcname3 = name_nlcomb(near(0))
   endif else begin
	   srcname3 = 'not in NLCOMB cat'
   endelse

   srcname1_uniq(uniq_no-1) = srcname1
   srcname2_uniq(uniq_no-1) = srcname2
   srcname3_uniq(uniq_no-1) = srcname3
   srcid_uniq(uniq_no-1) = srcid


   ;  Mark the findings now treated

   ismarked(w) = 1

   ;  Find next unmarked finding

   dum = where( ismarked eq 0, num ) ; Get number of unmarked findings
   if num gt 0 then begin
	   while ismarked(cur) eq 1 do cur = cur + 1
   endif

   if chat gt 4 then print,'num = ', num,'   cur for next loop = ', cur

endwhile


; Remove old version of unique catalog

if file_test(file_unique_cat,/reg) then spawn,'\rm '+file_unique_cat

; Create empty unique catalog FITS file

fxhmake, phdr, /init, /exten
a = 1
writefits,file_unique_cat,a, phdr

s20 = '01234567890123456789'
fxbhmake, uchdr, uniq_no, /init
fxbaddcol, 1, uchdr, 0.0, 'RA_OBJ'
fxbaddcol, 2, uchdr, 0.0, 'DEC_OBJ'
fxbaddcol, 3, uchdr, s20, 'SRCNAME1'
fxbaddcol, 4, uchdr, s20, 'SRCNAME2'
fxbaddcol, 5, uchdr, s20, 'SRCNAME3'
fxbaddcol, 6, uchdr, s20, 'SOURCE_ID'
fxbaddcol, 7, uchdr, 0L, 'NUMFIND'
fxbaddcol, 8, uchdr, lonarr(max_num_findings), 'LIST_INT',/var

fxaddpar,uchdr,'EXTNAME','JMX_UNIQ_ISSW_CAT','JEM-X ISSW catalog of sources'
fxaddpar,uchdr,'DATE',systime(),'Date of creation'
fxaddpar,uchdr,'ORIGIN','/home/njw/jemx/survey/mk_unique_issw_cat.pro','made this'
fxaddpar,uchdr,'RESPONSI','Niels J. Westergaard, DSRI','Programmer'

fxbcreate,uunit, file_unique_cat, uchdr

;  Fill up the file with values

for i = 0L, uniq_no-1 do begin
   fxbwrite,uunit, ra_obj_uniq(i), 1, i+1
   fxbwrite,uunit, dec_obj_uniq(i), 2, i+1
   fxbwrite, uunit, srcname1_uniq(i), 3, i+1
   fxbwrite, uunit, srcname2_uniq(i), 4, i+1
   fxbwrite, uunit, srcname3_uniq(i), 5, i+1
   fxbwrite, uunit, srcid_uniq(i), 6, i+1
   fxbwrite, uunit, len_list_int(i), 7, i+1
   p = pos_list_int(i)
   l = len_list_int(i)
   if l gt max_num_findings then begin
      print,'List exceed for i = ', i,' l = ', l
      l = max_num_findings
   endif
   fxbwrite, uunit, list_int(p:p+l-1), 8, i+1
endfor

fxbfinish, uunit

print
print,'  Log file : ', logfile
print

goto, normalexit

faultexit:

   print,'Faulty exit NB NB NB !!!'

normalexit:


print,'Closing log file'
free_lun,lun

end
