pro mk_unique_jiir_cat, dol_in_cat, file_unique_cat, clog=clog, chat=chat, accrad=accrad
;
;  Make the 'unique catalog' from catalog generated by 'mk_jiir_fits_source_cat'
;  where a source only appears once
;
;  2005-06-08/NJW  Cloned from /home/njw/0idl/proc/mk_unique_issw_cat.pro
;  2005-10-28/NJW  Updated with column 'NAME' in stead of 'SRCNAME' and
;                  extra column 'ERR_RAD'
;  2006-01-13/NJW  Only assign the source name after final positions has been found
;                  and introduce proper definition of the error radius (err_rad)
;                  based on err_rad from input catalog
;
;
if n_params() lt 2 then begin
   print,'Syntax: mk_unique_jiir_cat, dol_in_cat, file_unique_cat[,chat=][,accrad=]'
   print,'     Keyword      chat    : level of chattiness, 1 - 5'
   print,'                  accrad  : acceptance radius in degrees (default 0.07)'
   return
endif

version = 3 ;   NB: remember to update this value
verdate = '2006-01-13'

max_num_entries = 100000L
max_num_findings = 2000

accept_radius = 0.07
if keyword_set(accrad) then accept_radius = accrad

if not keyword_set(chat) then chat = 3

logfile = get_next_filename('mujc_???.txt')
openw,log,logfile,/get_lun



; Read the contents of the input catalog

errmsg = ''
print,'Reading '+dol_in_cat
printf,log,'Input catlog: '+fullpath(dol_in_cat)
rdfitscol,dol_in_cat,swid,'SWID',err=errmsg,/sil
rdfitscol,dol_in_cat,name,'NAME',err=errmsg,/sil
rdfitscol,dol_in_cat,ra_obj,'RA_OBJ',err=errmsg,/sil
rdfitscol,dol_in_cat,dec_obj,'DEC_OBJ',err=errmsg,/sil
rdfitscol,dol_in_cat,detsig,'DETSIG',err=errmsg,/sil
rdfitscol,dol_in_cat,err_rad,'ERR_RAD',err=errmsg,/sil

;* rdfitscol,dol_in_cat,offaxis,'OFFAXIS',err=errmsg,/sil
;* rdfitscol,dol_in_cat,flux,'FLUX',err=errmsg,/sil
;* rdfitscol,dol_in_cat,flux_err,'FLUX_ERR',err=errmsg,/sil
;* rdfitscol,dol_in_cat,e_min,'E_MIN',err=errmsg,/sil
;* rdfitscol,dol_in_cat,e_max,'E_MAX',err=errmsg,/sil
;* rdfitscol,dol_in_cat,exposure,'EXPOSURE',err=errmsg,/sil
;* rdfitscol,dol_in_cat,ebin_num,'EBIN_NUM',err=errmsg,/sil
;* rdfitscol,dol_in_cat,jemx_num,'JEMX_NUM',err=errmsg,/sil

; Avoid negative DETSIG

w = where( detsig lt 0.01, nw )
if nw gt 0 then begin
   print,'Warning: '+stri(nw)+' DETSIG values smaller than 0.01 exist'
   print,'  The value of those is reset to 0.01'
   printf,log,'Warning: '+stri(nw)+' DETSIG values smaller than 0.01 exist'
   printf,log,'  The value of those is reset to 0.01'
endif
detsig = detsig > 0.01

if errmsg ne '' then begin
   print,errmsg
   printf,log,errmsg
   free_lun, log
   return
endif

num_entries_cat = n_elements(ra_obj)
if chat gt 2 then print,'##0## num_entries_cat = ', num_entries_cat
printf,log,'Number of rows: ', stri(num_entries_cat)
ismarked = intarr(num_entries_cat)


; Define DOL and filename for the unique catalog

dol_unique_cat = file_unique_cat+'+1'

printf,log,'DOL of output Unique cat: ', fullpath(dol_unique_cat)
printf,log,'Filename of output Unique cat: ', fullpath(file_unique_cat)


;  Prepare arrays for saving unique data

ra_obj_uniq = fltarr(max_num_entries)
dec_obj_uniq = fltarr(max_num_entries)
srcname_uniq = strarr(max_num_entries)
detsig_uniq = fltarr(max_num_entries)
err_rad_uniq = fltarr(max_num_entries)
pos_list_int = lonarr(max_num_entries)
len_list_int = lonarr(max_num_entries)

list_int = lonarr(num_entries_cat)
list_uno = lonarr(num_entries_cat)

;  Walk through the input catalog sources


num = num_entries_cat
ra = ra_obj
dec = dec_obj

cur = 0L
uniq_no = 0L
ans = ''
dum = where( ismarked eq 0, num ) ; Get number of unmarked findings

while num gt 0 do begin

   uniq_no = uniq_no + 1L

   if uniq_no eq max_num_entries then begin
      print,'More unique sources than allowed for! Terminate.'
      printf,log,'More unique sources than allowed for! Terminate.'
      free_lun, log
      return
   endif

   ; Find the 'findings' that can be identified with current one

   r = arcdist(ra(cur), dec(cur), ra, dec, /deg)
   w = where( r le accept_radius and ismarked eq 0, n_w, $
         complement=m, ncompl=n_m)
   ;* m = where( r gt accept_radius or  ismarked eq 1, n_m)
   bestpos = [ra(cur), dec(cur)]
   ;* srcname = name(cur)
   weight = fltarr(n_w) + 1./n_w ; initial definition

   if chat gt 4 then begin
      print,' ----------  Begin with uniq_no = '+stri(uniq_no)+' ---------'
      print,'     Initial  n_w = '+stri(n_w)
      print,'     Working with unmarked finding cur:  '+stri(cur)
      printf,log,' ----------  Begin with uniq_no = '+stri(uniq_no)+' ---------'
      printf,log,'     Initial  n_w = '+stri(n_w)
      printf,log,'     Working with unmarked finding cur:  '+stri(cur)
   endif

   if n_w eq 0 then begin
      print,'Error ##1##, n_w == 0, cur = '+stri(cur)+' uniq_no = '+stri(uniq_no)
      print,'n_w = ', n_w,'  n_m = ', n_m
      printf,log,'Error ##1##, n_w == 0, cur = '+stri(cur)+' uniq_no = '+stri(uniq_no)
      printf,log,'n_w = ', n_w,'  n_m = ', n_m
      goto, faultexit
   endif

   if n_w gt 1 then begin ; Try to iterate if it makes sense

      repeat begin  ; See if better position will change selection

         w_previous = w

         weight = detsig(w)
         if max(weight) le 0.0 then begin
            weight = replicate(1., n_w)
            print,'DETSIG problem with input source cur = ', cur
            print,'                and  uniq_no = ', uniq_no
            printf,log,'DETSIG problem with input source cur = ', cur
            printf,log,'                and  uniq_no = ', uniq_no
         endif

         ; normalize 'weight'
         weight = weight / total(weight)

         bestpos = best_skypos( ra(w), dec(w), weight )

         r = arcdist( bestpos(0), bestpos(1), ra, dec, /deg )
         w = where( r le accept_radius and ismarked eq 0, n_w, $
                complement=m, ncompl=n_m )
         ;* m = where( r gt accept_radius or  ismarked eq 1, n_m)

         if chat gt 4 then print,'uniq_no = ', uniq_no,' 2. n_w = ', n_w

         if n_w eq 0 then begin
            print,'Mark ##2##'
            print,'cur = ',cur,' uniq_no = ', uniq_no
            print,'n_w = ', n_w,'  n_m = ', n_m
            goto, faultexit
         endif

      endrep until cmparr(w, w_previous) eq 0

   endif

   ; Now we have a new unique source

   if chat gt 4 then begin
      printf,log,' New unique source, uniq_no: '+stri(uniq_no)
      printf,log,' Number of contributions (n_w) is ', n_w
      printf,log,' Number of contributions (n_elements(w)) is ', n_elements(w)
      printf,log,' bestpos: ', bestpos(0), bestpos(1)
   endif

   list_uno(w) = uniq_no

   ; Save values to storage arrays

   ra_obj_uniq(uniq_no-1) = bestpos(0)
   dec_obj_uniq(uniq_no-1) = bestpos(1)
   detsig_uniq(uniq_no-1) = max(detsig(w))
   if chat gt 4 then printf,log,' detsig: ', max(detsig(w))
   len_list_int(uniq_no-1) = n_w
   if uniq_no eq 1 then begin
      pos_list_int(uniq_no-1) = 0
   endif else begin
      pos_list_int(uniq_no-1) = pos_list_int(uniq_no-2) $
	   + len_list_int(uniq_no-2)
   endelse
   list_int(pos_list_int(uniq_no-1):$
	   pos_list_int(uniq_no-1)+n_w-1) = w

   ; Get sourcename from standard X-ray source catalog or 
   ;     from the chosen one

   res = nearest_source( bestpos(0), bestpos(1), 0.1, clog=clog )
   if res(0) eq '?' then res(0) = 'NEW SOURCE'
   srcname_uniq(uniq_no-1) = res(0)
   if chat gt 4 then printf,log,' name: '+res(0)

   ;  Define the position error

   var_err_rad = total( (weight*err_rad(w))^2 )
   syst_err_rad = 2.778e-3 ; degrees = 10 arcsec
   err_rad_uniq(uniq_no-1) = sqrt( var_err_rad + syst_err_rad^2 )
   if chat gt 4 then begin
      nweight = n_elements(w)
      printf,log,' n_elements(weight): ', n_elements(w)
      for k = 0, (5 < nweight) - 1 do begin
         printf,log,'         weight('+stri(k)+') = ', weight(k)
      endfor
      printf,log,' var_err_rad: ', var_err_rad
      printf,log,' err_rad_uniq: ', sqrt( var_err_rad + syst_err_rad^2 )
   endif

   ;  Mark the findings now treated

   ismarked(w) = 1

   ;  Find next unmarked finding

   dum = where( ismarked eq 0, num ) ; Get number of unmarked findings
   if num gt 0 then begin
	   while ismarked(cur) eq 1 do cur = cur + 1
   endif

   if chat gt 4 then begin
      print,'num = ', num,'   cur for next loop = ', cur
      printf,log,'num = ', num,'   cur for next loop = ', cur
   endif

endwhile


; Remove old version of unique catalog

if file_test(file_unique_cat,/reg) then spawn,'\rm '+file_unique_cat

; Create empty unique catalog FITS file

fxhmake, phdr, /init, /exten
a = 1
writefits,file_unique_cat,a, phdr

s20 = '01234567890123456789'
fxbhmake, uchdr, uniq_no, /init
fxbaddcol, 1, uchdr, 0.0, 'RA_OBJ'
fxbaddcol, 2, uchdr, 0.0, 'DEC_OBJ'
fxbaddcol, 3, uchdr, s20, 'NAME'
fxbaddcol, 4, uchdr, 0.0, 'DETSIG'
fxbaddcol, 5, uchdr, 0.0, 'ERR_RAD'
fxbaddcol, 6, uchdr, 0L, 'NUMFIND'
fxbaddcol, 7, uchdr, lonarr(max_num_findings), 'LIST_INT',/var

fxaddpar,uchdr,'EXTNAME','JMX_UNIQ_JIIR_CAT','JEM-X JIIR catalog of sources'
fxaddpar,uchdr,'DATE',systime(),'Date of creation'
fxaddpar,uchdr,'ORIGIN','/home/njw/jemx/survey/mk_unique_jiir_cat.pro','made this'
fxaddpar,uchdr,'VERSION',version,'Version of generating program'
fxaddpar,uchdr,'VERDATE',verdate,'Date of this version'
fxaddpar,uchdr,'RESPONSI','Niels J. Westergaard, DNSC','Programmer and responsible'
fxaddpar,uchdr,'INPUTCAT', fullpath(dol_in_cat),'Input catalog'

fxbcreate,uunit, file_unique_cat, uchdr

;  Fill up the file with values

for i = 0L, uniq_no-1 do begin
   fxbwrite,uunit, ra_obj_uniq(i), 1, i+1
   fxbwrite,uunit, dec_obj_uniq(i), 2, i+1
   fxbwrite, uunit, srcname_uniq(i), 3, i+1
   fxbwrite,uunit, detsig_uniq(i), 4, i+1
   fxbwrite,uunit, err_rad_uniq(i), 5, i+1
   fxbwrite, uunit, len_list_int(i), 6, i+1
   p = pos_list_int(i)
   l = len_list_int(i)
   if l gt max_num_findings then begin
      print,'List exceed for i = ', i,' l = ', l
      l = max_num_findings
   endif
   fxbwrite, uunit, list_int(p:p+l-1), 7, i+1
endfor

fxbfinish, uunit

print
print,'  Log file : ', logfile
print

goto, normalexit

faultexit:

   print,'Faulty exit NB NB NB !!!'

normalexit:


print,'Closing log file'
free_lun,log

end
