function mnbrak, ax, bx, cx, fa, fb, fc, func=func
;
; same subroutine in 'Numerical Recipes' section 10.1
;
if not keyword_set(func) then begin
   print,'MNBRAK error, function name is missing'
endif
gold = 1.618034
glimit = 100.
tiny = 1.e-19
fa = call_function(func, ax)
fb = call_function(func, bx)
if fb gt fa then begin
   dum = ax
   ax = bx
   bx = dum
   dum = fb
   fb = fa
   fa = dum
endif

cx = bx + gold * (bx - ax)
fc = call_function(func, cx)

while               ; grand while loop starts
wloop:   if fb ge fc then begin
      r = (bx - ax) * (fb - fc)
      q = (bx - cx) * (fb - fa)
      div = max([abs(q-r),tiny])
      if r gt q then div = -div
      u = bx - ((bx-cx)*q-(bx-ax)*r)/(2.*div)
      ulim = bx + glimit*(cx - bx)
      if (bx-u)*(u-cx) gt 0 then begin
         fu = call_function(func, u)
         if fu lt fc then begin
            ax = bx
            fa = fb
            bx = u
            fb = fu
            goto, wloop
         endif else if fu gt fb then begin
            cx = u
            fc = fu
            goto, wloop
         endelse
         u = cx + gold*(cx-bx)
         fu = call_function(func, u)
      endif else if (cx-u)*(u-ulim) gt 0 then begin
         fu = call_function(func, u)
         if fu lt fc then begin
            bx = cx
            cx = u
            u = cx + gold*(cx-bx)
            fb = fc
            fc = fu
            fu = call_function(func, u)
         endif
      endelse if (u-ulim)*(ulim-cx) ge 0 then begin
         u = ulim
         fu = call_function(func, u)
      else begin
         u = cx + gold*(cx-bx)
         fu = call_function(func, u)
      endelse
      ax = bx
      bx = cx
      cx = u
      fa = fb
      fb = fc
      fc = fu
      goto,wloop
   endif
   return,[ax,bx,cx]
   end
         
end
