pro mosaic_oview,verbose=verbose,silent=silent
;
;  Show contents of various 'mosaic_???.fits' files in
; /r6/jemx/njw/mosaic
;
;   2003-09-22/NJW
;

vb =  keyword_set(verbose)

bpath = ''
if !version.os eq 'linux' then bpath = '/mnt/win_f/r6/jemx/njw/mosaic/'
if !version.os eq 'sunos' then bpath = '/r6/jemx/njw/mosaic/'

outputfile = bpath+'overview.txt'
if vb then outputfile = bpath+'overview_large.txt'
openw,lun,outputfile,/get_lun

list = file_search(bpath+'mosaic_???.fits',count=nlist)

for i = 0, nlist-1 do begin
;for i = 4, 6 do begin

   hdr = headfits(list(i),exten=1)
   com = fxpar(hdr,'COMMENT')
   nc = n_elements(com)

   printf,lun
   printf,lun,'-----------------------------'
   printf,lun,'       '+list(i)
   if not keyword_set(silent) then print,'       '+list(i)
   printf,lun
   if vb then begin
      printlf,lun,com
      if not keyword_set(silent) then printl,com
      printf,lun,'nc = ', nc
      if not keyword_set(silent) then print,'nc = ', nc
   endif

   ; Get center and diameter

   ra = fxpar(hdr,'CRVAL1')
   dec = fxpar(hdr,'CRVAL2')
   cdelt = fxpar(hdr,'CD2_2')
   naxis1 = fxpar(hdr,'NAXIS1')

   printf,lun,'          Center (RA,Dec) : ',string(ra,dec,format='(f7.2,f7.2)')
   printf,lun,'          Diameter (deg)  : ',string(naxis1*cdelt,format='(f7.2)')
   printf,lun

   first = 1

   for j = 0, nc-1 do begin

      ; see if it is CBJ or NL name style
      pos = strpos(com(j),'skyima2_')
      pos1 = strpos(com(j),'_',pos+8)
      pos2 = strpos(com(j),'_',pos1+1)
      style = -1
      if pos ge 0 and pos1 gt pos and pos2 gt pos1 then style = 0 else begin
         pos = strpos(com(j),'skyimage_')
         pos1 = strpos(com(j),'_',pos+9)
         pos2 = strpos(com(j),'_',pos1+1)
         if pos ge 0 and pos1 gt pos and pos2 gt pos1 then style = 1
      endelse
      if style eq -1 then begin
         printf,lun,'Unknown naming convention of ingoing files'
         goto, next_file
      endif
   
      if style eq 0 then begin
         posf = strpos(com(j),'.fits',/reverse_search)
         pidstr_nl = strmid(com(j),posf-4,4)
         revstr    = strmid(com(j),posf-9,4)
         e_codestr = strmid(com(j),posf-11,1)
         pid = fix(pidstr_nl)/10
      endif else begin
         posf = strpos(com(j),'.fits',/reverse_search)
         e_codestr = strmid(com(j),posf-1,1)
         posp =  strpos(com(j),'_',posf-3,/reverse_search)
         pidstr = strmid(com(j),posp+1,posf-posp-3)
         posr = strpos(com(j),'_',posp-1,/reverse_search)
         revstr = strmid(com(j),posr+1,posp-posr-1)
         pid = fix(pidstr)
      endelse
      rev = fix(revstr)
      e_code = fix(e_codestr)
   
      if first then begin
   
         revarr = [rev]
         pidarr = [pid]
         stylearr = [style]
         e_codearr = [e_code]
         first = 0
   
      endif else begin
   
         revarr = [revarr,rev]
         pidarr = [pidarr,pid]
         stylearr = [stylearr,style]
         e_codearr = [e_codearr,e_code]
   
      endelse
   
   endfor
   
   ; Find the energy intervals present

   e_codearr = e_codearr(sort(e_codearr))
   e_present = e_codearr(uniq(e_codearr))
   e_present_str = ''
   n_e = n_elements(e_present)
   for ii = 0, n_e-1 do e_present_str = e_present_str+' '+stri(e_present(ii))

   ; Split into subarrays - one per revolution number
   is = sort(revarr)
   revarr = revarr(is)
   pidarr = pidarr(is)
   stylearr = stylearr(is)

   u_rev = uniq(revarr)
   n_rev = n_elements(u_rev)

   for m = 0, n_rev-1 do begin

      w = where(revarr eq revarr(u_rev(m)), nw)
      revarr_sub = revarr(w)
      pidarr_sub = pidarr(w)
      stylearr_sub = stylearr(w)

      if n_e eq 1 then $
         printf,lun,'Rev '+stri(revarr_sub(0))+'    Energy band '+e_present_str else $
         printf,lun,'Rev '+stri(revarr_sub(0))+'    Energy bands '+e_present_str
      is = sort(pidarr_sub)
      nn = (nw-1)/10 + 1
      for k = 0, nn-1 do begin
         s = ''
         for l = 0, (9 < (nw-1)) do s = s+stri(pidarr_sub(is(l+k*10)))+' '
         nw = nw - 10
         printf,lun,'PIDs : ', s
      endfor
      if style eq 1 then printf,lun,'CBJ images' else printf,lun, 'NL images'
   endfor

   next_file:

endfor

free_lun, lun

; Change permissions in created file

spawn,'chmod 664 '+outputfile

end
