pro mosaic_view, h=h, imlist=imlist
;
;  A procedure to show pointing directions for a
;  number of FITS images
;
;  If keywords 'imlist' has been defined then the input
;  files will be taken from that, else an interactive
;  dialog will be startet
;
;
;  2003-09-18/NJW
;
if keyword_set(h) then begin
   print,'Syntax: mosaic_view[, imlist=]'
   return
endif

if keyword_set(imlist) then begin
   image_list = imlist
endif else begin
   image_list = dialog_pickfile(path='/r6/jemx/cbj/jmx2_images/0100', $
           filter='*.fits',/multiple_files)
   image_list = image_list+'+1'
   printl,image_list
   answer = ''
   read,'Continue ? ... ', answer
   if answer ne 'y' and answer ne '' then return
endelse
nlist = n_elements(image_list)

dr = !pi / 180

diameter = 15. ; degrees

; Walk through list to extract basic information

k = 0
for i = 0, nlist-1 do begin
   get_exten_no, image_list(i), filename, extno
   l = file_search(filename,/test_reg,count=nl)
   if nl ne 1 then begin
      print,'File '+filename+' is missing, skip and continue'
      continue
   endif
   hdr = headfits(filename,ext=extno)
   sz = size(hdr)
   if sz(sz(0)+1) ne 7 then begin
      print,'Header of '+image_list(i)+' not retrievable'
      continue
   endif
   if k eq 0 then begin
      filelist = [filename]
      extlist = [extno]
      crval1 = [fxpar(hdr,'crval1')]
      crval2 = [fxpar(hdr,'crval2')]
      crpix1 = [fxpar(hdr,'crpix1')]
      crpix2 = [fxpar(hdr,'crpix2')]
      cd1_1 = [fxpar(hdr,'cd1_1')]
      cd1_2 = [fxpar(hdr,'cd1_2')]
      cd2_1 = [fxpar(hdr,'cd2_1')]
      cd2_2 = [fxpar(hdr,'cd2_2')]
   endif else begin
      filelist = [filelist,filename]
      extlist = [extlist,extno]
      crval1 = [crval1,fxpar(hdr,'crval1')]
      crval2 = [crval2,fxpar(hdr,'crval2')]
      crpix1 = [crpix1,fxpar(hdr,'crpix1')]
      crpix2 = [crpix2,fxpar(hdr,'crpix2')]
      cd1_1 = [cd1_1,fxpar(hdr,'cd1_1')]
      cd1_2 = [cd1_2,fxpar(hdr,'cd1_2')]
      cd2_1 = [cd2_1,fxpar(hdr,'cd2_1')]
      cd2_2 = [cd2_2,fxpar(hdr,'cd2_2')]
   endelse
   k = k + 1
endfor

for i = 0, k-1 do begin
   print,'crval: ', crval1(i), crval2(i)
   ;print,'crpix: ', crpix1(i), crpix2(i)
   ;print,'cd1_1 cd1_2: ', cd1_1(i), cd1_2(i)
   ;print,'cd2_1 cd2_2: ', cd2_1(i), cd2_2(i)
endfor

avg_crval1 = avg(crval1)
avg_crval2 = avg(crval2)

print,'Center for output image: ', avg_crval1, avg_crval2

cent_dist = arcdist( crval1, crval2, avg_crval1, avg_crval2, /deg)

plot,crval1,crval2,ps=2

end
