pro nearby_sources, ra_in, dc_in, radius, force=force, clog=clog, $
                    silent=silent, nof=nof
;
;
;  NJW/000802, copied from plot0082.pro
;    updated NJW/010125 with general common setup
;
;    2003-10-24/NJW Updated VERSION 1.2 Ordered in increasing distance
;    2005-11-09/NJW Updated VERSION 2.0 Compatible with read_catalog version 2
;    2006-01-12/NJW Updated VERSION 2.1 Included use of 'cat_com_update'
;    2006-12-12/NJW Updated VERSION 2.2 Make rad_min and rad_max possible
;    2006-12-20/NJW Updated VERSION 2.3 Keywords silent and nof
;
;  Output list of sources within the radius from RA=ra and DEC=dec
;        (both in decimal degrees)
;  The output goes to the screen and to 'near_srcs_nnnn.dat'
;
;  Keyword  force:   Force reading the catalog contents
;           clog :   The DOL of the catalogue
;

common cat_com_v2, cat, num_entries_cat, dol_of_cat

source = {   name:'', ra_obj:0.0, dec_obj:0.0, spe_modl:'', $
             spe_npar:0, spe_pars:fltarr(10), $
             intens:0.0, category:'', catalogue:'' }

if n_params() lt 3 then begin
   print,'Syntax: NEARBY_SOURCES, ra, dec, radius, force=,clog='
   print,'         Unit is decimal degrees (ra/dc maybe given in (string) HMS,DMS)'
   print,'         radius can be a 2 element array with rad_min, rad_max
   print,'   Keywords:'
   print,'         Set /force if catalog has changed'
   print,'         Define catalog by clog= (DOL[incl ext_no])'
   print,'         Suppress extra info by /silent'
   print,'         Suppress output to file by /nof (no file)'
   return
endif

nrad = n_elements(radius)
if nrad ne 1 and nrad ne 2 then begin
   print,'Bad format of radius argument'
   return
endif
szra = size(ra_in)
szdc = size(dc_in)
if szra(0) ne 0 or szdc(0) ne 0 then begin
   print,'Input coordinate must be scalar'
   return
endif
if szra(1) eq 7 then begin
   if szdc(1) eq 7 then begin  ; Coordinate given in HMS/DMS
      stringad, ra_in+' '+dc_in, ra, dc  ; Convert to decimal degrees
   endif else begin
      print,'Both input coordinates must be strings'
      return
   endelse
endif else begin
   if szdc(1) eq 7 then begin
      print,'Both input coordinates must be decimal degrees'
      return
   endif
   ra = ra_in
   dc = dc_in
endelse

; Keyword silent

if not keyword_set(silent) then vb = 1 else vb = 0

; Keyword nof (no file)

if not keyword_set(nof) then nof = 0

; Read catalog if requested or different from already existing

cat_com_update, clog=clog, force=force

if not nof then begin
   outname = get_next_filename('near_srcs_????.dat')
   openw,lout,outname,/get_lun
   printf,lout,'//                  '+systime()
   printf,lout,'//  Results from IDL procedure nearby_sources.pro'
   printf,lout,'//  Using '+ dol_of_cat
   printf,lout,'//'
   printf,lout,'// Column 1:  Row number'
   printf,lout,'// Column 2:  Source name'
   printf,lout,'// Column 3:  Source category'
   printf,lout,'// Column 4:  RA(2000) in degrees'
   printf,lout,'// Column 5:  DEC(2000) in degrees'
   printf,lout,'// Column 6:  Distance [degrees]'
   printf,lout,'//'
   printf,lout,'// ra_cen = ', ra
   printf,lout,'// dc_cen = ', dc
   if nrad eq 1 then begin
      printf,lout,'// radius = ', radius
   endif else begin
      printf,lout,'// radius_min = ', radius(0)
      printf,lout,'// radius_max = ', radius(1)
   endelse
   printf,lout,'//'
endif


ra_cen = ra
dc_cen = dc


if vb then begin
   print
   print,'Using: ',dol_of_cat
   if not nof then print,'Output to: ',outname
   print
endif

dist = arcdist(cat.ra_obj,cat.dec_obj,ra_cen,dc_cen,/deg)
if nrad eq 1 then begin
   selection = where( dist lt radius, n_selection)
   if n_selection eq 0 then begin
      print,'No sources inside circle'
      return
   endif
endif else begin
   selection = where( dist lt radius(1) and dist gt radius(0), n_selection)
   if n_selection eq 0 then begin
      print,'No sources inside annulus'
      return
   endif
endelse
rownum = selection + 1 ; Start counting with 1
dist = dist(selection)
scat = cat(selection)

w = sort(dist)
dist = dist(w)
scat = scat(w)
rownum = rownum(w)

name = scat.name
ra = scat.ra_obj
dec = scat.dec_obj
category = scat.category

n = n_selection

; prepare writing found sources to file

for i = 0, n_selection-1 do begin
   print,name(i),ra(i),dec(i),$
         format='(a20,f10.4,f10.4)'
   strdist = string(dist(i)*60,format='(f7.1)')
   ;* print,'    Distance:'+strdist+' arcmin,   HMS/DMS position:   ', $
   ;*          adstring(ra(i),dec(i))
   print,'    Distance:'+strdist+' arcmin'
   if not nof then begin
      name_a = strtrim(name(i),2)
      name_a = strcharrepl(name_a, ' ', '~')
      printf,lout,rownum(i),name_a,category(i),ra(i),$
               dec(i),dist(i),$
               format='(i6,x,a20,3x,a8,f10.5,f10.5,f7.3)'
   endif
endfor

if not nof then free_lun,lout

end
