function nearest_source, ra_in, dc_in, radius, force=force, clog=clog
;
;
;  2003-03-28/NJW, copied from 'nearby_sources'
;  2005-10-20/NJW updated to use /r6/jemx/catalogs/gnrl_refr_cat_latest.fits+1
;                           in stead of ./DSRI_CAT_002.fits+1
;
;   Returns string array with source name, RA_cat, DEC_cat, category, and distance [deg]
;   if there is a source within the given radius else ['?','','','','-1'] is returned
;
;  Keyword  force:   Force reading the catalog contents
;           clog :   The DOL of the catalogue
;

;common auxl_data, flux_aux, name_aux, category_aux, catalog_aux,$
;       ra_aux, dec_aux, serial_aux

common cat_com_v2, cat, num_entries_cat, dol_of_cat

; source = {   name:'', ra_obj:0.0, dec_obj:0.0, spe_modl:'', spe_npar:0, $
;              spe_pars:fltarr(10), intens:0.0, category:'', catalogue:'' }

if n_params() lt 3 then begin
   print,'Syntax: str = NEAREST_SOURCE( ra, dec, radius[,force=][,clog=])'
   print,'         Unit is decimal degrees (ra/dc maybe given in (string) HMS,DMS)'
   print,'         Set /force if catalog has changed'
   print,'         Define catalog by clog= (DOL[incl ext_no])'
   return,''
endif

szra = size(ra_in)
szdc = size(dc_in)
if szra(0) ne 0 or szdc(0) ne 0 then begin
   print,'Input coordinate must be scalar'
   return,''
endif
if szra(1) eq 7 then begin
   if szdc(1) eq 7 then begin  ; Coordinate given in HMS/DMS
      stringad, ra_in+' '+dc_in, ra, dc  ; Convert to decimal degrees
   endif else begin
      print,'Both input coordinates must be strings'
      return,''
   endelse
endif else begin
   if szdc(1) eq 7 then begin
      print,'Both input coordinates must be decimal degrees'
      return,''
   endif
   ra = ra_in
   dc = dc_in
endelse


; Read the contents of the X-ray source catalog

cat_com_update, clog=clog, force=force

ra_cen = ra
dc_cen = dc





dista = arcdist(cat.ra_obj,cat.dec_obj,ra_cen,dc_cen,/deg)
w = sort(dista)

if dista(w(0)) gt radius then begin
   return,['?','','','','-1']
endif
name = cat(w(0)).name
ra = cat(w(0)).ra_obj
dec = cat(w(0)).dec_obj
category = cat(w(0)).category

return,[stri(name),stri(ra), stri(dec), stri(category),stri(dista(w(0)))]

end
