function nfits_extens, filename
;
;  Return the highest extension number in a FITS file
;  where the PHDU has number 0 (zero)
;
;     NJW/2002-01-24
;
if n_params() lt 1 then begin
   print,'Syntax: n = nfits_extens(filename)'
   return, -1
endif

list = file_search(filename,/test_reg,count=nlist)
if nlist eq 0 then begin
   print,filename+' does not exist'
   return, -1
endif

; Is it a FITS file?

hdr = headfits(filename)

sz = size(hdr)
type = sz(sz(0)+1)

if type ne 7 or sz(0) ne 1 then begin
   print,''''+filename+''' is not a FITS file'
   return, -1
endif

if fxpar(hdr,'EXTEND') ne 1 then return, 0

; Now it has been confirmed that it is a FITS file and
; that it possibly has extension

lun = fxposit(filename,1,/read)
a = fstat(lun)
fsiz = a.size

if a.cur_ptr eq fsiz then begin
   free_lun,lun
   return, 0
endif

i = 0

repeat begin

   status = fxmove(lun,1) ; step one extension
   a = fstat(lun)
   i = i + 1

endrep until a.cur_ptr ge fsiz

free_lun, lun

return, i

end
