;
; $Id: funct.pro,v 1.1 91/03/29 12:27:44 jeffry Exp $
;
PRO	ngaussFUNCT,ngauss,X,A,F,PDER
;+
; NAME:
;	FUNCT
; PURPOSE:
;	EVALUATE THE SUM OF A GAUSSIAN AND A 2ND ORDER POLYNOMIAL
;	AND OPTIONALLY RETURN THE VALUE OF IT'S PARTIAL DERIVATIVES.
;	NORMALLY, THIS FUNCTION IS USED BY CURVEFIT TO FIT THE
;	SUM OF A LINE AND A VARYING BACKGROUND TO ACTUAL DATA.
;
; CATEGORY:
;	E2 - CURVE AND SURFACE FITTING.
; CALLING SEQUENCE:
;	FUNCT,X,A,F,PDER
; INPUTS:
;       NGAUSS=NUMBER OF GAUSS FUNCTIONS 
;	X = VALUES OF INDEPENDENT VARIABLE.
;	A = PARAMETERS OF EQUATION DESCRIBED BELOW.
; OUTPUTS:
;	F = VALUE OF FUNCTION AT EACH X(I).
;
; OPTIONAL OUTPUT PARAMETERS:
;	PDER = (N_ELEMENTS(X),6) ARRAY CONTAINING THE
;		PARTIAL DERIVATIVES.  P(I,J) = DERIVATIVE
;		AT ITH POINT W/RESPECT TO JTH PARAMETER.
; COMMON BLOCKS:
;	NONE.
; SIDE EFFECTS:
;	NONE.
; RESTRICTIONS:
;	NONE.
; PROCEDURE:
;	F = A(0)*EXP(-Z^2/2) + A(3) + A(4)*X + A(5)*X^2
;	Z = (X-A(1))/A(2)
; MODIFICATION HISTORY:
;	WRITTEN, DMS, RSI, SEPT, 1982.
;-
	ON_ERROR,2                        ;Return to caller if an error occurs

        F=x*0.0 
        FOR NG=0,NGAUSS-1,1 DO BEGIN
        NGP=3*NG  
	Z = (X-A(NGP+1))/A(NGP+2)	;GET Z
	EZ = EXP(-Z^2/2.)*(ABS(Z) LE 7.) ;GAUSSIAN PART IGNORE SMALL TERMS
	F = F+A(NGP+0)*EZ
        ENDFOR
        NPOL=3*NGAUSS  
        F=F+ A(NPOL) + A(NPOL+1)*X + A(NPOL+2)*X^2 ;FUNCTIONS.
	IF N_PARAMS(0) LE 3 THEN RETURN ;NEED PARTIAL?
;
	PDER = FLTARR(N_ELEMENTS(X),3*NGAUSS+3) ;YES, MAKE ARRAY.
        FOR NG=0,NGAUSS-1,1 DO BEGIN
        NGP=3*NG
        Z=(X-A(NGP+1))/A(NGP+2)
        EZ=EXP(-Z^2/2.)*(ABS(Z) LE 7.)  
	PDER(0,NGP) = EZ		;COMPUTE PARTIALS
	PDER(0,NGP+1) = A(NGP) * EZ * Z/A(NGP+2)
	PDER(0,NGP+2) = PDER(*,NGP+1) * Z
        ENDFOR
        NPOL=3*NGAUSS 
	PDER(*,NPOL) = 1.
	PDER(0,NPOL+1) = X
	PDER(0,NPOL+2) = X^2
	RETURN
END
