pro odataplot, x, y, dy, psym=psym, $
     xbar=xbar, fxbar=fxbar, itype=itype, _extra=e
;
; Plot of datapoints with 'errorbars' in x-direction defined
; by channel limits derived from spacing between points.
; In the y-direction the length of the error bars are given by '+-dy'
; In the x-direction bars only appear if keyword 'xbar' has been
; specified
;
; The type of plot is indicated with the keyword 'itype'
;   itype = 0  :    x lin - y lin (default)
;   itype = 1  :    x lin - y log
;   itype = 2  :    x log - y lin
;   itype = 3  :    x log - y log
;
;   ~1995/NJW
;   2004-09-28/NJW  Updated with better error message
;   2005-05-27/NJW  Included keyword 'fxbar': fixed x-bar
;   2005-07-28/NJW  Special situation with only one point
;
if( n_params() ne 3 ) then begin
   print,'Syntax: odataplot, x, y, dy[, psym=] $'
   print,'    [,/xbar][,fxbar=][, itype=]'
   return
endif
nx = n_elements(x)
if( (nx ne n_elements(y)) or (nx ne n_elements(dy)) ) then begin
  print,'DATAPLOT error: The arrays have different dimensions !'
  return
endif

; Define the plot type (lin-lin, lin-log, log-lin, log-log)

it = 0
if keyword_set(itype) then it = itype
xlog = 0
ylog = 0
if it gt 1 then xlog = 1
if (it mod 2) eq 1 then ylog = 1

; Define boundaries between abscissa values
;   but only if there are two or more points

nx = n_elements(x)
if nx gt 1 then begin
   sx = shift(x,1)
   sxl = fltarr(nx+1)
   if xlog then begin
      sx = sqrt(x*sx)
      sxl(0:nx-1) = sx
      sxl(0) = sqrt(x(0)^3 / x(1))
      sxl(nx) = sqrt(x(nx-1)^3 / x(nx-2))
   endif else begin
      sx = 0.5*(x + sx)
      sxl(0:nx-1) = sx
      sxl(0) = (3*x(0) - x(1))*0.5
      sxl(nx) = (3*x(nx-1) - x(nx-2))*0.5
   endelse
endif

; plot first horizontal piece
if keyword_set(xbar) and nx gt 1 then oplot,sxl(0:1),[y(0),y(0)],_extra=e
; plot first vertical piece
oplot,[x(0),x(0)],[y(0)-dy(0),y(0)+dy(0)],_extra=e
for i = 1L, nx do begin
  ;  horizontal pieces (only if requested)
  if keyword_set(xbar) and nx gt 1 then $
          oplot,sxl(i-1:i),[y(i-1),y(i-1)],_extra=e
  ; vertical pieces
  oplot,[x(i-1),x(i-1)],[y(i-1)-dy(i-1),y(i-1)+dy(i-1)],_extra=e
endfor

; Plot fixed horizontal piece if requested

if keyword_set(fxbar) then begin
   for i = 0, nx-1 do begin
      oplot,[x(i)-fxbar,x(i)+fxbar],[y(i),y(i)],_extra=e
   endfor
endif

if keyword_set(psym) then oplot,x,y,psym=psym,_extra=e

end
