pro oplot_spectrum, eb1, eb2, rate_array, err_array, $
      perkev=perkev, _extra=e
;
;   2005-12-21/NJW, cloned from plot_spectrum
;
;   Plot one or more spectra as cnt/keV/s
;
;  eb1 : lower energy boundaries
;  eb2 : upper energy boundaries
;  rate_array : counts per channel per s
;  err_array : error in counts per channel per s
;
;  Several spectra can be given; then dimensions are: (nchan, nspectra)
;
;  Keywords:   perkev     set if rate and error are given as /keV/s
;
;   
;

if n_params() lt 4 then begin
   print,'Syntax: plot_spectrum, eb1, eb2, rate_array, err_array, $'
   print,'            [itype=][,/perkev]'
   return
endif

sz = size(rate_array)
sze = size(err_array)
if sz(0) ne 2 and sz(0) ne 1 then begin
   print,'OPLOT_SPECTRUM: The spectral array has bad dimensions'
   return
endif

if sz(0) ne sze(0) or sz(1) ne sze(1) or sz(2) ne sze(2) then begin
   print,'OPLOT_SPECTRUM: Mismatch of dimensions in rate and err arrays'
   return
end


if n_elements(eb1) ne n_elements(eb2) then begin
   print,'The channel boundary arrays have different number of elements'
   return
endif

if sz(0) eq 2 then begin
   nchan = sz(1)
   nspec = sz(2)
endif else begin
   nchan = sz(1)
   nspec = 1
endelse

if n_elements(eb1) ne nchan then begin
   print,'The number of channel boundaries does not match spectral array'
   return
endif

spec = rate_array
erra = err_array
if not keyword_set(perkev) then begin
   for i = 0, nspec-1 do begin
      spec(*,i) = rate_array(*,i) / (eb2 - eb1)
      erra(*,i) = err_array(*,i) / (eb2 - eb1)
   endfor
endif

ymax = max(spec+erra)
aux = spec - erra
ymin = min(aux(where(aux gt 0)))

if eb1(0) le 0.0 then eb = 0.5*(eb1 + eb2) else eb = sqrt(eb1*eb2)

for i = 0, nspec-1 do begin

   y1 = spec(*,i) - erra(*,i)
   y2 = spec(*,i) + erra(*,i)
   y = spec(*,i)

   odataplotf,eb1,eb,eb2,y1,y,y2,_extra=e

endfor


end
