function plane_fit, array, select=select
;
; Makes a plane fit to the 2D array 'array' using indices as
; coordinates
;
; If a selection of elements are to be used in the fit,
; then the keyword 'select' with index array (result of where ?)
; can be introduced
;
; Returns the fit in a DOUBLE array of same size as 'array'
;
;--- Make arrays of indices
;
sz = size(array)
xi = dblarr(sz(1),sz(2))
yj = dblarr(sz(1),sz(2))
x = double(indgen(sz(1)))
y = double(indgen(sz(2)))
for j = 0,sz(2)-1 do xi(*,j) = x
for i = 0,sz(1)-1 do yj(i,*) = y

;--- Setup coefficient matrices

om  = dblarr(3,3)
rhs = dblarr(3)
fit = dblarr(sz(1),sz(2))

if keyword_set(select) then begin
   xisel = xi(select)
   yjsel = yj(select)
   arraysel = array(select)
   nsel = n_elements(select)
endif else begin
   xisel = xi
   yjsel = yj
   arraysel = array
   nsel = sz(4)
endelse
om(0,0) = total(xisel*xisel)
om(0,1) = total(xisel*yjsel)
om(0,2) = total(xisel)
rhs(0)  = total(xisel*arraysel)

om(1,0) = om(0,1)
om(1,1) = total(yjsel*yjsel)
om(1,2) = total(yjsel)
rhs(1)  = total(yjsel*arraysel)

om(2,0) = om(0,2)
om(2,1) = om(1,2)
om(2,2) = nsel
rhs(2)  = total(arraysel)

;--- Invert the matrix to solve 3 equations

res = invert(om) # rhs

;--- Construct the return array with the best fitting plane

for i = 0, sz(1)-1 do begin
   for j = 0, sz(2)-1 do begin
      fit(i,j) = res(0)*i + res(1)*j + res(2)
   endfor
endfor

return, fit

end
