pro plint_ghist, gain_hist_file
;
;   2005-09-01/NJW
;
;   "Prepare gain history index table for linear interpolation"
;
if n_params() lt 1 then begin
   print,'Syntax: plint_ghist, gain_hist_file'
   return
endif

if not file_test(gain_hist_file,/reg) then begin
   print,gain_hist_file+' does not exist'
   return
endif

; Make a backup to begin with

print
print,'Starting '+gain_hist_file
print
answer = ''
read,'Do you want to make a backup ? ... ', answer
if strmid(strupcase(answer),0,1) eq 'Y' then spawn,'back '+gain_hist_file

rdfitscol,gain_hist_file+'+1',tstart,'tstart',/sil,nrows=nrows
rdfitscol,gain_hist_file+'+1',tstop,'tstop',/sil
rdfitscol,gain_hist_file+'+1',pkchan_1,'pkchan_1',/sil
rdfitscol,gain_hist_file+'+1',pkchan_2,'pkchan_2',/sil
rdfitscol,gain_hist_file+'+1',pkchan_3,'pkchan_3',/sil
rdfitscol,gain_hist_file+'+1',pkchan_4,'pkchan_4',/sil
time = 0.5*(tstart+tstop)
pk = fltarr(4,nrows)
pk(0,*) = pkchan_1
pk(1,*) = pkchan_2
pk(2,*) = pkchan_3
pk(3,*) = pkchan_4

makewin,0,xs=800,ys=500
makewin,1

for chan = 0, 3 do begin

   yrg = [min(pk(chan,*)),max(pk(chan,*))]
   yrg = [yrg(0),yrg(1)+0.2*(yrg(1)-yrg(0))] ; extend by 20%

   ; If not first channel then see if previous curve is good enough

   enter_points = 1
   if chan gt 0 then begin
      p = reform(pk(chan,*),n_elements(pk(chan,*)))
      w = where(p gt 0.0)
      factor = total(p(w)*res(w)) / total(res(w)^2)
      wset,0
      plot,time,p,ps=1,symsize=0.4,yr=yrg
      oplot,time,res*factor
      answer = ''
      read,'Can you accept this ? ... ', answer
      if strmid(strupcase(answer),0,1) eq 'Y' then begin
         res = res * factor
         enter_points = 0
      endif
   endif

   if enter_points then begin

      ; Divide into sections for higher precision
      
      i1 = 0
      i2 = (i1 + 300) < (nrows-1)
      
      first = 1
      while i1 lt nrows-1 do begin
         sec = indgen(i2-i1+1) + i1
         wset,1
         plot,time,pk(chan,*),ps=1,symsize=0.3,yr=yrg
         oplot,time(i1)*[1,1],[min(pk(chan,*)),max(pk(chan,*))]
         oplot,time(i2)*[1,1],[min(pk(chan,*)),max(pk(chan,*))]
         xyouts,0.2,0.8,'CHAN '+stri(chan+1),/norm,charsize=2
         wset,0
         plot,time(sec),pk(chan,sec),ps=1,symsize=0.7,yr=yrg
         if i1 gt 0 then oplot,xv,yv,thick=2

         i1 = (i1 + 200) < (nrows-1)
         i2 = (i1 + 300) < (nrows-1)

         oplot,time(i1)*[1,1],yrg,li=2

         curmark,mrk,col=255
         x = reform(mrk(0,*),n_elements(mrk(0,*)))
         y = reform(mrk(1,*),n_elements(mrk(1,*)))
         if first then begin
            xv = x
            yv = y
            first = 0
         endif else begin
            xv = [xv, x]
            yv = [yv, y]
         endelse
         oplot,x,y,thick=2
      
      endwhile
         
      is = sort(xv)
      xv = xv(is)
      yv = yv(is)
   
      res = float(interpol(yv,xv,time))

   endif

   ; repeat plot to make sure

   plot,time,pk(chan,*),ps=1,symsize=0.5,yr=yrg
   oplot,time,res,thick=3
   answer = ''
   read,stri(chan+1)+': Save this ? ... ', answer
   if strmid(strupcase(answer),0,1) eq 'Y' then begin
      colname = 'PKCHAN_'+stri(chan+1)
      print,'Substituting '+colname+' ...'
      fits_replace_col, gain_hist_file+'+1',colname,res
   endif

endfor

end
