pro plofitsky, imdol, ticklen=ticklen, chsiz=chsiz, title=title, $
     decstep=decstep, rastep=rastep, tickcol=tickcol, cut=cut, usecut=usecut
;
;  Plot FITS sky image
;
;   2004-04-01/NJW
;

; setup common to remember the cut from one run to the next
; (set the cut while plot device is 'x' and save for PS plot)

common image_cut, image_cut_low, image_cut_high
common pfs_image_info, imheader

if n_params() lt 1 then begin
print,'Syntax: plofitsky, imdol[,ticklen=][,chsiz=][,title=]$'
print,'            [,decstep=][,rastep=][,tickcol=][,/cut][,/usecut]'
print,'Keywords:'
print,'           ticklen      Length of tickmarks in normalized coords (e.g. 0.03)'
print,'           chsiz        Character size of coordinate markings (e.g. 0.9 PS, 1.4 X)'
print,'           title        Written above image'
print,'           decstep      Step between declination tickmarks in (integer) degrees'
print,'           rastep       Step between Right Ascension tickmarks in (integer) degrees'
print,'           tickcol      Color of tickmarks'
print,'           cut          If set an interactive process for defining image cuts is started'
print,'           usecut       Uses the previously defined image cut values'
return
endif


if not keyword_set(decstep) then decstep = 2.0
if not keyword_set(rastep) then rastep = 2.0

if not keyword_set(chsiz) then chsiz = 1.2

if not keyword_set(tickcol) then tickcol = 0

chat = 5

d_std = xlingen(fix(180.01/decstep)-1,-90.+decstep,90.-decstep)
a_std = xlingen(fix(720.01/rastep)+1,0.,720.)
a_stq = a_std
w = where( a_std ge 360., nw)
if nw gt 0 then a_stq(w) = a_stq(w) - 360.

get_exten_no, imdol, imfile, extno
im = readfits(imfile,imhdr,exten=extno)
imheader = imhdr  ; store in common area
ima = im
w = wherenan( im, nw)
if nw gt 0 then ima(w) = 0.0

if !d.name ne 'PS' and keyword_set(cut) then begin
set_cut,ima,cut_low,cut_high
image_cut_low = cut_low
image_cut_high = cut_high
ima = (ima > image_cut_low) < image_cut_high
endif

if keyword_set(usecut) then begin
szc = size(image_cut_low)
iscut = szc(0)+szc(1)
if iscut ne 0 then ima = (ima > image_cut_low) < image_cut_high $
else print,'Warning: no cut exists in common'
endif

imsz = size(ima)

xdim = imsz(1)
ydim = imsz(2)
aspect = (ydim*1.0)/xdim

if not keyword_set(ticklen) then ticklen = 0.03

ticpixx = fix(ydim * ticklen)
ticpixy = fix(xdim * ticklen)

;
; Fix dimension of plot window in x-direction:
;
;    xs = factor * xdim / (!p.position(2) - !p.position(0))
; => factor = xs * (!p.position(2) - !p.position(0)) / xdim
;
;    ys = factor * ydim / (!p.position(3) - !p.position(1))
;  or
;    ys = xs * (ydim/xdim) * (!p.position(2) - !p.position(0)) / (!p.position(3) - !p.position(1))
;
;  in order to maintain the aspect ratio on the display
;
if !d.name eq 'PS' then begin
plsz = 16.
cheight = 0.02 * chsiz
titchsiz = 1.2
endif else begin
plsz = 800
cheight = 0.01 * chsiz
titchsiz = 2.0
endelse

xsz = plsz

!p.position = [0.05,0.05,0.95,0.95]
if keyword_set(title) then !p.position = [0.05,0.05,0.95,0.90]

plot,[0,1],/nodata,xsty=5,ysty=21

dxnorm = !p.position(2) - !p.position(0)
dynorm = !p.position(3) - !p.position(1)

ysz = xsz * aspect * dxnorm / dynorm

if !d.name eq 'PS' then begin
   xof = 3. + (16.-xsz)/2
   yof = 8. + (16.-ysz)/2
   device,xsize=xsz,ysize=ysz,xo=xof,yo=yof
   tvscl,congrid(ima,50*xsz*dxnorm,50*ysz*dynorm),$
   !x.window(0),!y.window(0),$
   xs=!x.window(1) - !x.window(0), $
   ys=!y.window(1) - !y.window(0), /norm
endif else begin
   window,0,xs=xsz,ys=ysz
   tvscl,congrid(ima,xsz*dxnorm,ysz*dynorm), $
   xsz*!p.position(0), ysz*!p.position(1)
endelse

plot,[0,1],/nodata,xsty=5,ysty=21,/noerase
oplot,[0,0.999,0.999,0,0],[0,0,0.999,0.999,0]
if keyword_set(title) then begin
xyouts,0.5,1.0+3.5*cheight,title,align=0.5,charsize=titchsiz
endif

skypos_fits,imhdr,1,ydim/2,r1,d1,/hdr,dir='sky',/sil
skypos_fits,imhdr,xdim,ydim/2,r2,d2,/hdr,dir='sky',/sil
diam = arcdist(r1,d1,r2,d2)

if chat gt 3 then begin
   print,'Left  RADec: ', r1,d1
   print,'Right RADec: ', r2,d2
   print,'Diameter : ', diam
endif

; Scan image for grid points

;---------------------------------------------------
; Lower horizontal axis

darr = fltarr(xdim)
dars = fltarr(xdim)
aarr = fltarr(xdim)
aars = fltarr(xdim)

for i = 0L, xdim-1 do begin
   ii = i
   x = float(ii) / (xdim-1)
   jj = 0
   y = float(jj) / (ydim-1)
   skypos_fits,imhdr,ii+1,jj+1,r,d,/hdr,dir='sky',/sil
   darr(i) = d
   aarr(i) = r
   jj = ticpixx - 1
   y = float(jj) / (ydim-1)
   skypos_fits,imhdr,ii+1,jj+1,r,d,/hdr,dir='sky',/sil
   dars(i) = d
   aars(i) = r
endfor

;  Remove jumps if crossing 358,359,0,1 ...

aars = remove_jump(aars, 360.)
aarr = remove_jump(aarr, 360.)

; assume that darr and dars are monotonous

; first check for declination

sel = where( d_std gt min(darr) and d_std lt max(darr) $
         and d_std gt min(dars) and d_std lt max(dars), nsel)
print,'nsel = ', nsel

if nsel gt 1 then begin

   x_out = interpol(findgen(xdim),darr,d_std(sel))
   x_in = interpol(findgen(xdim),dars,d_std(sel))

   
   i_a = -1
   if nsel ge 3 then i_a = nsel/2

   for i = 0, nsel - 1 do begin
      oplot,[x_out(i),x_in(i)]/(xdim-1),[0,float(ticpixx - 1)/(ydim-1)],$
            color=tickcol
      if i eq i_a then begin
         xyouts,x_out(i)/(xdim-1),-1.5*cheight,'Decl. '+stri(fix(d_std(sel(i)))),$
             align=0.5,charsize=chsiz
      endif else begin
         xyouts,x_out(i)/(xdim-1),-1.5*cheight,stri(fix(d_std(sel(i)))),$
             align=0.5,charsize=chsiz
      endelse
   endfor

endif else print,'Skip declination'

; then check for Right Ascension

sel = where( a_std gt min(aarr) and a_std lt max(aarr) $
         and a_std gt min(aars) and a_std lt max(aars), nsel)
print,'nsel = ', nsel

if nsel gt 1 then begin

   x_out = interpol(findgen(xdim),aarr,a_std(sel))
   x_in = interpol(findgen(xdim),aars,a_std(sel))

   i_a = -1
   if nsel ge 3 then i_a = nsel/2

   for i = 0, nsel - 1 do begin
      oplot,[x_out(i),x_in(i)]/(xdim-1),[0,float(ticpixx - 1)/(ydim-1)],$
            color=tickcol
      if i eq i_a then begin
         xyouts,x_out(i)/(xdim-1),-1.5*cheight,'R.A. '+stri(fix(a_stq(sel(i)))),$
              align=0.5,charsize=chsiz
      endif else begin
         xyouts,x_out(i)/(xdim-1),-1.5*cheight,stri(fix(a_stq(sel(i)))),$
              align=0.5,charsize=chsiz
      endelse
   endfor

endif else print,'Skip Right Ascension'

;---------------------------------------------------
; Upper horizontal axis

darr = fltarr(xdim)
dars = fltarr(xdim)
aarr = fltarr(xdim)
aars = fltarr(xdim)

for i = 0L, xdim-1 do begin
   ii = i
   x = float(ii) / (xdim-1)
   jj = ydim - 1
   y = float(jj) / (ydim-1)
   skypos_fits,imhdr,ii+1,jj+1,r,d,/hdr,dir='sky',/sil
   darr(i) = d
   aarr(i) = r
   jj = ydim - ticpixx
   y = float(jj) / (ydim-1)
   skypos_fits,imhdr,ii+1,jj+1,r,d,/hdr,dir='sky',/sil
   dars(i) = d
   aars(i) = r
endfor

;  Remove jumps if crossing 358,359,0,1 ...

aars = remove_jump(aars, 360.)
aarr = remove_jump(aarr, 360.)

; assume that darr and dars are monotonous

; first check for declination

sel = where( d_std gt min(darr) and d_std lt max(darr) $
         and d_std gt min(dars) and d_std lt max(dars), nsel)
print,'nsel = ', nsel

if nsel gt 1 then begin

   i_a = -1
   if nsel ge 3 then i_a = nsel/2

   x_out = interpol(findgen(xdim),darr,d_std(sel))
   x_in = interpol(findgen(xdim),dars,d_std(sel))

   for i = 0, nsel - 1 do begin
      oplot,[x_out(i),x_in(i)]/(xdim-1),[1,float(ydim-ticpixx)/(ydim-1)],$
            color=tickcol
      if i eq i_a then begin
         xyouts,x_out(i)/(xdim-1),1.0+0.5*cheight,'Decl. '+stri(fix(d_std(sel(i)))),$
              align=0.5,charsize=chsiz
      endif else begin
         xyouts,x_out(i)/(xdim-1),1.0+0.5*cheight,stri(fix(d_std(sel(i)))),$
              align=0.5,charsize=chsiz
      endelse
   endfor

endif else print,'Skip declination'

; then check for Right Ascension

sel = where( a_std gt min(aarr) and a_std lt max(aarr) $
         and a_std gt min(aars) and a_std lt max(aars), nsel)
print,'nsel = ', nsel

if nsel gt 1 then begin

   x_out = interpol(findgen(xdim),aarr,a_std(sel))
   x_in = interpol(findgen(xdim),aars,a_std(sel))

   i_a = -1
   if nsel ge 3 then i_a = nsel/2

   for i = 0, nsel - 1 do begin
      oplot,[x_out(i),x_in(i)]/(xdim-1),[1,float(ydim-ticpixx)/(ydim-1)],$
            color=tickcol
      if i eq i_a then begin
         xyouts,x_out(i)/(xdim-1),1.0+0.5*cheight,'R.A. '+stri(fix(a_stq(sel(i)))),$
              align=0.5,charsize=chsiz
      endif else begin
         xyouts,x_out(i)/(xdim-1),1.0+0.5*cheight,stri(fix(a_stq(sel(i)))),$
              align=0.5,charsize=chsiz
      endelse
   endfor

endif else print,'Skip Right Ascension'



;---------------------------------------------------------------------------------
; Left vertical axis

darr = fltarr(ydim)
dars = fltarr(ydim)
aarr = fltarr(ydim)
aars = fltarr(ydim)

for i = 0L, ydim-1 do begin
   jj = i
   y = float(jj) / (ydim-1)
   ii = 0
   x = float(ii) / (xdim-1)
   skypos_fits,imhdr,ii+1,jj+1,r,d,/hdr,dir='sky',/sil
   darr(i) = d
   aarr(i) = r
   ii = ticpixy - 1
   x = float(ii) / (xdim-1)
   skypos_fits,imhdr,ii+1,jj+1,r,d,/hdr,dir='sky',/sil
   dars(i) = d
   aars(i) = r
endfor

;  Remove jumps if crossing 358,359,0,1 ...

aars = remove_jump(aars, 360.)
aarr = remove_jump(aarr, 360.)


; assume that darr and dars are monotonous

; first check for declination

sel = where( d_std gt min(darr) and d_std lt max(darr) $
         and d_std gt min(dars) and d_std lt max(dars), nsel)
print,'nsel = ', nsel

if nsel gt 1 then begin

   y_out = interpol(findgen(ydim),darr,d_std(sel))
   y_in = interpol(findgen(ydim),dars,d_std(sel))

   i_a = -1
   if nsel ge 3 then i_a = nsel/2

   for i = 0, nsel - 1 do begin
      oplot,[0,float(ticpixy - 1)/(xdim-1)],[y_out(i),y_in(i)]/(ydim-1),$
            color=tickcol
      if i eq i_a then begin
         xyouts,-0.5*cheight,y_out(i)/(ydim-1),charsize=chsiz, $
            'Decl. '+stri(fix(d_std(sel(i)))),align=0.5,ori=90
      endif else begin
         xyouts,-0.5*cheight,y_out(i)/(ydim-1),charsize=chsiz, $
            stri(fix(d_std(sel(i)))),align=0.5,ori=90
      endelse
   endfor

endif else print,'Skip declination'

; then check for Right Ascension

sel = where( a_std gt min(aarr) and a_std lt max(aarr) $
         and a_std gt min(aars) and a_std lt max(aars), nsel)
print,'nsel = ', nsel

if nsel gt 1 then begin

   y_out = interpol(findgen(ydim),aarr,a_std(sel))
   y_in = interpol(findgen(ydim),aars,a_std(sel))

   i_a = -1
   if nsel ge 3 then i_a = nsel/2

   for i = 0, nsel - 1 do begin
      oplot,[0,float(ticpixy - 1)/(xdim-1)],[y_out(i),y_in(i)]/(ydim-1),$
            color=tickcol
      if i eq i_a then begin
         xyouts,-0.5*cheight,y_out(i)/(ydim-1),charsize=chsiz, $
            'R.A. '+stri(fix(a_stq(sel(i)))),align=0.5,ori=90
      endif else begin
         xyouts,-0.5*cheight,y_out(i)/(ydim-1),charsize=chsiz, $
            stri(fix(a_stq(sel(i)))),align=0.5,ori=90
      endelse
   endfor

endif else print,'Skip Right Ascension'


;---------------------------------------------------------------------------------
; Right vertical axis

darr = fltarr(ydim)
dars = fltarr(ydim)
aarr = fltarr(ydim)
aars = fltarr(ydim)

for i = 0L, ydim-1 do begin
   jj = i
   y = float(jj) / (ydim-1)
   ii = xdim - 1
   x = float(ii) / (xdim-1)
   skypos_fits,imhdr,ii+1,jj+1,r,d,/hdr,dir='sky',/sil
   darr(i) = d
   aarr(i) = r
   ii = xdim - ticpixy
   x = float(ii) / (xdim-1)
   skypos_fits,imhdr,ii+1,jj+1,r,d,/hdr,dir='sky',/sil
   dars(i) = d
   aars(i) = r
endfor

;  Remove jumps if crossing 358,359,0,1 ...

aars = remove_jump(aars, 360.)
aarr = remove_jump(aarr, 360.)


; assume that darr and dars are monotonous

; first check for declination

sel = where( d_std gt min(darr) and d_std lt max(darr) $
         and d_std gt min(dars) and d_std lt max(dars), nsel)
print,'nsel = ', nsel

if nsel gt 1 then begin

   y_out = interpol(findgen(ydim),darr,d_std(sel))
   y_in = interpol(findgen(ydim),dars,d_std(sel))

   i_a = -1
   if nsel ge 3 then i_a = nsel/2

   for i = 0, nsel - 1 do begin
      oplot,[1,float(xdim-ticpixy)/(xdim-1)],[y_out(i),y_in(i)]/(ydim-1),$
            color=tickcol
      if i eq i_a then begin
         xyouts,1.0+1.5*cheight,y_out(i)/(ydim-1),charsize=chsiz, $
            'Decl. '+stri(fix(d_std(sel(i)))),align=0.5,ori=90
      endif else begin
         xyouts,1.0+1.5*cheight,y_out(i)/(ydim-1),charsize=chsiz, $
            stri(fix(d_std(sel(i)))),align=0.5,ori=90
      endelse
   endfor

endif else print,'Skip declination'

; then check for Right Ascension

sel = where( a_std gt min(aarr) and a_std lt max(aarr) $
         and a_std gt min(aars) and a_std lt max(aars), nsel)
print,'nsel = ', nsel

if nsel gt 1 then begin

   y_out = interpol(findgen(ydim),aarr,a_std(sel))
   y_in = interpol(findgen(ydim),aars,a_std(sel))

   i_a = -1
   if nsel ge 3 then i_a = nsel/2

   for i = 0, nsel - 1 do begin
      oplot,[1,float(xdim-ticpixy)/(xdim-1)],[y_out(i),y_in(i)]/(ydim-1),$
            color=tickcol
      if i eq i_a then begin
         xyouts,1.0+1.5*cheight,y_out(i)/(ydim-1),charsize=chsiz, $
            'R.A. '+stri(fix(a_stq(sel(i)))),align=0.5,ori=90
      endif else begin
         xyouts,1.0+1.5*cheight,y_out(i)/(ydim-1),charsize=chsiz, $
            stri(fix(a_stq(sel(i)))),align=0.5,ori=90
      endelse
   endfor

endif else print,'Skip Right Ascension'



end
