pro plot0146, basdir, jemxnum,res=res
;
;   plot0146
;
;  Get list of event files and make plot of Xe line
;
if n_params() lt 2 then begin
   print,'Syntax: plot0146, basdir, jemxnum[,/res]'
   print,' Keyword ''res'' for reset i.e. re-read the data'
   return
endif

common com_plot0146, hsum, x, basdir_com, jemxnum_com

nj = stri(jemxnum)

re_read = 0
sz = size(hsum)
if sz(0)+sz(1) eq 0 then re_read = 1
sz = size(x)
if sz(0)+sz(1) eq 0 then re_read = 1
sz = size(basdir_com)
if sz(0)+sz(1) eq 0 then re_read = 1 else begin
   if basdir_com ne basdir then re_read = 1
endelse
sz = size(jemxnum_com)
if sz(0)+sz(1) eq 0 then re_read = 1 else begin
   if jemxnum_com ne jemxnum then re_read = 1
endelse
if keyword_set(res) then re_read = 1

if re_read then begin

   list = file_search(basdir,'jmx'+nj+'_full_cor.fits',count=nlist)
   
   basdir_com = basdir
   jemxnum_com = jemxnum
   minval = 6.0
   maxval = 38.0
   binsize = 0.1
   
   ; Get PI channel data
   
   rdfitscolc,'/r6/jemx/ic/imod_grp/JMX1-FBDS-MOD_001.fits+1',e_min,'E_MIN',/sil
   rdfitscolc,'/r6/jemx/ic/imod_grp/JMX1-FBDS-MOD_001.fits+1',e_max,'E_MAX',/sil
   
   for i = 0, nlist-1 do begin
   
      rdfitscol,list(i)+'+1',pi,'PI',nrows=nrows
      rdfitscol,list(i)+'+1',status,'STATUS',/sil
      rdfitscol,list(i)+'+1',detx,'DETX',/sil
      rdfitscol,list(i)+'+1',dety,'DETY',/sil
      radius = sqrt(detx^2 + dety^2)
      w = where( status le 64 and radius lt 110, nw )
      print,i,nrows,nw
      pi = pi(w)
      status = status(w)
      r = randomu(seed,nw)
      ener = e_min(pi) + r*(e_max(pi) - e_min(pi))
      if i eq 0 then begin
         histo,ener,hsum,x,minval=minval,maxval=maxval,binsize=binsize,/sil
      endif else begin
         histo,ener,h,x,minval=minval,maxval=maxval,binsize=binsize,/sil
         hsum = hsum + h
      endelse
   
   endfor
   
endif

; Prepare folding with gauss function

sigma = fltarr(n_elements(hsum)) + 0.3

xbkg = [6.5,10.9,14.5,22.5,36.]
wbkg = [1.0,1.2,1.,3.,2.]
ybkg = fltarr(5)
for i = 0,4 do begin
   w = where(x gt xbkg(i)-0.5*wbkg(i) and x lt xbkg(i)+0.5*wbkg(i))
   ybkg(i) = avg(hsum(w))
endfor
bkg = interpol(ybkg,xbkg,x,/spline)

!p.multi = [0,1,3]

if !d.name ne 'PS' then begin
   window,0,xs=500,ys=800
   thick = 3
endif else thick = 5
plot,x,fold_gauss(x,hsum/bkg-1,sigma),yr=[-0.1,1.0],tit='JMX'+nj+' spectrum',$
   xtit='Energy [keV]',ytit='hist/bkg - 1',thick=thick,charsize=1.3
xyouts,0.15,0.9,'Radius < 110 mm',/norm,charsize=1.8
xyouts,0.15,0.85,'Data under '+basdir,/norm,charsize=1.5
plotnumber,146
plotsign
wxe = where(x gt 23 and x lt 35)
res = gaussfit(x(wxe),hsum(wxe)/bkg(wxe)-1,a,nterms=3)

yarr = hsum(wxe)/bkg(wxe)-1
plot,x(wxe),yarr,tit='Xe region with fit',ps=10,charsize=1.3
oplot,x(wxe),res,thick=thick
str = string(a,format='(f5.2,f6.2,f6.2)')
xyouts,x(wxe(0))+1,0.8*max(yarr),'Fit: '+str,charsize=1.4
print,'Xe peak fit: ',a
;
wmo = where(x gt 14.5 and x lt 19.5)
yarr = hsum(wmo)/bkg(wmo)-1
res = gaussfit(x(wmo),yarr,a,nterms=3)
plot,x(wmo),yarr,tit='Mo region with fit', ps=10,charsize=1.3
oplot,x(wmo),res,thick=thick
str = string(a,format='(f5.2,f6.2,f6.2)')
xyouts,x(wmo(0))+0.5,0.8*max(yarr),'Fit: '+str,charsize=1.4
print,'Mo peak fit: ',a

end
