pro pointing_plot, rev, ra0, dec0, radius, read=read, log=log, $
         movie=movie, pane=pane, shift=shift
;
;  Plot pointings from a revolution
;
;  2004-11-02/NJW
;
if n_params() lt 1 then begin
   print,'Syntax: pointing_plot, rev[, ra0, dec0, radius][,/read][,pane=]$'
   print,'               [,shift=]'
   return
endif

mon = 0
if keyword_set(log) then begin
   openw,lun,log,/get_lun
   mon = 1
endif

if keyword_setx(pane) then window,pane

revstr = string(rev,format='(i4.4)')
filename = '/r6/jemx/pointings/pointings_'+revstr+'p.dat'
if getenv('HOST') eq 'njw-notebook.spacecenter.dk' then begin
   filename = '/home/njw/r6/pointings/pointings_'+revstr+'p.dat'
endif
if mon then printf,lun,filename

rscol, filename, swid, 1, /sil, /str
rscol, filename, ra, 2, /sil
rscol, filename, dec, 3, /sil

if mon then $
   for imon = 0, n_elements(swid)-1 do $
      printf,lun,swid(imon),ra(imon),dec(imon)

if n_params() ge 4 then begin

   r = arcdist( ra0, dec0, ra, dec )
   w = where( r lt radius, nw )
   if nw eq 0 then begin
      print,'Sorry, no pointings were close enough'
      if mon then begin
         printf,lun,'Sorry, no pointings were close enough'
         free_lun,lun
      endif
      return
   endif
   
   swid = swid(w)
   ra = ra(w)
   dec = dec(w)
   
   plot, ra, dec, psym=2, $
      xr=ra0+radius*[1,-1]/cos(dec0*!pi/180),$
      yr=dec0+radius*[-1,1], xtit='R.A. [degrees]',$
      ytit='Declination [degrees]'
   res = convert_coord([0.14,0.85],/normal,/to_data)
   xyouts,res(0),res(1),'Revol: '+stri(rev),charsize=2.5
   def_sym,'c'
   oplot,[ra0],[dec0],psym=8,symsize=2

   ;  Find size of y-axis in data space
   yspan = !y.crange(1) - !y.crange(0)
   sep = 0.03 * yspan
   print,'sep=', sep,' yspan=', yspan

   for i = 0, nw-1 do begin
      pid = strmid(swid(i),5,3)
      sub = strmid(swid(i),10,1)
      off = sep
      for j = 0, i-1 do begin
         if arcdist(ra(j),dec(j),ra(i),dec(i)) lt sep then off = off + sep
      endfor
      xyouts,ra(i),dec(i)+off,pid+'/'+sub,align=0.5,charsize=1.1
   endfor

endif else begin

   ;  Plot the grid

   !p.position = [0.01,0.01,0.99,0.99]
   plot,[0,1],xr=[180,-180],yr=[-90,90],/nodata,$
        xstyle=1+4,ystyle=17+4

   ; lon grid
   
   b = xlingen(100,-90,90)
   for lon = -179.99, 180.1, 89.99 do begin
      l = fltarr(100) + lon
      aitoff,l,b,x,y
      listy = 1
      if lon lt -179 or lon gt 179 then listy = 0
      oplot,x,y,li=listy
   endfor
   
   ; lat grid
   
   l = xlingen(100,-179.999,180)
   for lat = -60.,60.01,30. do begin
      b = fltarr(100) + lat
      aitoff,l,b,x,y
      oplot,x,y,li=1
   endfor

   xyouts,0,70,'Revol: '+stri(rev),charsize=3,align=0.5

   ; Overplot the pointings

   glactc, ra, dec, 2000, gl, gb, 1, /deg

   if mon then $
      for imon = 0, n_elements(swid)-1 do $
         printf,lun,swid(imon),gl(imon),gb(imon)

   if keyword_set(shift) then begin
      gl = gl + shift
   endif

   aitoff,gl,gb,x,y

   if keyword_set(movie) then begin
      for imo = 0, n_elements(swid)-1 do begin
         oplot,[x(imo)],[y(imo)],ps=2
         print,swid(imo)
         wait,0.5
         oplot,[x(imo)],[y(imo)],ps=2,color=140
      endfor
   endif else oplot, x, y, ps=2

   if keyword_set(read) then begin
      repeat begin
         curmark1,pos
         rever_aitoff,pos(0),pos(1),l,b
         r = arcdist(l,b,gl,gb)
         z = min(r,imin)
         print,'SWID: ', swid(imin)
         glactc, rap, decp, 2000, l, b, 2, /deg
         print,'RADEC: ', rap, decp
         ans = ''
         read,'Continue ? ... ', ans
      endrep until ans ne 'y' and ans ne ''

        ;  Install the 'parameter' file: sourcemap.par if it does not exist in the
        ;  current directory

      if not file_test('sourcemap.par',/reg) then begin
         if !version.os eq 'Win32' then par_template = 'f:\r6\jemx\catalogs\sourcemap.par'
         if !version.os eq 'sunos' then par_template = '/r6/jemx/catalogs/sourcemap.par'
         if !version.os eq 'linux' then begin
            if getenv('HOSTNAME') eq 'lin6' then par_template = '/r6/jemx/catalogs/sourcemap.par' $
            else par_template = '/home/njw/r6/catalogs/sourcemap.par'
         endif
         par = read_slist(par_template)
         write_slist, 'sourcemap.par', par
      endif
      n = comreplace('sourcemap.par','ra_cen',rap)
      n = comreplace('sourcemap.par','dc_cen',decp)
      n = comreplaces('sourcemap.par','plotheader','Pointing Plot')
   endif
   
   !p.position = 0
endelse

if mon then free_lun,lun

end
