function radial_distribution, image, cen_x, cen_y, rvec=rvec, ang1=ang1, ang2=ang2
;
; Radial distribution in image with center (cen_x, cen_y) in the section [ang1,ang2]
; if keywords are given (angles in degrees)
;
;   2004-10-04/NJW
;
if n_params() lt 3 then begin
   print,'Syntax: res = radial_distribution, image, cen_x, cen_y[, rvec=][, ang1=, ang2=]'
   print,'  Angles to be given in degrees'
   return,-1
endif

sz = size(image)

if sz(0) ne 2 then begin
   print,'RADIAL_DISTRIBUTION error, not a 2D array'
   return,-1
endif

d = distances(sz(1),sz(2),cen_x,cen_y)
x = fltarr(sz(1),sz(2))
y = x
for i = 0, sz(1)-1 do x(i,*) = i - cen_x
for i = 0, sz(2)-1 do y(*,i) = i - cen_y
a = atan(y,x) * 180. / !pi

if keyword_setx(ang1) and keyword_setx(ang2) then asel = 1 else asel = 0

if asel then print,'Using angular selection'
if not asel then print,'No angular selection'

if asel then begin
   wa = where(a gt ang1 and a le ang2, nwa)
   if nwa eq 0 then begin
      print,'RADIAL_DISTRIBUTION error, no pixels in angular section'
      return,-1
   endif
   rmax = max(d(wa))
endif else rmax = max(d)
print,'Max radius: ', rmax

ndist = fix(rmax)
rvec = findgen(ndist)
rdist = fltarr(ndist)
for i = 0, ndist-1 do begin
   w = where(d ge i and d lt i+1, nw)
   if nw eq 0 then continue
   if asel then begin
      wa = where(a(w) gt ang1 and a(w) le ang2, nwa)
      if nwa eq 0 then continue
      rdist(i) = total(image(w(wa))) / nwa
   endif else rdist(i) = total(image(w)) / nw
endfor

return, rdist

end

