function ran_counts, c, bkg, silent=silent
;
; Randomize count spectrum 'c' adding background 'bkg' per bin
; if given
;
;   NJW Updated 010802
;

np = n_params()
if np lt 1 then begin
   print,'Syntax: spectrum = ran_counts(c [,bkg][,/silent])
   print
   print,'   where   ''c'' is the input (ideal) count spectrum'
   print,'     and   ''bkg'' is the background per bin (same for all)'
   print,'   If no background is given it is assumed to be zero'
   return,-1.
endif

vb = 1
if keyword_set(silent) then vb = 0

n = total(c)
nc = n_elements(c)
cr = fltarr(nc)
b = accumulate(c)
b = b / max(b)
a = shift(b,1)
a(0) = 0.
nleft = long(n)
if vb then print,nleft,' counts in total of array'
if nleft gt 0 then begin
   nblock = (nleft - 1)/1000 + 1
   if vb then print,nblock,' blocks'
   for nb = 0, nblock-1 do begin
      nfor = min([1000, nleft])
      if vb then print, nfor,' counts will be distributed'
      r = randomu(seed, nfor)
      for j = 0, nfor-1 do begin
         i = where( r(j) gt a and r(j) le b)
         cr(i) = cr(i) + 1.
      endfor
      nleft = nleft - 1000
   endfor
endif
; ------------------------------------------------------
; Add background component with uniform distribution
; ------------------------------------------------------
if( np gt 1 ) then begin
   n = bkg*nc
   b = accumulate(fltarr(nc)+1.)
   b = b / max(b)
   a = shift(b,1)
   a(0) = 0.
   nleft = long(n)
   if vb then print,nleft,' counts in total of background'
   if nleft gt 0 then begin
      nblock = (nleft - 1)/1000 + 1
      if vb then print,nblock,' blocks'
      for nb = 0, nblock-1 do begin
         nfor = nleft < 1000
         if vb then print, nfor,' counts will be distributed'
         r = randomu(seed, nfor)
         for j = 0, nfor-1 do begin
            i = where( r(j) gt a and r(j) le b)
            cr(i) = cr(i) + 1.
         endfor
         nleft = nleft - 1000
      endfor
   endif
endif

return, cr

end
