function randmin, ndim, npoints_d, plim_in, prec, fun=fun, lg=lg, sil=sil
;
;  Origin NJW when ?
;
;    Updated 2003-08-28/NJW
;
; Find minimum of multi dimensional function 'fun' using random numbers
;    Call: ndim     number of dimensions
;          npoints_d number of points per dimension where function is
;                    evaluated
;          plim     2 by ndim array with coordinate limits
;          prec     ndim array with coordinate precisions
;
;  Keywords: fun  :  Name of function to minimize
;             lg  :  Use logarithmic spacing of points
;            sil  :  Silence! suppress terminal messages
;
;   The region is tested with npoints_d in each dimension
;   and the function is evaluated in each point.
;
if n_params() lt 4 then begin
   print,'Syntax: res = randmin( ndim, npoints_d, plim, prec, fun=fun, lg=lg )'
   print,'    plim must be 2 dimensional'
   return, -1
endif

openw,lun,'randmin.dat',/get_lun
printf,lun,'//  Running randmin '+systime()
printf,lun,'// ndim = ', ndim
printf,lun,'// npoints_d = ', npoints_d
printf,lun,'// plim_in(*,0) = ', plim_in(*,0)
printf,lun,'// plim_in(*,1) = ', plim_in(*,1)
printf,lun,'// prec = ', prec
printf,lun,'// fun = ', fun
free_lun, lun

plim = plim_in

sz = size(plim)
if( sz(0) ne 2 ) then begin
   print,'plim must be 2 dimensional'
   return, -1
endif
if( (sz(1) ne 2) or (sz(2) ne ndim) ) then begin
   print,'The dimensions of plim must be 2 x ndim'
   return, -1
endif
if( n_elements(prec) ne ndim ) then begin
   print,'prec must have ndim elements'
   return, -1
endif

if keyword_set(fun) then fun_name = fun else fun_name='funk'
ulog = intarr(ndim)
if keyword_set(lg) then ulog = lg

iter = 0
npoints = npoints_d * ndim
x = fltarr(ndim,npoints)
y = fltarr(npoints)
dif = fltarr(ndim)
;
repeat begin

;
; define random points for each dimension
;
   for i=0,ndim-1 do begin
      if ulog(i) eq 0 then begin
         x(i,*) = randomu(seed,npoints)*(plim(1,i) - plim(0,i)) + plim(0,i)
      endif else begin
         x(i,*) = exp(randomu(seed,npoints)*alog(plim(1,i) / plim(0,i)) $
                          + alog(plim(0,i)))
      endelse
   endfor

   for i=0,npoints-1 do y(i) = call_function(fun_name, x(*,i))

;  Now sort for increasing y values

   isort = sort(y)
   y = y(isort) ; added 2003-08-28/NJW
   for i = 0, ndim-1 do x(i,*) = x(i,isort)

   hdr = ['// block = '+string(iter), '// plim(*,0) = '+string(plim(*,0)), $
          '// plim(*,1) = '+string(plim(*,1)),'// ymin = '+string(y(0))]
   ;* wstab,'randmin.dat',hdr,x(0,*),x(1,*),y,/app

   write_slist,'randmin.dat',hdr,/app

;
; Reduce interval for each dimension
;
   for i = 0, ndim-1 do begin
      qmin = x(i,0)
      qmax = x(i,0)
      for j = 1, npoints_d do begin
         if x(i,j) gt qmax then qmax = x(i,j)
         if x(i,j) lt qmin then qmin = x(i,j)
      endfor
      plim(0,i) = qmin
      plim(1,i) = qmax
   endfor
;
   for i = 0, ndim-1 do begin
      if ulog(i) eq 0 then dif(i) = plim(1,i) - plim(0,i) $
                      else dif(i) = plim(1,i)/plim(0,i) - 1.0
   endfor
   test = where( dif gt prec, ntest )
   iter = iter + 1
   if not keyword_set(sil) then begin
      print,'Iteration # ',iter
      print, plim
      print, 'test = ', test
      print, 'ntest = ', ntest
   endif
;
endrep until (ntest eq 0) or (iter gt 50)

res = fltarr(2)
res(0) = 0.5*(plim(0,0) + plim(1,0))
res(1) = 0.5*(plim(0,1) + plim(1,1))

return, res

end
