pro rd_8s_log, filename, m, t, p8
;
;  Read the log file of Stefano Giozzi from the motor position reading
;  together with the recorded time of the 8 s pulse
;
;   010705/NJW
;
if n_params() lt 4 then begin
   print,'Syntax: rd_8s_log, filename, m, t, p8'
   return
endif

mot = { m1:0L, m2:0L, m3:0L, m4:0L }
tim = { t1:0d, t2:0d, t3:0d, t4:0d }
pl8 = { pt:0d, dt:0d}

flist = findfile(filename,count=n_file)
if n_file ne 1 then begin
   print,'RD_8S_LOG could not find file : ', filename
   tit='Pick an XY table Log File'
	filename = dialog_pickfile(filter='*.txt',title=tit)
   if strlen(filename) eq 0 then begin
   	print,'Still no file found - I give up'
   	return
   endif
endif

openr, lun, filename, /get_lun

reset_val = 1.8d9 - 201428.d0

time_reset1 = 0.d0
time_reset2 = 0.d0
time_reset3 = 0.d0
time_reset4 = 0.d0
time_reset8 = 0.d0

n_entries = 0L
n_8s_pulses = 0L

t_prev1 = -1.d0
t_prev2 = -1.d0
t_prev3 = -1.d0
t_prev4 = -1.d0

t_prev8 = -1.d0

n_lineskips = 0

s=''
while not eof(lun) do begin

   readf,lun,s

   ; Get number of numbers

   s = strtrim(strcompress(s),2)
   tok = str_sep(s,' ')
   nn = n_elements(tok)

   if nn eq 8 or nn eq 10 then begin ; Legal record

      ; Update table with motor positions

      if n_entries eq 0 then begin
         m = replicate(mot,300000L)
         t = replicate(tim,300000L)
      endif

      m(n_entries).m1 = long(tok(0))
      m(n_entries).m2 = long(tok(1))
      m(n_entries).m3 = long(tok(2))
      m(n_entries).m4 = long(tok(3))

      t_now = double(tok(4))
      if t_now lt t_prev1 then time_reset1 = time_reset1 + reset_val
      t_prev1 = t_now
      t(n_entries).t1 = t_now + time_reset1
      t_now = double(tok(5))
      if t_now lt t_prev2 then time_reset2 = time_reset2 + reset_val
      t_prev2 = t_now
      t(n_entries).t2 = t_now + time_reset2
      t_now = double(tok(6))
      if t_now lt t_prev3 then time_reset3 = time_reset3 + reset_val
      t_prev3 = t_now
      t(n_entries).t3 = t_now + time_reset3
      t_now = double(tok(7))
      if t_now lt t_prev4 then time_reset4 = time_reset4 + reset_val
      t_prev4 = t_now
      t(n_entries).t4 = t_now + time_reset4

      n_entries = n_entries + 1

      if nn eq 10 then begin ; there are also 8s pulse times

         if n_8s_pulses eq 0 then begin
            p8 = replicate(pl8, 30000L)
         endif
         t_now = double(tok(8))
         if t_now lt t_prev8 then time_reset8 = time_reset8 + reset_val
         t_prev8 = t_now
         p8(n_8s_pulses).pt = t_now + time_reset8
         p8(n_8s_pulses).dt = double(tok(9))
         n_8s_pulses = n_8s_pulses + 1

      endif

   endif else n_lineskips = n_lineskips + 1 ; Skip line if number of numbers is not legal


endwhile

if n_entries gt 0 then begin
   m = m(0:n_entries-1)
   t = t(0:n_entries-1)
endif else begin
   print,'RD_8S_LOG warning : No valid motor entries in ', filename
endelse
if n_8s_pulses gt 0 then begin
   p8 = p8(0:n_8s_pulses-1)
endif else begin
   print,'RD_8S_LOG warning : No valid 8s pulse times in ', filename
endelse

print,'Summary for file: ', filename
print,'.............................',n_entries,' motor readings'
print,'.............................',n_8s_pulses,' 8s pulses'
print,'.............................',n_lineskips,' lines skipped'

free_lun, lun

end

