pro rdfitscol, filename_extno_in, col_data, col_id, silent=silent, hdr=hdr,$
                errmsg=errmsg, nrows=nrows
;
; Read a FITS binary extension table column
;
;  990211/NJW
;  Updated 000807/NJW
;
;   Data is returned in 'col_data'
;   The col_id can be a column number or name
;

if n_params() lt 3 then begin
   print,'Syntax: RDFITSCOL, filename_extno, col_data, col_id, $'
   print,'             errmsg=, silent=, hdr=, nrows='
   print,'      col_id can be a number or a name'
   return
endif

filename_extno = filename_extno_in

errmsg = ''
vb = 1 - keyword_set(silent)
get_exten_no, filename_extno, filename, extno, /noresolve
;* print,'#1# filename = '+filename

filename = gz_proxy_file(filename)
if filename eq '' then begin
   print,'RDFITSCOL Error: File not found'
   return
endif

filename_extno = filename+'['+extno+']'

get_exten_no, filename_extno, filename, extno

errmsg = ''
fxbopen,unit,filename,extno,hdr,errmsg=errmsg
if errmsg ne '' then begin
   print,'%FXBOPEN error: '+errmsg
   return
endif

nrows = fxpar(hdr,'NAXIS2')
if nrows eq 0 then begin
   errmsg = 'No rows in table'
   col_data = '-1'
   fxbclose, unit
   return
endif

errmsg = ''
col_number = fxbcolnum( unit, col_id, errmsg=errmsg)
if errmsg ne '' then begin
   print,errmsg
   fxbclose, unit
   return
endif

if vb then begin
   print,'Reading file '+filename_extno
   if col_number lt 10 then begin
      sc = 'TTYPE'+string(col_number,format='(i1)')
   endif else begin
      sc = 'TTYPE'+string(col_number,format='(i2)')
   endelse
   print,'column named: '+fxpar(hdr,sc)
   print,'with ',nrows,' rows'
endif
fxbread,unit,col_data,col_number
fxbclose,unit
end
