function rebin_equi, num, e1, e2, f, emin=emin, emax=emax
;
;  Rebin a spectrum in 'f' (counts per bin) into
;  bins of equal size
;
;   2003-08-29/NJW
;
if n_params() ne 4 then begin
   print,'Syntax: newf = rebin_equi( num, e1, e2, f[,emin=][,emax=])'
   print,'     num   :  number of bins in rebinned spectrum'
   print,'      e1   :  lower energy boundaries'
   print,'      e2   :  upper energy boundaries'
   print,'       f   :  input spectrum'
   print,'  Returns array 3 x num, (0,*) emin, (1,*) emax, (2,*) newf'
   return,-1
endif

nelem = n_elements(e1)
if nelem ne n_elements(e2) or nelem ne n_elements(f) then begin
   print,'Error in REBIN_EQUI, mismatching array dimensions'
   return,-1
endif

maxe = max(e2)
mine = min(e1)
if keyword_set(emin) then mine = emin
if keyword_set(emax) then mine = emax

res = fltarr(3,num)

eb = xlingen(num+1,mine, maxe)
new_e1 = eb(0:num-1)
new_e2 = eb(1:num)
new_de = (maxe - mine) / num

res(0,*) = new_e1
res(1,*) = new_e2

for i = 0, num-1 do begin

   w = where(e1 gt new_e1(i), nw)
   if nw eq 0 then i1 = nelem-1 else i1 = w(0) - 1
   w = where(e2 ge new_e2(i), nw)
   if nw eq 0 then print,'##2## trouble'
   i2 = w(0)

   if i1 eq i2 then begin
      res(2,i) = f(i1) * new_de / (e2(i1) - e1(i1))
   endif else begin
      sum = 0.0
      for j = i1, i2 do begin
         if j lt i2 then begin
            width = e2(j) - (e1(j) > new_e1(i))
         endif else begin
            width = new_e2(i) - e1(j)
         endelse
         sum = sum + f(j) * width / (e2(j) - e1(j))
      endfor

      res(2,i) = sum

   endelse

endfor

return, res

end
