pro rebin_psd, fx_in, psd_in, n_out, fx_out, psd_out
;
;  Rebin to log-scale
;  Assume that input fx_in is in linear scale
;
if n_params() lt 5 then begin
   print,'Syntax: rebin_psd, fx_in, psd_in, n_out, fx_out, psd_out'
   return
endif

n  = n_elements(fx_in)
b1 = fx_in(0) - 0.5*(fx_in(1)-fx_in(0))
b2 = fx_in(n-1) + 0.5*(fx_in(n-1)-fx_in(n-2))
n_bds = n_out + 1
bds = xloggen(n_bds, b1, b2)
sbds = shift(bds,1)
w_bds = bds(1:n_bds-1) - sbds(1:n_bds-1)

fx_out = fltarr(n_out)
psd_out = fltarr(n_out)

; find out where the log bins are larger than 2x linear bins

w = where( w_bds gt 2.01*(fx_in(1)-fx_in(0)), n_w)
if n_w le 0 then begin
   print,'Too many logarithmic bins'
   return
endif

if w(0) eq 0 then begin
   print,'Logarithmic all the way'
endif else begin
   fxlim = bds(w(0))
   w = where( fx_in lt fxlim, n_w )
   n_orig = n_w
   fx_out(0:n_orig-1) = fx_in(0:n_orig-1)
   psd_out(0:n_orig-1) = psd_in(0:n_orig-1)
   n_out = n_out - n_orig
   b1 = fx_in(n_orig-1) - 0.5*(fx_in(n_orig)-fx_in(n_orig-1))
   b2 = fx_in(n-1) + 0.5*(fx_in(n-1)-fx_in(n-2))
   n_bds = n_out + 1
   bds = xloggen(n_bds, b1, b2)
   sbds = shift(bds,1)
   w_bds = bds(1:n_bds-1) - sbds(1:n_bds-1)
endelse
   
for i = 0, n_out-1 do begin
   w = where(fx_in lt bds(i+1) and fx_in ge bds(i), n_w)
   if n_w gt 0 then begin
      fx_out(i+n_orig) = avg(fx_in(w))
      psd_out(i+n_orig) = avg(psd_in(w))
   endif else begin
      print,'Nothing in bin #', i
   endelse
endfor

end
   
