pro rem_dsri_cat_source, serial
;
;  Remove a row in DSRI_CAT.fits and store it in DSRI_CAT_REMOVED.fits
;  The row = source is identified with the serial number
;
;  Assumes a structure: Primary header with a single binary table extension
;
;   NJW/2002-04-04
;
;  The only way to do this seems to copy the original extension
;  to new one and then rename
;
if n_params() lt 1 then begin
   print,'Syntax: rem_dsri_cat_source, serial
   return
endif

dsri_cat = '/home/njw/jsim/Catalogs/DSRI_CAT.fits[1]'
dsri_cat_removed = '/home/njw/jsim/Catalogs/DSRI_CAT_REMOVED.fits[1]'

; First get the row number to remove

rdfitscol, dsri_cat, sercol, 'SERIAL', /silent
w = where( sercol eq long(serial), n_w)
if n_w eq 1 then begin
   rownumber = w(0) + 1
endif else begin
   print,'The requested serial number not found'
   return
endelse

; Now add extra row to DSRI_CAT_REMOVED.fits

st1 = '/home/njw/jsim/add_rows/add_rows '
st2 = '"/home/njw/jsim/Catalogs/DSRI_CAT_REMOVED.fits[1]" '
st3 = '1'
spawn,st1+st2+st3


get_exten_no, dsri_cat, dsri_cat_file, dsri_cat_extno
get_exten_no, dsri_cat_removed, dsri_cat_rem_file, dsri_cat_rem_extno

;  Get the primary header of DSRI_CAT

prim_hdr = headfits(dsri_cat_file)

fxbopen, unit_in, dsri_cat_file, dsri_cat_extno, header,access='R'

fxbopen, unit_rm, dsri_cat_rem_file, dsri_cat_rem_extno, hdr_rm, access='RW'

nrows = fxpar(header, 'NAXIS2')
ncols = fxpar(header, 'TFIELDS')

nrows_rm = fxpar(hdr_rm, 'NAXIS2')


; Prepare new FITS file

; and write the file with primary header to disk

filename = '/pool1/tmp.fits'

a = 1
writefits, filename, a, prim_hdr

;  create the extension with one less rows

fxaddpar, header, 'NAXIS2', nrows-1, 'Number of rows in table'
fxbcreate, unit_out, filename, header

; Copy all the old columns

for col = 1, ncols do begin
   fxbread, unit_in, copydata, col
   szc = size(copydata)
   if szc(0) lt 1 or szc(0) gt 2 then begin
      print,'Strange data in column ', col
      fxbclose, unit_in
      fxbclose, unit_out
      return
   endif
   rowcnt = 1
   for row = 1, nrows do begin
      if row ne rownumber then begin

         ; copy all rows except deleted one

         if szc(0) eq 2 then begin
            fxbwrite, unit_out, copydata(*,row-1), col, rowcnt
         endif else begin
            fxbwrite, unit_out, copydata(row-1), col, rowcnt
         endelse
         rowcnt = rowcnt + 1
      endif else begin

         ; save deleted row to DSRI_CAT_REMOVED

         if szc(0) eq 2 then begin
            fxbwrite, unit_rm, copydata(*,row-1), col, nrows_rm
         endif else begin
            fxbwrite, unit_rm, copydata(row-1), col, nrows_rm
         endelse
      endelse
   endfor
endfor

fxbclose, unit_in

fxbfinish, unit_out

fxbfinish, unit_rm

; Finally replace old file with new temporary file

spawn,'mv /pool1/tmp.fits '+dsri_cat_file

end
