function rem_extremes, im_orig, hbs=hbs, nsig=nsig
;
; Return image where extremes are removed and replaced
; with averages. The extreme and average are defined in
; a local reference.
;
; Call : im_orig     original image
;
; Keywords:  hbs     half-box-size = size of local area
;            nsig    number of sigmas for defining extremes
;
;  The definition of 'an extreme' changed from abs(val) > nsigma*rms
;          to val > nsigma*rms + avg     010518/NJW

im = im_orig
szim = size(im)

; Keywords

;         Number of sigmas i.e. the limit
if keyword_set(nsig) then ns = nsig else begin
   ns = 1.
   print,'The limit is ', ns,' sigmas'
endelse

;         Half box size
if keyword_set(hbs) then hb = hbs else begin
   hb = 8
   print,'Half box size is ', hb
endelse


step = 2*hb + 1
for j = 0, szim(2), step do begin
   for i = 0, szim(1), step do begin  ; Define a box for every position
      x1 = (i - hb) > 0
      x2 = (i + hb) < (szim(1)-1)
      y1 = (j - hb) > 0
      y2 = (j + hb) < (szim(2)-1)
      box = im(x1:x2,y1:y2)
      dev = rms(box)
      avbox = avg(box)
      extremes = where( box gt ns*dev + avbox, n_extremes )
      if n_extremes gt 0 then begin
         ordinaries = where( box le ns*dev + avbox)
         box(extremes) = avg(box(ordinaries))
         im(x1:x2,y1:y2) = box   ; Back substitution
      endif
   endfor
endfor
return, im
end
