function repair_array, array, value=value
;
;   2005-09-01/NJW
;
;   Substitute array elements of value 'value' (typically 0.0)
;   with interpolation between adjacent elements of different value.
;
if n_params() lt 1 then begin
   print,'Syntax: new_array = repair_array( array[, value=])'
   print,'        where ''array'' is a 1D array'
   print,'    Keyword ''value'': test against this, default is zero'
   return, -1
endif

if not keyword_set(value) then value = 0.0
w = where( array eq value, nw, complement=m, ncomplement=nm )
print,stri(nw)+' elements with value: '+stri(value)
if nw eq 0 then begin
   print,'No elements to change!'
   return, array
endif
if nm eq 0 then begin
   print,'All elements have value '+stri(value)+', skip!'
   return, array
endif
;
;  Define the groups of value
;

y = array
ny = n_elements(y)

print,'Index of first no-change value: ', m(0)

if m(0) gt 0 then begin
   ; get first non-zero value
   ;    and fill out initial values
   val = y(m(0))
   i = 0
   while w(i) eq i do begin
      y(i) = val
      i = i + 1
   endwhile
   print,'Filled '+stri(i)+' leading values'
endif

print,'Index of last no-change value: ', m(nm-1)

if m(nm-1) lt ny-1 then begin
   ; get last non-zero value
   ;    and fill out trailing values
   val = y(m(nm-1))
   i = nw-1
   kount = 0
   while w(i) eq i + ny - nw do begin
      y(w(i)) = val
      i = i - 1
      kount = kount + 1
      if i lt 0 then break
   endwhile
   print,'Filled '+stri(kount)+' trailing values'
endif

; Start over because y has - possibly changed -
;           to check for intrinsic gaps

w = where( y eq value, nw, complement=m, ncomplement=nm )
print,stri(nw)+' internal elements with value: '+stri(value)

if nw eq 0 then return, y

close_neighbors, w, gbeg, gend, ngrps

for j = 0, nw-1 do begin
   ; singleton or group ?
   if ngrps gt 0 then begin
      k = where( j ge gbeg and j le gend, nk )
   endif else nk = 0
   if nk ge 1 then begin ; inside group
      k = k(0)
      len = gend(k) - gbeg(k) + 2
      v = y(w(gbeg(k))-1) + (w(j)-w(gbeg(k))+1) $
            * (y(w(gend(k))+1) - y(w(gbeg(k))-1)) / len
   endif else begin ; this is a singleton
      v = 0.5*(y(w(j)-1) + y(w(j)+1))
   endelse
   y(w(j)) = v
endfor

return, y

end
