pro revol_info, revno, ijd_b=ijd_b, ijd_e=ijd_e, dt_b=dt_b, dt_e=dt_e, silent=silent
;
;   Use /r6/jemx/integral_history/revolution_latest.fits to return
;   times for begin and end of revolution
;
;   2004-03-04/NJW
;
if n_params() lt 1 then begin
   print,'Syntax: revol_info, revno[, ijd_b=][, ijd_e=][, dt_b=][, dt_e=]'
   return
endif

base = ''
if 'njw-notebook' eq getenv('HOSTNAME') then base = '/mnt/win_f'

dol = base+'/r6/jemx/integral_history/revolution_latest.fits+1'

rdfitscol,dol, revol_no, 'REVOLUTION',/sil
rdfitscol,dol, time_perigee, 'TIME_PERIGEE',/sil

; The TIME_PERIGEE refers to the beginning of the revolution

if revno gt max(revol_no) then begin
   print,'The requested revolution number exceeds the largest number in'
   print,' /r6/jemx/integral_history/revolution_latest.fits'
   print
   print,'Look for later version of ''revolution_yyyymmdd.fits'' at ISDC:'
   print,' /isdc/pvphase/nrt/ops_1/aux/adp/ref/revno'
   print
   return
endif

w = where(revol_no eq revno, nw)
if nw ne 1 then begin
   print,'The requested revolution number is not in'
   print,'/r6/jemx/integral_history/revolution_latest.fits'
   print,'Is your input number correct ?'
   print
   return
endif

ijd_b = time_perigee(w(0))
ijd2dattim, ijd_b, s
dt_b = s

if revno lt max(revol_no) then begin
   ijd_e = time_perigee(w(0)+1)
endif else begin
   ijd_e = 2*time_perigee(w(0)) - time_perigee(w(0)-1) ; extrapolate
endelse
ijd2dattim, ijd_e, s
dt_e = s

if not keyword_set(silent) then begin
   print,'IJD start : ', ijd_b
   print,'IJD   end : ', ijd_e
   print,'Date start : ', dt_b
   print,'Date   end : ', dt_e
endif
end
