pro rewrite_fits_image, filename_extno, data, exten=exten
;
;   Overwrite existing image in FITS file. The arrays
;   must match.
;
if n_params() lt 2 then begin
   print,'Syntax: rewrite_fits_image, filename_extno, data[, exten=]'
   print,'    filename can be of DOL type - then keyword exten is not necessary'
   print,'    Keyword exten will override DOL extension if given'
   return
endif

get_exten_no, filename_extno, filename, extno
if keyword_set(exten) then extno = exten

; Get existing header

hdr = headfits(filename,exten=extno)

naxes = fxpar(hdr,'NAXIS')
naxis = fxpar(hdr,'NAXIS*')
bitpix = fxpar(hdr,'BITPIX')

sz = size(data)
type_in = sz(sz(0)+1)
if type_in ge 6 then begin
   print,'Data of this type currently not handled'
   return
endif

if naxes ne sz(0) then begin
   print,'FITS dimension does not match data'
   return
endif
for i = 0, naxes-1 do begin
   if naxis(i) ne sz(i+1) then begin
      print,'FITS dimension '+stri(i+1)+' does not match data'
      return
   endif
endfor


case type_in of
     1 : begin
           if bitpix ne 8 then begin
              print,'Input data of type byte, FITS is not'
              return
           endif
         end
     2 : begin
           if bitpix ne 16 then begin
              print,'Input data of type int, FITS is not'
              return
           endif
         end
     3 : begin
           if bitpix ne 32 then begin
              print,'Input data of type long, FITS is not'
              return
           endif
         end
     4 : begin
           if bitpix ne -32 then begin
              print,'Input data of type float, FITS is not'
              return
           endif
         end
     5 : begin
           if bitpix ne 8 then begin
              print,'Input data of type byte, FITS is not'
              return
           endif
         end
endcase

; Now formalities are in order
;
;  Move to beginning of required extension

unit = fxposit(filename,extno)

; Get header and test for 'END     '

line = ''
for i = 0,79 do line = line + ' '
h = replicate(line,36)

repeat begin
   readu,unit,h
   endline = where(strmid(h,0,8) eq 'END     ', n_end)
endrep until n_end eq 1

big_endian = is_ieee_big()
if not big_endian then begin
   newdata = data
   host_to_ieee, newdata
   writeu,unit,newdata
endif else writeu,unit,data

free_lun, unit

return
end
