;
; main program for ROXSAN monitor PC sensitivity calculations
; Generate sensitivity curve in the style of Stewart/Wells
;
;
;  1) get relevant arrays
;           a) Effective area of ROXSAN-monitor
detarea = 3.1416 * 7.5^2 * 0.9 ; 90% efficiency due to collimator
;           b) Quantum efficiences of detector
restore,'/d/njw/roxsan/qeroxmon.dat'
;    this gives arrays : ener
;                        witr  (window transmission 3 mu polyimide)
;                        xeabs (absorption in 12 atm cm Xe)
; set up energy scale
ir = where(ener gt 2.)
e = ener(ir)
deltae = 2 * 0.33 * sqrt(e) ; twice the FWHM energy resolution
;           d) Define DXB (extra galactic part)
fdxb = 11.*e^(-1.46) * absorp(5.e20,e)
fcrab = 9.7*e^(-2.1) * absorp(3.e21,e)
;           e) Cell area and solid angle
comega = 0.0174533^2  ; 1.00 square degree in steradians
acell  = detarea ; cm2
fp = 1.e-3       ; particle background cts/cm2/s/keV
;
aeff = detarea * witr(ir)* xeabs(ir)
flim = e
; sample plot commands
!p.title = 'ROXSAN-monitor sensitivity     '+date()
!y.title = 'Flux (phot. cm!u-2!n s!u-1!n keV!u-1!n)'
!x.title = 'Energy (keV)'
plot_oo,e,flim,thick=2.0,yr=[1.e-5,1.e00],/nodata
for i = 1,4 do begin
   tobs = 10.^i
   np = tobs * acell * fp * deltae
   ndh = tobs * comega * fdxb * aeff * deltae
   ns = 5.*sqrt(4.+np+ndh)
   flim = ns / (tobs * aeff * deltae)
   oplot,e,flim,thick=2.0
   tekst = string(i,format='("10!u",i1,"!n s")')
   xyouts,e(20),flim(20)*1.2,tekst,size=1.5
endfor
oplot,e,fcrab,linestyle=3
oplot,e,0.1*fcrab,linestyle=3
oplot,e,0.01*fcrab,linestyle=3
oplot,e,0.001*fcrab,linestyle=3
oplot,e,(e/e)*fp,linestyle=2
oplot,e,fdxb*comega,linestyle=1
xyouts,15.,.3e00,'5!4r!3 detection',charsize=1.5
xyouts,15.,.1e00,'0.66!9r!3E keV detection band',charsize=1.2
xyouts,e(55),fcrab(55)*1.1,'Crab',size=1.7
xyouts,e(205)*0.5,0.0011*fcrab(205),'mCrab',size=1.7
end
