pro rscolc, filename, col_dat, col_def, str=str, int=int, long=long, dble=dble,$
          silent=silent, block=block, trace=trace
;
; Same as 'rscol' with cache files
;
;  2003-08-25/NJW
;
;

if n_params() lt 3 then begin
   print,'RSCOLC, (input)filename, (return)col_array, (input)column_number'
   print,'    NB! the column must be identified by its number ( != rscol)'
   print
   print,'Keywords:    /str    - a string is returned'
   print,'             /int    - a short integer is returned'
   print,'             /long   - a long integer is returned'
   print,'             /dble   - a double is returned'
   print,'             /silent - no extra messages'
   print,'             block=  - read only this block of rows'
   print,'             /trace  - produce test output'
   retall
endif

vb = 1 - keyword_set(silent)
tr = keyword_set(trace)
sz = size(col_def)
if sz(sz(0)+1) eq 7 then begin
   col_def_str = col_def
   col_def_num = 0
endif else begin
   col_def_str = 'none'
   col_def_num = fix(col_def)
endelse

if !version.os eq 'sunos' then begin
   cache_dir = '/pool14/'
   if strmid(filename,0,1) ne '/' then begin
      fullfilename = getenv('PWD')+'/'+filename
   endif else fullfilename = filename
endif
if !version.os eq 'linux' then begin
   cache_dir = '/mnt/win_f/cache/'
   if strmid(filename,0,1) ne '/' then begin
      fullfilename = getenv('PWD')+'/'+filename
   endif else fullfilename = filename
endif
if !version.os eq 'Win32' then begin
   cache_dir = 'c:\work\'
   if strmid(filename,1,1) ne ':' then begin
      fullfilename = getenv('PWD')+'\'+filename
   endif else fullfilename = filename
endif

; Get last serial number in 'cache_dir'

list_serial = file_search(cache_dir+'cache_rcc_last_serial.number',count=n_list_serial)
last_serial = 0L
if n_list_serial eq 1 then begin
   if tr then print,'##0## open(r) file: ',cache_dir+'cache_rcc_last_serial.number'
   openr,lun,cache_dir+'cache_rcc_last_serial.number',/get_lun
   readf,lun,last_serial
   if tr then print,'##1## got last_serial = ', last_serial
   free_lun,lun
endif else begin
   if tr then print,'##2## open(w) file: ',cache_dir+'cache_rcc_last_serial.number'
   openw,lun,cache_dir+'cache_rcc_last_serial.number',/get_lun
   printf,lun,last_serial,format='(i4.4)'
   if tr then print,'##3## wrote last_serial = ', last_serial
   free_lun,lun
endelse
   
;  Find the cache file candidates

found = 0
list_i = file_search(cache_dir+'rcc_cache_????.iden',count=n_list_i)
if tr then print,'##4## Found ', n_list_i,' cache id files'
if n_list_i gt 0 then begin ; There are some cache id files
                            ; Look for current name and column
   i = 0
   repeat begin
      if tr then print,'##5## repeat loop, i = ', i
      if tr then print,'##6## open(r) id file: ', list_i(i)
      openr,lun,list_i(i),/get_lun
      file_id = ''
      readf,lun,file_id
      colname = ''
      readf,lun,colname
      colnumber = 0
      readf,lun,colnumber
      blockstr = ''
      readf,lun,blockstr
      free_lun,lun
      if tr then print,'##7## file/col: ', file_id,'  ', colname
      if tr then print,'##8## block: ', blockstr

      block_ok = 1
      if keyword_setx(block) then begin
	 if blockstr eq 'none' then block_ok = 0 else begin
            block_num = fix(blockstr)
            block_ok = ( block_num eq block )
	 endelse
      endif

      if fullfilename eq file_id and $
            ((col_def_str eq colname and col_def_str ne 'none') or $
	    (col_def_num eq colnumber and col_def_num gt 0) ) $
	    and block_ok then begin

         found = 1
         ; extract serial number
         str_serial = str_reverse(strmid(str_reverse(list_i(i)),5,4))
         if tr then print,'##8## Match! serial number = ', str_serial
      endif
      i = i + 1
   endrep until (found or i eq n_list_i)

endif

if found then begin ; check for existence of data file (idlsave)

   datname = cache_dir+'rcc_cache_'+str_serial+'.idlsav'
   if tr then print,'##9## Check for existence of data file: ', datname
   l = file_search(datname, count=n_l)
   if n_l ne 1 then found = 0
   if tr then begin
      if found then print,'##10## It''s there' else print,'##3## It''s missing!'
   endif

endif

if found then begin

   if vb then print,'Restoring column data from '+datname+' ...'
   restore,file=datname
   nrows = n_elements(col_data)

endif else begin

   rscol, filename, col_dat, col_def, str=str, int=int, long=long, dble=dble,$
          silent=silent, block=block


   ; Save column data into cache area for quick retrieval next time

   ; 1) update file with last serial number

   last_serial = last_serial + 1L
   str_serial = string(last_serial,format='(i4.4)')
   openw,lun,cache_dir+'cache_rcc_last_serial.number',/get_lun
   printf,lun,str_serial
   free_lun,lun

   ; 2) write data identification file

   openw,lun,cache_dir+'rcc_cache_'+str_serial+'.iden',/get_lun
   printf,lun,fullfilename
   printf,lun,col_def_str
   printf,lun,col_def_num
   if keyword_setx(block) then printf,lun,block else printf,lun,'none'
   free_lun,lun

   ; 3) save column data in IDL format

   save,file=cache_dir+'rcc_cache_'+str_serial+'.idlsav',col_dat

endelse



end

