function rsmatrix, filename, silent=silent, int=int, long=long, dble=dble
;
; This function will read an ASCII file organized as a 2D matrix
;
;              IDL> arr = rsmatrix('mytable')
;
;  'arr' will contain the lines as rows
;
; The lines that start with non-digit characters are interpreted as
; comment lines and will be displayed but skipped in
; the reading of the data
;
if n_params() lt 1 then begin
   print,'Syntax: arr = rsmatrix( filename[,/silent][,/int][,/long][,/dble])'
   print,' Default returned type is float'
   return, -1
endif

nmax = 10000
n = n_columns(filename)
print,'% RSMATRIX: ', n,' columns found in file'
openr,lun,filename,/get_lun
c = fltarr(nmax,n)
x = fltarr(n)
if keyword_set(int) then begin
   c = intarr(nmax,n)
   x = intarr(n)
endif
if keyword_set(long) then begin
   c = lonarr(nmax,n)
   x = lonarr(n)
endif
if keyword_set(dble) then begin
   c = dblarr(nmax,n)
   x = dblarr(n)
endif
s = ' '
i = 0
while not eof(lun) and i lt nmax do begin
  readf,lun,s
  st = strtrim(s,1) ; remove leading blanks
  if strlen(st) gt 0 then begin
     if( strpos('-.0123456789',strmid(st,0,1)) lt 0 ) then begin
        if not keyword_set(silent) then print,s
     endif else begin
        reads,s,x
        for j = 0, n-1 do c(i,j) = x(j)
        i = i + 1
     endelse
   endif
endwhile
print,'% RSMATRIX: ', i,' rows found in file'
c = c(0:i-1,*)
close,lun
free_lun,lun
return,c
end
