pro sa_swg, dol_of_swg, spec=spec, nostat=nostat
;
;  Standard Analysis of JSIM simulation results
;   starting from a selected Science Window Group
;
if n_params() lt 1 then begin
   print,'Syntax: sa_swg,<dol_of_swg>[,/nostat]'
   return
endif



; Get the SWG




pos = strpos(dol_of_swg,'.fits')
swg_base_name = strmid(dol_of_swg,0,pos)

;  Get statistics of number of counts etc.

if not keyword_set(nostat) then begin
   jsim_statistics, dol_of_swg ; works for both JEMX units
endif

for jemxnum = 1, 2 do begin

   strjemx = 'JMX'+strtrim(jemxnum,2)

   ; Find the source lists for each image

   ebm_get_all_idxmembers_swg, dol_of_swg, strjemx+'-FIND-RES-IDX',$
                      arr_file_find,errmsg, count=n_mem_find


      ;  Loop over all the members

   for mem = 0, n_mem_find - 1 do begin

      get_exten_no, arr_file_find(mem), ffind, extno_find


      ; Compare results with input sources

      jsim_vs_input, swg_base_name, extno_find

      rps,/sq,file=swg_base_name+'_'+strtrim(extno_find,2)+'_svi.ps'
      loadct,0
      jsim_vs_input, swg_base_name, extno_find
      xps,/x,/nop

   endfor  ;  Terminate loop over all FIND IDX table members

   if keyword_set(spec) then begin

      ; Plot the spectra

      ; Get the number of included sources

      ebm_get_child_by_name, swg, strjemx+'-SPEC-NJW', specfile, errmsg

      get_exten_no, specfile, fspec, extno_spec
      fxbopen, unit, fspec, extno_spec
      hdr = fxbheader(unit)
      fxbclose,unit

      nbins = fxpar(hdr,'NAXIS2')
      nbytes = fxpar(hdr,'NAXIS1')

      nsources = (nbytes - 12)/8

      if nbins gt 0 then begin

         ; Do the plotting

         for i_source = 1, nsources do begin
            pos = strpos(fspec,'.fits')
            bspec = strmid(fspec,0,pos)
            ff = bspec+'_'+strtrim(i_source,2)+'.ps'
            rps,/por,file=ff
            loadct,0
            jsim_plot_spectrum,specfile,i_source,pressure=pressure,alpha=1.0
            xps,/x,/nop
         endfor

      endif

   endif ; Terminate 'if spectral plots are requested'
        
endfor ; end loop over JEMX units

end
