pro setpar, parfile, parname, value, errmsg=errmsg
;
;  Update a parameter file (IRAF standard) with
;  a new value
;
;   NJW/010531
;
if n_params() ne 3 then begin
   print,'Syntax: setpar, parfile, parname, value[,errmsg=]'
   return
endif

sz = size(value)
strval = strtrim(value,2)
errmsg = ''
if strval eq '' then strval = '""'

a = findfile(parfile,count=n_a)
if n_a ne 1 then begin
   print,'SETPAR: No such file: ', parfile
   errmsg = 'File not found'
   return
endif

list = read_slist(parfile, count=n_lines)

any_changes = 0

for i = 0, n_lines-1 do begin

   line = list(i)
   pos = strpos(line,'#') ; Prepare removing characters after '#'
   if pos ge 0 then begin
      com  = strmid(line,pos,999) ; save the comment
      line = strmid(line,0,pos) ; extract part for analysis
   endif
   tok = strsplit(line,','/extract)
   n_tok = n_elements(tok)
   if n_tok ge 7 then begin
      ; this may be a parameter
      if tok(0) eq parname then begin ; This is the one
         ; find out if a string value is expected
         if strtrim(tok(1),2) eq 's' then begin ; make sure that the
             ; begin and end of the string is a '"'
            if strmid(strval,0,1) ne '"' then strval = '"'+strval
            if strmid(strval,strlen(strval)-1,1) ne '"' then $
                  strval = strval+'"'
         endif
         tok(3) = strval              ; replace with new value
         newpar = str_join(tok,',')   ; combine to single string
         if pos gt 0 then newpar = newpar + com ; add comment (if any)
         list(i) = newpar
         any_changes = 1
      endif
   endif

endfor

; Write back if there are changes

if any_changes then begin
   write_slist, parfile, list
endif else begin
   print,'SETPAR, file(',parfile,') param: ', parname,' not found'
   errmsg = 'Parameter not found; no change'
endelse

end


