pro shortdate2ijd, shortdate, ijd
;
;  2003-01-27/NJW
;
;  Convert a (array of) date string (such as 030127) to
;  IJD i.e. number of days since Jan 01, 00:00, 2000
;
if n_params() ne 2 then begin
   print,'Syntax: shortdate2ijd, shortdate, ijd'
   return
endif

; Initial data definition

days_in_month = long([31,28,31,30,31,30,31,31,30,31,30,31])
days_in_month_leap = long([31,29,31,30,31,30,31,31,30,31,30,31])
ijd_tmp = -1.0;
ijd = -1.0;

acc_days = lonarr(12)
acc_days_leap = lonarr(12)
for i = 0, 10 do begin
   acc_days(i+1) = acc_days(i) + days_in_month(i)
   acc_days_leap(i+1) = acc_days_leap(i) + days_in_month_leap(i)
endfor

first = 1

; Analyze input (array of) string(s) and check format

sz = size(shortdate)
if sz(sz(0)+1) ne 7 then begin
   print,'1. argument is not of type string'
   return
endif
nelem = n_elements(shortdate)

for i = 0, nelem-1 do begin

   curstr = strcompress(shortdate(i),/remove_all)
   len = strlen(curstr)

   if len ne 6 then begin
      print,'#'+strtrim(i,2)+' '+shortdate(i)+' invalid format'
      goto, next
   endif



   year = strmid(curstr,0,2)

   if not is_digit(year) then begin
      print,'#'+strtrim(i,2)+' '+shortdate(i)+' invalid format (year is not a number)'
      goto, next
   endif

   iyear = fix(year) + 2000

   if iyear mod 4 eq 0 then cur_year_is_leap = 1 else cur_year_is_leap = 0

   month = strmid(curstr,2,2)

   if not is_digit(month) then begin
      print,'#'+strtrim(i,2)+' '+shortdate(i)+' invalid format (month is not a number)'
      goto, next
   endif

   if fix(month) lt 1 or fix(month) gt 12 then begin
      print,'#'+strtrim(i,2)+' '+shortdate(i)+' illegal month number'
      goto, next
   endif

   day = strmid(curstr,4,2)

   if not is_digit(day) then begin
      print,'#'+strtrim(i,2)+' '+shortdate(i)+' invalid format (day is not a number)'
      goto, next
   endif

   daymax = days_in_month(fix(month)-1)
   if cur_year_is_leap and fix(month) eq 2 then daymax = daymax + 1

   if fix(day) lt 1 or fix(day) gt daymax then begin
      print,'#'+strtrim(i,2)+' '+shortdate(i)+' invalid day number'
      goto, next
   endif

   hour = '0'
   minute = '0'
   second = '0'


   num_years = long(iyear - 2000)
   num_leap_years = (num_years+3L)/4L ; before current year

   num_days = num_years * 365L + num_leap_years

   if cur_year_is_leap then begin
      num_days = num_days + acc_days_leap(fix(month)-1) + fix(day) - 1
   endif else begin
      num_days = num_days + acc_days(fix(month)-1) + fix(day) - 1
   endelse
   num_seconds = double(hour)*3600d0 + double(minute)*60d0 + double(second)

   ijd_tmp = double(num_days) + num_seconds/(24d0*3600d0)

   if first then begin
      ijd = ijd_tmp
      first = 0
   endif else begin
      ijd = [ijd, ijd_tmp]
   endelse




   next:
endfor

end
