pro slide, image, psf, k_image, s_image, greg=greg, blevel=blevel
;
;  Slide a psf across the image and for each point find
;  the fitting quality
;
;    2003-10-31/NJW
;
if n_params() ne 4 then begin
   print,'Syntax: slide, image, psf, > k_image, > s_image[,greg=][,blevel=]'
   return
endif

openw,log,'slide.log',/get_lun

szim = size(image)
szps = size(psf)

xdimi = szim(1)
ydimi = szim(2)
dimpsf = szps(1)
half = dimpsf/2
norm = 1./n_elements(psf)

if not keyword_set(blevel) then blevel = 0.1

printf,log,'xdimi = '+stri(xdimi)+'  ydimi = '+stri(ydimi)
printf,log,'dimpsf = '+stri(dimpsf)+'  half = '+stri(half)
printf,log,norm,format='("norm = ",e14.4)'
printf,log,'blevel = ', blevel

k_image = image*0.0
s_image = k_image

div = total(psf^2)
printf,log,div,format='("div = ",e14.4)'
bzone = where(psf lt blevel, nbzone)
if nbzone lt 10 then begin
   print,'Problem with background zone'
   return
endif
printf,log,'nbzone = '+stri(nbzone)

; Let i,j be the lower left corner of the PSF in the image

for j = 0, ydimi - dimpsf do begin
;print,j, ydimi-dimpsf
for i = 0, xdimi - dimpsf do begin
   section = image(i:i+dimpsf-1,j:j+dimpsf-1)
   sigma = rms(section(bzone))
   if sigma eq 0. then sigma = 1.0
   ; best fit
   k = total(section*psf) / div
   s = total(((k*psf-section)/sigma)^2)*norm

   k_image(i+half,j+half) = k
   s_image(i+half,j+half) = s

endfor
endfor

free_lun, log

ii = bytarr(xdimi,ydimi)
ii(half:xdimi-1-half,half:ydimi-1-half) = 1
greg = where( ii eq 1 and image ne 0 )

a = avg(k_image(half:xdimi-1-half,half:ydimi-1-half))
k_image(0:half-1,*) = a
k_image(*,0:half-1) = a
k_image(*,ydimi-half:ydimi-1) = a
k_image(xdimi-half:xdimi-1,*) = a

a = avg(s_image(half:xdimi-1-half,half:ydimi-1-half))
s_image(0:half-1,*) = a
s_image(*,0:half-1) = a
s_image(*,ydimi-half:ydimi-1) = a
s_image(xdimi-half:xdimi-1,*) = a

return

end
