pro snstvt, e, effarea, omega, fp, cellarea, choice, fraction, tobs, eline, $
            fcont, despec, dedet, e1, e2, fl
;
; General main program for sensitivity calculations
;
;  1) Get table with effective area (including telescope and q)
;                    (e,effarea)

flag = 0 ; For checking existence of all required variables
sz = size(e)
sz0 = sz(1+sz(0))
if( sz0 lt 2 or sz0 gt 5 ) then begin
   print,'e array must be defined'
   flag = 1
endif
sz = size(effarea)
sz0 = sz(1+sz(0))
if( sz0 lt 2 or sz0 gt 5 ) then begin
   print,'effarea array must be defined'
   flag = 1
endif
sz = size(omega)
sz0 = sz(1+sz(0))
if( sz0 lt 2 or sz0 gt 5 ) then begin
   print,'omega must be defined'
   print,'omega is the FOV solid angle of a pixel in sterad'
   flag = 1
endif
sz = size(fp)
sz0 = sz(1+sz(0))
if( sz0 lt 2 or sz0 gt 5 ) then begin
   print,'fp must be defined'
   print,'fp (array) is the particle bckgd in cts/(cm2 s keV)'
   flag = 1
endif
sz = size(cellarea)
sz0 = sz(1+sz(0))
if( sz0 lt 2 or sz0 gt 5 ) then begin
   print,'cellarea must be defined'
   print,'cellarea is the cell area on detector in cm2'
   flag = 1
endif
sz = size(choice)
sz0 = sz(1+sz(0))
if( sz0 ne 7 ) then begin
   print,'choice must be defined'
   print,'choice is a string indicating s:source detection'
   print,'                           or l:line detection'
   flag = 1
endif
sz = size(fraction)
sz0 = sz(1+sz(0))
if( sz0 lt 2 or sz0 gt 5 ) then begin
   print,'fraction must be defined'
   print,'fraction is the fraction of photons in search cell'
   flag = 1
endif
sz = size(tobs)
sz0 = sz(1+sz(0))
if( sz0 lt 2 or sz0 gt 5 ) then begin
   print,'tobs must be defined'
   print,'tobs is the observations time in seconds'
   flag = 1
endif
if( choice eq 'l' ) then begin
   sz = size(eline)
   sz0 = sz(1+sz(0))
   if( sz0 lt 2 or sz0 gt 5 ) then begin
      print,'eline must be defined'
      print,'eline is the energy of the line in keV'
      flag = 1
   endif
   sz = size(fcont)
   sz0 = sz(1+sz(0))
   if( sz0 lt 2 or sz0 gt 5 ) then begin
      print,'fcont must be defined'
      print,'fcont is the continuum at the line in ph/(cm2 s keV)'
      flag = 1
   endif
   sz = size(despec)
   sz0 = sz(1+sz(0))
   if( sz0 lt 2 or sz0 gt 5 ) then begin
      print,'despec must be defined'
      print,'despec is the spectrometer resolution element in keV'
      flag = 1
   endif
   sz = size(dedet)
   sz0 = sz(1+sz(0))
   if( sz0 lt 2 or sz0 gt 5 ) then begin
      print,'dedet must be defined'
      print,'dedet is the detector energy resolution in keV'
      flag = 1
   endif
endif else begin
   sz = size(e1)
   sz0 = sz(1+sz(0))
   if( sz0 lt 2 or sz0 gt 5 ) then begin
      print,'e1 must be defined'
      print,'e1 is the start of the energy band in keV'
      flag = 1
   endif
   sz = size(e2)
   sz0 = sz(1+sz(0))
   if( sz0 lt 2 or sz0 gt 5 ) then begin
      print,'e2 must be defined'
      print,'e2 is the end of the energy band in keV'
      flag = 1
   endif
endelse
if( flag gt 0 ) then stop

; setting the significance level:
nsigma = 3.

print,'Size of e :       ', n_elements(e)
print,'Size of effarea : ', n_elements(effarea)
print,'Omega = ', omega
; print,'Fp =    ', fp
print,'Tobs = ', tobs
print,'Cellarea = ', cellarea
if( choice eq 'l' ) then begin
   print,'Eline = ', eline
;   print,'Fcont = ', fcont
;   print,'Despec = ', despec
;   print,'Dedet = ', dedet
endif else begin
   print,'E1 = ', e1
   print,'E2 = ', e2
endelse
;
;--------------------------------------------------------------
;  In the case of line detection:
;          a) Get energy of line : eline (keV)
;          b) Get continuum at line : fcont (ph/(cm2 s keV))
;          c) Get spectrometer energy resolution element
;                                             : despec (keV)
;          d) Get detector energy resolution  : dedet (keV)
;--------------------------------------------------------------
;  In the case of source detection:
;          a) Get energy band boundaries: e1 & e2 (keV)
;--------------------------------------------------------------

; define energy intervals : de
nel = n_elements(e)
ee = fltarr(nel+1)
ee(1:nel) = e
ee(0) = 2.*e(0) - e(1)
de = e - ee(0:nel-1)

;           d) Define DXB (extra galactic part)

; fdxb = 11.*e^(-1.46) * absorp(5.e20,e)
; fdxb = 0 * 4.8 * exp(-e/40.) / e

fdxb = 10.1 * e^(-1.424) * exp(-e/54.2) ; Comastri DXB 001030/NJW

;
if( choice eq 's' ) then begin
   ie = where( e gt e1 and e lt e2 )
   if( ie(0) eq -1 ) then begin
      print,'Energy array ''e'' not dense enough !'
      stop
   endif
   np = cellarea * total(fp(ie)*de(ie)) * tobs
   ir = where( (e le e2) and (e ge e1))
   ndxb = omega * total(fdxb(ir)*effarea(ir)*de(ir)) * tobs
   ns = nsigma * sqrt(4. + ndxb + np)
   print,'Np = ', np
   print,'Ndxb = ', ndxb
   print,'Ns = ', ns
   fxavg = ns / (fraction * tobs * total(effarea(ir)*de(ir)))
   print,'Fxavg = ', fxavg,' ph/(cm2 s keV)'
   print,'Sxavg = ', 1.6e-9*fxavg*0.5*(e1+e2),' erg/(cm2 s)'
endif else begin
   i = max(where( e le eline ) )
   np = cellarea * fp(i) * dedet(i) * tobs
   ndxb = omega * fdxb(i) * effarea(i) * despec(i) * tobs
   ncont = fraction * fcont * effarea(i) * despec(i) * tobs
   ns = nsigma * sqrt(4. + ndxb + np + ncont)
   print,'Fdxb = ', fdxb(i)
   print,'Np = ', np
   print,'Ndxb = ', ndxb
   print,'cellarea = ', cellarea
   print,'Eff area = ', effarea(i)
   print,'Delta-E (spectrometer) : ', despec(i)
   ; print,'Ncont = ', ncont
   print,'Ns = ', ns
   fl = ns / (fraction * tobs * effarea(i))
   print,'Fl(0) = ', fl(0), ' ph/(cm2 s)'
endelse
close,2
end
