pro sourcemap, rep=rep, gal=gal
;
; Originally Program plot0082
;
;  NJW/000726, copied from plot0067.pro
;  NJW/010126, copied from plot0082.pro
;  NJW/040615, updated to set the !x/y.style parameters
;
; Draw a map of sources in smaller region in RA-DEC or Galactic coords.
;
;  Keyword: rep  : repeat previous plot
;           gal  : If set then galactic coordinates else use celestial (equatorial)
;


common cat_com_v2, cat, num_entries_cat, dol_of_cat

!x.style = 1
!y.style = 17

;  Install the 'parameter' file: sourcemap.par if it does not exist in the
;  current directory

if not file_test('sourcemap.par',/reg) then begin
   if !version.os eq 'Win32' then par_template = 'f:\r6\jemx\catalogs\sourcemap.par'
   if !version.os eq 'sunos' then par_template = '/r6/jemx/catalogs/sourcemap.par'
   if !version.os eq 'linux' then begin
      if getenv('HOSTNAME') eq 'lin6' then par_template = '/r6/jemx/catalogs/sourcemap.par' $
      else par_template = '/mnt/win_f/r6/jemx/catalogs/sourcemap.par'
   endif
   par = read_slist(par_template)
   write_slist, 'sourcemap.par', par
endif


repeet = 0
if keyword_set(rep) then repeet = 1
;          The spelling is intended. Else there is a conflict with
;          the IDL statement 'repeat'

celest = 1 ; default celestial system
if repeet then begin ; select coordsystem of previous plot
   coordsys = comgets('sourcemap.par', 'coordsys', ierr )
   letter = strmid( coordsys, 0, 1)
   if letter eq 'g' then celest = 0 else celest = 1
endif else begin
   if keyword_set(gal) then celest = 0
endelse

if celest then begin
   ierr = comreplaces( 'sourcemap.par', 'coordsys', 'celestial' )
   xtitstr = 'RA (2000) [deg]'
   ytitstr = 'DEC (2000) [deg]'
endif else begin
   ierr = comreplaces( 'sourcemap.par', 'coordsys', 'galactic' )
   xtitstr = 'Gal. Long. [deg]'
   ytitstr = 'Gal. Lat.  [deg]'
endelse

openw,lout,'output',/get_lun

;   Prepare to avoid writing text on top of each other

n_boxes = 0
boxes = fltarr(4,300) ; each row is a box of text in normal coordinates
xtnormv = fltarr(300) ; save values when two passes are required
ytnormv = fltarr(300) ; save values when two passes are required

; Get name of input catalogue file


szin = size(dol_of_cat)
if szin(0)+szin(1) eq 0 then begin
   old_catalogue = ''
endif else begin
   input_catalogue = dol_of_cat
   old_catalogue = input_catalogue
endelse

if repeet then begin
   input_catalogue = comgets('sourcemap.par','input_catalogue',ierr)
endif else begin
   input_catalogue = get_pars('sourcemap.par','input_catalogue')
endelse

; Read the contents of the catalogue

cat_com_update, clog=input_catalogue

;   Choose the central point and radius in degrees

answer = ''

ra_cen = 0.0
dc_cen = 0.0
gl_cen = 0.0
gb_cen = 0.0
radius = 0.0

if celest then begin
   print,'The right ascension and declination (2000) in decimal degrees'
   if repeet then ra_cen = comget('sourcemap.par','ra_cen',ierr)$
   else ra_cen = get_par_ra('sourcemap.par','ra_cen')

   if repeet then dc_cen = comget('sourcemap.par','dc_cen',ierr)$
   else dc_cen = get_par_dec('sourcemap.par','dc_cen')

   ; Get the center of field in galactic coordinates

   glactc,ra_cen/15.,dc_cen,2000,gl_cen,gb_cen,1

   ierr = comreplace('sourcemap.par', 'gl_cen', gl_cen )
   ierr = comreplace('sourcemap.par', 'gb_cen', gb_cen )

endif else begin
   print,'The galactic longitude and latitude in decimal degrees'
   if repeet then gl_cen = comget('sourcemap.par','gl_cen',ierr)$
   else gl_cen = get_par('sourcemap.par','gl_cen')

   if repeet then gb_cen = comget('sourcemap.par','gb_cen',ierr)$
   else gb_cen = get_par('sourcemap.par','gb_cen')

   ; Get the center of field in celestial coordinates

   glactc,ra_cen_hour,dc_cen,2000,gl_cen,gb_cen,2
   ra_cen = ra_cen_hour * 15.0

   ierr = comreplace('sourcemap.par', 'ra_cen', ra_cen )
   ierr = comreplace('sourcemap.par', 'dc_cen', dc_cen )

endelse


dither_around_pointing,ra_cen,dc_cen,0.0,patt=2



if repeet then radius = comget('sourcemap.par','radius',ierr)$
else radius = get_par('sourcemap.par','radius')


if repeet then limit = comget('sourcemap.par','limit',ierr)$
else limit = get_par('sourcemap.par','limit')


if repeet then sourcetype = comgets('sourcemap.par','sourcetype',ierr) $
else begin
sourcetype = comgets('sourcemap.par','sourcetype',ierr)
print,'Choose an X-ray source type.'
print,'Type of sources (''any'' to get all independently of type) [',$
               strtrim(sourcetype,2),']'
read,'                                  New source type : ... ', answer
if answer eq '' then begin
   print,'The sourcetype is: ', sourcetype
endif else begin
   sourcetype = answer
   ierr = comreplaces('sourcemap.par','sourcetype', sourcetype)
endelse
endelse
sourcetype = strupcase(sourcetype)


c = cat.catalogue
ndd = 9999
print,'  Catalogues in the data base:'
while ndd gt 0 do begin
   print,'           ',c(0)
   nam = strtrim(c(0),2)
   dd = where(strpos(c,nam) lt 0,ndd)
   if ndd gt 0 then c = c(dd)
endwhile



if repeet then catalogsel = comgets('sourcemap.par','catalogue',ierr) $
else begin
catalogsel = comgets('sourcemap.par','catalogue',ierr)
print,'Choose an X-ray source catalogue.'
print,'Catalogue (''any'' to get all independently of type) [',$
               strtrim(catalogsel,2),']'
read,'                                  New catalogue : ... ', answer
if answer eq '' then begin
   print,'The catalogue is: ', catalogsel
endif else begin
   catalogsel = answer
   ierr = comreplaces('sourcemap.par','catalogue', catalogsel)
endelse
endelse
catalogsel = strupcase(catalogsel)




if repeet then plotheader = comgets('sourcemap.par','plotheader',ierr) $
else begin
plotheader = comgets('sourcemap.par','plotheader',ierr)
print,'Plot header [',strtrim(plotheader,2),']'
read,'                     New header : ... ', answer
if answer eq '' then begin
   print,'The header is: ', plotheader
endif else begin
   plotheader = answer
   ierr = comreplaces('sourcemap.par','plotheader', plotheader)
endelse
endelse




if repeet then labels = comgets('sourcemap.par','labels',ierr) $
else begin
labels = comgets('sourcemap.par','labels',ierr)
print,'Do you want labels in the plot? [',strtrim(labels,2),']'
read,'                                : ... ', answer
if answer eq '' then begin
   print,'Labels ?  : ', labels
endif else begin
   labels = strmid(answer,0,1)
   ierr = comreplaces('sourcemap.par','labels', labels)
endelse
endelse


if repeet then extralist = comgets('sourcemap.par','extralist',ierr) $
else begin
extralist = comgets('sourcemap.par','extralist',ierr)
print,'Filename with extra plot points [',strtrim(extralist,2),']'
read,'                                : ... ', answer
if answer eq '' then begin
   if extralist eq 'none' or extralist eq '' then begin
      print,'No extra points included'
   endif else begin
      print,'Including points from: ', extralist
   endelse
endif else begin
   extralist = answer
   ierr = comreplaces('sourcemap.par','extralist', extralist)
endelse
endelse

extrapoints = 0
if extralist ne 'none' and extralist ne '' then begin

   extrapoints = 1
   rstab,extralist, exc1, exc2, nrows=n_extra
   cosys = comgets(extralist, 'coordsys', ierr)

   ;  if same coordinate system as plot then do nothing
   ;  else make appropriate conversion

   if celest and cosys eq 'galactic' then begin
      for i = 0, n_extra-1 do begin
         glactc,rax_hour,dcx,2000,exc1(i),exc2(i),2
         exc1(i) = rax_hour * 15.
         exc2(i) = dcx
      endfor
   endif
   if not celest and cosys eq 'celestial' then begin
      for i = 0, n_extra-1 do begin
         glactc,ra_cen_hour,dc_cen,2000,gl_cen,gb_cen,2
         glactc,exc1(i)/15.,exc2(i),2000,zlx,zbx,1
         exc1(i) = zlx
         exc2(i) = zbx
      endfor
   endif

endif

; Make header for source information on terminal

print
print,'Sources in the FOV:'
print
print,'          Name       Intensity    RA      DEC   Gal.lon.  lat.'
print


; max_point_size = 0.9
max_point_size = 1.6
min_point_size = 0.3

intens = cat.intens
name = cat.name
category = cat.category
catalog = cat.catalogue
ra   = cat.ra_obj
dec  = cat.dec_obj


selection = where(intens gt limit * 2.e-11 , n_selection )
if n_selection le 0 then begin
   print,'  -- no sources above intens limit !'
   free_lun,lout
   return
endif

intens = intens(selection)
name = name(selection)
ra = ra(selection)
dec = dec(selection)
category = category(selection)
catalog = catalog(selection)

if sourcetype ne 'ANY' then begin ; select on source type
   search = strpos(category, sourcetype)
   selection = where( search ge 0 , n_selection )
   if n_selection eq 0 then begin
      print,'No sources in this category: ', sourcetype
      free_lun,lout
      return
   endif
   intens = intens(selection)
   ra = ra(selection)
   name = name(selection)
   dec = dec(selection)
   category = category(selection)
   catalog = catalog(selection)
endif

if catalogsel ne 'ANY' then begin ; select on catalogue
   search = strpos(catalog, catalogsel)
   selection = where( search ge 0 , n_selection )
   if n_selection eq 0 then begin
      print,'No sources in this catalogue: ', catalogsel
      free_lun,lout
      return
   endif
   intens = intens(selection)
   ra = ra(selection)
   name = name(selection)
   dec = dec(selection)
   category = category(selection)
   catalog = catalog(selection)
endif

n = n_elements(intens)

gl = fltarr(n) ;  galactic longitude
gb = fltarr(n) ;  galactic latitude

acoef = (max_point_size - min_point_size) / alog10(1000.)
bcoef = min_point_size - acoef * alog10(limit * 2.e-11)

for i = 0, n-1 do begin
   glactc,ra(i)/15.,dec(i),2000,zl,zb,1
   gl(i) = zl
   gb(i) = zb
endfor

distances = arcdist(ra,dec,ra_cen,dc_cen,/deg)
selection = where( distances lt radius, n_selection)
if n_selection eq 0 then begin
   print,'No sources inside circle '
   free_lun,lout
   return
endif
intens = intens(selection)
name = name(selection)
ra = ra(selection)
dec = dec(selection)
category = category(selection)
catalog = catalog(selection)
gl = gl(selection)
gb = gb(selection)

; Define common coordinates

if celest then begin
   x = ra
   y = dec
   x_cen = ra_cen
   y_cen = dc_cen
endif else begin
   x = gl
   y = gb
   x_cen = gl_cen
   y_cen = gb_cen
endelse

n = n_selection

; Sort according to second coordinate

isort = sort(y)
intens = intens(isort)
name = name(isort)
x = x(isort)
y = y(isort)
category = category(isort)
catalog = catalog(isort)
ra = ra(isort)
dec = dec(isort)
gl = gl(isort)
gb = gb(isort)
point_size = acoef * alog10(intens) + bcoef

;--------------------------------------------------------
;
;   The selection of sources is finished and the plotting
;   can start
;
;--------------------------------------------------------

n_pass = 1
if !d.name eq 'PS' then n_pass = 2

for i_pass = 1, n_pass do begin

printf,lout
printf,lout,'Start pass ', i_pass
printf,lout


if !d.name eq 'PS' then begin
   !p.font = 0
   device,/portrait,xsize=17.0,ysize=17.0,yoffset=10.0
   device,/times
   height = 600.
   csiz = 0.7
endif else begin
   window,0,xsize=600,ysize=600
   height = 12.
   csiz = 1.0
endelse

!p.position = [0.1,0.1,0.95,0.95]

def_sym,'c',/fill
cosy = cos(y_cen*!pi/180)
xra = [x_cen+radius/cosy,x_cen-radius/cosy]
yra = [y_cen-radius,y_cen+radius]

; Shift sources with X 180 -> 360 to negative if
; plot range requires it

if xra(1) lt 0 then begin
   h = where(x gt 180, n_h)
   if n_h gt 0 then x(h) = x(h) - 360
   if extrapoints then begin
      h = where(exc1 gt 180, n_h)
      if n_h gt 0 then exc1(h) = exc1(h) - 360
   endif
endif

; Shift sources with X 0 -> 180 to 360 +  if
; plot range requires it

if xra(0) gt 360 then begin
   h = where(x lt 180, n_h)
   if n_h gt 0 then x(h) = x(h) + 360
   if extrapoints then begin
      h = where(exc1 lt 180, n_h)
      if n_h gt 0 then exc1(h) = exc1(h) + 360
   endif
endif

plot, x, y, xr=xra, yr=yra, xtitle=xtitstr, $
     ytitle=ytitstr, title=plotheader, /nodata, charsize=1.3
;*   ,$ color=4

oplot, xra,[y_cen,y_cen],li=2
oplot, [x_cen,x_cen],yra,li=2
if extrapoints then oplot,exc1,exc2,psym=7,symsize=0.8
plotname,'sourcemap'
plotsign

; prepare writing found sources to file
; but only in pass 1

if i_pass eq 1 then begin


   ; Initial loop to protect the data points from text

   for i = 0, n-1 do begin
      res = convert_coord([x(i),y(i)],/data,/to_normal)
      ; protect the data point:
      boxes(0,n_boxes) = res(0) - 0.01
      boxes(2,n_boxes) = res(0) + 0.01
      boxes(1,n_boxes) = res(1) - 0.01
      boxes(3,n_boxes) = res(1) + 0.01
      ;* drawbox,boxes(*,n_boxes)
      n_boxes = n_boxes + 1
   endfor

endif ; check for pass 1

for i = 0, n-1 do begin
   name(i) = strtrim(strcompress(name(i)),2)
   def_sym,'c',/fill
   oplot,[x(i)], [y(i)],psym=8,symsize=point_size(i) ;*  ,color=3

   if i_pass eq 1 then begin

   ; Find empty region for label

   printf,lout,'Search for region for ', i,': ',name(i)
   res = convert_coord([x(i),y(i)],/data,/to_normal)
   xtnorm = res(0)
   ytnorm = res(1)
   printf,lout,'Data point (norm) : ', xtnorm, ytnorm
   found = 0
   xtnorm_ok = 0.12  ; default label position if no better place is found
   ytnorm_ok = 0.90
   while not found and xtnorm gt 0.12 do begin
   while not found and ytnorm lt 0.9 do begin
      ytnorm = ytnorm + 0.02
      if !d.name ne 'PS' then begin
         textbox, xtnorm, ytnorm, name(i), boxt,$
                /notext,/normal,charheight=height
      endif else begin
         textbox, xtnorm, ytnorm, name(i), boxt,$
                /normal,charheight=height
      endelse
   ; make sure that textbox does not exceed frame
      while boxt(2) gt 0.95 do begin
         xtnorm = xtnorm - 0.01
         if !d.name ne 'PS' then begin
            textbox, xtnorm, ytnorm, name(i), boxt,$
                   /notext,/normal,charheight=height
         endif else begin
            textbox, xtnorm, ytnorm, name(i), boxt,$
                   /normal,charheight=height
         endelse
      endwhile

      printf,lout,'Try box: ', boxt

      ; test for overlap with previous boxes

      found = 1
      for j = 0, n_boxes-1 do begin
         if boxoverlap( boxt, boxes(*,j) ) then found = 0
      endfor
      if found then begin
         printf,lout,'This box worked'
         xtnorm_ok = xtnorm
         ytnorm_ok = ytnorm
      endif else begin
         printf,lout,'Nix - try again'
      endelse
   endwhile
   xtnorm = xtnorm - 0.02
   ytnorm = res(1)
   endwhile

   printf,lout,'While loop has terminated'
   if found then printf,lout,'A solution was found' else $
                    printf,lout,'No empty space'

   xtnormv(i) = xtnorm_ok  ; save value for pass 2
   ytnormv(i) = ytnorm_ok  ; save value for pass 2

   endif ; check for pass 1

   if i_pass eq 2 then begin
      xtnorm_ok = xtnormv(i)    ;  retrieve values found in pass 1
      ytnorm_ok = ytnormv(i)    ;  retrieve values found in pass 1
   endif

   if labels eq 'y' then begin

   textbox,xtnorm_ok,ytnorm_ok,name(i),boxt,/normal,charheight=height
   ;* drawbox, boxt
   boxes(*,n_boxes) = boxt
   n_boxes = n_boxes + 1
   uline = convert_coord([boxt(0),boxt(2)],[boxt(1),boxt(1)],/normal,/to_data)
   oplot,uline(0,0:1),uline(1,0:1)
   oplot,[avg(uline(0,0:1)),x(i)],[uline(1,0),y(i)]

   endif ; Terminate test for labels wanted

   ; Update plot with limit and symbols

   limsym = convert_coord([0.58,0.775],[0.15,0.15],/norm,/to_data)
   siz1 = acoef*alog10(2.e-11) + bcoef
   siz2 = acoef*alog10(2.e-8) + bcoef
   oplot,[limsym(0,0)],[limsym(1,0)],psym=8,symsize=siz1
   oplot,[limsym(0,1)],[limsym(1,1)],psym=8,symsize=siz2
   xyouts,0.6,0.14,'1 mCrab',/norm,charsize=1.3
   xyouts,0.8,0.14,'1 Crab',/norm,charsize=1.3
   str_limit = string(limit,format='(f6.1)')
   if limit lt 0.1 then str_limit = string(limit,format='(f6.3)')

   xyouts,0.12,0.14,'Lower limit: '+strtrim(str_limit,2)+' mCrab',/norm,$
                     charsize=csiz
   xyouts,0.12,0.17,'Source category: '+sourcetype, /norm,charsize=csiz
   xyouts,0.12,0.20,'Source catalog: '+catalogsel, /norm,charsize=csiz
   xyouts,0.12,0.23,'Input catalog: '+input_catalogue, /norm,charsize=csiz



   if i_pass eq 1 then begin

      ;print,i,' ',strtrim(name(i),2),' ',ra(i),dec(i),gl(i),gb(i),intens(i)
      print,strtrim(name(i),2),intens(i),ra(i),dec(i),gl(i),gb(i), $
            format='(a20,e10.2,4f8.2)'
      name1 = strtrim(name(i),2)
      nameparts = strsplit(name1,' ',/extract)
      name2 = str_join(nameparts,'~')

   endif ; end check for pass 1
endfor

if !d.name eq 'PS' then device,/close

endfor ; Terminate the loop over the two passes

;free_lun,lun
free_lun,lout

end
