pro spec2phaii, rate_in, stat_err_in, specresp_in, rmf_file, $
      outspename, outarfname, $
      numjemx=numjemx, expo=expo
;
;  Write a spectrum with errors to a standard PHAII file
;
;    2005-11-08/NJW, first version cloned from 'collect_spectra'
;

nparams = n_params()
if nparams lt 6 then begin
   print
   print,'Syntax: spec2phaii, rate, stat_err, specresp, rmf_file, $'
   print,'        outspename, outarfname[,numjemx=][,expo=]'
   print,'    Keyword: numjemx :  1 or 2'
   print,'    Keyword: expo    :  Exposure in s'
   print
   print,'   ''specresp'' is either a 500 element array to be saved as ARF'
   print,'   or a string variable, in which case the ARF is taken from the rmf_file'
   print
   return
endif

if not keyword_set(numjemx) then numjemx = 1
if numjemx ne 1 and numjemx ne 2 then begin
   print,'Illegal JEMX number'
   return
endif
snj = stri(numjemx)
rate = float(rate_in)
stat_err = float(stat_err_in)

if n_elements(rate) ne n_elements(stat_err) then begin
   print,'The number of elements of ''rate'' must that of ''stat_err'''
   return
endif
num_chans = fix(n_elements(rate))

; Act according to the datatype of specresp

sz = size(specresp_in)
if sz(sz(0)+1) eq 7 then begin
   rdfitscol,rmf_file+'[JMX'+snj+'-AXIS-ARF]',arf,'specresp'
endif else begin
   if n_elements(specresp_in) ne 500 then begin
      print,'The number of elements of ''specresp'' must be 500'
      return
   endif
   arf = float(specresp_in)
endelse
if not keyword_set(expo) then begin
   print,'Warning: exposure arbitrarily set to 1000 s'
   expo = 1000.
endif
expo = double(expo)

fxaddpar, kwds, 'TELESCOP','INTEGRAL'
fxaddpar, kwds, 'INSTRUME','JEMX'
fxaddpar, kwds, 'CHANTYPE','PI'
fxaddpar, kwds, 'DETCHANS',num_chans
fxaddpar, kwds, 'HDUCLASS','OGIP'
fxaddpar, kwds, 'HDUCLAS1','SPECTRUM'
fxaddpar, kwds, 'HDUCLAS2','NET'
fxaddpar, kwds, 'HDUCLAS3','RATE'
fxaddpar, kwds, 'HDUVERS','1.2.0'
fxaddpar, kwds, 'GROUPING',0
fxaddpar, kwds, 'POISSERR','F'
fxaddpar, kwds, 'CORRFILE','none'
fxaddpar, kwds, 'CORRSCAL',1.0
fxaddpar, kwds, 'AREASCAL',1.0
fxaddpar, kwds, 'RESPFILE',rmf_file
fxaddpar, kwds, 'COMMENT','Made by spec2phaii.pro by NJW at DNSC'

wrmfitscols,outspename, kwds=kwds, $
     'SPEC_NUM',replicate(1,1), $
     'ROWID',replicate('J00000+0000',1), $
     'CHANNEL',reform(indgen(num_chans)+1,num_chans,1), $
     'RATE',reform(rate,num_chans,1), $
     'STAT_ERR',reform(stat_err,num_chans,1), $
     'EXPOSURE', replicate(expo,1), $
     'ANCRFILE', replicate(outarfname+'{1}',1), $
     'BACKFILE', replicate('                                ',1), $
     'BACKSCAL', replicate(1.d0,1)


;  Update the checksum

spawn,'fchecksum '+outspename+' update=yes'

; Create the ARF file

wrmfitscols,outarfname, $
     'SPECRESP', reform(arf,500,1)

;  Update the checksum

spawn,'fchecksum '+outarfname+' update=yes'


end
