pro spectrum2fits, pi_spec, pi_stat_err, njmx=njmx, texp=texp, name=name
;
;   Transform spectrum from array to FITS and XSPEC compatible
;
;   2003-06-17/NJW
;

if n_params() lt 2 then begin
   print,'Syntax: spectrum2fits, pi_spec, pi_stat_err[, njmx=][,texp=][, name=]'
   print,'  Keyword   njmx   : JEMX instrument number (defaults to 2)'
   return
endif

numjemx = 2
if keyword_set(njmx) then numjemx = njmx
if numjemx ne 1 and numjemx ne 2 then begin
   print,'Illegal JEMX number'
   return
endif
snj = stri(numjemx)

spec = pi_spec
stat_err = pi_stat_err
if keyword_set(texp) then begin
   spec = spec / texp
   stat_err = stat_err / texp
endif

; Check presence of template spectral/ARF files

spefile = 'jmx'+snj+'_coll_spe.fits'
arffile = 'jmx'+snj+'_coll_arf.fits'
if keyword_set(name) then begin
   spefile = 'jmx'+snj+'_'+name+'_spe.fits'
   arffile = 'jmx'+snj+'_'+name+'_arf.fits'
endif
l = file_search(spefile,count=nl)
if nl eq 0 then spawn,'cp /home/njw/jemx/spectra/jmx'+snj+'_coll_spe.fits '+spefile
l = file_search(arffile,count=nl)
if nl eq 0 then spawn,'cp /home/njw/jemx/spectra/jmx'+snj+'_coll_arf.fits '+arffile

; Set proper anchor file name

if keyword_set(name) then begin
   fxbopen,unit, spefile, 1, access='RW'
   fxbwrite,unit,arffile,12,1
   fxbfinish, unit
endif


dataplot,findgen(256),spec,stat_err

;  Update standard file with spectrum

fxbopen, unit, spefile, 1, access='RW'
fxbwrite, unit, float(spec), 6, 1
fxbwrite, unit, float(stat_err), 7, 1
fxbfinish, unit

;  Update the checksum

spawn,'fchecksum '+spefile+' update=yes'

;  Update file with collected average ARF

print
print,'Remember to update the ARF if required !'
print


end
