pro substi_axis_arf, numjemx, ijd, instance_num
;
;  Change the AXIS-ARF in jmxi_rmf_grp_nnnn.fits
;      where 'nnnn' is the instance number and 'ijd'
;      is an IJD time that applies
;
;   2003-06-19/NJW
;

if n_params() lt 2 then begin
   print,'Syntax: substi_axis_arf, numjemx, ijd, instance_num'
   print,'  where ''instance_num'' is the instance number of the RMF'
   print,'        and ''ijd'' is an IJD time that applies'
   return
endif

; See that catalog of all ARFs exists

strj = stri(numjemx)
all_arf_file = '/home/njw/jemx/spectra/jmx'+strj+'_all_arf_0001.fits'
l = file_search(all_arf_file,/test_regular,count=nl)

if nl ne 1 then begin
   print,'No action - '+all_arf_file+' not found'
   return
endif

; Get the validity times

rdfitscol,all_arf_file+'+1',tstart,'TSTART',/sil,nrows=ngt
rdfitscol,all_arf_file+'+1',tstop,'TSTOP',/sil
rdfitscol,all_arf_file+'+1',comm,'COMMENT',/sil

for i = 0, ngt-1 do begin
   if ijd ge tstart(i) and ijd lt tstop(i) then break
endfor
if i eq ngt then begin
   print,'No data for this time: ', ijd
   return
endif

row_select = i + 1 ; row counting starts with 1
print,'Comment for chosen row: ', comm(i)


;   Get the RMF data

str_instance = string(instance_num,format='(i4.4)')

rmf_file = '/home/njw/jemx/response_matrix/jmx'+strj+'_rmf_grp_'+str_instance+'.fits'
l = file_search(rmf_file,/test_regular,count=nl)
if nl ne 1 then begin
   print,'No action - '+rmf_file+' not found'
   return
endif

grpname = rmf_file+'+1'

ebm_get_child_by_name,grpname,'JMX'+strj+'-AXIS-ARF',arf_name
;rdfitscol,arf_name,default_arf,'SPECRESP',/sil

get_exten_no, arf_name, arf_file, arf_ext
   


; Open the all_ARF and read the relevant ARF
   
fxbopen, unit, all_arf_file, 1, access='R'
fxbread, unit, arfnew, 7, row_select
fxbclose, unit
   
; Open the RMF and dump the new catalog ARF
   
fxbopen, unit, rmf_file, arf_ext, access='RW'

for i = 0, 499 do fxbwrite, unit, arfnew(i), 3, i+1
   
fxbfinish, unit



end

