pro test_unique_cat, dol_or_file_unique_cat
;
;   2006-01-12/NJW
;
;   Read a unique catalog and its origin catalog
;   and check the consistency
;

if n_params() ne 1 then begin
   print,'Syntax: test_unique_cat, file_name_unique_cat'
   return
endif

get_exten_no, dol_or_file_unique_cat, file_name_unique_cat, uextno
if uextno eq 0 then uextno = 1

if not file_test(file_name_unique_cat,/reg) then begin
   print,file_name_unique_cat+' does not exist'
   return
endif

hdr = headfits( file_name_unique_cat, ext=uextno )
inputcat = fxpar( hdr, 'inputcat' )

get_exten_no, inputcat, file_inputcat, extno

if not file_test(file_inputcat,/reg) then begin
   print,'The mother catalog: '+file_inputcat+' does not exist'
   return
endif

if extno eq 0 then dol_cat = inputcat+'+1' else $
                   dol_cat = inputcat
rdfitscol, dol_cat, ra_objs, 'ra_obj', nrows=nrowss
rdfitscol, dol_cat, dec_objs, 'dec_obj',/sil
rdfitscol, dol_cat, names, 'name',/sil
names = strtrim(names,2)
rdfitscol, dol_cat, detsigs, 'detsig',/sil

dol_ucat_ks = file_name_unique_cat+'+1'
rdfitscol, dol_ucat_ks, ra_obj, 'ra_obj', nrows=nrows
rdfitscol, dol_ucat_ks, dec_obj, 'dec_obj',/sil
rdfitscol, dol_ucat_ks, name, 'name',/sil
name = strtrim(name,2)
rdfitscol, dol_ucat_ks, detsig, 'detsig',/sil
rdfitscol, dol_ucat_ks, err_rad, 'err_rad',/sil
rdfitscol, dol_ucat_ks, numfind, 'numfind',/sil

logfile = get_next_filename('tuc_???.txt')
openw, log, logfile, /get_lun
printf,log,'//     '+systime()
printf,log,'// test_unique_cat, '+dol_or_file_unique_cat
printf,log,'// Mother catalog: '+inputcat
printf,log,'//'
fxbopen, unit, file_name_unique_cat, 1
lcolnum = fxbcolnum(unit,'list_int')

for i = 0, nrows-1 do begin
   if name(i) eq 'NEW SOURCE' then continue ; skip when not identified
   printf,log,'// i = ', i,'  ; -------------------'
   printf,log,'// ucat_name = '+name(i)
   fxbread, unit, list_int, lcolnum, i+1
   refcat = nearest_source( ra_obj(i), dec_obj(i), 0.4 )
   printf,log,'// nearest_source = '+refcat(0)
   distb = arcdist(float(refcat(1)),float(refcat(2)),ra_obj(i),dec_obj(i))
   printf,log,'// distance = ', distb*60.,' ; arcmin'
   printf,log,'// numfind = ', numfind(i)
   w = where( name(i) eq names, nw )
   printf,log,'// n_found_in_mother_cat = ', nw
   w = where( name(i) ne names(list_int), nw )
   printf,log,'// n_of_false_ids = ', nw
   if nw gt 0 then $
      for j = 0, nw-1 do printf,log,'// included = '+names(list_int(w(j)))
endfor

fxbclose, unit
free_lun, log

end
