pro textbox, x, y, str, boxnorm, charsize=charsize, $
                     alignment=alignment,notext=notext,normal=normal,$
                     charheight=charheight
;
;  Print out a text string 'str' just as 'xyouts'. This procedure
;  also returns a box [x1,y1,x2,y2] in normal coordinates around
;  the text string
;
;  The keyword 'notext' inhibits the output of text to window
;  but only sets the circumscribing box
;
;  With keyword 'normal' set (x,y) must be in normal coordinates
;  else in data coordinates
;
;   991129/NJW
;
if n_params() ne 4 then begin
   print,'%TEXTBOX: textbox, x, y, str, boxnorm,$ '
   print,'             charsize=charsize,notext=notext, $'
   print,'             normal=normal, charheight=charheight'
   return
endif

chsiz = 1.
if keyword_set(charsize) then chsiz = charsize
align = 0.0
if keyword_set(alignment) then align=alignment
nom = 0
if keyword_set(normal) then nom = 1
height = 15.
if keyword_set(charheight) then height = charheight

; Write string to window

if keyword_set(notext) then begin
   xyouts,x,y,str,width=wnorm,charsize=-chsiz,alignment=align,normal=nom
endif else begin
   xyouts,x,y,str,width=wnorm,charsize=chsiz,alignment=align,normal=nom
endelse

; start of string position in normal coordinates:

if nom then begin
   xstartnorm = x - align*wnorm
   ystartnorm = y
endif else begin
   res = convert_coord([x,y],/data,/to_normal)
   xstartnorm = res(0) - align*wnorm
   ystartnorm = res(1)
endelse

; end of string position in normal coordinates:

xendnorm = xstartnorm + wnorm
yendnorm = ystartnorm

; Now get the size in y direction:

; start position in device coordinates:
res = convert_coord([xstartnorm,ystartnorm],/normal,/to_device)
xstartdev = res(0)
ystartdev = res(1) - 0.2*height

; The standard charactersize in y direction is 10 in device coordinates

yenddev = ystartdev + height
res = convert_coord([xstartdev,yenddev],/device,/to_normal)
yendnorm = res(1)
res = convert_coord([xstartdev,ystartdev],/device,/to_normal)
ystartnorm = res(1)

boxnorm = [xstartnorm, ystartnorm, xendnorm, yendnorm]

end
