function thruput_avg105, offaxis
;
;  Calculates the throughput of JEMX for a source at offaxis [degrees]
;  relative to the instrument optical axis
;  The derived angle 'omega' is defined
;  with respect to a collimator grid direction
;
;   NJW  970221
;    Cloned from thruput.pro 980828 (NJW)
;    Cloned from thruput_instr.pro 040330 (NJW)
;     NB! radiusMax = 105 mm in detector
;

yp = offaxis * 60
zp = offaxis * 0.

; --- off axis angle

alpha = sqrt(yp^2 + zp^2) / 3437.75  ; converted to radians
;* print,'alpha = ', alpha*3437.75, ' arcmin'

; --- Omega angle (azimuth)

angles = abs([zp,yp])
omega = atan(min(angles), max(angles))

; --- area of the two circles

d = tan(alpha) * 3401.                     ; Det-Mask
f = circ_area1(d, 267.5, 105.) / (!pi * 105.^2)
;* print,'rel. circ area = ', f

; --- through collimator

q = (57./6.6) * tan(alpha)
;* print,'q = ', q
t = (1 - q * cos(omega)) * (1. - q * sin(omega))
;* print,' thru coll = ', t

return, (f * t) > 0.

end
