pro triplot, x, y1, y2, y3, share1, share2, ps1=ps1, ps2=ps2, ps3=ps3, $
     smsz1=smsz1, smsz2=smsz2, smsz3=smsz3, $
     yr1=yr1, yr2=yr2, yr3=yr3, psign=psign, pnum=pnum, $
     title=title, ytit1=ytit1, ytit2=ytit2, ytit3=ytit3, xtit=xtit
;
;  Plot three frames with common x-axis
;
;    2005-09-08/NJW
;    2005-12-06/NJW, updated to include keywords 'smszi' for symbol size
;
;    Note that the general functionality has only been introduced for the
;    first plot and must be added for the second and third one for
;    completeness.
;
if n_params() ne 6 then begin
   print,'Syntax: triplot, x, y1, y2, y3, share1, share2, [, ps1=][, ps2=] $'
   print,'  [, ps3=][,yr1=][,smsz1=][,smsz2=][,smsz3=][, yr2=][, yr3=][, title=] $'
   print,'  [, ytit1=][, ytit2=][, ytit3=][, xtit=]'
   print,'  ''share1'' is the vertical fraction of the plot window occupied by the upper plot'
   print,'  ''share2'' is the vertical fraction of the plot window occupied by the middle plot'
   print,' y1, y2, and y3 can be 2D arrays, where the first dimension must match'
   print,' the dimension of x. In that case y1(*,1 etc) will be shown as overplot'
   print,' Use e.g.  ynew = [[y1old],[y2old],[  ],...]'
   return
endif

!p.multi = [0,1,3]
maxx = max(x)
minx = min(x)
xwidth = maxx - minx
!x.range = [minx-0.05*xwidth,maxx+0.05*xwidth]

normxlow = 0.1
normxhigh = 0.95
normylow = 0.1
normyhigh = 0.95
yboarder1 = normyhigh - share1*(normyhigh-normylow)
yboarder2 = normyhigh - (share1+share2)*(normyhigh-normylow)

;  The first plot

!p.position = [normxlow,yboarder1,normxhigh,normyhigh]
nopl = 0 ; Number of overplots
sz = size(y1)
if sz(0) eq 2 then begin
   z = y1(*,0)
   nopl = sz(2)
   if keyword_set(ps1) then begin
      if n_elements(ps1) ne sz(2) then begin
         print,'Size of ps1 must match 2. dim of y1'
         return
      endif
      zps1 = ps1(0)
   endif
   if keyword_set(smsz1) then begin
      if n_elements(smsz1) ne sz(2) then begin
         print,'Size of smsz1 must match 2. dim of y1'
         return
      endif
   endif else begin
      smsz1 = fltarr(sz(2)) + 1.0
   endelse
endif else begin
   z = y1
   if keyword_set(ps1) then zps1 = ps1
   if not keyword_set(smsz1) then smsz1 = 1.
endelse

plot,x,z,ps=zps1,yr=yr1,xstyle=7,title=title,ytit=ytit1,symsize=smsz1(0)
if nopl gt 1 then begin
   for i = 1, nopl-1 do begin
      if keyword_set(ps1) then oplot,x,y1(*,i),ps=ps1(i), symsize=smsz1(i) $
             else oplot,x,y1(*,i), symsize=smsz1(i)
   endfor
endif
axis,xaxis=1,xtickname=replicate(' ',60)
axis,xaxis=0,xtickname=replicate(' ',60)
if keyword_set(pnum) then plotnumber,pnum
if keyword_set(psign) then plotsign

; The second plot

!p.position = [normxlow,yboarder2,normxhigh,yboarder1]
plot,x,y2,ps=ps2,yr=yr2,ytit=ytit2,xstyle=7
axis,xaxis=1,xtickname=replicate(' ',60)
axis,xaxis=0,xtickname=replicate(' ',60)

; The third plot

!p.position = [normxlow,normylow,normxhigh,yboarder2]
plot,x,y3,ps=ps3,yr=yr3,ytit=ytit3, xtit=xtit

; reset

!p.multi = 0
!p.position = 0

end
