pro tvcont2_2in1, a, aa, b, bb, xa, ya, xb, yb, plsize=plsize, $
         pane=pane, lva=lva, lvb=lvb, _extra=e

;
;  Combine two 'tv' plots each with contour plot 
;  in one figure - side by side
;
;      tvscl(a) + contour(aa)   |    tvscl(b) + contour(bb)
;
npar = n_params()
if npar lt 4 then begin
   print,'TVCONT2_2IN1, a, aa, b, bb[, xa, ya[, xb, yb]],plsize=,pane='
   return
end
pan = 0
if keyword_set(pane) then pan = pane

sza = size(a)
szaa = size(aa)
if (sza(1) ne szaa(1)) or (sza(2) ne szaa(2)) then begin
   print,'Error - bad dimensions'
   return
endif

szb = size(b)
szbb = size(bb)
if (szb(1) ne szbb(1)) or (szb(2) ne szbb(2)) then begin
   print,'Error - bad dimensions'
   return
endif

xdima = sza(1)
xdima = sza(1)
ydima = sza(2)
aspect = float(ydima)/xdima

;
; Define default values
;
if !d.name eq 'PS' then plsz = 16. else plsz = 600
mx = 0.07    ; normalized coordinates
nx = 0.07    ; normalized coordinates
ox = 0.05    ; normalized coordinates
my = 0.1    ; normalized coordinates
ny = 0.05    ; normalized coordinates
sx = 0.5*(1 - mx - nx - ox)    ; normalized coordinates
sy = 1 - my - ny    ; normalized coordinates
x1 = mx
x2 = mx + sx
x3 = mx + sx + nx
x4 = mx + sx + nx + sx
y1 = my
y2 = my + sy
;
; Use keyword value is given
;
if keyword_set(plsize) then plsz = plsize
print,'aspect = ', aspect,'  plsz = ', plsz

; xsz is the window size (device coordinates) in x

; sfx is x frame size in device coordinates

; aspect = sfy / sfx

xsz = plsz
sfx = plsz * sx
sfy = aspect * sfx
ysz = sfy / sy

!x.style = 1
!y.style = 17
if !d.name eq 'PS' then begin
   xof = 2. + (16.-xsz)/2
   yof = 8. + (16.-ysz)/2
   device,xsize=xsz,ysize=ysz,xo=xof,yo=yof
endif

; 1)  Start first frame

!p.position = [x1,y1,x2,y2]
xfactor = !p.position(2)-!p.position(0)
yfactor = !p.position(3)-!p.position(1)
if !d.name eq 'X' then begin
   window,pan,xs=xsz,ys=ysz
   tv,replicate(100,xsz,ysz)
   tvscl,congrid(a,xsz*xfactor,ysz*yfactor), $
                xsz*!p.position(0),ysz*!p.position(1)
endif else begin
   !x.window(0) = !p.position(0)
   !x.window(1) = !p.position(2)
   !y.window(0) = !p.position(1)
   !y.window(1) = !p.position(3)
   tvscl,congrid(a,400,400*aspect),!x.window(0),!y.window(0),$
      xsize=!x.window(1)-!x.window(0),$
      ysize=!y.window(1)-!y.window(0),/norm
endelse
if keyword_set(lva) then begin
   if npar lt 5 then contour,aa,col=0,/noerase,lev=lva, _extra=e $
      else contour,aa,xa,ya,col=0,/noerase,lev=lva, _extra=e
endif else begin
   if npar lt 5 then contour,aa,col=0,/noerase,_extra=e $
      else contour,aa,xa,ya,col=0,/noerase,_extra=e
endelse

; 2) Second frame

!p.position = [x3,y1,x4,y2]
xfactor = !p.position(2)-!p.position(0)
yfactor = !p.position(3)-!p.position(1)
if !d.name eq 'X' then begin
   tvscl,congrid(b,xsz*xfactor,ysz*yfactor), $
                xsz*!p.position(0),ysz*!p.position(1)
endif else begin
   !x.window(0) = !p.position(0)
   !x.window(1) = !p.position(2)
   !y.window(0) = !p.position(1)
   !y.window(1) = !p.position(3)
   tvscl,congrid(b,400,400*aspect),!x.window(0),!y.window(0),$
      xsize=!x.window(1)-!x.window(0),$
      ysize=!y.window(1)-!y.window(0),/norm
endelse
if keyword_set(lvb) then begin
   if npar lt 5 then contour,bb,col=0,/noerase,lev=lvb, ytit='',_extra=e $
      else if npar lt 7 then contour,bb,xa,ya,col=0,/noerase,lev=lvb, ytit='',_extra=e $
      else contour,bb,xb,yb,col=0,/noerase,lev=lvb, ytit='',_extra=e
endif else begin
   if npar lt 5 then contour,bb,col=0,/noerase,ytit='',_extra=e $
      else if npar lt 7 then contour,bb,xa,ya,col=0,/noerase,ytit='',_extra=e $
      else contour,bb,xb,yb,col=0,/noerase,ytit='',_extra=e
endelse

end



