pro tvcont_aitoff, a, plsize=plsize, pane=pane, _extra=e, bgcol=bgcol,$
           dlon=dlon, dlat=dlat,linestyle=linestyle,ppos=ppos
;
; Combine 'tv' plot with contour plot for Aitoff projection of full sphere
; Assume that 'a' is a map in a full Aitoff projection
;
; The keyword 'plsize' defines the size (for PS in cm)
; or the largest side of the plot
;
;   2006-09-20/NJW, based on tvcont.pro and aitoff_gridm.pro
;
npar = n_params()
if npar lt 1 then begin
   print,'tvcont_aitoff, array[, x, y][,pane=][,plsize=][,bgcol=][,extra keywords]'
   print,'Syntax:  aitoff_gridm[,/help][,dlon=][,dlat][,linestyle=][,ppos=]'
   print,'   Keyword      help   :   print this text'
   print,'                dlon   :   step in longitude [default 60 deg]'
   print,'                dlat   :   step in latitude [default 30 deg]'
   print,'             linestyle :   usual IDL definition'
   print,'                ppos   :   override IDL !p.position'
   return
endif

pan = 0
if keyword_set(pane) then pan = pane
bgc = 100
if keyword_setx(bgcol) then bgc = bgcol
print,'bgcol = ', bgc

sz = size(a)
xdim = sz(1)
ydim = sz(2)
aspect = (ydim*1.0)/xdim
; Define default values
;
if !d.name eq 'PS' then plsz = 16. else plsz = 600
;
; Use keyword value is given
;
if keyword_set(plsize) then plsz = plsize
print,'aspect = ', aspect,'  plsz = ', plsz
if aspect lt 1.0 then begin
   xsz = plsz
   ysz = aspect * plsz
endif else begin
   xsz = plsz / aspect
   ysz = plsz
endelse
print,'xsz = ', xsz, ' ysz = ', ysz,' plsz = ',plsz
!x.style = 5
!y.style = 21
if !d.name eq 'PS' then begin
   xof = 2. + (16.-xsz)/2
   yof = 8. + (16.-ysz)/2
   device,xsize=xsz,ysize=ysz,xo=xof,yo=yof
endif
!p.position = [0.01,0.01,0.99,0.99]
xfactor = !p.position(2)-!p.position(0)
yfactor = !p.position(3)-!p.position(1)
if !d.name ne 'PS' then begin
   window,pan,xs=xsz,ys=ysz
   tv,replicate(bgc,xsz,ysz)
   tvscl,shift(congrid(a,xsz*xfactor,ysz*yfactor),-1,0), $
                xsz*!p.position(0),ysz*!p.position(1)
endif else begin
   tvscl,shift(congrid(a,800,800*aspect),-1,0),!x.window(0),!y.window(0),$
      xsize=!x.window(1)-!x.window(0),$
      ysize=!y.window(1)-!y.window(0),/norm
endelse




x = xlingen(xdim,-180,180)
y = xlingen(ydim,-90,90)
contour,a,x,y,col=0,/noerase,_extra=e









if not keyword_set(linestyle) then linestyle = 1
if not keyword_set(dlon) then dlon = 60.
if not keyword_set(dlat) then dlat = 30.
step_lon = dlon - 0.011/fix(360./dlon)

; Gridlines with constant longitude

b = xlingen(100,-90,90)
for lon = -179.99, 180.1, step_lon do begin
   l = fltarr(100) + lon
   aitoff, l, b, x, y
   listy = linestyle
   if lon lt -179 or lon gt 179 then listy = 0
   oplot, x, y, li=listy
endfor

; Gridlines with constant latitude

l = xlingen(100,-179.999,180)
for lat = -90.+dlat,90.01-dlat,dlat do begin
   b = fltarr(100) + lat
   aitoff, l, b, x, y
   oplot,x,y,li=linestyle
endfor

end
