function twod_intpol, x, y, xarr, yarr, array
;
; 2D linear interpolation
;
;  Call:    x      x-coordinate where value is wanted
;           y      y-coordinate where value is wanted
;           xarr   array of x-values - increasing values
;           yarr   array of y-values - increasing values
;           array  array with values

nx = n_elements(xarr)
ny = n_elements(yarr)
sz = size(array)
if nx ne sz(1) or ny ne sz(2) then begin
   print,'% TWOD_INTPOL error: mismatching array sizes'
   retall
endif

;         6       |     |
;              -------------
;         3       |     |
;              -------------
;         0       |     |
;
;               0    1    2
;
; ... Where is (x,y) in the above diagram ?

ix = 0
if x gt xarr(0) then ix = 1
if x gt xarr(nx-1) then ix = 2
iy = 0
if y gt yarr(0) then iy = 3
if y gt yarr(ny-1) then iy = 6
k = ix + iy
case k of
   0 : return, array(0,0)
   6 : return, array(0,ny-1)
   8 : return, array(nx-1,ny-1)
   2 : return, array(nx-1,0)
   3 : begin
          z = interpol(array(0,*),yarr,y)
          return,z(0)
       end
   5 : begin
          z = interpol(array(nx-1,*),yarr,y)
          return,z(0)
       end
   1 : begin
          z = interpol(array(*,0),xarr,x)
          return,z(0)
       end
   7 : begin
          z = interpol(array(*,ny-1),xarr,x)
          return,z(0)
       end
  else : begin

;
;... find y limits
;
          i1 = 0
          i2 = ny-1
          while i2 - i1 gt 1 do begin
             i = (i1 + i2)/2
             if y ge yarr(i) then i1 = i
             if y lt yarr(i) then i2 = i
          endwhile
          z1 = interpol(array(*,i1),xarr,x)
          z2 = interpol(array(*,i2),xarr,x)
          t  = z1(0) + (z2(0) - z1(0))*(y-yarr(i1))/(yarr(i2)-yarr(i1))
          return,t
        end
endcase
end
