pro unfold_grid_swids, filename, target_dir, arccheck=arccheck
;
; grid_on_sphere project (e.g. q048)
;
;   2006-12-08/NJW
;
; Get list of serial numbers
if n_params() ne 2 then begin
   print,'Syntax: unfold_grid_swids, filename, target_dir[, arccheck=]'
   print,'    Keyword arccheck eq 1  => checking for JMX1 data in archive /r8'
   print,'    Keyword arccheck eq 2  => checking for JMX2 data in archive /r8'
   return
endif

lser = comgets( filename, 'block', nvals )
arcdir = '/r8/jemx/arc/rev_2/scw/'
if keyword_set(arccheck) then begin
   openw, lun, 'failure_report.txt', /get_lun
endif

for i = 0, nvals - 1 do begin
   sernum = fix(lser(i))
   rscol, filename, swids, 1, /str, /sil, block=sernum
   fname = 'swid_'+string(sernum,format='(i5.5)')+'.list'
   write_slist, app_slash(target_dir)+fname, swids
   print,'Just made '+app_slash(target_dir)+fname
   if keyword_set(arccheck) then begin
      jmxstr = string(arccheck,format='(i1)')
      evfile = 'jmx'+jmxstr+'_events.fits.gz'
      print,'Checking for existence of jmx'+jmxstr+'_events.fits.gz ...'
      for j = 0, n_elements(swids)-1 do begin
         revol = strmid(swids(j),0,4)
         if file_test( arcdir+revol+'/'+swids(j)+'.001/'+evfile ) then begin
            print,swids(j)+' OK'
         endif else begin
            print,swids(j)+' missing'
            printf,lun,swids(j)+'  '+fname
         endelse
      endfor
   endif
      
endfor

if keyword_set(arccheck) then free_lun, lun

end
