pro uniminchi2,ndim,npoints_d,plim,prec
;
; Find minimum of multi dimensional function 'funkchi2' using uniformly
; distributed numbers
;    Call: ndim     number of dimensions
;          npoints_d number of points per dimension where function is
;                    evaluated
;          plim     2 by ndim array with coordinate limits
;          prec     ndim array with coordinate precisions
;
if( n_params() ne 4 ) then begin
   print,' unimin, dim, npoints_d, plim, prec '
   return
endif
sz = size(plim)
if( sz(0) ne 2 ) then begin
   print,'plim must be 2 dimensional'
   return
endif
if( (sz(1) ne 2) or (sz(2) ne ndim) ) then begin
   print,'The dimensions of plim must be 2 x ndim'
   return
endif
if( n_elements(prec) ne ndim ) then begin
   print,'prec must have ndim elements'
   return
endif
iter = 0
x = fltarr(ndim,npoints_d)
dif = fltarr(ndim)
p = fltarr(ndim)
delta = npoints_d / 4
;
repeat begin
;
; define uniformly distributed points for each dimension
;
   for i=0,ndim-1 do x(i,*) = distu(npoints_d)*(plim(1,i) - plim(0,i)) + plim(0,i)
   c = intarr(ndim) + npoints_d
   ymin = 1.e38
   repeat begin
      nextcomb,ndim,npoints_d,c
      for i = 0,ndim-1 do p(i) = x(i,c(i))
      y = funkchi2(p)
      if( y lt ymin ) then begin
         ymin = y
         cmin = c
      endif
   endrep until total(c) eq ndim*(npoints_d - 1)
   print,' So far best Chi2 = ', ymin
;
; Reduce interval for each dimension
;
   for i = 0, ndim-1 do begin
      klo = 0 > (cmin(i) - delta)
      khi = npoints_d-1 < (cmin(i) + delta)
      plim(0,i) = x(i,klo)
      plim(1,i) = x(i,khi)
   endfor
;
   dif(*) = plim(1,*) - plim(0,*)
   test = where( dif gt prec, ntest )
   iter = iter + 1
   print,'Iteration # ',iter
   print, plim
;
endrep until (ntest eq 0) or (iter gt 50)
end
