pro uniminchi3,ndim,npoints_d,plim,prec,ymin
;
; Find minimum of multi dimensional function 'funkchi2' using uniformly
; distributed numbers
; Some housekeeping is done to avoid scanning dimension where the fit
; cannot be improved
;    Call: ndim     number of dimensions
;          npoints_d number of points per dimension where function is
;                    evaluated
;          plim     2 by ndim array with coordinate limits
;          prec     ndim array with coordinate precisions
;
if( n_params() ne 5 ) then begin
   print,' uniminchi3, dim, npoints_d, plim, prec, ymin '
   return
endif
sz = size(plim)
if( sz(0) ne 2 ) then begin
   print,'plim must be 2 dimensional'
   return
endif
if( (sz(1) ne 2) or (sz(2) ne ndim) ) then begin
   print,'The dimensions of plim must be 2 x ndim'
   return
endif
if( n_elements(prec) ne ndim ) then begin
   print,'prec must have ndim elements'
   return
endif
iter = 0
x = fltarr(ndim,npoints_d)
p = fltarr(ndim)
delta = npoints_d / 4
;
repeat begin
;
; define uniformly distributed points for each dimension
;
   for i=0,ndim-1 do x(i,*) = distu(npoints_d)*(plim(1,i) - plim(0,i)) + plim(0,i)
;
; Start fitting
;
   dif = plim(1,*) - plim(0,*)
   sgt = where( dif ge prec, nsgt)
   slt = where( dif lt prec, nslt)
   print,'# to fit = ', nsgt,' and # to leave as is ', nslt
   r = indgen(ndim)
   ymin = funkchi2(x(*,npoints_d/2))
   print,'Initial ymin = chi2 = ', ymin
;
   if( nsgt gt 0 ) then begin   ; only fit if necessary
      if( nslt gt 0 ) then begin ; in this case some will not be fit
         r(0:nsgt-1) = sgt
         r(nsgt:ndim-1) = slt
      endif
      print,' permutation r = ', r
;
      c = intarr(nsgt) + npoints_d
      cmin = c / 2
      for i = nsgt,ndim-1 do begin
         p(r(i)) = x(r(i), npoints_d/2)
         print, 'p(',r(i),') fixed at ',p(r(i))
      endfor
      repeat begin
         nextcomb,nsgt,npoints_d,c
         for i = 0,nsgt-1 do p(r(i)) = x(r(i),c(i))
         y = funkchi2(p)
         if( y lt ymin ) then begin
            ymin = y
            cmin = c
         endif
      endrep until total(c) eq nsgt*(npoints_d - 1)
      print,' So far best Chi2 = ', ymin
;
; Reduce interval for each fitted dimension
;
      for i = 0, nsgt-1 do begin
         klo = 0 > (cmin(i) - delta)
         khi = npoints_d-1 < (cmin(i) + delta)
         plim(0,r(i)) = x(r(i),klo)
         plim(1,r(i)) = x(r(i),khi)
      endfor
   endif
;
   dif = plim(1,*) - plim(0,*)
   test = where( dif gt prec, ntest )
   iter = iter + 1
   print,'Iteration # ',iter
   print, plim
;
endrep until (ntest eq 0) or (iter gt 50)
end
