pro upd_all_arf_from_rmfgrp, numjemx
;
;  Replace the column 'AXIS_ARF' in /home/njw/jemx/spectra/arf_repair/jmxi_all_arf_0003.fits
;  with values from the jmxi_rmf_grp_nnnn.fits files
;
;  'eline' is table (size 500) of energies (in keV)
;         and is taken from the actual jmxi_rmf_grp_nnnn.fits
;
;   2004-03-24/NJW
;   2004-05-19/NJW updated to insert ARFs in version 0003
;

if n_params() lt 1 then begin
   print,'Syntax: upd_all_arf_from_rmfgrp, numjemx
   return
endif

strj = stri(numjemx)
arf_all_file = '/home/njw/jemx/spectra/arf_repair/jmx'+strj+'_all_arf_0003.fits'

if not file_test(arf_all_file,/reg) then begin
   print,'No action - '+arf_all_file+' not found'
   return
endif

rmfgrp = strarr(6,2)
ij = numjemx - 1

; Define where to get the input data from

rmfgrp(0,0) = '/home/njw/jemx/response_matrix/jmx1_rmf_grp_0003.fits'
rmfgrp(1,0) = '/home/njw/jemx/response_matrix/jmx1_rmf_grp_0003.fits'
rmfgrp(2,0) = '/r6/jemx/spec_calib/jmx1_0044/j_src_spectra-4.0.0/jmx1_rmf_grp_0014.fits'
rmfgrp(3,0) = '/r6/jemx/spec_calib/jmx1_0045/j_src_spectra-4.0.0/jmx1_rmf_grp_0015.fits'
rmfgrp(4,0) = '/r6/jemx/spec_calib/jmx1_0102/j_src_spectra-4.0.0/jmx1_rmf_grp_0016.fits'
rmfgrp(5,0) = '/r6/jemx/spec_calib/jmx1_0170/j_src_spectra-4.0.0/jmx1_rmf_grp_0017.fits'
rmfgrp(0,1) = '/home/njw/jemx/response_matrix/jmx2_rmf_grp_0003.fits'
rmfgrp(1,1) = '/home/njw/jemx/response_matrix/jmx2_rmf_grp_0003.fits'
rmfgrp(2,1) = '/r6/jemx/spec_calib/jmx2_0044/j_src_spectra-4.0.0/jmx2_rmf_grp_0014.fits'
rmfgrp(3,1) = '/r6/jemx/spec_calib/jmx2_0045/j_src_spectra-4.0.0/jmx2_rmf_grp_0015.fits'
rmfgrp(4,1) = '/r6/jemx/spec_calib/jmx2_0102/j_src_spectra-4.0.0/jmx2_rmf_grp_0016.fits'
rmfgrp(5,1) = '/r6/jemx/spec_calib/jmx2_0170/j_src_spectra-4.0.0/jmx2_rmf_grp_0017.fits'



hdr = headfits(arf_all_file, exten=1)
nrows = fxpar(hdr,'naxis2')
if nrows lt 12 then begin
   print,'Wrong number of rows'
   return
endif

; Open the all_arf file
   
fxbopen, unit, arf_all_file, 1, access='RW'
   

for irmf = 0, 5 do begin

   row_num = irmf + 7 ; First 6 rows are for j_src_spectra-3.5.1

   ;   Get the RMF data

   rmf_file = rmfgrp(irmf,ij)
   if not file_test(rmf_file,/reg) then begin
      print,'WARNING ! - '+rmf_file+' not found'
      continue
   endif

   grpname = rmf_file+'+1'

   ebm_get_child_by_name,grpname,'JMX'+strj+'-RMF.-RSP',rmf_name
   rdfitscol,rmf_name,elo,'ENERG_LO',/sil
   rdfitscol,rmf_name,ehi,'ENERG_HI',/sil
   eline = 0.5*(elo + ehi)

   ebm_get_child_by_name,grpname,'JMX'+strj+'-AXIS-ARF',arf_name
   rdfitscol,arf_name,arf,'SPECRESP',/sil
   
   ; write new values
   
   dat = ndate(2)

   colnum = fxbcolnum( unit, 'DATE' )
   fxbwrite, unit, dat, colnum, row_num

   colnum = fxbcolnum( unit, 'ELINE' )
   fxbwrite, unit, eline, colnum, row_num

   colnum = fxbcolnum( unit, 'AXIS_ARF' )
   fxbwrite, unit, arf, colnum, row_num
   
   colnum = fxbcolnum( unit, 'CREATOR' )
   fxbwrite, unit, 'j_src_spectra 4.0.0', colnum, row_num
   
endfor


fxbfinish, unit

print, arf_all_file+' has now been updated'
print



end


