pro upd_jmx_image_files
;
;  Update JEM-X image files with a keyword 'DATGROUP' showing
;  the main group of the data ownership
;
;  Standard values are 'SURVEY', 'PV', and 'PRIVATE'
;
;  An optional keyword: 'DATOWNER' can be added when the owner
;  name is known (e.g. 'Mereghetti'). After expiration of
;  ownership period (1 year) this could change value to 'PUBLIC'
;
;  2004-02-11/NJW
;
;----------------------

; Prepare updates with ftools

s = 'DATGROUP = ''PV'' / Performance verification phase'
write_slist,'tmpfil_pv',s
s = 'DATGROUP = ''SURVEY'' / Belongs to survey'
write_slist,'tmpfil_survey',s
s = 'DATGROUP = ''PRIVATE'' / Private data'
write_slist,'tmpfil_private',s

cmark = ['', '1_5_']
stype = ['PV','SURVEY']

;  Open log file

openw,log,'upd_jmx_image_files.log',/get_lun

first = 1

; Get list of all CBJ images

if file_test('cbj_images.idlsav') then begin
   restore,file='cbj_images.idlsav'
endif else begin
   spawn,'find /r6/jemx/cbj/jmx2_images -name ''skyimage*fits'' -print', cbj_images
   save,cbj_images,file='cbj_images.idlsav'
endelse

for type = 0, 1 do begin ; BIG loop  type=0: PV, type=1: SURVEY

;  Get list of SWIDs

if type eq 0 then begin
   list = read_slist('/r6/jemx/pointings/swids_of_group_pv.list', count=n_list)
endif else begin
   list = read_slist('/r6/jemx/pointings/swids_of_group_survey.list', count=n_list)
   ;list = reverse(list)
endelse

; Walk through list and check the existence of NL and CBJ
; image files

k_found = 0
k = 0L
for i = 0, n_list-1 do begin

   print,'SWID ', list(i)
   print

   for icm = 0,1 do begin
      capcmark = cmark(icm)

      for ecode = 0, 4 do begin

         k = k + 1L
         ;p = k mod 235L
         p = 1
         np = not p

         cbj_rev = stri(fix(strmid(list(i),0,4)))
         strrev = strmid(list(i),0,4)
         cbj_pid = stri(fix(strmid(list(i),4,4)))
         cbj_eco = stri(ecode)
         fname = '/r6/jemx/cbj/jmx2_images/'+strrev+$
            '/skyimage_'+capcmark+cbj_rev+'_'+cbj_pid+'_'+cbj_eco+'.fits'
         ;monitor, np, 'fname: '+fname, /kbhit

         if file_test(fname,/reg) then begin
            monitor, np, 'fname: '+fname,/kbhit
            if first then begin
               cbj_upd_list = fname
               first = 0
            endif else begin
               cbj_upd_list = [cbj_upd_list, fname]
            endelse
            num_ext = nfits_extens(fname)
            for i_ext = 0, num_ext do begin
               hdr = headfits(fname,ext=i_ext)
               dg = fxpar(hdr,'DATGROUP')
               sz = size(dg)
               if sz(1) ne 7 then begin ; no such keyword
                  monitor, np, 'ext#'+stri(i_ext)+' No DATGROUP keyword, update!'
                  if type eq 0 then begin
                     spawn,'fmodhead '+fname+'+'+stri(i_ext)+' tmpfil_pv'
                  endif else begin
                     spawn,'fmodhead '+fname+'+'+stri(i_ext)+' tmpfil_survey'
                  endelse
               endif else begin
                  monitor, np, 'ext#'+stri(i_ext)+$
                    ' DATGROUP is there, check content'
                  if strtrim(dg,2) ne stype(type) then begin
                     printf,log,'----DATGROUP conflict---- Expected '+stype(type)
                     printf,log,fname+'+'+stri(i_ext)+' '+dg
                     monitor, np, 'Conflict! '+dg
                  endif else begin
                     monitor, np,'OK ('+dg+')'
                  endelse
               endelse
            endfor
            k_found = k_found + 1
         endif  else begin
            ;monitor, np, 'No such file - no action',/kbhit
         endelse

      endfor ; Loop over ecode

   endfor ; Loop over coarse/fine images

endfor ; Loop over all SWIDs in list

endfor ; End of BIG 'type'(PV - SURVEY) loop

print
print,'k_found = ', k_found

free_lun, log

not_pv_survey = filter_done( cbj_upd_list, cbj_images )

write_slist,'not_pv_survey.list', not_pv_survey
write_slist,'cbj_upd_list.list', cbj_upd_list

end
