pro upd_jmx_image_private
;
;  Update JEM-X image files with a keyword 'DATGROUP' showing
;  the main group of the data ownership
;
;  Assume that 'upd_jmx_image_files' has been run updating
;  PV and SURVEY groups.
;  The remaining image files are allocated to group 'PRIVATE'
;
;  An optional keyword: 'DATOWNER' can be added when the owner
;  name is known (e.g. 'Mereghetti'). After expiration of
;  ownership period (1 year) this could change value to 'PUBLIC'
;
;  2004-02-11/NJW
;
;----------------------

; Prepare updates with ftools

s = 'DATGROUP = ''PRIVATE'' / Private data'
write_slist,'tmpfil_private',s


;  Open log file

openw,log,'upd_jmx_image_private.log',/get_lun

first = 1

; Get list of all CBJ left-over images

list = read_slist('not_pv_survey.list',count=n_list)


; Walk through list

for i = 0, n_list-1 do begin

   print,'File: ', list(i)
   print

   if file_test(list(i),/reg) then begin

      print,'Updating: '+list(i)
      num_ext = nfits_extens(list(i))
      for i_ext = 0, num_ext do begin
         hdr = headfits(list(i),ext=i_ext)
         dg = fxpar(hdr,'DATGROUP')
         sz = size(dg)
         if sz(1) ne 7 then begin ; no such keyword
            spawn,'fmodhead '+list(i)+'+'+stri(i_ext)+' tmpfil_private'
         endif else begin
            if dg ne stype(type) then begin
               printf,log,'----DATGROUP conflict---- Expected PRIVATE'
               printf,log,list(i)+'+'+stri(i_ext)+' '+dg
            endif
         endelse
      endfor

   endif  else begin
      printf,log,'----Missing file----'
      printf,log,list(i)
   endelse


endfor


free_lun, log


end
