pro upd_jnsc
;
;  Update the JEMX New Source Catalog with a new entry.
;
;   2003-11-28/NJW
;
ra = 0.0
read,'RA ? ... ', ra
dec = 0.0
read,'DEC ? ... ', dec
unique = 0
read,'Unique # ... ', unique

;  Get source name

sourceid = jmxname(ra,dec)

print,'Resulting source name: '+sourceid
print

fname = strmid(sourceid,4,7)+'.tex'
user = getenv('USER')
if user eq 'njw' then begin
   htex_file = '/r4/njw/Htex/jemx_new_srcs/'+fname
endif else htex_file = fname

print,'Going to create '+htex_file
openw,htex,htex_file,/get_lun
printf,htex,'\newpage'
printf,htex
printf,htex,'\subsection{'+sourceid+'}\index{'+sourceid+'}'
printf,htex,'Responsible: '+strupcase(user)+' (DSRI)\\[2mm]'
printf,htex,'Latest update: '+date(3)+'\\[2mm]'
printf,htex,'\coords{'+string(ra,format='(f7.3)')+'}{'+string(dec,format='(f7.3)')+'}\\[2mm]'
printf,htex,'The coordinates are based on values in JSCC.'
printf,htex
printf,htex,'\subsubsection{Method of detection}'
printf,htex
printf,htex,'\subsubsection{SWIDs used for detection}'
printf,htex

if unique ge 0 then begin

   get_jsc_details, unique, logname=logname

   printf,htex,'\begin{tabular}{ccccc}'

   list = read_slist(logname)
   nlist = n_elements(list)
   for i = 0, nlist-1 do printf,htex,list(i)

   printf,htex,'\end{tabular}'

endif

printf,htex,'\subsubsection{Catalogs consulted for attempted identification}'
printf,htex
printf,htex,'/r6/jemx/catalogs/gnrl\_refr\_cat\_0009.fits by ISDC\\[2mm]'
printf,htex,'/r6/jemx/catalogs/DSRI\_CAT\_002.fits by DSRI (NJW)\\[2mm]'
printf,htex,'/r6/jemx/catalogs/nl\_cat\_combine.fits by DSRI (NL)'

printf,htex
printf,htex,'\subsubsection{Verification of pointing quality}'
printf,htex
printf,htex,'\subsubsection{Comparison with IBIS results}'
printf,htex
printf,htex,'\subsubsection{Results from other satellites}'
printf,htex
printf,htex,'\subsubsection{Spectrum}'
printf,htex
printf,htex,'\subsubsection{Lightcurve}'
printf,htex
printf,htex,'\subsubsection{Suggested classification (source category)}'

free_lun,htex

;-------------------------------------------------

; Update /r6/jemx/catalogs/jemx_new_sources_0001.fits

catfile = '/r6/jemx/catalogs/jemx_new_sources_0001.fits'

print,'Going to update '+catfile

spawn,'/home/njw/bin/fits_add_rows '+catfile+' 1'

hdr = headfits(catfile,exten=1)
nrows = fxpar(hdr,'NAXIS2')

print,'After adding extra row there are '+stri(nrows)+' rows'

fxbopen,unit,catfile,1,hdr,access='RW'

errmsg = ''
colnum_ra = fxbcolnum( unit, 'RA_OBJ', err=errmsg)
if errmsg ne '' then print,'##9## errmsg: ', errmsg
colnum_dec = fxbcolnum( unit, 'DEC_OBJ', err=errmsg)
if errmsg ne '' then print,'##10## errmsg: ', errmsg
colnum_id = fxbcolnum( unit, 'SOURCEID', err=errmsg)
if errmsg ne '' then print,'##11## errmsg: ', errmsg
colnum_status = fxbcolnum( unit, 'STATUS', err=errmsg)
if errmsg ne '' then print,'##12## errmsg: ', errmsg

fxbwrite, unit, sourceid, colnum_id, nrows, err=errmsg
if errmsg ne '' then print,'##13## errmsg: ', errmsg
fxbwrite, unit, ra, colnum_ra, nrows, err=errmsg
if errmsg ne '' then print,'##14## errmsg: ', errmsg
fxbwrite, unit, dec, colnum_dec, nrows, err=errmsg
if errmsg ne '' then print,'##15## errmsg: ', errmsg
fxbwrite, unit, 0, colnum_status, nrows, err=errmsg
if errmsg ne '' then print,'##16## errmsg: ', errmsg

fxbfinish, unit

if user ne 'njw' then begin
   print,'Please edit the just created file: '+htex_file
   print,'to add and correct the information'
   print,'Then send an email to njw@dsrid.k attaching '+htex_file
   print,'for adding to the written document.'
   print,' -- Thanks'
   print
endif

end
