pro upd_respfile, list_of_spe_fitsnames, force=force
;
;  Update the RESPFILE keyword to position reachable on the SUN unix
;  (UHURU) system
;
;  This is specially written for data produced with script 'dojsa'
;
;   2005-08-05/NJW
;
if n_params() ne 1 then begin
   print,'Syntax: upd_respfile, list_of_fitsnames_of_spectral_files'
   print,'  Keyword ''force'' : if set, then the updating will happen'
   print,'                      even if already done'
   return
endif

nlist = n_elements(list_of_spe_fitsnames)

for i = 0, nlist-1 do begin

   hdr = headfits(list_of_spe_fitsnames(i),exten=1)
   print,'Doing: '+list_of_spe_fitsnames(i)

   naxis2 = fxpar(hdr,'NAXIS2')
   if naxis2 le 0 then begin
      print,'No sources found in spectral file, skip'
      continue
   endif

   respfile = fxpar(hdr,'RESPFILE',count=n)
   if n ne 1 then begin
      print,'Did not find RESPFILE keyword, skip'
      continue
   endif

   if not keyword_set(force) then begin
      rspforig = fxpar(hdr,'RSPFORIG',count=n)
      if n ge 1 then begin
         print,'RSPFORIG keyword exists already, skip'
         continue
      endif
   endif

   rdfitscol,list_of_spe_fitsnames(i)+'+1',rowid,'ROWID'
   print,'  ROWID found in the file:'
   printl,rowid
   ;**rdfitscol,list_of_spe_fitsnames(i)+'+1',ancrfile,'ANCRFILE',nrows=nrows
   ancrfile = strarr(naxis2)
   for j = 0, naxis2-1 do begin
      ancr = basename(list_of_spe_fitsnames(j))+'{'+stri(j+1)+'}'
      strput, ancr, 'arf', strpos(ancr,'spe')
      ancrfile(j) = ancr
   endfor
   fits_replace_col, list_of_spe_fitsnames(i)+'+1','ANCRFILE',ancrfile,1

   text = strarr(2)
   text(0) = 'RSPFORIG = '''+respfile+''' / Original RESPFILE'
   text(1) = 'RESPFILE = ''/r6/jemx/ic/rmf_grp/'+basename(respfile)+''' / New RESPFILE'
   write_slist,'tmpfil',text

   spawn,'fmodhead '+list_of_spe_fitsnames(i)+'+1 tmpfil=tmpfil'

endfor

end
