pro update_all_arf, numjemx, eflt, row=row
;
;  Add or replace a row in /home/njw/jemx/spectra/jmxi_all_arf_0001.fits
;    If keyword 'row' is given then this row number wil be updated
;    else a new row will be added to the file
;
;  'eline' is table (size 500) of energies (in keV)
;         and is taken from jmxi_rmf_grp_0003.fits
;  'eflt' is the EFLT table (size 500) of response relative to
;                jmxi_rmf_grp_0003.fits (JMXi-AXIS-ARF)
;  'axis_arf' is calculated here as the product
;                of eflt and references ARF (see line above)
;
;   2003-06-17/NJW
;

if n_params() lt 2 then begin
   print,'Syntax: update_all_arf, numjemx, eflt[, row=]'
   return
endif

neflt = n_elements(eflt)
if neflt ne 500 then begin
   print,'Argument ''eflt'' has wrong number of elements (should be 500)'
   return
endif

strj = stri(numjemx)
arf_all_file = '/home/njw/jemx/spectra/jmx'+strj+'_all_arf_0001.fits'
l = file_search(arf_all_file,/test_regular,count=nl)

if nl ne 1 then begin
   print,'No action - /home/njw/jemx/spectra/jmx'+strj+'_all_arf_0001.fits not found'
   return
endif

hdr = headfits(arf_all_file, exten=1)
nrows = fxpar(hdr,'naxis2')

if keyword_set(row) then begin
   row_num = row
   if row_num gt nrows then begin
      print,'Requested row number does not exist'
      return
   endif
endif else begin ; create an extra row
   fxbaddrows,arf_all_file,1
   nrows = nrows + 1
   row_num = nrows
endelse

;   Get the RMF data

rmf_file = '/home/njw/jemx/response_matrix/jmx'+strj+'_rmf_grp_0003.fits'
l = file_search(rmf_file,/test_regular,count=nl)
if nl ne 1 then begin
   print,'No action - '+rmf_file+' not found'
   return
endif

grpname = rmf_file+'+1'
ebm_get_child_by_name,grpname,'JMX'+strj+'-FBDS-MOD',fbds_name
;rdfitscol,fbds_name,e_min,'E_MIN',/sil
;rdfitscol,fbds_name,e_max,'E_MAX',/sil

ebm_get_child_by_name,grpname,'JMX'+strj+'-RMF.-RSP',rmf_name
rdfitscol,rmf_name,elo,'ENERG_LO',/sil
rdfitscol,rmf_name,ehi,'ENERG_HI',/sil
;rdfitscol,rmf_name,matrix,'MATRIX',/sil
eline = 0.5*(elo + ehi)

ebm_get_child_by_name,grpname,'JMX'+strj+'-AXIS-ARF',arf_name
rdfitscol,arf_name,arf,'SPECRESP',/sil
   
; Open the all_arf and write new values
   
fxbopen, unit, arf_all_file, 1, access='RW'
   
text = ''
read,'Enter comments (max 33 char) : ... ', text

fxbwrite, unit, text, 1, row_num

dat = ndate(2)

fxbwrite, unit, dat, 2, row_num

tstart = 1.d0
read,'Enter tstart : ... ', tstart

fxbwrite, unit, tstart, 3, row_num

tstop = 1.d0
read,'Enter tstop : ... ', tstop

fxbwrite, unit, tstop, 4, row_num

fxbwrite, unit, eline, 5, row_num
fxbwrite, unit, eflt, 6, row_num
fxbwrite, unit, eflt*arf, 7, row_num
   
fxbfinish, unit





end


