pro update_dsri_cat_iden, list_name
;
;  update DSRI_CAT_IDEN.fits with list of identifiers
;
;  The file 'list_name' must have the structure:
;
;  //
;  // serial = n
;  //
;  Identifier 1
;  Identifier 2
;  .
;  .
;  .
;  Identifier N
;

file_dsri_cat_iden = '/home/njw/jsim/Catalogs/DSRI_CAT_IDEN.fits[1]'

print,'Going to update ', file_dsri_cat_iden

npar = n_params()
if npar ge 1 then begin

   list = read_slist(list_name)
   n_list = n_elements(list)
   idens = where( strmid(list,0,2) ne '//' , n_idens )
   if n_idens eq 0 then begin
      print,'There were no identifiers in the list'
      return
   endif

   serial = long(comget(list_name,'serial',ierr))
   if ierr ne 1 then begin
      print,'Keyword ''serial'' is missing or multiple in ', list_name
      print,'    No update is made'
      return
   endif

   new_list = list(idens)

endif else begin

   ; Interactive input

   serial = 0L
   read,'Enter the serial number : ... ', serial
   str = ''
   read,'Enter the new identification name : ... ', str

   new_list = [str]

endelse

get_exten_no, file_dsri_cat_iden, filename, extno
rdfitscol,file_dsri_cat_iden,old_iden,'IDENTIFIER',nrows=numrows,/sil
old_iden = strtrim(old_iden,2)
rdfitscol,file_dsri_cat_iden,old_serial,'SERIAL',/sil

print, numrows,' rows in DSRI_CAT_IDEN identifier table'

; Verify uniqueness of new identifiers

for i = 0, numrows-1 do begin
   w = where( strlowcase(strcompress(old_iden(i),/rem)) $
           eq strlowcase(strcompress(new_list,/rem)), n_w)
   if n_w gt 0 then begin
      print,'Warning! Identifier ',new_list(w),' already in DSRI_CAT_IDEN.fits'
      print,'   with serial number: ', old_serial(i)
      nnew = n_elements(new_list)
      if nnew eq 1 then begin
         print,'No more identifiers in list - no update is made'
         return
      endif
      if w(0) eq 0 then new_list = new_list(1:*) else begin
         if w(0) eq nnew-1 then new_list = new_list(0:nnew-2) else $
            new_list = [new_list(0:w(0)-1),new_list(w(0)+1:*)]
      endelse
   endif
endfor

n_idens = n_elements(new_list)

print
print,n_idens,' rows must be added'
print

arg1 = '/home/njw/jsim/add_rows/add_rows '
arg2 = '"'+file_dsri_cat_iden+'" '
arg3 = strtrim(n_idens,2)

spawn,arg1+arg2+arg3

errmsg = ''

fxbopen,unit,filename,extno,hdr,access='RW'
colnumser = fxbcolnum( unit, 'SERIAL', err=errmsg)
colnumid = fxbcolnum( unit, 'IDENTIFIER', err=errmsg)
if errmsg ne '' then begin
   print,'##0## errmsg: ', errmsg
   return
endif

for i = 0, n_idens-1 do begin

   fxbwrite, unit, serial, colnumser, numrows+i+1, err=errmsg
   if errmsg ne '' then print,'##1## errmsg: ', errmsg
   fxbwrite, unit, new_list(i), colnumid, numrows+i+1, err=errmsg
   if errmsg ne '' then print,'##2## errmsg: ', errmsg

endfor

fxbfinish, unit, err=errmsg



end
