function where_are, little_list, big_list, acompl=acompl, errmsg=errmsg
;
;  Return the indices of 'big_list' where elements from
;  'little_list' are found.
;
;  Example: little_list = [2,5,7]
;           big_list    = [8,7,6,5,4,3,2,1]
;  where_are returns [6,3,1]
;
;  Keyword 'acompl' will return the indices of 'big_list' where the
;  elements match none from little list which corresponds to
;  [0,2,4,5,7] in the example.
;  If not all elements of 'little_list' are found in 'big_list'
;  then this is reported in keywords 'errmsg'
;
;  If elements are repeated in the input arrays then the result
;  can be strange
;
;   2005-10-03/NJW
;   2005-12-05/NJW, updated to correct for error when the two arrays
;                   are identical
;
if n_params() lt 2 then begin
   print,'Syntax: res = where_are(little_list, big_list, acompl=, errmsg=)'
   return,-1
endif

nl = n_elements(little_list)
nb = n_elements(big_list)
;  set up an array to contain all the indices of big_list
;  where values do not match little_list:
acompl = indgen(nb,/long)

;  Test for repeated values and issue a warning if found

errmsg = ''
k = big_list(sort(big_list))
u = uniq(k)
if n_elements(u) lt nb then begin
   print,'Warning: big_list is not unique'
   errmsg = errmsg+'Warning: big_list is not unique'
endif
k = little_list(sort(little_list))
u = uniq(k)
if n_elements(u) lt nl then begin
   print,'Warning: little_list is not unique'
   errmsg = errmsg+' Warning: little_list is not unique'
endif

; Loop over elements in 'little_list' and check if they
; exist in 'big_list' and if yes, where and also remove
; that index from 'acompl'

first_nf = 1
first = 1
for i = 0L, nl-1 do begin
   w = where( little_list(i) eq big_list, nw )
   if nw eq 0 then begin
      if first_nf then begin
         errmsg = errmsg+' At least one element not found in big_list'
         first_nf = 0
      endif
   endif else begin
      if first then begin
         res = w(0)
         first = 0
      endif else begin
         res = [res, w(0)]
      endelse
      m = where( w(0) eq acompl, nm, complement=am, ncomplement=nam )
      if nam > 0 then begin
         acompl = acompl(am)
      endif else acompl = -1
   endelse
endfor

if first then begin
   errmsg = errmsg + ' No match at all'
   return, -1
endif else begin
   return, res
endelse

end
