pro wrmfitscols, filename, n1, d1, n2, d2, n3, d3, n4, d4, n5, d5, $
     n6, d6, n7, d7, n8, d8, n9, d9, n10, d10, n11, d11, n12, d12, $
     n13, d13, n14, d14, n15, d15, n16, d16, n17, d17, n18, d18, $
     n19, d19, n20, d20, n21, d21, n22, d22, n23, d23, n24, d24, $
     kwds=kwds,app=app, nowrite=nowrite
;
;  Create a new FITS file with one extension:
;  a binary table file and write several (up to 24)
;  columns to it
;
;  NJW/010629, updated /020103, /040802, /040930 with the 'nowrite' keyword
;
;  The keyword 'kwds' defines a pseudo header string array with extra keywords
;  to include. It should be made in this way:
;   IDL> fxaddpar,kwds,'KEYWORD',value,'comment' ; In first call 'kwds' is undefined
;   IDL> fxaddpar,kwds,'NEXTKW',value,'next comment'   etc.
;
;  For vector columns the first index is the number of data values in the bin;
;  The second index is the row number e.g. a(12,6) will be written as
;  6 rows with 12 numbers in each bin

; Define the binary extension header

if n_params() lt 3 then begin
   print,'Syntax: wrmfitscols, filename, name1, data1, name2, ..., name20, data20 $'
   print,'            [,kwds=][,/app][,/nowrite]'
   print
   print,'The keyword ''kwds'' defines a pseudo header string array with extra keywords'
   print,'to include. It should be made in this way:'
   print,'IDL> fxaddpar,kwds,''KEYWORD'',value,''comment'' ; In first call ''kwds'' is undefined'
   print,'IDL> fxaddpar,kwds,''NEXTKW'',value,''next comment''   etc.'
   print
   print,'For vector columns the first index is the number of data values in the bin;'
   print,'The second index is the row number e.g. a(12,6) will be written as'
   print,'6 rows with 12 numbers in each bin'
   return
endif

ncols = (n_params()-1)/2

colnumber = 1
sz1 = size(d1)
if sz1(0) lt 1 or sz1(0) gt 2 then goto, fexit
if sz1(0) eq 2 and sz1(sz1(0)+1) eq 7 then goto, gexit
nrows = sz1(sz1(0))

; Check all arrays to have same length

for colnumber = 2, ncols do begin

   case colnumber of
      2: begin
            sz2 = size(d2)
            if sz2(0) lt 1 or sz2(0) gt 2 then goto, fexit
            if sz2(0) eq 2 and sz2(sz2(0)+1) eq 7 then goto, gexit
            if sz2(sz2(0)) ne nrows then goto, eexit
         end
      3: begin
            sz3 = size(d3)
            if sz3(0) lt 1 or sz3(0) gt 2 then goto, fexit
            if sz3(0) eq 2 and sz3(sz3(0)+1) eq 7 then goto, gexit
            if sz3(sz3(0)) ne nrows then goto, eexit
         end
      4: begin
            sz4 = size(d4)
            if sz4(0) lt 1 or sz4(0) gt 2 then goto, fexit
            if sz4(0) eq 2 and sz4(sz4(0)+1) eq 7 then goto, gexit
            if sz4(sz4(0)) ne nrows then goto, eexit
         end
      5: begin
            sz5 = size(d5)
            if sz5(0) lt 1 or sz5(0) gt 2 then goto, fexit
            if sz5(0) eq 2 and sz5(sz5(0)+1) eq 7 then goto, gexit
            if sz5(sz5(0)) ne nrows then goto, eexit
         end
      6: begin
            sz6 = size(d6)
            if sz6(0) lt 1 or sz6(0) gt 2 then goto, fexit
            if sz6(0) eq 2 and sz6(sz6(0)+1) eq 7 then goto, gexit
            if sz6(sz6(0)) ne nrows then goto, eexit
         end
      7: begin
            sz7 = size(d7)
            if sz7(0) lt 1 or sz7(0) gt 2 then goto, fexit
            if sz7(0) eq 2 and sz7(sz7(0)+1) eq 7 then goto, gexit
            if sz7(sz7(0)) ne nrows then goto, eexit
         end
      8: begin
            sz8 = size(d8)
            if sz8(0) lt 1 or sz8(0) gt 2 then goto, fexit
            if sz8(0) eq 2 and sz8(sz8(0)+1) eq 7 then goto, gexit
            if sz8(sz8(0)) ne nrows then goto, eexit
         end
      9: begin
            sz9 = size(d9)
            if sz9(0) lt 1 or sz9(0) gt 2 then goto, fexit
            if sz9(0) eq 2 and sz9(sz9(0)+1) eq 7 then goto, gexit
            if sz9(sz9(0)) ne nrows then goto, eexit
         end
     10: begin
            sz10 = size(d10)
            if sz10(0) lt 1 or sz10(0) gt 2 then goto, fexit
            if sz10(0) eq 2 and sz10(sz10(0)+1) eq 7 then goto, gexit
            if sz10(sz10(0)) ne nrows then goto, eexit
         end
     11: begin
            sz11 = size(d11)
            if sz11(0) lt 1 or sz11(0) gt 2 then goto, fexit
            if sz11(0) eq 2 and sz11(sz11(0)+1) eq 7 then goto, gexit
            if sz11(sz11(0)) ne nrows then goto, eexit
         end
     12: begin
            sz12 = size(d12)
            if sz12(0) lt 1 or sz12(0) gt 2 then goto, fexit
            if sz12(0) eq 2 and sz12(sz12(0)+1) eq 7 then goto, gexit
            if sz12(sz12(0)) ne nrows then goto, eexit
         end
     13: begin
            sz13 = size(d13)
            if sz13(0) lt 1 or sz13(0) gt 2 then goto, fexit
            if sz13(0) eq 2 and sz13(sz13(0)+1) eq 7 then goto, gexit
            if sz13(sz13(0)) ne nrows then goto, eexit
         end
     14: begin
            sz14 = size(d14)
            if sz14(0) lt 1 or sz14(0) gt 2 then goto, fexit
            if sz14(0) eq 2 and sz14(sz14(0)+1) eq 7 then goto, gexit
            if sz14(sz14(0)) ne nrows then goto, eexit
         end
     15: begin
            sz15 = size(d15)
            if sz15(0) lt 1 or sz15(0) gt 2 then goto, fexit
            if sz15(0) eq 2 and sz15(sz15(0)+1) eq 7 then goto, gexit
            if sz15(sz15(0)) ne nrows then goto, eexit
         end
     16: begin
            sz16 = size(d16)
            if sz16(0) lt 1 or sz16(0) gt 2 then goto, fexit
            if sz16(0) eq 2 and sz16(sz16(0)+1) eq 7 then goto, gexit
            if sz16(sz16(0)) ne nrows then goto, eexit
         end
     17: begin
            sz17 = size(d17)
            if sz17(0) lt 1 or sz17(0) gt 2 then goto, fexit
            if sz17(0) eq 2 and sz17(sz17(0)+1) eq 7 then goto, gexit
            if sz17(sz17(0)) ne nrows then goto, eexit
         end
     18: begin
            sz18 = size(d18)
            if sz18(0) lt 1 or sz18(0) gt 2 then goto, fexit
            if sz18(0) eq 2 and sz18(sz18(0)+1) eq 7 then goto, gexit
            if sz18(sz18(0)) ne nrows then goto, eexit
         end
     19: begin
            sz19 = size(d19)
            if sz19(0) lt 1 or sz19(0) gt 2 then goto, fexit
            if sz19(0) eq 2 and sz19(sz19(0)+1) eq 7 then goto, gexit
            if sz19(sz19(0)) ne nrows then goto, eexit
         end
     20: begin
            sz20 = size(d20)
            if sz20(0) lt 1 or sz20(0) gt 2 then goto, fexit
            if sz20(0) eq 2 and sz20(sz20(0)+1) eq 7 then goto, gexit
            if sz20(sz20(0)) ne nrows then goto, eexit
         end
     21: begin
            sz21 = size(d21)
            if sz21(0) lt 1 or sz21(0) gt 2 then goto, fexit
            if sz21(0) eq 2 and sz21(sz21(0)+1) eq 7 then goto, gexit
            if sz21(sz21(0)) ne nrows then goto, eexit
         end
     22: begin
            sz22 = size(d22)
            if sz22(0) lt 1 or sz22(0) gt 2 then goto, fexit
            if sz22(0) eq 2 and sz22(sz22(0)+1) eq 7 then goto, gexit
            if sz22(sz22(0)) ne nrows then goto, eexit
         end
     23: begin
            sz23 = size(d23)
            if sz23(0) lt 1 or sz23(0) gt 2 then goto, fexit
            if sz23(0) eq 2 and sz23(sz23(0)+1) eq 7 then goto, gexit
            if sz23(sz23(0)) ne nrows then goto, eexit
         end
     24: begin
            sz24 = size(d24)
            if sz24(0) lt 1 or sz24(0) gt 2 then goto, fexit
            if sz24(0) eq 2 and sz24(sz24(0)+1) eq 7 then goto, gexit
            if sz24(sz24(0)) ne nrows then goto, eexit
         end

   endcase

endfor

if keyword_set(nowrite) then nrows = 0

fxbhmake, bheader, nrows,/init

for colnumber = 1, ncols do begin

   index = colnumber
   case colnumber of
      1: begin
            if sz1(0) eq 1 then fxbaddcol,index,bheader,d1(imax7(d1)),n1 $
            else fxbaddcol,index,bheader,d1(*,0),n1
         end
      2: begin
            if sz2(0) eq 1 then fxbaddcol,index,bheader,d2(imax7(d2)),n2 $
            else fxbaddcol,index,bheader,d2(*,0),n2
         end
      3: begin
            if sz3(0) eq 1 then fxbaddcol,index,bheader,d3(imax7(d3)),n3 $
            else fxbaddcol,index,bheader,d3(*,0),n3
         end
      4: begin
            if sz4(0) eq 1 then fxbaddcol,index,bheader,d4(imax7(d4)),n4 $
            else fxbaddcol,index,bheader,d4(*,0),n4
         end
      5: begin
            if sz5(0) eq 1 then fxbaddcol,index,bheader,d5(imax7(d5)),n5 $
            else fxbaddcol,index,bheader,d5(*,0),n5
         end
      6: begin
            if sz6(0) eq 1 then fxbaddcol,index,bheader,d6(imax7(d6)),n6 $
            else fxbaddcol,index,bheader,d6(*,0),n6
         end
      7: begin
            if sz7(0) eq 1 then fxbaddcol,index,bheader,d7(imax7(d7)),n7 $
            else fxbaddcol,index,bheader,d7(*,0),n7
         end
      8: begin
            if sz8(0) eq 1 then fxbaddcol,index,bheader,d8(imax7(d8)),n8 $
            else fxbaddcol,index,bheader,d8(*,0),n8
         end
      9: begin
            if sz9(0) eq 1 then fxbaddcol,index,bheader,d9(imax7(d9)),n9 $
            else fxbaddcol,index,bheader,d9(*,0),n9
         end
     10: begin
            if sz10(0) eq 1 then fxbaddcol,index,bheader,d10(imax7(d10)),n10 $
            else fxbaddcol,index,bheader,d10(*,0),n10
         end
     11: begin
            if sz11(0) eq 1 then fxbaddcol,index,bheader,d11(imax7(d11)),n11 $
            else fxbaddcol,index,bheader,d11(*,0),n11
         end
     12: begin
            if sz12(0) eq 1 then fxbaddcol,index,bheader,d12(imax7(d12)),n12 $
            else fxbaddcol,index,bheader,d12(*,0),n12
         end
     13: begin
            if sz13(0) eq 1 then fxbaddcol,index,bheader,d13(imax7(d13)),n13 $
            else fxbaddcol,index,bheader,d13(*,0),n13
         end
     14: begin
            if sz14(0) eq 1 then fxbaddcol,index,bheader,d14(imax7(d14)),n14 $
            else fxbaddcol,index,bheader,d14(*,0),n14
         end
     15: begin
            if sz15(0) eq 1 then fxbaddcol,index,bheader,d15(imax7(d15)),n15 $
            else fxbaddcol,index,bheader,d15(*,0),n15
         end
     16: begin
            if sz16(0) eq 1 then fxbaddcol,index,bheader,d16(imax7(d16)),n16 $
            else fxbaddcol,index,bheader,d16(*,0),n16
         end
     17: begin
            if sz17(0) eq 1 then fxbaddcol,index,bheader,d17(imax7(d17)),n17 $
            else fxbaddcol,index,bheader,d17(*,0),n17
         end
     18: begin
            if sz18(0) eq 1 then fxbaddcol,index,bheader,d18(imax7(d18)),n18 $
            else fxbaddcol,index,bheader,d18(*,0),n18
         end
     19: begin
            if sz19(0) eq 1 then fxbaddcol,index,bheader,d19(imax7(d19)),n19 $
            else fxbaddcol,index,bheader,d19(*,0),n19
         end
     20: begin
            if sz20(0) eq 1 then fxbaddcol,index,bheader,d20(imax7(d20)),n20 $
            else fxbaddcol,index,bheader,d20(*,0),n20
         end
     21: begin
            if sz21(0) eq 1 then fxbaddcol,index,bheader,d21(imax7(d21)),n21 $
            else fxbaddcol,index,bheader,d21(*,0),n21
         end
     22: begin
            if sz22(0) eq 1 then fxbaddcol,index,bheader,d22(imax7(d22)),n22 $
            else fxbaddcol,index,bheader,d22(*,0),n22
         end
     23: begin
            if sz23(0) eq 1 then fxbaddcol,index,bheader,d23(imax7(d23)),n23 $
            else fxbaddcol,index,bheader,d23(*,0),n23
         end
     24: begin
            if sz24(0) eq 1 then fxbaddcol,index,bheader,d24(imax7(d24)),n24 $
            else fxbaddcol,index,bheader,d24(*,0),n24
         end
   endcase

endfor

; Add the extra keywords if required

if keyword_set(kwds) then begin
   list = get_kwds(kwds)
   if list(0) ne '' then begin
      nkwds = n_elements(list)
      for i = 0, nkwds-1 do begin
         value = fxpar(kwds,list(i),comment=comment)
         n_value = n_elements(value)
         if n_value gt 1 then begin
            for j = 0, n_value-1 do fxaddpar,bheader,list(i),value(j),comment
         endif else fxaddpar,bheader,list(i),value(0),comment
      endfor
   endif
endif

if not keyword_set(app) then begin

   ; Create a new file
   ; First create a dummy primary header
   ; and write the file to disk

   fxhmake,header,/init,/exten
   a = 1
   writefits, filename, a, header

endif

fxbcreate,unit, filename, bheader

if nrows ge 1 then begin

for colnumber = 1, ncols do begin

   index = colnumber
   case colnumber of
      1: begin
            if sz1(0) eq 1 then begin
               for i = 0L, nrows-1 do fxbwrite,unit,d1(i),index,i+1
            endif else begin
               for i = 0L, nrows-1 do fxbwrite,unit,d1(*,i),index,i+1
            endelse
         end
      2: begin
            if sz2(0) eq 1 then begin
               for i = 0L, nrows-1 do fxbwrite,unit,d2(i),index,i+1
            endif else begin
               for i = 0L, nrows-1 do fxbwrite,unit,d2(*,i),index,i+1
            endelse
         end
      3: begin
            if sz3(0) eq 1 then begin
               for i = 0L, nrows-1 do fxbwrite,unit,d3(i),index,i+1
            endif else begin
               for i = 0L, nrows-1 do fxbwrite,unit,d3(*,i),index,i+1
            endelse
         end
      4: begin
            if sz4(0) eq 1 then begin
               for i = 0L, nrows-1 do fxbwrite,unit,d4(i),index,i+1
            endif else begin
               for i = 0L, nrows-1 do fxbwrite,unit,d4(*,i),index,i+1
            endelse
         end
      5: begin
            if sz5(0) eq 1 then begin
               for i = 0L, nrows-1 do fxbwrite,unit,d5(i),index,i+1
            endif else begin
               for i = 0L, nrows-1 do fxbwrite,unit,d5(*,i),index,i+1
            endelse
         end
      6: begin
            if sz6(0) eq 1 then begin
               for i = 0L, nrows-1 do fxbwrite,unit,d6(i),index,i+1
            endif else begin
               for i = 0L, nrows-1 do fxbwrite,unit,d6(*,i),index,i+1
            endelse
         end
      7: begin
            if sz7(0) eq 1 then begin
               for i = 0L, nrows-1 do fxbwrite,unit,d7(i),index,i+1
            endif else begin
               for i = 0L, nrows-1 do fxbwrite,unit,d7(*,i),index,i+1
            endelse
         end
      8: begin
            if sz8(0) eq 1 then begin
               for i = 0L, nrows-1 do fxbwrite,unit,d8(i),index,i+1
            endif else begin
               for i = 0L, nrows-1 do fxbwrite,unit,d8(*,i),index,i+1
            endelse
         end
      9: begin
            if sz9(0) eq 1 then begin
               for i = 0L, nrows-1 do fxbwrite,unit,d9(i),index,i+1
            endif else begin
               for i = 0L, nrows-1 do fxbwrite,unit,d9(*,i),index,i+1
            endelse
         end
     10: begin
            if sz10(0) eq 1 then begin
               for i = 0L, nrows-1 do fxbwrite,unit,d10(i),index,i+1
            endif else begin
               for i = 0L, nrows-1 do fxbwrite,unit,d10(*,i),index,i+1
            endelse
         end
     11: begin
            if sz11(0) eq 1 then begin
               for i = 0L, nrows-1 do fxbwrite,unit,d11(i),index,i+1
            endif else begin
               for i = 0L, nrows-1 do fxbwrite,unit,d11(*,i),index,i+1
            endelse
         end
     12: begin
            if sz12(0) eq 1 then begin
               for i = 0L, nrows-1 do fxbwrite,unit,d12(i),index,i+1
            endif else begin
               for i = 0L, nrows-1 do fxbwrite,unit,d12(*,i),index,i+1
            endelse
         end
     13: begin
            if sz13(0) eq 1 then begin
               for i = 0L, nrows-1 do fxbwrite,unit,d13(i),index,i+1
            endif else begin
               for i = 0L, nrows-1 do fxbwrite,unit,d13(*,i),index,i+1
            endelse
         end
     14: begin
            if sz14(0) eq 1 then begin
               for i = 0L, nrows-1 do fxbwrite,unit,d14(i),index,i+1
            endif else begin
               for i = 0L, nrows-1 do fxbwrite,unit,d14(*,i),index,i+1
            endelse
         end
     15: begin
            if sz15(0) eq 1 then begin
               for i = 0L, nrows-1 do fxbwrite,unit,d15(i),index,i+1
            endif else begin
               for i = 0L, nrows-1 do fxbwrite,unit,d15(*,i),index,i+1
            endelse
         end
     16: begin
            if sz16(0) eq 1 then begin
               for i = 0L, nrows-1 do fxbwrite,unit,d16(i),index,i+1
            endif else begin
               for i = 0L, nrows-1 do fxbwrite,unit,d16(*,i),index,i+1
            endelse
         end
     17: begin
            if sz17(0) eq 1 then begin
               for i = 0L, nrows-1 do fxbwrite,unit,d17(i),index,i+1
            endif else begin
               for i = 0L, nrows-1 do fxbwrite,unit,d17(*,i),index,i+1
            endelse
         end
     18: begin
            if sz18(0) eq 1 then begin
               for i = 0L, nrows-1 do fxbwrite,unit,d18(i),index,i+1
            endif else begin
               for i = 0L, nrows-1 do fxbwrite,unit,d18(*,i),index,i+1
            endelse
         end
     19: begin
            if sz19(0) eq 1 then begin
               for i = 0L, nrows-1 do fxbwrite,unit,d19(i),index,i+1
            endif else begin
               for i = 0L, nrows-1 do fxbwrite,unit,d19(*,i),index,i+1
            endelse
         end
     20: begin
            if sz20(0) eq 1 then begin
               for i = 0L, nrows-1 do fxbwrite,unit,d20(i),index,i+1
            endif else begin
               for i = 0L, nrows-1 do fxbwrite,unit,d20(*,i),index,i+1
            endelse
         end
     21: begin
            if sz21(0) eq 1 then begin
               for i = 0L, nrows-1 do fxbwrite,unit,d21(i),index,i+1
            endif else begin
               for i = 0L, nrows-1 do fxbwrite,unit,d21(*,i),index,i+1
            endelse
         end
     22: begin
            if sz22(0) eq 1 then begin
               for i = 0L, nrows-1 do fxbwrite,unit,d22(i),index,i+1
            endif else begin
               for i = 0L, nrows-1 do fxbwrite,unit,d22(*,i),index,i+1
            endelse
         end
     23: begin
            if sz23(0) eq 1 then begin
               for i = 0L, nrows-1 do fxbwrite,unit,d23(i),index,i+1
            endif else begin
               for i = 0L, nrows-1 do fxbwrite,unit,d23(*,i),index,i+1
            endelse
         end
     24: begin
            if sz24(0) eq 1 then begin
               for i = 0L, nrows-1 do fxbwrite,unit,d24(i),index,i+1
            endif else begin
               for i = 0L, nrows-1 do fxbwrite,unit,d24(*,i),index,i+1
            endelse
         end
   endcase

endfor

endif

fxbfinish, unit

return

eexit:

   print,'Data for column #',strtrim(colnumber,2),' of different size than #1'
   return

fexit:

   print,'Data for column #',strtrim(colnumber,2),' has illegal number of dimensions'
   return

gexit:

   print,'Data for column #',strtrim(colnumber,2),' is string type with 2 dimensions'
   return

end
