pro wrnewfitscol, file_extno, colname, coldata, colname2, coldata2
;
;  Add one or two new columns to an existing FITS file extension
;
;  Assumes a structure: Primary header with a single binary table extension
;
;   NJW/2002-01-07
;
;  The only way to do this seems to copy the original extension
;  to new one and then rename
;
;  Vector columns:  First index is number of data values in each bin; the
;  second index is the row number
;

if n_params() lt 3 then begin
   print,'Syntax: wrnewfitscol, file_extno, colname, coldata[,colname2, coldata2]'
   return
endif
if n_params() gt 4 then two = 1 else two = 0

get_exten_no, file_extno, fitsname, extno

;  Get the primary header

prim_hdr = headfits(fitsname)

fxbopen, unit_in, fitsname, extno, header,access='R'

nrows = fxpar(header, 'NAXIS2')
ncols = fxpar(header, 'TFIELDS')

sz = size(coldata)
if sz(sz(0)) ne nrows then begin
   print,'WRNEWFITSCOL: Mismatch between existing number of rows and new array'
   return
endif
if sz(0) lt 1 or sz(0) gt 2 then begin
   print,'WRNEWFITSCOL: Illegal data structure of new column'
   return
endif
if two then begin
   sz2 = size(coldata2)
   if sz2(sz2(0)) ne nrows then begin
      print,'WRNEWFITSCOL: Mismatch between existing number of rows and new array no 2'
      return
   endif
   if sz2(0) lt 1 or sz2(0) gt 2 then begin
      print,'WRNEWFITSCOL: Illegal data structure of new column no 2'
      return
   endif
endif

; Add the new column to the header

if sz(0) eq 1 then begin
   fxbaddcol,ncols+1,header,coldata(imax7(coldata)),colname
endif else begin
   fxbaddcol,ncols+1,header,coldata(*,0),colname
endelse

if two then begin
   if sz2(0) eq 1 then begin
      fxbaddcol,ncols+2,header,coldata2(imax7(coldata2)),colname2
   endif else begin
      fxbaddcol,ncols+2,header,coldata2(*,0),colname2
   endelse
endif

; Prepare new FITS file

; and write the file with primary header to disk

filename = 'tmp.fits'
;-- earlier version: fxhmake,primhead,/init,/exten
a = 1
writefits, filename, a, prim_hdr

;  create the extension

fxbcreate, unit_out, filename, header

; Copy all the old columns

for col = 1, ncols do begin
   fxbread, unit_in, copydata, col
   szc = size(copydata)
   if nrows eq 1 then begin ; Expand dimensions
      if szc(0) eq 0 then begin
         copydata = [copydata]
         szc = size(copydata)
      endif
      if szc(0) eq 1 then begin
         copydata = reform(copydata,szc(1),1)
         szc = size(copydata)
      endif
   endif
   if szc(0) lt 1 or szc(0) gt 2 then begin
      print,'WRNEWFITSCOL: Strange data in column ', col
      fxbclose, unit_in
      fxbclose, unit_out
      return
   endif
   for row = 1L, nrows do begin
      if szc(0) eq 2 then begin
         fxbwrite, unit_out, copydata(*,row-1), col, row
      endif else begin
         fxbwrite, unit_out, copydata(row-1), col, row
      endelse
   endfor
endfor

fxbclose, unit_in

for row = 1L, nrows do begin
   if sz(0) le 1 then begin
      fxbwrite, unit_out, coldata(row-1), ncols+1, row
   endif else begin
      fxbwrite, unit_out, coldata(*,row-1), ncols+1, row
   endelse
endfor
if two then begin
   for row = 1L, nrows do begin
      if sz2(0) le 1 then begin
         fxbwrite, unit_out, coldata2(row-1), ncols+2, row
      endif else begin
         fxbwrite, unit_out, coldata2(*,row-1), ncols+2, row
      endelse
   endfor
endif

fxbfinish, unit_out

; Finally replace old file with new temporary file

spawn,'mv tmp.fits '+fitsname

end
