pro xfilesync, mode=mode, log=log
;
;  Extract directory synchronization files
;  2nd part of (filesync, xfilesync) system for directory/file
;  maintenance on two parallel systems (Linux and SunOs)
;
;    2003-06-02/NJW
;
;-----------------------------------------------
;
;  Find manual in 'filesync.pro'
;
;-----------------------------------------------

if not keyword_set(mode) then begin

   ; Locate tar file from other system in current directory

   t = file_search('sync.tar',count=nt)
   if nt ne 1 then begin
      print,'File: sync.tar not found'
      print,'Hint: Copy the file from twin directory to current directory'
      return
   endif

   ; Extract the file list with file modification time information

   spawn,'tar xf sync.tar synclist'

endif else begin ; When mode==1 synclist is already there

   openw,lupd,'syncupdates',/get_lun

endelse

; If keyword 'log' is set then open log file

if keyword_set(log) then begin
   openw,lulog,'sync.log',/get_lun
   printf,lulog,'=========================================='
   printf,lulog,' List of files extracted from twin dir '+ndate(2)
   printf,lulog,'=========================================='
   printf,lulog
endif

; Walk through this list and extract the file if newer than present
; version or not found in current directory

t = file_search('synclist',count=nt)
if nt ne 1 then begin
   print,'File: synclist not found'
   print,'Hint: Copy the file from twin directory to current directory'
   return
endif
list = read_slist('synclist',count=nlist)

num_to_update = 0

for i = 0, nlist-1 do begin

   tok = strsplit(list(i),/extract)

   ; Find local version of this file with name in tok(0)

   l = file_search( tok(0), /test_regular, count=nl)

   ; Set extraction flag if one of two conditions is fulfilled:
   ; File is new to current directory or younger than
   ; current version

   extract = 0
   if nl eq 0 then begin ; Not in current directory
      extract = 1
   endif else begin
      ; Get file modification time
      openr,lun,tok(0),/get_lun
      a = fstat(lun)
      free_lun,lun
      if long(tok(1)) gt a.mtime then extract = 1
   endelse
   if extract then begin
      num_to_update = num_to_update + 1
      if keyword_set(mode) then begin
         print,'Update required: '+tok(0)
         printf,lupd,tok(0)
      endif else begin
         print,'Extracting '+tok(0)
         if keyword_set(log) then printf,lulog,tok(0)
         spawn,'tar xf sync.tar '+tok(0)
      endelse
   endif

endfor

; Clean up all received from twin system

spawn,'\rm synclist'

if not keyword_set(mode) then begin
   spawn,'\rm synctarlist'
   spawn,'\rm sync.tar'
endif else begin
   free_lun, lupd
endelse

if num_to_update eq 0 then begin
   print
   print,'*****   No files need updating   ****'
   print
   if keyword_set(log) then printf,lulog,'*****   No files updated   ****'
endif else begin
   print
   print,'*****   '+stri(num_to_update)+' files need(ed) updating   ****'
   print
endelse

if keyword_set(log) then free_lun, lulog

end
