pro xfit_fit, p_res, cont=cont
;
;  Fitting a model to an observed spectrum
;
;    NJW/2002-06-28
;

common instrument, e_min, e_max, matrix, arf
common observation, rate, stat_err, countspec, number
common model, elo, ehi, eline, spectrcode
common results, const, param1, nh, chi2red, sx

if n_params() lt 1 then begin
   print,'Syntax: xfit_fit, p_res[,/cont]'
   return
endif

p = fltarr(4,3)
if keyword_set(cont) then begin
   p(0,*) = p_res
endif else begin
   p(0,*) = [1.,1.,1.]
endelse

p(1,*) = p(0,*) * [0.3,1.,1.]
p(2,*) = p(0,*) * [1.,0.3,1.]
p(3,*) = p(0,*) * [1.,1.,0.3]

plim = fltarr(2,3)
plim(*,0) = [0.01,100.]
if spectrcode eq 'PL' then plim(*,1) = [-1.,3.] else plim(*,1) = [0.01,100.]
plim(*,2) = [0.001,1000.]


p_res = amoeban( p, fun='xfit_fitfunc',plim=plim,itm=50,/sil)

;   Present the results

n_freedom = n_elements(countspec) - 3

chi2red = xfit_fitfunc(p_res)/n_freedom
print,chi2red,format='("Chi2,red =   ",f10.4)'

print,p_res(0),format='("Constant =    ",f10.4)'
print,p_res(1),format='("Param1   =    ",f10.4)'
print,p_res(2),format='("Nh/1e22  =    ",f10.4)'

;   Get the photon spectrum and source intensity

flux = xfit_photspec(p_res)
const = p_res(0)   ;  saving for 'common'
param1 = p_res(1)   ;  saving for 'common'
nh = p_res(2)   ;  saving for 'common'

if spectrcode eq 'DF' then begin
   dum = max(flux,index)
   sx = dum * (ehi(index)-elo(index)) * 1.6e-9
   print,sx,format='("Sx          = ",e13.4," erg/cm2/s")'
endif else begin
   sx = sflux(2.,10.,eline,flux)
   print,sx,format='("Sx(2-10keV) = ",e13.4," erg/cm2/s")'
endelse

end
