function xfit_fitfunc, p
;
;  Fit function that returns Chi2 for a given set of parameters
;  in array 'p':  (norm, param1, nh/1.e22)
;
;   NJW/2002-06-28
;
if n_params() lt 1 then begin
   print,'Syntax: chi2 = xfit_fitfunc(p)'
   return, -1.
endif
if( n_elements(p) ne 3 ) then begin
   print,'xfit_fitfunc must be called with 3 element array'
   return, -1.
endif

;   Define the common areas

common instrument, e_min, e_max, matrix, arf
common observation, rate, stat_err, countspec, number
common model, elo, ehi, eline, spectrcode
common results, const, param1, nh, chi2red, sx


param1 = p(1)
nh = p(2) * 1.e22

;   Generate the input spectrum

flux = xfit_photspec(p)


line_counts = flux * (ehi - elo) * arf
countspec = matrix#line_counts

c2 = chi2( countspec, rate, stat_err )


return, c2

end
