pro xfit_plot, pi=pi
;
;  plots the result of rfitting
;    Default is energy plot. Keyword 'pi' gives PI plot
;
;   NJW/2002-06-28
;
if n_params() lt 0 then begin
   print,'Syntax: xfit_plot
   return
endif

;   Define the common areas

common instrument, e_min, e_max, matrix, arf
common observation, rate, stat_err, countspec, number
common model, elo, ehi, eline, spectrcode
common results, const, param1, nh, chi2red, sx

!p.title = 'Spectrum #'+strtrim(number,2)+'  Model: '+spectrcode

if keyword_set(pi) then begin

if !d.name ne 'PS' then window,0,title='PI channels'

ymin = min([rate-stat_err,countspec])
ymax = max([rate+stat_err,countspec])
!x.title = 'PI bin number'
!y.title = 'Cts /s /bin'
dataplot, indgen(n_elements(countspec))+30, rate, stat_err, $
       yr=[ymin,ymax], /xbar
oplot,indgen(n_elements(countspec))+30, countspec, ps=10
xyouts,0.7,0.8,string(const,format='("Constant =    ",f10.4)'),/norm,charsize=1.2
xyouts,0.7,0.7,string(param1,format='("Param1   =    ",f10.4)'),/norm,charsize=1.2
xyouts,0.7,0.6,string(nh,format='("Nh/1e22  =    ",f10.4)'),/norm,charsize=1.2
xyouts,0.7,0.5,string(sx,format='("SX  =  ",e11.2," erg/cm2/s")'),/norm,charsize=1.2
xyouts,0.5,0.65,string(chi2red,format='("Chi2red  =  ",f10.4)'),/norm,charsize=1.2
plotsign

endif else begin

if !d.name ne 'PS' then window,1,title='Energy'

ymin = min([(rate-stat_err)/(e_max-e_min),countspec/(e_max-e_min)])
ymax = max([(rate+stat_err)/(e_max-e_min),countspec/(e_max-e_min)])
!x.title = 'Energy [keV]'
!y.title = 'Cts /s /keV'
dataplot, 0.5*(e_min+e_max), rate/(e_max-e_min), stat_err/(e_max-e_min), $
       yr=[ymin,ymax], xr=[1.5,50],  /xbar,it=2
oplot,0.5*(e_min+e_max), countspec/(e_max-e_min), ps=10
xyouts,0.5,0.85,string(const,format='("Constant =    ",f10.4)'),/norm,charsize=1.2
xyouts,0.5,0.8,string(param1,format='("Param1   =    ",f10.4)'),/norm,charsize=1.2
xyouts,0.5,0.75,string(nh,format='("Nh/1e22  =    ",f10.4)'),/norm,charsize=1.2
xyouts,0.5,0.7,string(sx,format='("SX  =  ",e11.2," cgs")'),/norm,charsize=1.2
xyouts,0.5,0.65,string(chi2red,format='("Chi2red  =  ",f10.4)'),/norm,charsize=1.2
plotsign

endelse


end
