close,2
openw,2,'output'
;
; main program for XSPECT sensitivity calculations
print,'Remember to set foil, choice, hpw'
;
;  1) get relevant arrays
;           a) Effective area of XSPECT
if( foil eq 3 ) then begin
   rtable,2,'/a/srg-inf/xspect03_kdj.aeff',eaeff,aeff
   printf,2,'0.3 mm foil telescope'
endif else begin
   rtable,2,'/a/srg-inf/xspect04_kdj.aeff',eaeff,aeff
   printf,2,'0.4 mm foil telescope'
endelse
;           b) Quantum efficiences of detectors
rtable,2,'/a/srg-inf/qeff.hepc',eqhepc,qhepc
rtable,2,'/a/srg-inf/qeff.lepc',eqlepc,qlepc
printf,2,hpw,format='("HPW = ",f3.1," arcmin")'
e1h = 2.
e2h = 6.
e1l = 0.3
e2l = 3.
printf,2,e1h,e2h,format='("HEPC Detection interval ",f4.2," - ",f5.2," keV")'
printf,2,e1l,e2l,format='("LEPC Detection interval ",f4.2," - ",f5.2," keV")'
;           c) Define standard spectrum : PL slope 1.7 NH = 1.e21
e = xloggen(200, 0.2, 20.)
if( choice eq 1 ) then begin
   u = absorp(1.e21,e)
   fx = e^(-1.7) * u
   printf,2,format='("PL ph index = 1.7, NH = 1.e21")'
endif else begin
   u = absorp(1.e20,e)
   fx = (1./e)*exp(-e) * u
   printf,2,format='("TB kT = 1 keV, NH = 1.e20")'
endelse
;               Get de values for integration
nel = n_elements(e)
ee = fltarr(nel+1)
ee(1:nel) = e
ee(0) = 2.*e(0) - e(1)
de = e - ee(0:nel-1)
;           d) Define DXB (extra galactic part)
fdxb = 11.*e^(-1.46) * absorp(5.e20,e)
;           e) Cell area and solid angle
comega = 3.14 * ((hpw/2.) / 3438.)^2
; Unit is steradians
acell  = comega * 800.^2 ; cm2
printf,2,comega,acell,format='("Omega = ",e11.2," sr. Acell = ",e11.2," cm2")'
;
aeff = tabnewx(eaeff,aeff,e)
qhepc = tabnewx(eqhepc,qhepc,e)
qlepc = tabnewx(eqlepc,qlepc,e)
irh = where( (e le e2h) and (e ge e1h) )
irl = where( (e le e2l) and (e ge e1l) )
ff = '(e9.2,f8.2,2f8.2,2e10.2)'
fhead='("   tobs     part.  diffuse    req.   S minimum")'
funit='("                                   0.5-4keV  2-10keV")'
printf,2,'Results for HEPC'
print,'Results for HEPC'
printf,2,format=fhead
print,format=fhead
printf,2,format=funit
print,format=funit
for j = 1, 5  do begin
   tobs = 1000. * 10.^((j-1)/2.)
   nsh = 0.5*tobs*total(fx(irh)*aeff(irh)*qhepc(irh)*de(irh))
   nph = tobs*acell*1.e-3*(e2h - e1h)
   ndh = tobs*comega*total(fdxb(irh)*aeff(irh)*qhepc(irh)*de(irh))
   nsrh = 5.*sqrt(4.+nph+ndh)
   sh = sflux(.5,4.,e,fx)
   shu = sflux(2.,10.,e,fx)
   sminh = sh*nsrh/nsh
   sminhu = shu*nsrh/nsh
   print,tobs,nph,ndh,nsrh,sminh,sminhu
   printf,2,tobs,nph,ndh,nsrh,sminh,sminhu,format=ff
endfor
printf,2,'Results for LEPC'
print,'Results for LEPC'
printf,2,format=fhead
print,format=fhead
printf,2,format=funit
print,format=funit
for j = 1, 5  do begin
   tobs = 1000. * 10.^((j-1)/2.)
   nsl = 0.5*tobs*total(fx(irl)*aeff(irl)*qlepc(irl)*de(irl))
   npl = tobs*acell*1.e-3*(e2l - e1l)
   ndl = tobs*comega*total(fdxb(irl)*aeff(irl)*qlepc(irl)*de(irl))
   nsrl = 5.*sqrt(4.+npl+ndl)
   sh = sflux(.5,4.,e,fx)
   shu = sflux(2.,10.,e,fx)
   sminl = sh*nsrl/nsl
   sminlu = shu*nsrl/nsl
   print,tobs,npl,ndl,nsrl,sminl,sminlu
   printf,2,tobs,npl,ndl,nsrl,sminl,sminlu,format=ff
endfor
close,2
end
